use dadsops
go
drop procedure new_foc
go
create procedure new_foc as
/* newly delivered calibration files */
declare @new_file_name varchar(50)
declare @new_expansion_number int
declare @ref_type varchar(50)
declare @useafter_date datetime
declare @stop_date datetime
/* observation start time */
declare @expstart datetime
/* data set name, to be used for error checking/handling, should extract */
/* datatype from dt_mapping rather than hardcode it here, this will do for now */
declare @data_set_name varchar(39)
/* severity level variables, to be reused for each reference file type */
declare @orig_equiv_sev int
declare @orig_equiv_mod int
declare @equiv_sev int
declare @equiv_mod int
/* used to store @@rowcount global variable */
declare @num_cal_files int
/* observation modes, calibration files used in the pipeline, */
/* best, and best_loc files */
declare @fcr_lineoff float
declare @fcr_sampoff float
declare @fcr_photplam float
declare @fcr_cammode char(7)
declare @fcr_optcrly char(3)
declare @fcr_pxformt char(7)
declare @fcr_smmmode char(7)
declare @fcr_unitab char(18)
declare @fcr_comptab char(18)
declare @fcr_linepfm int
declare @fcr_optelt1 int
declare @fcr_optelt2 int
declare @fcr_samppln int
declare @fcr_bachfile char(18)
declare @fcr_best_bac char(18)
declare @fcr_best_blm char(18)
declare @fcr_best_geo char(18)
declare @fcr_best_itf char(18)
declare @fcr_best_sde char(18)
declare @fcr_best_uni char(18)
declare @fcr_blmhfile char(18)
declare @fcr_geohfile char(18)
declare @fcr_graphtab char(18)
declare @fcr_itfhfile char(18)
declare @fcr_sdehfile char(18)
declare @fcr_unihfile char(18)
declare @fcr_best_unitab char(18)
declare @fcr_best_comptab char(18)
declare @fcr_best_graphtab char(18)
declare @fcr_best_loc_bac varchar(9)
declare @fcr_best_loc_blm varchar(9)
declare @fcr_best_loc_geo varchar(9)
declare @fcr_best_loc_itf varchar(9)
declare @fcr_best_loc_sde varchar(9)
declare @fcr_best_loc_uni varchar(9)
declare @fcr_best_loc_unitab varchar(9)
declare @ratio float		/* mod */
declare @wavelength float	/* mod */
declare @uni_count int		/* mod */
declare @unitab_count int	/* mod */

/**************************************************************************/
/************************ New   foc ***********************/
/**************************************************************************/

declare new_foc_cursor cursor for
        select  file_name, expansion_number
        from    new_cal_files
        where   instrument = 'FOC'
for read only

open new_foc_cursor

fetch new_foc_cursor into @new_file_name, @new_expansion_number

while (@@sqlstatus = 0)/* more newly delivered calibration files*/
begin

select @ref_type = foc_file.reference_file_type,
@useafter_date = foc_file.useafter_date,
@equiv_sev = foc_row.equivalence_class_severe,
@equiv_mod = foc_row.equivalence_class_moderate
,@fcr_cammode=foc_row.cammode
,@fcr_lineoff=foc_row.lineoff
,@fcr_linepfm=foc_row.linepfm
,@fcr_optcrly=foc_row.optcrly
,@fcr_optelt1=foc_row.optelt1
,@fcr_optelt2=foc_row.optelt2
,@fcr_pxformt=foc_row.pxformt
,@fcr_sampoff=foc_row.sampoff
,@fcr_samppln=foc_row.samppln
,@fcr_smmmode=foc_row.smmmode
,@wavelength=foc_row.wavelength		/* mod */
from foc_file foc_file, foc_row foc_row
where foc_file.file_name = @new_file_name 
and foc_row.file_name = @new_file_name
and foc_file.expansion_number = @new_expansion_number
and foc_row.expansion_number = @new_expansion_number


        if (@ref_type = 'BAC')
        begin
                        /* get first non-rejected file that has a */
                        /* useafter_date that is greater than the */
                        /* new files useafter_date - use for stop window */
                declare stop_date_cursor cursor for
                select  foc_file.useafter_date
                from foc_file foc_file, foc_row foc_row
                        where foc_row.file_name = foc_file.file_name
                        and foc_row.expansion_number = foc_file.expansion_number
                        and foc_file.reference_file_type = "BAC"
                        and foc_file.reject_flag = "N"
                        and foc_file.opus_flag = "Y"
                        and foc_file.useafter_date > @useafter_date
                        and foc_file.archive_date is not null
                        /* Print out the modes, if rft = image */
                        and foc_row.optcrly = @fcr_optcrly
                        and foc_row.pxformt = @fcr_pxformt
                order by foc_file.useafter_date
                for read only

                open stop_date_cursor

                fetch stop_date_cursor into @stop_date

                if (@@sqlstatus <> 0)  /* no stop date found-use todays date*/

                        select @stop_date = getdate()

                close stop_date_cursor

                deallocate cursor stop_date_cursor


                declare bac_update_cursor cursor for
                select fcr_bachfile
                  /* Modes aren't added to the select list, if rft = image */
                from foc_ref_data
                where fcr_expstart >= @useafter_date
                and fcr_expstart < @stop_date
                  /* Add modes to the where clause, if rft = image */
                        and fcr_optcrly = @fcr_optcrly
                        and fcr_pxformt = @fcr_pxformt
                for update

                open bac_update_cursor

                fetch bac_update_cursor into @fcr_bachfile
                  /* Don't add modes to the fetch statement, if rft = image */

                while (@@sqlstatus = 0) /* While more bac files */

                begin
/*++++++++++++++++++++++++++++++++++++++++++++++++++++++++++++++++++++++++++++++*/
                  if (@fcr_bachfile = NULL)  /* no file was used in pipeline */
                        select @fcr_best_loc_bac = "N/A"
                  else if (@new_file_name = @fcr_bachfile)  /* recommended = was used, if rft = image or table */
                        select @fcr_best_loc_bac = "NO CHANGE"
                  else
                        if (@equiv_sev = -1)
                        select @fcr_best_loc_bac = 'UNKNOWN'
                  else   /* recommended <> was used - compute level of change */
                    begin
                        select        @orig_equiv_sev = foc_row.equivalence_class_severe,
                                @orig_equiv_mod = foc_row.equivalence_class_moderate
                        from        foc_row foc_row
                        where        foc_row.file_name = @fcr_bachfile
                        and foc_row.optcrly = @fcr_optcrly
                        and foc_row.pxformt = @fcr_pxformt
 

                        if (@orig_equiv_sev = -1)
                        select @fcr_best_loc_bac = 'UNKNOWN'
                        else if ((@equiv_sev - @orig_equiv_sev) <> 0)
                                select @fcr_best_loc_bac = "SEVERE"
                        else if ((@equiv_mod - @orig_equiv_mod) <> 0)
                                select @fcr_best_loc_bac = "MODERATE"
                             else select @fcr_best_loc_bac = "TRIVIAL"
 
                    end      /*else*/
 
                   /* update row */
                   update foc_ref_data
                   set fcr_best_bac= @new_file_name, /* if rft = image or table */
                       fcr_best_loc_bac = @fcr_best_loc_bac
                   where  current of bac_update_cursor
        
                  fetch bac_update_cursor into @fcr_bachfile
                  /* Don't print modes, if rft = image */
 

                end /* while more bac files */

                close bac_update_cursor

                deallocate cursor bac_update_cursor
        end /* if @ref_type = 'BAC') */


        if (@ref_type = 'BLM')
        begin
                        /* get first non-rejected file that has a */
                        /* useafter_date that is greater than the */
                        /* new files useafter_date - use for stop window */
                declare stop_date_cursor cursor for
                select  foc_file.useafter_date
                from foc_file foc_file, foc_row foc_row
                        where foc_row.file_name = foc_file.file_name
                        and foc_row.expansion_number = foc_file.expansion_number
                        and foc_file.reference_file_type = "BLM"
                        and foc_file.reject_flag = "N"
                        and foc_file.opus_flag = "Y"
                        and foc_file.useafter_date > @useafter_date
                        and foc_file.archive_date is not null
                        /* Print out the modes, if rft = image */
                        and foc_row.optcrly = @fcr_optcrly
                        and foc_row.pxformt = @fcr_pxformt
                order by foc_file.useafter_date
                for read only

                open stop_date_cursor

                fetch stop_date_cursor into @stop_date

                if (@@sqlstatus <> 0)  /* no stop date found-use todays date*/

                        select @stop_date = getdate()

                close stop_date_cursor

                deallocate cursor stop_date_cursor


                declare blm_update_cursor cursor for
                select fcr_blmhfile
                  /* Modes aren't added to the select list, if rft = image */
                from foc_ref_data
                where fcr_expstart >= @useafter_date
                and fcr_expstart < @stop_date
                  /* Add modes to the where clause, if rft = image */
                        and fcr_optcrly = @fcr_optcrly
                        and fcr_pxformt = @fcr_pxformt
                for update

                open blm_update_cursor

                fetch blm_update_cursor into @fcr_blmhfile
                  /* Don't add modes to the fetch statement, if rft = image */

                while (@@sqlstatus = 0) /* While more blm files */

                begin
/*++++++++++++++++++++++++++++++++++++++++++++++++++++++++++++++++++++++++++++++*/
                  if (@fcr_blmhfile = NULL)  /* no file was used in pipeline */
                        select @fcr_best_loc_blm = "N/A"
                  else if (@new_file_name = @fcr_blmhfile)  /* recommended = was used, if rft = image or table */
                        select @fcr_best_loc_blm = "NO CHANGE"
                  else
                        if (@equiv_sev = -1)
                        select @fcr_best_loc_blm = 'UNKNOWN'
                  else   /* recommended <> was used - compute level of change */
                    begin
                        select        @orig_equiv_sev = foc_row.equivalence_class_severe,
                                @orig_equiv_mod = foc_row.equivalence_class_moderate
                        from        foc_row foc_row
                        where        foc_row.file_name = @fcr_blmhfile
                        and foc_row.optcrly = @fcr_optcrly
                        and foc_row.pxformt = @fcr_pxformt
 

                        if (@orig_equiv_sev = -1)
                        select @fcr_best_loc_blm = 'UNKNOWN'
                        else if ((@equiv_sev - @orig_equiv_sev) <> 0)
                                select @fcr_best_loc_blm = "SEVERE"
                        else if ((@equiv_mod - @orig_equiv_mod) <> 0)
                                select @fcr_best_loc_blm = "MODERATE"
                             else select @fcr_best_loc_blm = "TRIVIAL"
 
                    end      /*else*/
 
                   /* update row */
                   update foc_ref_data
                   set fcr_best_blm= @new_file_name, /* if rft = image or table */
                       fcr_best_loc_blm = @fcr_best_loc_blm
                   where  current of blm_update_cursor
        
                  fetch blm_update_cursor into @fcr_blmhfile
                  /* Don't print modes, if rft = image */
 

                end /* while more blm files */

                close blm_update_cursor

                deallocate cursor blm_update_cursor
        end /* if @ref_type = 'BLM') */


        if (@ref_type = 'GEO')
        begin
                        /* get first non-rejected file that has a */
                        /* useafter_date that is greater than the */
                        /* new files useafter_date - use for stop window */
                declare stop_date_cursor cursor for
                select  foc_file.useafter_date
                from foc_file foc_file, foc_row foc_row
                        where foc_row.file_name = foc_file.file_name
                        and foc_row.expansion_number = foc_file.expansion_number
                        and foc_file.reference_file_type = "GEO"
                        and foc_file.reject_flag = "N"
                        and foc_file.opus_flag = "Y"
                        and foc_file.useafter_date > @useafter_date
                        and foc_file.archive_date is not null
                        /* Print out the modes, if rft = image */
                        and foc_row.cammode = @fcr_cammode
                        and foc_row.lineoff = @fcr_lineoff
                        and foc_row.linepfm = @fcr_linepfm
                        and foc_row.optcrly = @fcr_optcrly
                        and foc_row.optelt1 = @fcr_optelt1
                        and foc_row.optelt2 = @fcr_optelt2
                        and foc_row.pxformt = @fcr_pxformt
                        and foc_row.sampoff = @fcr_sampoff
                        and foc_row.samppln = @fcr_samppln
                        and foc_row.smmmode = @fcr_smmmode
                order by foc_file.useafter_date
                for read only

                open stop_date_cursor

                fetch stop_date_cursor into @stop_date

                if (@@sqlstatus <> 0)  /* no stop date found-use todays date*/

                        select @stop_date = getdate()

                close stop_date_cursor

                deallocate cursor stop_date_cursor


                declare geo_update_cursor cursor for
                select fcr_geohfile
                  /* Modes aren't added to the select list, if rft = image */
                from foc_ref_data
                where fcr_expstart >= @useafter_date
                and fcr_expstart < @stop_date
                  /* Add modes to the where clause, if rft = image */
                        and fcr_cammode = @fcr_cammode
                        and fcr_lineoff = @fcr_lineoff
                        and fcr_linepfm = @fcr_linepfm
                        and fcr_optcrly = @fcr_optcrly
                        and fcr_optelt1 = @fcr_optelt1
                        and fcr_optelt2 = @fcr_optelt2
                        and fcr_pxformt = @fcr_pxformt
                        and fcr_sampoff = @fcr_sampoff
                        and fcr_samppln = @fcr_samppln
                        and fcr_smmmode = @fcr_smmmode
                for update

                open geo_update_cursor

                fetch geo_update_cursor into @fcr_geohfile
                  /* Don't add modes to the fetch statement, if rft = image */

                while (@@sqlstatus = 0) /* While more geo files */

                begin
/*++++++++++++++++++++++++++++++++++++++++++++++++++++++++++++++++++++++++++++++*/
                  if (@fcr_geohfile = NULL)  /* no file was used in pipeline */
                        select @fcr_best_loc_geo = "N/A"
                  else if (@new_file_name = @fcr_geohfile)  /* recommended = was used, if rft = image or table */
                        select @fcr_best_loc_geo = "NO CHANGE"
                  else
                        if (@equiv_sev = -1)
                        select @fcr_best_loc_geo = 'UNKNOWN'
                  else   /* recommended <> was used - compute level of change */
                    begin
                        select        @orig_equiv_sev = foc_row.equivalence_class_severe,
                                @orig_equiv_mod = foc_row.equivalence_class_moderate
                        from        foc_row foc_row
                        where        foc_row.file_name = @fcr_geohfile
                        and foc_row.cammode = @fcr_cammode
                        and foc_row.lineoff = @fcr_lineoff
                        and foc_row.linepfm = @fcr_linepfm
                        and foc_row.optcrly = @fcr_optcrly
                        and foc_row.optelt1 = @fcr_optelt1
                        and foc_row.optelt2 = @fcr_optelt2
                        and foc_row.pxformt = @fcr_pxformt
                        and foc_row.sampoff = @fcr_sampoff
                        and foc_row.samppln = @fcr_samppln
                        and foc_row.smmmode = @fcr_smmmode
 

                        if (@orig_equiv_sev = -1)
                        select @fcr_best_loc_geo = 'UNKNOWN'
                        else if ((@equiv_sev - @orig_equiv_sev) <> 0)
                                select @fcr_best_loc_geo = "SEVERE"
                        else if ((@equiv_mod - @orig_equiv_mod) <> 0)
                                select @fcr_best_loc_geo = "MODERATE"
                             else select @fcr_best_loc_geo = "TRIVIAL"
 
                    end      /*else*/
 
                   /* update row */
                   update foc_ref_data
                   set fcr_best_geo= @new_file_name, /* if rft = image or table */
                       fcr_best_loc_geo = @fcr_best_loc_geo
                   where  current of geo_update_cursor
        
                  fetch geo_update_cursor into @fcr_geohfile
                  /* Don't print modes, if rft = image */
 

                end /* while more geo files */

                close geo_update_cursor

                deallocate cursor geo_update_cursor
        end /* if @ref_type = 'GEO') */


        if (@ref_type = 'ITF')
        begin
                        /* get first non-rejected file that has a */
                        /* useafter_date that is greater than the */
                        /* new files useafter_date - use for stop window */
                declare stop_date_cursor cursor for
                select  foc_file.useafter_date
                from foc_file foc_file, foc_row foc_row
                        where foc_row.file_name = foc_file.file_name
                        and foc_row.expansion_number = foc_file.expansion_number
                        and foc_file.reference_file_type = "ITF"
                        and foc_file.reject_flag = "N"
                        and foc_file.opus_flag = "Y"
                        and foc_file.useafter_date > @useafter_date
                        and foc_file.archive_date is not null
                        /* Print out the modes, if rft = image */
                        and foc_row.lineoff = @fcr_lineoff
                        and foc_row.linepfm = @fcr_linepfm
                        and foc_row.optcrly = @fcr_optcrly
                        and foc_row.pxformt = @fcr_pxformt
                        and foc_row.sampoff = @fcr_sampoff
                        and foc_row.samppln = @fcr_samppln
                order by foc_file.useafter_date
                for read only

                open stop_date_cursor

                fetch stop_date_cursor into @stop_date

                if (@@sqlstatus <> 0)  /* no stop date found-use todays date*/

                        select @stop_date = getdate()

                close stop_date_cursor

                deallocate cursor stop_date_cursor


                declare itf_update_cursor cursor for
                select fcr_itfhfile
                  /* Modes aren't added to the select list, if rft = image */
                from foc_ref_data
                where fcr_expstart >= @useafter_date
                and fcr_expstart < @stop_date
                  /* Add modes to the where clause, if rft = image */
                        and fcr_lineoff = @fcr_lineoff
                        and fcr_linepfm = @fcr_linepfm
                        and fcr_optcrly = @fcr_optcrly
                        and fcr_pxformt = @fcr_pxformt
                        and fcr_sampoff = @fcr_sampoff
                        and fcr_samppln = @fcr_samppln
                for update

                open itf_update_cursor

                fetch itf_update_cursor into @fcr_itfhfile
                  /* Don't add modes to the fetch statement, if rft = image */

                while (@@sqlstatus = 0) /* While more itf files */

                begin
/*++++++++++++++++++++++++++++++++++++++++++++++++++++++++++++++++++++++++++++++*/
                  if (@fcr_itfhfile = NULL)  /* no file was used in pipeline */
                        select @fcr_best_loc_itf = "N/A"
                  else if (@new_file_name = @fcr_itfhfile)  /* recommended = was used, if rft = image or table */
                        select @fcr_best_loc_itf = "NO CHANGE"
                  else
                        if (@equiv_sev = -1)
                        select @fcr_best_loc_itf = 'UNKNOWN'
                  else   /* recommended <> was used - compute level of change */
                    begin
                        select        @orig_equiv_sev = foc_row.equivalence_class_severe,
                                @orig_equiv_mod = foc_row.equivalence_class_moderate
                        from        foc_row foc_row
                        where        foc_row.file_name = @fcr_itfhfile
                        and foc_row.lineoff = @fcr_lineoff
                        and foc_row.linepfm = @fcr_linepfm
                        and foc_row.optcrly = @fcr_optcrly
                        and foc_row.pxformt = @fcr_pxformt
                        and foc_row.sampoff = @fcr_sampoff
                        and foc_row.samppln = @fcr_samppln
 

                        if (@orig_equiv_sev = -1)
                        select @fcr_best_loc_itf = 'UNKNOWN'
                        else if ((@equiv_sev - @orig_equiv_sev) <> 0)
                                select @fcr_best_loc_itf = "SEVERE"
                        else if ((@equiv_mod - @orig_equiv_mod) <> 0)
                                select @fcr_best_loc_itf = "MODERATE"
                             else select @fcr_best_loc_itf = "TRIVIAL"
 
                    end      /*else*/
 
                   /* update row */
                   update foc_ref_data
                   set fcr_best_itf= @new_file_name, /* if rft = image or table */
                       fcr_best_loc_itf = @fcr_best_loc_itf
                   where  current of itf_update_cursor
        
                  fetch itf_update_cursor into @fcr_itfhfile
                  /* Don't print modes, if rft = image */
 

                end /* while more itf files */

                close itf_update_cursor

                deallocate cursor itf_update_cursor
        end /* if @ref_type = 'ITF') */


        if (@ref_type = 'SDE')
        begin
                        /* get first non-rejected file that has a */
                        /* useafter_date that is greater than the */
                        /* new files useafter_date - use for stop window */
                declare stop_date_cursor cursor for
                select  foc_file.useafter_date
                from foc_file foc_file, foc_row foc_row
                        where foc_row.file_name = foc_file.file_name
                        and foc_row.expansion_number = foc_file.expansion_number
                        and foc_file.reference_file_type = "SDE"
                        and foc_file.reject_flag = "N"
                        and foc_file.opus_flag = "Y"
                        and foc_file.useafter_date > @useafter_date
                        and foc_file.archive_date is not null
                        /* Print out the modes, if rft = image */
                        and foc_row.optelt1 = @fcr_optelt1
                        and foc_row.optelt2 = @fcr_optelt2
                        and foc_row.pxformt = @fcr_pxformt
                order by foc_file.useafter_date
                for read only

                open stop_date_cursor

                fetch stop_date_cursor into @stop_date

                if (@@sqlstatus <> 0)  /* no stop date found-use todays date*/

                        select @stop_date = getdate()

                close stop_date_cursor

                deallocate cursor stop_date_cursor


                declare sde_update_cursor cursor for
                select fcr_sdehfile
                  /* Modes aren't added to the select list, if rft = image */
                from foc_ref_data
                where fcr_expstart >= @useafter_date
                and fcr_expstart < @stop_date
                  /* Add modes to the where clause, if rft = image */
                        and fcr_optelt1 = @fcr_optelt1
                        and fcr_optelt2 = @fcr_optelt2
                        and fcr_pxformt = @fcr_pxformt
                for update

                open sde_update_cursor

                fetch sde_update_cursor into @fcr_sdehfile
                  /* Don't add modes to the fetch statement, if rft = image */

                while (@@sqlstatus = 0) /* While more sde files */

                begin
/*++++++++++++++++++++++++++++++++++++++++++++++++++++++++++++++++++++++++++++++*/
                  if (@fcr_sdehfile = NULL)  /* no file was used in pipeline */
                        select @fcr_best_loc_sde = "N/A"
                  else if (@new_file_name = @fcr_sdehfile)  /* recommended = was used, if rft = image or table */
                        select @fcr_best_loc_sde = "NO CHANGE"
                  else
                        if (@equiv_sev = -1)
                        select @fcr_best_loc_sde = 'UNKNOWN'
                  else   /* recommended <> was used - compute level of change */
                    begin
                        select        @orig_equiv_sev = foc_row.equivalence_class_severe,
                                @orig_equiv_mod = foc_row.equivalence_class_moderate
                        from        foc_row foc_row
                        where        foc_row.file_name = @fcr_sdehfile
                        and foc_row.optelt1 = @fcr_optelt1
                        and foc_row.optelt2 = @fcr_optelt2
                        and foc_row.pxformt = @fcr_pxformt
 

                        if (@orig_equiv_sev = -1)
                        select @fcr_best_loc_sde = 'UNKNOWN'
                        else if ((@equiv_sev - @orig_equiv_sev) <> 0)
                                select @fcr_best_loc_sde = "SEVERE"
                        else if ((@equiv_mod - @orig_equiv_mod) <> 0)
                                select @fcr_best_loc_sde = "MODERATE"
                             else select @fcr_best_loc_sde = "TRIVIAL"
 
                    end      /*else*/
 
                   /* update row */
                   update foc_ref_data
                   set fcr_best_sde= @new_file_name, /* if rft = image or table */
                       fcr_best_loc_sde = @fcr_best_loc_sde
                   where  current of sde_update_cursor
        
                  fetch sde_update_cursor into @fcr_sdehfile
                  /* Don't print modes, if rft = image */
 

                end /* while more sde files */

                close sde_update_cursor

                deallocate cursor sde_update_cursor
        end /* if @ref_type = 'SDE') */


        if (@ref_type = 'UNITAB')  /* process UNITAB and UNI together */
        begin
/* mod - entire section */

	/* first check to make sure that all associated UNI files have */
	/* been archived, if not, go to next new reference file */

	/* if all UNI files have been archive then update both UNI and */
	/* UNITAB entries in the affected datasets		       */

	/* check how many rows in the UNITAB file */
	select @unitab_count = count(*) from foc_file f, foc_row r
	where f.file_name= @new_file_name and
	      f.expansion_number = @new_expansion_number and
	      r.file_name = @new_file_name and
	      r.expansion_number = @new_expansion_number

	/* check how many UNI files (in the UNITAB file) have been archived*/
	select @uni_count = count(*) from foc_file f1
	where f1.file_name in (
	select r.uni_file_name from foc_file f, foc_row r
	where f.archive_date is not null and
	f.reject_flag = 'N' and
	f.opus_flag = 'Y' and
	f.file_name = @new_file_name and
	f.expansion_number = @new_expansion_number and
	r.file_name = @new_file_name and
	r.expansion_number =  @new_expansion_number) and
	f1.reject_flag = 'N' and
	f1.opus_flag = 'Y' and
	f1.archive_date is not null

  if (@unitab_count = @uni_count) /* all UNI files have been archived */
  begin


                        /* get first non-rejected file that has a */
                        /* useafter_date that is greater than the */
                        /* new files useafter_date - use for stop window */
                declare stop_date_cursor cursor for
                select  foc_file.useafter_date
                from foc_file foc_file, foc_row foc_row
                        where foc_row.file_name = foc_file.file_name
                        and foc_row.expansion_number = foc_file.expansion_number
                        and foc_file.reference_file_type = "UNITAB"
                        and foc_file.reject_flag = "N"
                        and foc_file.opus_flag = "Y"
                        and foc_file.useafter_date > @useafter_date
                        and foc_file.archive_date is not null
                order by foc_file.useafter_date
                for read only

                open stop_date_cursor

                fetch stop_date_cursor into @stop_date

                if (@@sqlstatus <> 0)  /* no stop date found-use todays date*/

                        select @stop_date = getdate()

                close stop_date_cursor

                deallocate cursor stop_date_cursor


declare update_foc_cursor  cursor for
select fcr_expstart,fcr_data_set_name
,fcr_cammode
,fcr_optcrly
,fcr_photplam
,fcr_unihfile
,fcr_unitab
from foc_ref_data
where
fcr_expstart >= @useafter_date and
fcr_expstart < @stop_date
for update

open update_foc_cursor 
fetch update_foc_cursor into @expstart,@data_set_name
,@fcr_cammode
,@fcr_optcrly
,@fcr_photplam
,@fcr_unihfile
,@fcr_unitab

while (@@sqlstatus = 0)
begin

if ((@fcr_photplam = NULL) OR (@fcr_photplam <= 0))
select @fcr_best_uni = 'N/A', @fcr_best_loc_uni = 'N/A',
	@fcr_best_unitab = 'N/A', @fcr_best_loc_unitab = 'N/A'
else
begin

select foc_row_1.wavelength, foc_file_1.file_name,
foc_row_1.uni_file_name,
foc_file_1.expansion_number, foc_row_1.equivalence_class_severe,
foc_row_1.equivalence_class_moderate, ratio=0.0000000
into #temp_foc 
from foc_file foc_file_1, foc_row foc_row_1
where foc_file_1.file_name = @new_file_name
and foc_row_1.file_name = @new_file_name
and foc_row_1.optcrly = @fcr_optcrly
and foc_row_1.cammode = @fcr_cammode

create unique clustered index tempind on #temp_foc (uni_file_name,wavelength)


declare  ratio_cursor cursor for
	select wavelength from #temp_foc
for update of ratio

open ratio_cursor

fetch ratio_cursor into @wavelength

while (@@sqlstatus = 0) begin
	if (@wavelength > @fcr_photplam)
	  select @ratio = @fcr_photplam/@wavelength
	else
	  select @ratio = @wavelength/@fcr_photplam
	update #temp_foc set ratio = @ratio
	 where current of ratio_cursor
	fetch ratio_cursor into @wavelength
end /*while*/

close ratio_cursor
deallocate cursor ratio_cursor

select @fcr_best_uni = o.uni_file_name, @wavelength = o.wavelength,
 @fcr_best_unitab = o.file_name,
 @equiv_sev = o.equivalence_class_severe,
 @equiv_mod = o.equivalence_class_moderate from #temp_foc o
 where o.ratio = (select max(i.ratio) from #temp_foc i)

/* compute severity level */
select @num_cal_files = @@rowcount
if (@num_cal_files = 0)    /* no recommended file found */
select @fcr_best_uni = 'N/A', @fcr_best_loc_uni = 'N/A',
       @fcr_best_unitab = 'N/A', @fcr_best_loc_unitab = 'N/A'
else
 begin /* process UNITAB first */
  if (@fcr_best_unitab = @fcr_unitab) /* recommended = was used */
   select @fcr_best_loc_unitab = 'NO CHANGE'
  else
   if (@fcr_unitab = NULL) /* no file was used in the pipeline */
    select @fcr_best_loc_unitab = 'N/A'
   else
    if (@equiv_sev = -1)
     select @fcr_best_loc_unitab = 'UNKNOWN'
   else
    begin
     select @orig_equiv_sev = foc_row_1.equivalence_class_severe,
     @orig_equiv_mod =  foc_row_1.equivalence_class_moderate
     from foc_row foc_row_1
     where foc_row_1.file_name = @fcr_unitab
     and foc_row_1.cammode = @fcr_cammode
     and foc_row_1.optcrly = @fcr_optcrly
     and foc_row_1.wavelength = @wavelength

     if (@orig_equiv_sev = -1)
	select @fcr_best_loc_unitab = 'UNKNOWN'
     else if ((@equiv_sev - @orig_equiv_sev) <> 0)
	select @fcr_best_loc_unitab = 'SEVERE'
     else if ((@equiv_mod - @orig_equiv_mod) <> 0)
		select @fcr_best_loc_unitab = 'MODERATE'
     else select @fcr_best_loc_unitab = 'TRIVIAL'
   end
           /* now process UNI next */
  if (@fcr_best_uni = @fcr_unihfile) /* recommended = was used */
   select @fcr_best_loc_uni = 'NO CHANGE'
  else
   if (@fcr_unihfile = NULL) /* no file was used in the pipeline */
    select @fcr_best_loc_uni = 'N/A'
   else
    if (@equiv_sev = -1)
     select @fcr_best_loc_uni = 'UNKNOWN'
   else
    begin
     select @orig_equiv_sev = foc_row_1.equivalence_class_severe,
     @orig_equiv_mod =  foc_row_1.equivalence_class_moderate
     from foc_row foc_row_1
     where foc_row_1.file_name = @fcr_unihfile
     and foc_row_1.cammode = @fcr_cammode
     and foc_row_1.optcrly = @fcr_optcrly
     and foc_row_1.wavelength = @wavelength

     if (@orig_equiv_sev = -1)
	select @fcr_best_loc_uni = 'UNKNOWN'
     else if ((@equiv_sev - @orig_equiv_sev) <> 0)
	select @fcr_best_loc_uni = 'SEVERE'
     else if ((@equiv_mod - @orig_equiv_mod) <> 0)
		select @fcr_best_loc_uni = 'MODERATE'
     else select @fcr_best_loc_uni = 'TRIVIAL'
   end
end /* computing severity level */


drop table #temp_foc

end  /* if photplam > 0 and not null */

update foc_ref_data
set
fcr_best_uni = @fcr_best_uni
,fcr_best_loc_uni = @fcr_best_loc_uni
,fcr_best_unitab = @fcr_best_unitab
,fcr_best_loc_unitab = @fcr_best_loc_unitab
where current of update_foc_cursor

fetch update_foc_cursor into @expstart,@data_set_name
,@fcr_cammode
,@fcr_optcrly
,@fcr_photplam
,@fcr_unihfile
,@fcr_unitab

end /* while more foc_ref_data updates */

end  /* if @unitab_count = @uni_count */
else /* not ready to process unitab yet - reset timestamp to keep it */
     /* in the new_cal_files table for tomorrow                      */
update new_cal_files set timestmp=null where instrument='FOC' and
       file_name= @new_file_name and expansion_number = @new_expansion_number

end /* if @ref_type = 'UNITAB') */


fetch new_foc_cursor into @new_file_name, @new_expansion_number

end /* while more newly delivered calibration files */

close new_foc_cursor

deallocate cursor new_foc_cursor


/**************************************************************************/
/************************ New foc : synphot *******************/
/**************************************************************************/
/* begin mod - OPR 35935 - 1/5/98 - Remove level of change computation */

declare new_synphot_cursor cursor for
        select  file_name, expansion_number
        from    new_cal_files
        where   instrument = 'SYNPHOT'
for read only

open new_synphot_cursor

fetch new_synphot_cursor into @new_file_name, @new_expansion_number

while (@@sqlstatus = 0)/* more newly delivered calibration files*/
begin

select @ref_type = synphot_file.reference_file_type,
@useafter_date = synphot_file.useafter_date
from synphot_file synphot_file
where synphot_file.file_name = @new_file_name 
and synphot_file.expansion_number = @new_expansion_number

        if (@ref_type = 'COMPTAB')
        begin
                        /* get first non-rejected file that has a */
                        /* useafter_date that is greater than the */
                        /* new files useafter_date - use for stop window */
                declare stop_date_cursor cursor for
                select synphot_file.useafter_date
                from synphot_file synphot_file, synphot_row synphot_row
                        where synphot_row.file_name = synphot_file.file_name
                        and synphot_row.expansion_number = synphot_file.expansion_number
                        and synphot_file.reference_file_type = "COMPTAB"
                        and synphot_file.reject_flag = "N"
                        and synphot_file.opus_flag = "Y"
                        and synphot_file.useafter_date > @useafter_date
                        and synphot_file.archive_date is not null
                order by synphot_file.useafter_date
                for read only

                open stop_date_cursor

                fetch stop_date_cursor into @stop_date

                if (@@sqlstatus <> 0)  /* no stop date found-use todays date*/

                        select @stop_date = getdate()

                close stop_date_cursor

                deallocate cursor stop_date_cursor


                declare comptab_update_cursor cursor for
                select fcr_comptab
                from foc_ref_data
                where fcr_expstart >= @useafter_date
                and fcr_expstart < @stop_date
                for update

                open comptab_update_cursor

                fetch comptab_update_cursor into @fcr_comptab

                while (@@sqlstatus = 0) /* While more comptab files */
		begin
                   /* update row */
                   update foc_ref_data
                   set fcr_best_comptab= @new_file_name
                   where  current of comptab_update_cursor
        
                  fetch comptab_update_cursor into @fcr_comptab

                end /* while more comptab files */

                close comptab_update_cursor

                deallocate cursor comptab_update_cursor
        end /* if @ref_type = 'COMPTAB') */


        if (@ref_type = 'GRAPHTAB')
        begin
                        /* get first non-rejected file that has a */
                        /* useafter_date that is greater than the */
                        /* new files useafter_date - use for stop window */
                declare stop_date_cursor cursor for
                select synphot_file.useafter_date
                from synphot_file synphot_file, synphot_row synphot_row
                        where synphot_row.file_name = synphot_file.file_name
                        and synphot_row.expansion_number = synphot_file.expansion_number
                        and synphot_file.reference_file_type = "GRAPHTAB"
                        and synphot_file.reject_flag = "N"
                        and synphot_file.opus_flag = "Y"
                        and synphot_file.useafter_date > @useafter_date
                        and synphot_file.archive_date is not null
                order by synphot_file.useafter_date
                for read only

                open stop_date_cursor

                fetch stop_date_cursor into @stop_date

                if (@@sqlstatus <> 0)  /* no stop date found-use todays date*/

                        select @stop_date = getdate()

                close stop_date_cursor

                deallocate cursor stop_date_cursor


                declare graphtab_update_cursor cursor for
                select fcr_graphtab
                from foc_ref_data
                where fcr_expstart >= @useafter_date
                and fcr_expstart < @stop_date
                for update

                open graphtab_update_cursor

                fetch graphtab_update_cursor into @fcr_graphtab

                while (@@sqlstatus = 0) /* While more graphtab files */
		begin 
                   /* update row */
                   update foc_ref_data
                   set fcr_best_graphtab= @new_file_name
                   where  current of graphtab_update_cursor
        
                  fetch graphtab_update_cursor into @fcr_graphtab

                end /* while more graphtab files */

                close graphtab_update_cursor

                deallocate cursor graphtab_update_cursor
        end /* if @ref_type = 'GRAPHTAB') */

fetch new_synphot_cursor into @new_file_name, @new_expansion_number

end /* while more newly delivered calibration files */

close new_synphot_cursor

deallocate cursor new_synphot_cursor
/* end mod */

return
go
