use dadsops
go
drop procedure new_hrs
go
create procedure new_hrs as
/* newly delivered calibration files */
declare @new_file_name varchar(50)
declare @new_expansion_number int
declare @ref_type varchar(50)
declare @useafter_date datetime
declare @stop_date datetime
/* observation start time */
declare @expstart datetime
/* data set name, to be used for error checking/handling, should extract */
/* datatype from dt_mapping rather than hardcode it here, this will do for now */
declare @data_set_name varchar(39)
/* severity level variables, to be reused for each reference file type */
declare @orig_equiv_sev int
declare @orig_equiv_mod int
declare @equiv_sev int
declare @equiv_mod int
/* used to store @@rowcount global variable */
declare @num_cal_files int
/* observation modes, calibration files used in the pipeline, */
/* best, and best_loc files */
declare @hsr_ccg2 char(18)
declare @hsr_ccr1 char(18)
declare @hsr_ccr2 char(18)
declare @hsr_ccr3 char(18)
declare @hsr_ccr4 char(18)
declare @hsr_ccr5 char(18)
declare @hsr_ccr6 char(18)
declare @hsr_ccr7 char(18)
declare @hsr_ccr8 char(18)
declare @hsr_ccr9 char(18)
declare @hsr_ccra char(18)
declare @hsr_ccrb char(18)
declare @hsr_ccrc char(18)
declare @hsr_ccrd char(18)
declare @hsr_ccre char(18)
declare @hsr_grating char(9)
declare @hsr_aperture char(8)
declare @hsr_sporder int
declare @hsr_abshfile char(18)
declare @hsr_best_abs char(18)
declare @hsr_best_dio char(18)
declare @hsr_best_net char(18)
declare @hsr_best_phc char(18)
declare @hsr_best_qin char(18)
declare @hsr_best_saa char(18)
declare @hsr_best_vig char(18)
declare @hsr_detector int
declare @hsr_diohfile char(18)
declare @hsr_dqihfile char(18)
declare @hsr_nethfile char(18)
declare @hsr_phchfile char(18)
declare @hsr_saahfile char(18)
declare @hsr_vighfile char(18)
declare @hsr_best_ccg2 char(18)
declare @hsr_best_ccr1 char(18)
declare @hsr_best_ccr2 char(18)
declare @hsr_best_ccr3 char(18)
declare @hsr_best_ccr4 char(18)
declare @hsr_best_ccr5 char(18)
declare @hsr_best_ccr6 char(18)
declare @hsr_best_ccr7 char(18)
declare @hsr_best_ccr8 char(18)
declare @hsr_best_ccr9 char(18)
declare @hsr_best_ccra char(18)
declare @hsr_best_ccrb char(18)
declare @hsr_best_ccrc char(18)
declare @hsr_best_ccrd char(18)
declare @hsr_best_ccre char(18)
declare @hsr_best_loc_abs varchar(9)
declare @hsr_best_loc_dio varchar(9)
declare @hsr_best_loc_net varchar(9)
declare @hsr_best_loc_phc varchar(9)
declare @hsr_best_loc_qin varchar(9)
declare @hsr_best_loc_saa varchar(9)
declare @hsr_best_loc_vig varchar(9)
declare @hsr_best_loc_ccg2 varchar(9)
declare @hsr_best_loc_ccr1 varchar(9)
declare @hsr_best_loc_ccr2 varchar(9)
declare @hsr_best_loc_ccr3 varchar(9)
declare @hsr_best_loc_ccr4 varchar(9)
declare @hsr_best_loc_ccr5 varchar(9)
declare @hsr_best_loc_ccr6 varchar(9)
declare @hsr_best_loc_ccr7 varchar(9)
declare @hsr_best_loc_ccr8 varchar(9)
declare @hsr_best_loc_ccr9 varchar(9)
declare @hsr_best_loc_ccra varchar(9)
declare @hsr_best_loc_ccrb varchar(9)
declare @hsr_best_loc_ccrc varchar(9)
declare @hsr_best_loc_ccrd varchar(9)
declare @hsr_best_loc_ccre varchar(9)

/**************************************************************************/
/************************ New   hrs ***********************/
/**************************************************************************/

declare new_hrs_cursor cursor for
        select  file_name, expansion_number
        from    new_cal_files
        where   instrument = 'HRS'
for read only

open new_hrs_cursor

fetch new_hrs_cursor into @new_file_name, @new_expansion_number

while (@@sqlstatus = 0)/* more newly delivered calibration files*/
begin

select @ref_type = hrs_file.reference_file_type,
@useafter_date = hrs_file.useafter_date,
@equiv_sev = hrs_row.equivalence_class_severe,
@equiv_mod = hrs_row.equivalence_class_moderate
,@hsr_sporder=hrs_row.sporder
,@hsr_aperture=hrs_row.aperture
,@hsr_grating=hrs_row.grating
,@hsr_detector=hrs_row.detector
from hrs_file hrs_file, hrs_row hrs_row
where hrs_file.file_name = @new_file_name 
and hrs_row.file_name = @new_file_name
and hrs_file.expansion_number = @new_expansion_number
and hrs_row.expansion_number = @new_expansion_number


        if (@ref_type = 'CCG2')
        begin
                        /* get first non-rejected file that has a */
                        /* useafter_date that is greater than the */
                        /* new files useafter_date - use for stop window */
                declare stop_date_cursor cursor for
                select  hrs_file.useafter_date
                from hrs_file hrs_file, hrs_row hrs_row
                        where hrs_row.file_name = hrs_file.file_name
                        and hrs_row.expansion_number = hrs_file.expansion_number
                        and hrs_file.reference_file_type = "CCG2"
                        and hrs_file.reject_flag = "N"
                        and hrs_file.opus_flag = "Y"
                        and hrs_file.useafter_date > @useafter_date
                        and hrs_file.archive_date is not null
/* The reference file type is table, don't print out the modes */
                order by hrs_file.useafter_date
                for read only

                open stop_date_cursor

                fetch stop_date_cursor into @stop_date

                if (@@sqlstatus <> 0)  /* no stop date found-use todays date*/

                        select @stop_date = getdate()

                close stop_date_cursor

                deallocate cursor stop_date_cursor


                declare ccg2_update_cursor cursor for
                select hsr_ccg2
                  /* Add modes to the select list, if rft = table */
                ,hsr_detector
                from hrs_ref_data
                where hsr_expstart >= @useafter_date
                and hsr_expstart < @stop_date
                  /* Modes aren't added to the where clause, if rft = table */
                for update

                open ccg2_update_cursor

                fetch ccg2_update_cursor into @hsr_ccg2
                  /* Add modes to the fetch statement, if rft = table */
                ,@hsr_detector

                while (@@sqlstatus = 0) /* While more ccg2 files */

                begin
/* The following section, surrounded by ++++'s, if rft = table */
/*++++++++++++++++++++++++++++++++++++++++++++++++++++++++++++++++++++++++++++++*/
                        select @equiv_sev = hrs_row.equivalence_class_severe,
                                @equiv_mod = hrs_row.equivalence_class_moderate
                        from hrs_row hrs_row
                        where hrs_row.file_name = @new_file_name
                        and hrs_row.expansion_number = @new_expansion_number
                        and hrs_row.detector = @hsr_detector

                select @num_cal_files = @@rowcount
                if (@num_cal_files <> 0)	/* recommended file found */
                begin
/*++++++++++++++++++++++++++++++++++++++++++++++++++++++++++++++++++++++++++++++*/
                  if (@hsr_ccg2 = NULL)  /* no file was used in pipeline */
                        select @hsr_best_loc_ccg2 = "N/A"
                  else if (@new_file_name = @hsr_ccg2)  /* recommended = was used, if rft = image or table */
                        select @hsr_best_loc_ccg2 = "NO CHANGE"
                  else
                        if (@equiv_sev = -1)
                        select @hsr_best_loc_ccg2 = 'UNKNOWN'
                  else   /* recommended <> was used - compute level of change */
                    begin
                        select        @orig_equiv_sev = hrs_row.equivalence_class_severe,
                                @orig_equiv_mod = hrs_row.equivalence_class_moderate
                        from        hrs_row hrs_row
                        where        hrs_row.file_name = @hsr_ccg2
                        and hrs_row.detector = @hsr_detector
 

                        if (@orig_equiv_sev = -1)
                        select @hsr_best_loc_ccg2 = 'UNKNOWN'
                        else if ((@equiv_sev - @orig_equiv_sev) <> 0)
                                select @hsr_best_loc_ccg2 = "SEVERE"
                        else if ((@equiv_mod - @orig_equiv_mod) <> 0)
                                select @hsr_best_loc_ccg2 = "MODERATE"
                             else select @hsr_best_loc_ccg2 = "TRIVIAL"
 
                    end      /*else*/
 
                   /* update row */
                   update hrs_ref_data
                   set hsr_best_ccg2= @new_file_name, /* if rft = image or table */
                       hsr_best_loc_ccg2 = @hsr_best_loc_ccg2
                   where  current of ccg2_update_cursor
        
                 end /* if recommended file found, if rft = table */
                  fetch ccg2_update_cursor into @hsr_ccg2
                  /* Print modes, if rft = table */
                ,@hsr_detector
 

                end /* while more ccg2 files */

                close ccg2_update_cursor

                deallocate cursor ccg2_update_cursor
        end /* if @ref_type = 'CCG2') */


        if (@ref_type = 'CCR1')
        begin
                        /* get first non-rejected file that has a */
                        /* useafter_date that is greater than the */
                        /* new files useafter_date - use for stop window */
                declare stop_date_cursor cursor for
                select  hrs_file.useafter_date
                from hrs_file hrs_file, hrs_row hrs_row
                        where hrs_row.file_name = hrs_file.file_name
                        and hrs_row.expansion_number = hrs_file.expansion_number
                        and hrs_file.reference_file_type = "CCR1"
                        and hrs_file.reject_flag = "N"
                        and hrs_file.opus_flag = "Y"
                        and hrs_file.useafter_date > @useafter_date
                        and hrs_file.archive_date is not null
/* The reference file type is table, don't print out the modes */
                order by hrs_file.useafter_date
                for read only

                open stop_date_cursor

                fetch stop_date_cursor into @stop_date

                if (@@sqlstatus <> 0)  /* no stop date found-use todays date*/

                        select @stop_date = getdate()

                close stop_date_cursor

                deallocate cursor stop_date_cursor


                declare ccr1_update_cursor cursor for
                select hsr_ccr1
                  /* Add modes to the select list, if rft = table */
                ,hsr_detector
                from hrs_ref_data
                where hsr_expstart >= @useafter_date
                and hsr_expstart < @stop_date
                  /* Modes aren't added to the where clause, if rft = table */
                for update

                open ccr1_update_cursor

                fetch ccr1_update_cursor into @hsr_ccr1
                  /* Add modes to the fetch statement, if rft = table */
                ,@hsr_detector

                while (@@sqlstatus = 0) /* While more ccr1 files */

                begin
/* The following section, surrounded by ++++'s, if rft = table */
/*++++++++++++++++++++++++++++++++++++++++++++++++++++++++++++++++++++++++++++++*/
                        select @equiv_sev = hrs_row.equivalence_class_severe,
                                @equiv_mod = hrs_row.equivalence_class_moderate
                        from hrs_row hrs_row
                        where hrs_row.file_name = @new_file_name
                        and hrs_row.expansion_number = @new_expansion_number
                        and hrs_row.detector = @hsr_detector

                select @num_cal_files = @@rowcount
                if (@num_cal_files <> 0)	/* recommended file found */
                begin
/*++++++++++++++++++++++++++++++++++++++++++++++++++++++++++++++++++++++++++++++*/
                  if (@hsr_ccr1 = NULL)  /* no file was used in pipeline */
                        select @hsr_best_loc_ccr1 = "N/A"
                  else if (@new_file_name = @hsr_ccr1)  /* recommended = was used, if rft = image or table */
                        select @hsr_best_loc_ccr1 = "NO CHANGE"
                  else
                        if (@equiv_sev = -1)
                        select @hsr_best_loc_ccr1 = 'UNKNOWN'
                  else   /* recommended <> was used - compute level of change */
                    begin
                        select        @orig_equiv_sev = hrs_row.equivalence_class_severe,
                                @orig_equiv_mod = hrs_row.equivalence_class_moderate
                        from        hrs_row hrs_row
                        where        hrs_row.file_name = @hsr_ccr1
                        and hrs_row.detector = @hsr_detector
 

                        if (@orig_equiv_sev = -1)
                        select @hsr_best_loc_ccr1 = 'UNKNOWN'
                        else if ((@equiv_sev - @orig_equiv_sev) <> 0)
                                select @hsr_best_loc_ccr1 = "SEVERE"
                        else if ((@equiv_mod - @orig_equiv_mod) <> 0)
                                select @hsr_best_loc_ccr1 = "MODERATE"
                             else select @hsr_best_loc_ccr1 = "TRIVIAL"
 
                    end      /*else*/
 
                   /* update row */
                   update hrs_ref_data
                   set hsr_best_ccr1= @new_file_name, /* if rft = image or table */
                       hsr_best_loc_ccr1 = @hsr_best_loc_ccr1
                   where  current of ccr1_update_cursor
        
                 end /* if recommended file found, if rft = table */
                  fetch ccr1_update_cursor into @hsr_ccr1
                  /* Print modes, if rft = table */
                ,@hsr_detector
 

                end /* while more ccr1 files */

                close ccr1_update_cursor

                deallocate cursor ccr1_update_cursor
        end /* if @ref_type = 'CCR1') */


        if (@ref_type = 'CCR2')
        begin
                        /* get first non-rejected file that has a */
                        /* useafter_date that is greater than the */
                        /* new files useafter_date - use for stop window */
                declare stop_date_cursor cursor for
                select  hrs_file.useafter_date
                from hrs_file hrs_file, hrs_row hrs_row
                        where hrs_row.file_name = hrs_file.file_name
                        and hrs_row.expansion_number = hrs_file.expansion_number
                        and hrs_file.reference_file_type = "CCR2"
                        and hrs_file.reject_flag = "N"
                        and hrs_file.opus_flag = "Y"
                        and hrs_file.useafter_date > @useafter_date
                        and hrs_file.archive_date is not null
/* The reference file type is table, don't print out the modes */
                order by hrs_file.useafter_date
                for read only

                open stop_date_cursor

                fetch stop_date_cursor into @stop_date

                if (@@sqlstatus <> 0)  /* no stop date found-use todays date*/

                        select @stop_date = getdate()

                close stop_date_cursor

                deallocate cursor stop_date_cursor


                declare ccr2_update_cursor cursor for
                select hsr_ccr2
                  /* Add modes to the select list, if rft = table */
                ,hsr_detector
                from hrs_ref_data
                where hsr_expstart >= @useafter_date
                and hsr_expstart < @stop_date
                  /* Modes aren't added to the where clause, if rft = table */
                for update

                open ccr2_update_cursor

                fetch ccr2_update_cursor into @hsr_ccr2
                  /* Add modes to the fetch statement, if rft = table */
                ,@hsr_detector

                while (@@sqlstatus = 0) /* While more ccr2 files */

                begin
/* The following section, surrounded by ++++'s, if rft = table */
/*++++++++++++++++++++++++++++++++++++++++++++++++++++++++++++++++++++++++++++++*/
                        select @equiv_sev = hrs_row.equivalence_class_severe,
                                @equiv_mod = hrs_row.equivalence_class_moderate
                        from hrs_row hrs_row
                        where hrs_row.file_name = @new_file_name
                        and hrs_row.expansion_number = @new_expansion_number
                        and hrs_row.detector = @hsr_detector

                select @num_cal_files = @@rowcount
                if (@num_cal_files <> 0)	/* recommended file found */
                begin
/*++++++++++++++++++++++++++++++++++++++++++++++++++++++++++++++++++++++++++++++*/
                  if (@hsr_ccr2 = NULL)  /* no file was used in pipeline */
                        select @hsr_best_loc_ccr2 = "N/A"
                  else if (@new_file_name = @hsr_ccr2)  /* recommended = was used, if rft = image or table */
                        select @hsr_best_loc_ccr2 = "NO CHANGE"
                  else
                        if (@equiv_sev = -1)
                        select @hsr_best_loc_ccr2 = 'UNKNOWN'
                  else   /* recommended <> was used - compute level of change */
                    begin
                        select        @orig_equiv_sev = hrs_row.equivalence_class_severe,
                                @orig_equiv_mod = hrs_row.equivalence_class_moderate
                        from        hrs_row hrs_row
                        where        hrs_row.file_name = @hsr_ccr2
                        and hrs_row.detector = @hsr_detector
 

                        if (@orig_equiv_sev = -1)
                        select @hsr_best_loc_ccr2 = 'UNKNOWN'
                        else if ((@equiv_sev - @orig_equiv_sev) <> 0)
                                select @hsr_best_loc_ccr2 = "SEVERE"
                        else if ((@equiv_mod - @orig_equiv_mod) <> 0)
                                select @hsr_best_loc_ccr2 = "MODERATE"
                             else select @hsr_best_loc_ccr2 = "TRIVIAL"
 
                    end      /*else*/
 
                   /* update row */
                   update hrs_ref_data
                   set hsr_best_ccr2= @new_file_name, /* if rft = image or table */
                       hsr_best_loc_ccr2 = @hsr_best_loc_ccr2
                   where  current of ccr2_update_cursor
        
                 end /* if recommended file found, if rft = table */
                  fetch ccr2_update_cursor into @hsr_ccr2
                  /* Print modes, if rft = table */
                ,@hsr_detector
 

                end /* while more ccr2 files */

                close ccr2_update_cursor

                deallocate cursor ccr2_update_cursor
        end /* if @ref_type = 'CCR2') */


        if (@ref_type = 'CCR3')
        begin
                        /* get first non-rejected file that has a */
                        /* useafter_date that is greater than the */
                        /* new files useafter_date - use for stop window */
                declare stop_date_cursor cursor for
                select  hrs_file.useafter_date
                from hrs_file hrs_file, hrs_row hrs_row
                        where hrs_row.file_name = hrs_file.file_name
                        and hrs_row.expansion_number = hrs_file.expansion_number
                        and hrs_file.reference_file_type = "CCR3"
                        and hrs_file.reject_flag = "N"
                        and hrs_file.opus_flag = "Y"
                        and hrs_file.useafter_date > @useafter_date
                        and hrs_file.archive_date is not null
/* The reference file type is table, don't print out the modes */
                order by hrs_file.useafter_date
                for read only

                open stop_date_cursor

                fetch stop_date_cursor into @stop_date

                if (@@sqlstatus <> 0)  /* no stop date found-use todays date*/

                        select @stop_date = getdate()

                close stop_date_cursor

                deallocate cursor stop_date_cursor


                declare ccr3_update_cursor cursor for
                select hsr_ccr3
                  /* Add modes to the select list, if rft = table */
                ,hsr_detector
                from hrs_ref_data
                where hsr_expstart >= @useafter_date
                and hsr_expstart < @stop_date
                  /* Modes aren't added to the where clause, if rft = table */
                for update

                open ccr3_update_cursor

                fetch ccr3_update_cursor into @hsr_ccr3
                  /* Add modes to the fetch statement, if rft = table */
                ,@hsr_detector

                while (@@sqlstatus = 0) /* While more ccr3 files */

                begin
/* The following section, surrounded by ++++'s, if rft = table */
/*++++++++++++++++++++++++++++++++++++++++++++++++++++++++++++++++++++++++++++++*/
                        select @equiv_sev = hrs_row.equivalence_class_severe,
                                @equiv_mod = hrs_row.equivalence_class_moderate
                        from hrs_row hrs_row
                        where hrs_row.file_name = @new_file_name
                        and hrs_row.expansion_number = @new_expansion_number
                        and hrs_row.detector = @hsr_detector

                select @num_cal_files = @@rowcount
                if (@num_cal_files <> 0)	/* recommended file found */
                begin
/*++++++++++++++++++++++++++++++++++++++++++++++++++++++++++++++++++++++++++++++*/
                  if (@hsr_ccr3 = NULL)  /* no file was used in pipeline */
                        select @hsr_best_loc_ccr3 = "N/A"
                  else if (@new_file_name = @hsr_ccr3)  /* recommended = was used, if rft = image or table */
                        select @hsr_best_loc_ccr3 = "NO CHANGE"
                  else
                        if (@equiv_sev = -1)
                        select @hsr_best_loc_ccr3 = 'UNKNOWN'
                  else   /* recommended <> was used - compute level of change */
                    begin
                        select        @orig_equiv_sev = hrs_row.equivalence_class_severe,
                                @orig_equiv_mod = hrs_row.equivalence_class_moderate
                        from        hrs_row hrs_row
                        where        hrs_row.file_name = @hsr_ccr3
                        and hrs_row.detector = @hsr_detector
 

                        if (@orig_equiv_sev = -1)
                        select @hsr_best_loc_ccr3 = 'UNKNOWN'
                        else if ((@equiv_sev - @orig_equiv_sev) <> 0)
                                select @hsr_best_loc_ccr3 = "SEVERE"
                        else if ((@equiv_mod - @orig_equiv_mod) <> 0)
                                select @hsr_best_loc_ccr3 = "MODERATE"
                             else select @hsr_best_loc_ccr3 = "TRIVIAL"
 
                    end      /*else*/
 
                   /* update row */
                   update hrs_ref_data
                   set hsr_best_ccr3= @new_file_name, /* if rft = image or table */
                       hsr_best_loc_ccr3 = @hsr_best_loc_ccr3
                   where  current of ccr3_update_cursor
        
                 end /* if recommended file found, if rft = table */
                  fetch ccr3_update_cursor into @hsr_ccr3
                  /* Print modes, if rft = table */
                ,@hsr_detector
 

                end /* while more ccr3 files */

                close ccr3_update_cursor

                deallocate cursor ccr3_update_cursor
        end /* if @ref_type = 'CCR3') */


        if (@ref_type = 'CCR4')
        begin
                        /* get first non-rejected file that has a */
                        /* useafter_date that is greater than the */
                        /* new files useafter_date - use for stop window */
                declare stop_date_cursor cursor for
                select  hrs_file.useafter_date
                from hrs_file hrs_file, hrs_row hrs_row
                        where hrs_row.file_name = hrs_file.file_name
                        and hrs_row.expansion_number = hrs_file.expansion_number
                        and hrs_file.reference_file_type = "CCR4"
                        and hrs_file.reject_flag = "N"
                        and hrs_file.opus_flag = "Y"
                        and hrs_file.useafter_date > @useafter_date
                        and hrs_file.archive_date is not null
/* The reference file type is table, don't print out the modes */
                order by hrs_file.useafter_date
                for read only

                open stop_date_cursor

                fetch stop_date_cursor into @stop_date

                if (@@sqlstatus <> 0)  /* no stop date found-use todays date*/

                        select @stop_date = getdate()

                close stop_date_cursor

                deallocate cursor stop_date_cursor


                declare ccr4_update_cursor cursor for
                select hsr_ccr4
                  /* Add modes to the select list, if rft = table */
                ,hsr_grating
                from hrs_ref_data
                where hsr_expstart >= @useafter_date
                and hsr_expstart < @stop_date
                  /* Modes aren't added to the where clause, if rft = table */
                for update

                open ccr4_update_cursor

                fetch ccr4_update_cursor into @hsr_ccr4
                  /* Add modes to the fetch statement, if rft = table */
                ,@hsr_grating

                while (@@sqlstatus = 0) /* While more ccr4 files */

                begin
/* The following section, surrounded by ++++'s, if rft = table */
/*++++++++++++++++++++++++++++++++++++++++++++++++++++++++++++++++++++++++++++++*/
                        select @equiv_sev = hrs_row.equivalence_class_severe,
                                @equiv_mod = hrs_row.equivalence_class_moderate
                        from hrs_row hrs_row
                        where hrs_row.file_name = @new_file_name
                        and hrs_row.expansion_number = @new_expansion_number
                        and hrs_row.grating = @hsr_grating

                select @num_cal_files = @@rowcount
                if (@num_cal_files <> 0)	/* recommended file found */
                begin
/*++++++++++++++++++++++++++++++++++++++++++++++++++++++++++++++++++++++++++++++*/
                  if (@hsr_ccr4 = NULL)  /* no file was used in pipeline */
                        select @hsr_best_loc_ccr4 = "N/A"
                  else if (@new_file_name = @hsr_ccr4)  /* recommended = was used, if rft = image or table */
                        select @hsr_best_loc_ccr4 = "NO CHANGE"
                  else
                        if (@equiv_sev = -1)
                        select @hsr_best_loc_ccr4 = 'UNKNOWN'
                  else   /* recommended <> was used - compute level of change */
                    begin
                        select        @orig_equiv_sev = hrs_row.equivalence_class_severe,
                                @orig_equiv_mod = hrs_row.equivalence_class_moderate
                        from        hrs_row hrs_row
                        where        hrs_row.file_name = @hsr_ccr4
                        and hrs_row.grating = @hsr_grating
 

                        if (@orig_equiv_sev = -1)
                        select @hsr_best_loc_ccr4 = 'UNKNOWN'
                        else if ((@equiv_sev - @orig_equiv_sev) <> 0)
                                select @hsr_best_loc_ccr4 = "SEVERE"
                        else if ((@equiv_mod - @orig_equiv_mod) <> 0)
                                select @hsr_best_loc_ccr4 = "MODERATE"
                             else select @hsr_best_loc_ccr4 = "TRIVIAL"
 
                    end      /*else*/
 
                   /* update row */
                   update hrs_ref_data
                   set hsr_best_ccr4= @new_file_name, /* if rft = image or table */
                       hsr_best_loc_ccr4 = @hsr_best_loc_ccr4
                   where  current of ccr4_update_cursor
        
                 end /* if recommended file found, if rft = table */
                  fetch ccr4_update_cursor into @hsr_ccr4
                  /* Print modes, if rft = table */
                ,@hsr_grating
 

                end /* while more ccr4 files */

                close ccr4_update_cursor

                deallocate cursor ccr4_update_cursor
        end /* if @ref_type = 'CCR4') */


        if (@ref_type = 'CCR5')
        begin
                        /* get first non-rejected file that has a */
                        /* useafter_date that is greater than the */
                        /* new files useafter_date - use for stop window */
                declare stop_date_cursor cursor for
                select  hrs_file.useafter_date
                from hrs_file hrs_file, hrs_row hrs_row
                        where hrs_row.file_name = hrs_file.file_name
                        and hrs_row.expansion_number = hrs_file.expansion_number
                        and hrs_file.reference_file_type = "CCR5"
                        and hrs_file.reject_flag = "N"
                        and hrs_file.opus_flag = "Y"
                        and hrs_file.useafter_date > @useafter_date
                        and hrs_file.archive_date is not null
/* The reference file type is table, don't print out the modes */
                order by hrs_file.useafter_date
                for read only

                open stop_date_cursor

                fetch stop_date_cursor into @stop_date

                if (@@sqlstatus <> 0)  /* no stop date found-use todays date*/

                        select @stop_date = getdate()

                close stop_date_cursor

                deallocate cursor stop_date_cursor


                declare ccr5_update_cursor cursor for
                select hsr_ccr5
                  /* Add modes to the select list, if rft = table */
                ,hsr_grating
                from hrs_ref_data
                where hsr_expstart >= @useafter_date
                and hsr_expstart < @stop_date
                  /* Modes aren't added to the where clause, if rft = table */
                for update

                open ccr5_update_cursor

                fetch ccr5_update_cursor into @hsr_ccr5
                  /* Add modes to the fetch statement, if rft = table */
                ,@hsr_grating

                while (@@sqlstatus = 0) /* While more ccr5 files */

                begin
/* The following section, surrounded by ++++'s, if rft = table */
/*++++++++++++++++++++++++++++++++++++++++++++++++++++++++++++++++++++++++++++++*/
                        select @equiv_sev = hrs_row.equivalence_class_severe,
                                @equiv_mod = hrs_row.equivalence_class_moderate
                        from hrs_row hrs_row
                        where hrs_row.file_name = @new_file_name
                        and hrs_row.expansion_number = @new_expansion_number
                        and hrs_row.grating = @hsr_grating

                select @num_cal_files = @@rowcount
                if (@num_cal_files <> 0)	/* recommended file found */
                begin
/*++++++++++++++++++++++++++++++++++++++++++++++++++++++++++++++++++++++++++++++*/
                  if (@hsr_ccr5 = NULL)  /* no file was used in pipeline */
                        select @hsr_best_loc_ccr5 = "N/A"
                  else if (@new_file_name = @hsr_ccr5)  /* recommended = was used, if rft = image or table */
                        select @hsr_best_loc_ccr5 = "NO CHANGE"
                  else
                        if (@equiv_sev = -1)
                        select @hsr_best_loc_ccr5 = 'UNKNOWN'
                  else   /* recommended <> was used - compute level of change */
                    begin
                        select        @orig_equiv_sev = hrs_row.equivalence_class_severe,
                                @orig_equiv_mod = hrs_row.equivalence_class_moderate
                        from        hrs_row hrs_row
                        where        hrs_row.file_name = @hsr_ccr5
                        and hrs_row.grating = @hsr_grating
 

                        if (@orig_equiv_sev = -1)
                        select @hsr_best_loc_ccr5 = 'UNKNOWN'
                        else if ((@equiv_sev - @orig_equiv_sev) <> 0)
                                select @hsr_best_loc_ccr5 = "SEVERE"
                        else if ((@equiv_mod - @orig_equiv_mod) <> 0)
                                select @hsr_best_loc_ccr5 = "MODERATE"
                             else select @hsr_best_loc_ccr5 = "TRIVIAL"
 
                    end      /*else*/
 
                   /* update row */
                   update hrs_ref_data
                   set hsr_best_ccr5= @new_file_name, /* if rft = image or table */
                       hsr_best_loc_ccr5 = @hsr_best_loc_ccr5
                   where  current of ccr5_update_cursor
        
                 end /* if recommended file found, if rft = table */
                  fetch ccr5_update_cursor into @hsr_ccr5
                  /* Print modes, if rft = table */
                ,@hsr_grating
 

                end /* while more ccr5 files */

                close ccr5_update_cursor

                deallocate cursor ccr5_update_cursor
        end /* if @ref_type = 'CCR5') */


        if (@ref_type = 'CCR6')
        begin
                        /* get first non-rejected file that has a */
                        /* useafter_date that is greater than the */
                        /* new files useafter_date - use for stop window */
                declare stop_date_cursor cursor for
                select  hrs_file.useafter_date
                from hrs_file hrs_file, hrs_row hrs_row
                        where hrs_row.file_name = hrs_file.file_name
                        and hrs_row.expansion_number = hrs_file.expansion_number
                        and hrs_file.reference_file_type = "CCR6"
                        and hrs_file.reject_flag = "N"
                        and hrs_file.opus_flag = "Y"
                        and hrs_file.useafter_date > @useafter_date
                        and hrs_file.archive_date is not null
/* The reference file type is table, don't print out the modes */
                order by hrs_file.useafter_date
                for read only

                open stop_date_cursor

                fetch stop_date_cursor into @stop_date

                if (@@sqlstatus <> 0)  /* no stop date found-use todays date*/

                        select @stop_date = getdate()

                close stop_date_cursor

                deallocate cursor stop_date_cursor


                declare ccr6_update_cursor cursor for
                select hsr_ccr6
                  /* Add modes to the select list, if rft = table */
                ,hsr_grating
                from hrs_ref_data
                where hsr_expstart >= @useafter_date
                and hsr_expstart < @stop_date
                  /* Modes aren't added to the where clause, if rft = table */
                for update

                open ccr6_update_cursor

                fetch ccr6_update_cursor into @hsr_ccr6
                  /* Add modes to the fetch statement, if rft = table */
                ,@hsr_grating

                while (@@sqlstatus = 0) /* While more ccr6 files */

                begin
/* The following section, surrounded by ++++'s, if rft = table */
/*++++++++++++++++++++++++++++++++++++++++++++++++++++++++++++++++++++++++++++++*/
                        select @equiv_sev = hrs_row.equivalence_class_severe,
                                @equiv_mod = hrs_row.equivalence_class_moderate
                        from hrs_row hrs_row
                        where hrs_row.file_name = @new_file_name
                        and hrs_row.expansion_number = @new_expansion_number
                        and hrs_row.grating = @hsr_grating

                select @num_cal_files = @@rowcount
                if (@num_cal_files <> 0)	/* recommended file found */
                begin
/*++++++++++++++++++++++++++++++++++++++++++++++++++++++++++++++++++++++++++++++*/
                  if (@hsr_ccr6 = NULL)  /* no file was used in pipeline */
                        select @hsr_best_loc_ccr6 = "N/A"
                  else if (@new_file_name = @hsr_ccr6)  /* recommended = was used, if rft = image or table */
                        select @hsr_best_loc_ccr6 = "NO CHANGE"
                  else
                        if (@equiv_sev = -1)
                        select @hsr_best_loc_ccr6 = 'UNKNOWN'
                  else   /* recommended <> was used - compute level of change */
                    begin
                        select        @orig_equiv_sev = hrs_row.equivalence_class_severe,
                                @orig_equiv_mod = hrs_row.equivalence_class_moderate
                        from        hrs_row hrs_row
                        where        hrs_row.file_name = @hsr_ccr6
                        and hrs_row.grating = @hsr_grating
 

                        if (@orig_equiv_sev = -1)
                        select @hsr_best_loc_ccr6 = 'UNKNOWN'
                        else if ((@equiv_sev - @orig_equiv_sev) <> 0)
                                select @hsr_best_loc_ccr6 = "SEVERE"
                        else if ((@equiv_mod - @orig_equiv_mod) <> 0)
                                select @hsr_best_loc_ccr6 = "MODERATE"
                             else select @hsr_best_loc_ccr6 = "TRIVIAL"
 
                    end      /*else*/
 
                   /* update row */
                   update hrs_ref_data
                   set hsr_best_ccr6= @new_file_name, /* if rft = image or table */
                       hsr_best_loc_ccr6 = @hsr_best_loc_ccr6
                   where  current of ccr6_update_cursor
        
                 end /* if recommended file found, if rft = table */
                  fetch ccr6_update_cursor into @hsr_ccr6
                  /* Print modes, if rft = table */
                ,@hsr_grating
 

                end /* while more ccr6 files */

                close ccr6_update_cursor

                deallocate cursor ccr6_update_cursor
        end /* if @ref_type = 'CCR6') */


        if (@ref_type = 'CCR7')
        begin
                        /* get first non-rejected file that has a */
                        /* useafter_date that is greater than the */
                        /* new files useafter_date - use for stop window */
                declare stop_date_cursor cursor for
                select  hrs_file.useafter_date
                from hrs_file hrs_file, hrs_row hrs_row
                        where hrs_row.file_name = hrs_file.file_name
                        and hrs_row.expansion_number = hrs_file.expansion_number
                        and hrs_file.reference_file_type = "CCR7"
                        and hrs_file.reject_flag = "N"
                        and hrs_file.opus_flag = "Y"
                        and hrs_file.useafter_date > @useafter_date
                        and hrs_file.archive_date is not null
/* The reference file type is table, don't print out the modes */
                order by hrs_file.useafter_date
                for read only

                open stop_date_cursor

                fetch stop_date_cursor into @stop_date

                if (@@sqlstatus <> 0)  /* no stop date found-use todays date*/

                        select @stop_date = getdate()

                close stop_date_cursor

                deallocate cursor stop_date_cursor


                declare ccr7_update_cursor cursor for
                select hsr_ccr7
                  /* Add modes to the select list, if rft = table */
                ,hsr_grating
                from hrs_ref_data
                where hsr_expstart >= @useafter_date
                and hsr_expstart < @stop_date
                  /* Modes aren't added to the where clause, if rft = table */
                for update

                open ccr7_update_cursor

                fetch ccr7_update_cursor into @hsr_ccr7
                  /* Add modes to the fetch statement, if rft = table */
                ,@hsr_grating

                while (@@sqlstatus = 0) /* While more ccr7 files */

                begin
/* The following section, surrounded by ++++'s, if rft = table */
/*++++++++++++++++++++++++++++++++++++++++++++++++++++++++++++++++++++++++++++++*/
                        select @equiv_sev = hrs_row.equivalence_class_severe,
                                @equiv_mod = hrs_row.equivalence_class_moderate
                        from hrs_row hrs_row
                        where hrs_row.file_name = @new_file_name
                        and hrs_row.expansion_number = @new_expansion_number
                        and hrs_row.grating = @hsr_grating

                select @num_cal_files = @@rowcount
                if (@num_cal_files <> 0)	/* recommended file found */
                begin
/*++++++++++++++++++++++++++++++++++++++++++++++++++++++++++++++++++++++++++++++*/
                  if (@hsr_ccr7 = NULL)  /* no file was used in pipeline */
                        select @hsr_best_loc_ccr7 = "N/A"
                  else if (@new_file_name = @hsr_ccr7)  /* recommended = was used, if rft = image or table */
                        select @hsr_best_loc_ccr7 = "NO CHANGE"
                  else
                        if (@equiv_sev = -1)
                        select @hsr_best_loc_ccr7 = 'UNKNOWN'
                  else   /* recommended <> was used - compute level of change */
                    begin
                        select        @orig_equiv_sev = hrs_row.equivalence_class_severe,
                                @orig_equiv_mod = hrs_row.equivalence_class_moderate
                        from        hrs_row hrs_row
                        where        hrs_row.file_name = @hsr_ccr7
                        and hrs_row.grating = @hsr_grating
 

                        if (@orig_equiv_sev = -1)
                        select @hsr_best_loc_ccr7 = 'UNKNOWN'
                        else if ((@equiv_sev - @orig_equiv_sev) <> 0)
                                select @hsr_best_loc_ccr7 = "SEVERE"
                        else if ((@equiv_mod - @orig_equiv_mod) <> 0)
                                select @hsr_best_loc_ccr7 = "MODERATE"
                             else select @hsr_best_loc_ccr7 = "TRIVIAL"
 
                    end      /*else*/
 
                   /* update row */
                   update hrs_ref_data
                   set hsr_best_ccr7= @new_file_name, /* if rft = image or table */
                       hsr_best_loc_ccr7 = @hsr_best_loc_ccr7
                   where  current of ccr7_update_cursor
        
                 end /* if recommended file found, if rft = table */
                  fetch ccr7_update_cursor into @hsr_ccr7
                  /* Print modes, if rft = table */
                ,@hsr_grating
 

                end /* while more ccr7 files */

                close ccr7_update_cursor

                deallocate cursor ccr7_update_cursor
        end /* if @ref_type = 'CCR7') */


        if (@ref_type = 'CCR8')
        begin
                        /* get first non-rejected file that has a */
                        /* useafter_date that is greater than the */
                        /* new files useafter_date - use for stop window */
                declare stop_date_cursor cursor for
                select  hrs_file.useafter_date
                from hrs_file hrs_file, hrs_row hrs_row
                        where hrs_row.file_name = hrs_file.file_name
                        and hrs_row.expansion_number = hrs_file.expansion_number
                        and hrs_file.reference_file_type = "CCR8"
                        and hrs_file.reject_flag = "N"
                        and hrs_file.opus_flag = "Y"
                        and hrs_file.useafter_date > @useafter_date
                        and hrs_file.archive_date is not null
/* The reference file type is table, don't print out the modes */
                order by hrs_file.useafter_date
                for read only

                open stop_date_cursor

                fetch stop_date_cursor into @stop_date

                if (@@sqlstatus <> 0)  /* no stop date found-use todays date*/

                        select @stop_date = getdate()

                close stop_date_cursor

                deallocate cursor stop_date_cursor


                declare ccr8_update_cursor cursor for
                select hsr_ccr8
                  /* Add modes to the select list, if rft = table */
                ,hsr_grating
                ,hsr_sporder
                ,hsr_aperture
                from hrs_ref_data
                where hsr_expstart >= @useafter_date
                and hsr_expstart < @stop_date
                  /* Modes aren't added to the where clause, if rft = table */
                for update

                open ccr8_update_cursor

                fetch ccr8_update_cursor into @hsr_ccr8
                  /* Add modes to the fetch statement, if rft = table */
                ,@hsr_grating
                ,@hsr_sporder
                ,@hsr_aperture

                while (@@sqlstatus = 0) /* While more ccr8 files */

                begin
/* The following section, surrounded by ++++'s, if rft = table */
/*++++++++++++++++++++++++++++++++++++++++++++++++++++++++++++++++++++++++++++++*/
                        select @equiv_sev = hrs_row.equivalence_class_severe,
                                @equiv_mod = hrs_row.equivalence_class_moderate
                        from hrs_row hrs_row
                        where hrs_row.file_name = @new_file_name
                        and hrs_row.expansion_number = @new_expansion_number
                        and hrs_row.grating = @hsr_grating
                        and hrs_row.sporder = @hsr_sporder
                        and hrs_row.aperture = @hsr_aperture

                select @num_cal_files = @@rowcount
                if (@num_cal_files <> 0)	/* recommended file found */
                begin
/*++++++++++++++++++++++++++++++++++++++++++++++++++++++++++++++++++++++++++++++*/
                  if (@hsr_ccr8 = NULL)  /* no file was used in pipeline */
                        select @hsr_best_loc_ccr8 = "N/A"
                  else if (@new_file_name = @hsr_ccr8)  /* recommended = was used, if rft = image or table */
                        select @hsr_best_loc_ccr8 = "NO CHANGE"
                  else
                        if (@equiv_sev = -1)
                        select @hsr_best_loc_ccr8 = 'UNKNOWN'
                  else   /* recommended <> was used - compute level of change */
                    begin
                        select        @orig_equiv_sev = hrs_row.equivalence_class_severe,
                                @orig_equiv_mod = hrs_row.equivalence_class_moderate
                        from        hrs_row hrs_row
                        where        hrs_row.file_name = @hsr_ccr8
                        and hrs_row.grating = @hsr_grating
                        and hrs_row.sporder = @hsr_sporder
                        and hrs_row.aperture = @hsr_aperture
 

                        if (@orig_equiv_sev = -1)
                        select @hsr_best_loc_ccr8 = 'UNKNOWN'
                        else if ((@equiv_sev - @orig_equiv_sev) <> 0)
                                select @hsr_best_loc_ccr8 = "SEVERE"
                        else if ((@equiv_mod - @orig_equiv_mod) <> 0)
                                select @hsr_best_loc_ccr8 = "MODERATE"
                             else select @hsr_best_loc_ccr8 = "TRIVIAL"
 
                    end      /*else*/
 
                   /* update row */
                   update hrs_ref_data
                   set hsr_best_ccr8= @new_file_name, /* if rft = image or table */
                       hsr_best_loc_ccr8 = @hsr_best_loc_ccr8
                   where  current of ccr8_update_cursor
        
                 end /* if recommended file found, if rft = table */
                  fetch ccr8_update_cursor into @hsr_ccr8
                  /* Print modes, if rft = table */
                ,@hsr_grating
                ,@hsr_sporder
                ,@hsr_aperture
 

                end /* while more ccr8 files */

                close ccr8_update_cursor

                deallocate cursor ccr8_update_cursor
        end /* if @ref_type = 'CCR8') */


        if (@ref_type = 'CCR9')
        begin
                        /* get first non-rejected file that has a */
                        /* useafter_date that is greater than the */
                        /* new files useafter_date - use for stop window */
                declare stop_date_cursor cursor for
                select  hrs_file.useafter_date
                from hrs_file hrs_file, hrs_row hrs_row
                        where hrs_row.file_name = hrs_file.file_name
                        and hrs_row.expansion_number = hrs_file.expansion_number
                        and hrs_file.reference_file_type = "CCR9"
                        and hrs_file.reject_flag = "N"
                        and hrs_file.opus_flag = "Y"
                        and hrs_file.useafter_date > @useafter_date
                        and hrs_file.archive_date is not null
/* The reference file type is table, don't print out the modes */
                order by hrs_file.useafter_date
                for read only

                open stop_date_cursor

                fetch stop_date_cursor into @stop_date

                if (@@sqlstatus <> 0)  /* no stop date found-use todays date*/

                        select @stop_date = getdate()

                close stop_date_cursor

                deallocate cursor stop_date_cursor


                declare ccr9_update_cursor cursor for
                select hsr_ccr9
                  /* Add modes to the select list, if rft = table */
                ,hsr_grating
                ,hsr_sporder
                from hrs_ref_data
                where hsr_expstart >= @useafter_date
                and hsr_expstart < @stop_date
                  /* Modes aren't added to the where clause, if rft = table */
                for update

                open ccr9_update_cursor

                fetch ccr9_update_cursor into @hsr_ccr9
                  /* Add modes to the fetch statement, if rft = table */
                ,@hsr_grating
                ,@hsr_sporder

                while (@@sqlstatus = 0) /* While more ccr9 files */

                begin
/* The following section, surrounded by ++++'s, if rft = table */
/*++++++++++++++++++++++++++++++++++++++++++++++++++++++++++++++++++++++++++++++*/
                        select @equiv_sev = hrs_row.equivalence_class_severe,
                                @equiv_mod = hrs_row.equivalence_class_moderate
                        from hrs_row hrs_row
                        where hrs_row.file_name = @new_file_name
                        and hrs_row.expansion_number = @new_expansion_number
                        and hrs_row.grating = @hsr_grating
                        and hrs_row.sporder = @hsr_sporder

                select @num_cal_files = @@rowcount
                if (@num_cal_files <> 0)	/* recommended file found */
                begin
/*++++++++++++++++++++++++++++++++++++++++++++++++++++++++++++++++++++++++++++++*/
                  if (@hsr_ccr9 = NULL)  /* no file was used in pipeline */
                        select @hsr_best_loc_ccr9 = "N/A"
                  else if (@new_file_name = @hsr_ccr9)  /* recommended = was used, if rft = image or table */
                        select @hsr_best_loc_ccr9 = "NO CHANGE"
                  else
                        if (@equiv_sev = -1)
                        select @hsr_best_loc_ccr9 = 'UNKNOWN'
                  else   /* recommended <> was used - compute level of change */
                    begin
                        select        @orig_equiv_sev = hrs_row.equivalence_class_severe,
                                @orig_equiv_mod = hrs_row.equivalence_class_moderate
                        from        hrs_row hrs_row
                        where        hrs_row.file_name = @hsr_ccr9
                        and hrs_row.grating = @hsr_grating
                        and hrs_row.sporder = @hsr_sporder
 

                        if (@orig_equiv_sev = -1)
                        select @hsr_best_loc_ccr9 = 'UNKNOWN'
                        else if ((@equiv_sev - @orig_equiv_sev) <> 0)
                                select @hsr_best_loc_ccr9 = "SEVERE"
                        else if ((@equiv_mod - @orig_equiv_mod) <> 0)
                                select @hsr_best_loc_ccr9 = "MODERATE"
                             else select @hsr_best_loc_ccr9 = "TRIVIAL"
 
                    end      /*else*/
 
                   /* update row */
                   update hrs_ref_data
                   set hsr_best_ccr9= @new_file_name, /* if rft = image or table */
                       hsr_best_loc_ccr9 = @hsr_best_loc_ccr9
                   where  current of ccr9_update_cursor
        
                 end /* if recommended file found, if rft = table */
                  fetch ccr9_update_cursor into @hsr_ccr9
                  /* Print modes, if rft = table */
                ,@hsr_grating
                ,@hsr_sporder
 

                end /* while more ccr9 files */

                close ccr9_update_cursor

                deallocate cursor ccr9_update_cursor
        end /* if @ref_type = 'CCR9') */


        if (@ref_type = 'CCRA')
        begin
                        /* get first non-rejected file that has a */
                        /* useafter_date that is greater than the */
                        /* new files useafter_date - use for stop window */
                declare stop_date_cursor cursor for
                select  hrs_file.useafter_date
                from hrs_file hrs_file, hrs_row hrs_row
                        where hrs_row.file_name = hrs_file.file_name
                        and hrs_row.expansion_number = hrs_file.expansion_number
                        and hrs_file.reference_file_type = "CCRA"
                        and hrs_file.reject_flag = "N"
                        and hrs_file.opus_flag = "Y"
                        and hrs_file.useafter_date > @useafter_date
                        and hrs_file.archive_date is not null
/* The reference file type is table, don't print out the modes */
                order by hrs_file.useafter_date
                for read only

                open stop_date_cursor

                fetch stop_date_cursor into @stop_date

                if (@@sqlstatus <> 0)  /* no stop date found-use todays date*/

                        select @stop_date = getdate()

                close stop_date_cursor

                deallocate cursor stop_date_cursor


                declare ccra_update_cursor cursor for
                select hsr_ccra
                  /* Add modes to the select list, if rft = table */
                ,hsr_grating
                from hrs_ref_data
                where hsr_expstart >= @useafter_date
                and hsr_expstart < @stop_date
                  /* Modes aren't added to the where clause, if rft = table */
                for update

                open ccra_update_cursor

                fetch ccra_update_cursor into @hsr_ccra
                  /* Add modes to the fetch statement, if rft = table */
                ,@hsr_grating

                while (@@sqlstatus = 0) /* While more ccra files */

                begin
/* The following section, surrounded by ++++'s, if rft = table */
/*++++++++++++++++++++++++++++++++++++++++++++++++++++++++++++++++++++++++++++++*/
                        select @equiv_sev = hrs_row.equivalence_class_severe,
                                @equiv_mod = hrs_row.equivalence_class_moderate
                        from hrs_row hrs_row
                        where hrs_row.file_name = @new_file_name
                        and hrs_row.expansion_number = @new_expansion_number
                        and hrs_row.grating = @hsr_grating

                select @num_cal_files = @@rowcount
                if (@num_cal_files <> 0)	/* recommended file found */
                begin
/*++++++++++++++++++++++++++++++++++++++++++++++++++++++++++++++++++++++++++++++*/
                  if (@hsr_ccra = NULL)  /* no file was used in pipeline */
                        select @hsr_best_loc_ccra = "N/A"
                  else if (@new_file_name = @hsr_ccra)  /* recommended = was used, if rft = image or table */
                        select @hsr_best_loc_ccra = "NO CHANGE"
                  else
                        if (@equiv_sev = -1)
                        select @hsr_best_loc_ccra = 'UNKNOWN'
                  else   /* recommended <> was used - compute level of change */
                    begin
                        select        @orig_equiv_sev = hrs_row.equivalence_class_severe,
                                @orig_equiv_mod = hrs_row.equivalence_class_moderate
                        from        hrs_row hrs_row
                        where        hrs_row.file_name = @hsr_ccra
                        and hrs_row.grating = @hsr_grating
 

                        if (@orig_equiv_sev = -1)
                        select @hsr_best_loc_ccra = 'UNKNOWN'
                        else if ((@equiv_sev - @orig_equiv_sev) <> 0)
                                select @hsr_best_loc_ccra = "SEVERE"
                        else if ((@equiv_mod - @orig_equiv_mod) <> 0)
                                select @hsr_best_loc_ccra = "MODERATE"
                             else select @hsr_best_loc_ccra = "TRIVIAL"
 
                    end      /*else*/
 
                   /* update row */
                   update hrs_ref_data
                   set hsr_best_ccra= @new_file_name, /* if rft = image or table */
                       hsr_best_loc_ccra = @hsr_best_loc_ccra
                   where  current of ccra_update_cursor
        
                 end /* if recommended file found, if rft = table */
                  fetch ccra_update_cursor into @hsr_ccra
                  /* Print modes, if rft = table */
                ,@hsr_grating
 

                end /* while more ccra files */

                close ccra_update_cursor

                deallocate cursor ccra_update_cursor
        end /* if @ref_type = 'CCRA') */


        if (@ref_type = 'CCRB')
        begin
                        /* get first non-rejected file that has a */
                        /* useafter_date that is greater than the */
                        /* new files useafter_date - use for stop window */
                declare stop_date_cursor cursor for
                select  hrs_file.useafter_date
                from hrs_file hrs_file, hrs_row hrs_row
                        where hrs_row.file_name = hrs_file.file_name
                        and hrs_row.expansion_number = hrs_file.expansion_number
                        and hrs_file.reference_file_type = "CCRB"
                        and hrs_file.reject_flag = "N"
                        and hrs_file.opus_flag = "Y"
                        and hrs_file.useafter_date > @useafter_date
                        and hrs_file.archive_date is not null
/* The reference file type is table, don't print out the modes */
                order by hrs_file.useafter_date
                for read only

                open stop_date_cursor

                fetch stop_date_cursor into @stop_date

                if (@@sqlstatus <> 0)  /* no stop date found-use todays date*/

                        select @stop_date = getdate()

                close stop_date_cursor

                deallocate cursor stop_date_cursor


                declare ccrb_update_cursor cursor for
                select hsr_ccrb
                  /* Add modes to the select list, if rft = table */
                ,hsr_grating
                ,hsr_sporder
                ,hsr_aperture
                from hrs_ref_data
                where hsr_expstart >= @useafter_date
                and hsr_expstart < @stop_date
                  /* Modes aren't added to the where clause, if rft = table */
                for update

                open ccrb_update_cursor

                fetch ccrb_update_cursor into @hsr_ccrb
                  /* Add modes to the fetch statement, if rft = table */
                ,@hsr_grating
                ,@hsr_sporder
                ,@hsr_aperture

                while (@@sqlstatus = 0) /* While more ccrb files */

                begin
/* The following section, surrounded by ++++'s, if rft = table */
/*++++++++++++++++++++++++++++++++++++++++++++++++++++++++++++++++++++++++++++++*/
                        select @equiv_sev = hrs_row.equivalence_class_severe,
                                @equiv_mod = hrs_row.equivalence_class_moderate
                        from hrs_row hrs_row
                        where hrs_row.file_name = @new_file_name
                        and hrs_row.expansion_number = @new_expansion_number
                        and hrs_row.grating = @hsr_grating
                        and hrs_row.sporder = @hsr_sporder
                        and hrs_row.aperture = @hsr_aperture

                select @num_cal_files = @@rowcount
                if (@num_cal_files <> 0)	/* recommended file found */
                begin
/*++++++++++++++++++++++++++++++++++++++++++++++++++++++++++++++++++++++++++++++*/
                  if (@hsr_ccrb = NULL)  /* no file was used in pipeline */
                        select @hsr_best_loc_ccrb = "N/A"
                  else if (@new_file_name = @hsr_ccrb)  /* recommended = was used, if rft = image or table */
                        select @hsr_best_loc_ccrb = "NO CHANGE"
                  else
                        if (@equiv_sev = -1)
                        select @hsr_best_loc_ccrb = 'UNKNOWN'
                  else   /* recommended <> was used - compute level of change */
                    begin
                        select        @orig_equiv_sev = hrs_row.equivalence_class_severe,
                                @orig_equiv_mod = hrs_row.equivalence_class_moderate
                        from        hrs_row hrs_row
                        where        hrs_row.file_name = @hsr_ccrb
                        and hrs_row.grating = @hsr_grating
                        and hrs_row.sporder = @hsr_sporder
                        and hrs_row.aperture = @hsr_aperture
 

                        if (@orig_equiv_sev = -1)
                        select @hsr_best_loc_ccrb = 'UNKNOWN'
                        else if ((@equiv_sev - @orig_equiv_sev) <> 0)
                                select @hsr_best_loc_ccrb = "SEVERE"
                        else if ((@equiv_mod - @orig_equiv_mod) <> 0)
                                select @hsr_best_loc_ccrb = "MODERATE"
                             else select @hsr_best_loc_ccrb = "TRIVIAL"
 
                    end      /*else*/
 
                   /* update row */
                   update hrs_ref_data
                   set hsr_best_ccrb= @new_file_name, /* if rft = image or table */
                       hsr_best_loc_ccrb = @hsr_best_loc_ccrb
                   where  current of ccrb_update_cursor
        
                 end /* if recommended file found, if rft = table */
                  fetch ccrb_update_cursor into @hsr_ccrb
                  /* Print modes, if rft = table */
                ,@hsr_grating
                ,@hsr_sporder
                ,@hsr_aperture
 

                end /* while more ccrb files */

                close ccrb_update_cursor

                deallocate cursor ccrb_update_cursor
        end /* if @ref_type = 'CCRB') */


        if (@ref_type = 'CCRC')
        begin
                        /* get first non-rejected file that has a */
                        /* useafter_date that is greater than the */
                        /* new files useafter_date - use for stop window */
                declare stop_date_cursor cursor for
                select  hrs_file.useafter_date
                from hrs_file hrs_file, hrs_row hrs_row
                        where hrs_row.file_name = hrs_file.file_name
                        and hrs_row.expansion_number = hrs_file.expansion_number
                        and hrs_file.reference_file_type = "CCRC"
                        and hrs_file.reject_flag = "N"
                        and hrs_file.opus_flag = "Y"
                        and hrs_file.useafter_date > @useafter_date
                        and hrs_file.archive_date is not null
/* The reference file type is table, don't print out the modes */
                order by hrs_file.useafter_date
                for read only

                open stop_date_cursor

                fetch stop_date_cursor into @stop_date

                if (@@sqlstatus <> 0)  /* no stop date found-use todays date*/

                        select @stop_date = getdate()

                close stop_date_cursor

                deallocate cursor stop_date_cursor


                declare ccrc_update_cursor cursor for
                select hsr_ccrc
                  /* Add modes to the select list, if rft = table */
                ,hsr_grating
                from hrs_ref_data
                where hsr_expstart >= @useafter_date
                and hsr_expstart < @stop_date
                  /* Modes aren't added to the where clause, if rft = table */
                for update

                open ccrc_update_cursor

                fetch ccrc_update_cursor into @hsr_ccrc
                  /* Add modes to the fetch statement, if rft = table */
                ,@hsr_grating

                while (@@sqlstatus = 0) /* While more ccrc files */

                begin
/* The following section, surrounded by ++++'s, if rft = table */
/*++++++++++++++++++++++++++++++++++++++++++++++++++++++++++++++++++++++++++++++*/
                        select @equiv_sev = hrs_row.equivalence_class_severe,
                                @equiv_mod = hrs_row.equivalence_class_moderate
                        from hrs_row hrs_row
                        where hrs_row.file_name = @new_file_name
                        and hrs_row.expansion_number = @new_expansion_number
                        and hrs_row.grating = @hsr_grating

                select @num_cal_files = @@rowcount
                if (@num_cal_files <> 0)	/* recommended file found */
                begin
/*++++++++++++++++++++++++++++++++++++++++++++++++++++++++++++++++++++++++++++++*/
                  if (@hsr_ccrc = NULL)  /* no file was used in pipeline */
                        select @hsr_best_loc_ccrc = "N/A"
                  else if (@new_file_name = @hsr_ccrc)  /* recommended = was used, if rft = image or table */
                        select @hsr_best_loc_ccrc = "NO CHANGE"
                  else
                        if (@equiv_sev = -1)
                        select @hsr_best_loc_ccrc = 'UNKNOWN'
                  else   /* recommended <> was used - compute level of change */
                    begin
                        select        @orig_equiv_sev = hrs_row.equivalence_class_severe,
                                @orig_equiv_mod = hrs_row.equivalence_class_moderate
                        from        hrs_row hrs_row
                        where        hrs_row.file_name = @hsr_ccrc
                        and hrs_row.grating = @hsr_grating
 

                        if (@orig_equiv_sev = -1)
                        select @hsr_best_loc_ccrc = 'UNKNOWN'
                        else if ((@equiv_sev - @orig_equiv_sev) <> 0)
                                select @hsr_best_loc_ccrc = "SEVERE"
                        else if ((@equiv_mod - @orig_equiv_mod) <> 0)
                                select @hsr_best_loc_ccrc = "MODERATE"
                             else select @hsr_best_loc_ccrc = "TRIVIAL"
 
                    end      /*else*/
 
                   /* update row */
                   update hrs_ref_data
                   set hsr_best_ccrc= @new_file_name, /* if rft = image or table */
                       hsr_best_loc_ccrc = @hsr_best_loc_ccrc
                   where  current of ccrc_update_cursor
        
                 end /* if recommended file found, if rft = table */
                  fetch ccrc_update_cursor into @hsr_ccrc
                  /* Print modes, if rft = table */
                ,@hsr_grating
 

                end /* while more ccrc files */

                close ccrc_update_cursor

                deallocate cursor ccrc_update_cursor
        end /* if @ref_type = 'CCRC') */


        if (@ref_type = 'CCRD')
        begin
                        /* get first non-rejected file that has a */
                        /* useafter_date that is greater than the */
                        /* new files useafter_date - use for stop window */
                declare stop_date_cursor cursor for
                select  hrs_file.useafter_date
                from hrs_file hrs_file, hrs_row hrs_row
                        where hrs_row.file_name = hrs_file.file_name
                        and hrs_row.expansion_number = hrs_file.expansion_number
                        and hrs_file.reference_file_type = "CCRD"
                        and hrs_file.reject_flag = "N"
                        and hrs_file.opus_flag = "Y"
                        and hrs_file.useafter_date > @useafter_date
                        and hrs_file.archive_date is not null
/* The reference file type is table, don't print out the modes */
                order by hrs_file.useafter_date
                for read only

                open stop_date_cursor

                fetch stop_date_cursor into @stop_date

                if (@@sqlstatus <> 0)  /* no stop date found-use todays date*/

                        select @stop_date = getdate()

                close stop_date_cursor

                deallocate cursor stop_date_cursor


                declare ccrd_update_cursor cursor for
                select hsr_ccrd
                  /* Add modes to the select list, if rft = table */
                ,hsr_detector
                from hrs_ref_data
                where hsr_expstart >= @useafter_date
                and hsr_expstart < @stop_date
                  /* Modes aren't added to the where clause, if rft = table */
                for update

                open ccrd_update_cursor

                fetch ccrd_update_cursor into @hsr_ccrd
                  /* Add modes to the fetch statement, if rft = table */
                ,@hsr_detector

                while (@@sqlstatus = 0) /* While more ccrd files */

                begin
/* The following section, surrounded by ++++'s, if rft = table */
/*++++++++++++++++++++++++++++++++++++++++++++++++++++++++++++++++++++++++++++++*/
                        select @equiv_sev = hrs_row.equivalence_class_severe,
                                @equiv_mod = hrs_row.equivalence_class_moderate
                        from hrs_row hrs_row
                        where hrs_row.file_name = @new_file_name
                        and hrs_row.expansion_number = @new_expansion_number
                        and hrs_row.detector = @hsr_detector

                select @num_cal_files = @@rowcount
                if (@num_cal_files <> 0)	/* recommended file found */
                begin
/*++++++++++++++++++++++++++++++++++++++++++++++++++++++++++++++++++++++++++++++*/
                  if (@hsr_ccrd = NULL)  /* no file was used in pipeline */
                        select @hsr_best_loc_ccrd = "N/A"
                  else if (@new_file_name = @hsr_ccrd)  /* recommended = was used, if rft = image or table */
                        select @hsr_best_loc_ccrd = "NO CHANGE"
                  else
                        if (@equiv_sev = -1)
                        select @hsr_best_loc_ccrd = 'UNKNOWN'
                  else   /* recommended <> was used - compute level of change */
                    begin
                        select        @orig_equiv_sev = hrs_row.equivalence_class_severe,
                                @orig_equiv_mod = hrs_row.equivalence_class_moderate
                        from        hrs_row hrs_row
                        where        hrs_row.file_name = @hsr_ccrd
                        and hrs_row.detector = @hsr_detector
 

                        if (@orig_equiv_sev = -1)
                        select @hsr_best_loc_ccrd = 'UNKNOWN'
                        else if ((@equiv_sev - @orig_equiv_sev) <> 0)
                                select @hsr_best_loc_ccrd = "SEVERE"
                        else if ((@equiv_mod - @orig_equiv_mod) <> 0)
                                select @hsr_best_loc_ccrd = "MODERATE"
                             else select @hsr_best_loc_ccrd = "TRIVIAL"
 
                    end      /*else*/
 
                   /* update row */
                   update hrs_ref_data
                   set hsr_best_ccrd= @new_file_name, /* if rft = image or table */
                       hsr_best_loc_ccrd = @hsr_best_loc_ccrd
                   where  current of ccrd_update_cursor
        
                 end /* if recommended file found, if rft = table */
                  fetch ccrd_update_cursor into @hsr_ccrd
                  /* Print modes, if rft = table */
                ,@hsr_detector
 

                end /* while more ccrd files */

                close ccrd_update_cursor

                deallocate cursor ccrd_update_cursor
        end /* if @ref_type = 'CCRD') */


        if (@ref_type = 'CCRE')
        begin
                        /* get first non-rejected file that has a */
                        /* useafter_date that is greater than the */
                        /* new files useafter_date - use for stop window */
                declare stop_date_cursor cursor for
                select  hrs_file.useafter_date
                from hrs_file hrs_file, hrs_row hrs_row
                        where hrs_row.file_name = hrs_file.file_name
                        and hrs_row.expansion_number = hrs_file.expansion_number
                        and hrs_file.reference_file_type = "CCRE"
                        and hrs_file.reject_flag = "N"
                        and hrs_file.opus_flag = "Y"
                        and hrs_file.useafter_date > @useafter_date
                        and hrs_file.archive_date is not null
/* The reference file type is table, don't print out the modes */
                order by hrs_file.useafter_date
                for read only

                open stop_date_cursor

                fetch stop_date_cursor into @stop_date

                if (@@sqlstatus <> 0)  /* no stop date found-use todays date*/

                        select @stop_date = getdate()

                close stop_date_cursor

                deallocate cursor stop_date_cursor


                declare ccre_update_cursor cursor for
                select hsr_ccre
                  /* Add modes to the select list, if rft = table */
                from hrs_ref_data
                where hsr_expstart >= @useafter_date
                and hsr_expstart < @stop_date
                  /* Modes aren't added to the where clause, if rft = table */
                for update

                open ccre_update_cursor

                fetch ccre_update_cursor into @hsr_ccre
                  /* Add modes to the fetch statement, if rft = table */

                while (@@sqlstatus = 0) /* While more ccre files */

                begin
/* The following section, surrounded by ++++'s, if rft = table */
/*++++++++++++++++++++++++++++++++++++++++++++++++++++++++++++++++++++++++++++++*/
                        select @equiv_sev = hrs_row.equivalence_class_severe,
                                @equiv_mod = hrs_row.equivalence_class_moderate
                        from hrs_row hrs_row
                        where hrs_row.file_name = @new_file_name
                        and hrs_row.expansion_number = @new_expansion_number

                select @num_cal_files = @@rowcount
                if (@num_cal_files <> 0)	/* recommended file found */
                begin
/*++++++++++++++++++++++++++++++++++++++++++++++++++++++++++++++++++++++++++++++*/
                  if (@hsr_ccre = NULL)  /* no file was used in pipeline */
                        select @hsr_best_loc_ccre = "N/A"
                  else if (@new_file_name = @hsr_ccre)  /* recommended = was used, if rft = image or table */
                        select @hsr_best_loc_ccre = "NO CHANGE"
                  else
                        if (@equiv_sev = -1)
                        select @hsr_best_loc_ccre = 'UNKNOWN'
                  else   /* recommended <> was used - compute level of change */
                    begin
                        select        @orig_equiv_sev = hrs_row.equivalence_class_severe,
                                @orig_equiv_mod = hrs_row.equivalence_class_moderate
                        from        hrs_row hrs_row
                        where        hrs_row.file_name = @hsr_ccre
 

                        if (@orig_equiv_sev = -1)
                        select @hsr_best_loc_ccre = 'UNKNOWN'
                        else if ((@equiv_sev - @orig_equiv_sev) <> 0)
                                select @hsr_best_loc_ccre = "SEVERE"
                        else if ((@equiv_mod - @orig_equiv_mod) <> 0)
                                select @hsr_best_loc_ccre = "MODERATE"
                             else select @hsr_best_loc_ccre = "TRIVIAL"
 
                    end      /*else*/
 
                   /* update row */
                   update hrs_ref_data
                   set hsr_best_ccre= @new_file_name, /* if rft = image or table */
                       hsr_best_loc_ccre = @hsr_best_loc_ccre
                   where  current of ccre_update_cursor
        
                 end /* if recommended file found, if rft = table */
                  fetch ccre_update_cursor into @hsr_ccre
                  /* Print modes, if rft = table */
 

                end /* while more ccre files */

                close ccre_update_cursor

                deallocate cursor ccre_update_cursor
        end /* if @ref_type = 'CCRE') */


        if (@ref_type = 'ABS')
        begin
                        /* get first non-rejected file that has a */
                        /* useafter_date that is greater than the */
                        /* new files useafter_date - use for stop window */
                declare stop_date_cursor cursor for
                select  hrs_file.useafter_date
                from hrs_file hrs_file, hrs_row hrs_row
                        where hrs_row.file_name = hrs_file.file_name
                        and hrs_row.expansion_number = hrs_file.expansion_number
                        and hrs_file.reference_file_type = "ABS"
                        and hrs_file.reject_flag = "N"
                        and hrs_file.opus_flag = "Y"
                        and hrs_file.useafter_date > @useafter_date
                        and hrs_file.archive_date is not null
                        /* Print out the modes, if rft = image */
                        and hrs_row.grating = @hsr_grating
                order by hrs_file.useafter_date
                for read only

                open stop_date_cursor

                fetch stop_date_cursor into @stop_date

                if (@@sqlstatus <> 0)  /* no stop date found-use todays date*/

                        select @stop_date = getdate()

                close stop_date_cursor

                deallocate cursor stop_date_cursor


                declare abs_update_cursor cursor for
                select hsr_abshfile
                  /* Modes aren't added to the select list, if rft = image */
                from hrs_ref_data
                where hsr_expstart >= @useafter_date
                and hsr_expstart < @stop_date
                  /* Add modes to the where clause, if rft = image */
                        and hsr_grating = @hsr_grating
                for update

                open abs_update_cursor

                fetch abs_update_cursor into @hsr_abshfile
                  /* Don't add modes to the fetch statement, if rft = image */

                while (@@sqlstatus = 0) /* While more abs files */

                begin
/*++++++++++++++++++++++++++++++++++++++++++++++++++++++++++++++++++++++++++++++*/
                  if (@hsr_abshfile = NULL)  /* no file was used in pipeline */
                        select @hsr_best_loc_abs = "N/A"
                  else if (@new_file_name = @hsr_abshfile)  /* recommended = was used, if rft = image or table */
                        select @hsr_best_loc_abs = "NO CHANGE"
                  else
                        if (@equiv_sev = -1)
                        select @hsr_best_loc_abs = 'UNKNOWN'
                  else   /* recommended <> was used - compute level of change */
                    begin
                        select        @orig_equiv_sev = hrs_row.equivalence_class_severe,
                                @orig_equiv_mod = hrs_row.equivalence_class_moderate
                        from        hrs_row hrs_row
                        where        hrs_row.file_name = @hsr_abshfile
                        and hrs_row.grating = @hsr_grating
 

                        if (@orig_equiv_sev = -1)
                        select @hsr_best_loc_abs = 'UNKNOWN'
                        else if ((@equiv_sev - @orig_equiv_sev) <> 0)
                                select @hsr_best_loc_abs = "SEVERE"
                        else if ((@equiv_mod - @orig_equiv_mod) <> 0)
                                select @hsr_best_loc_abs = "MODERATE"
                             else select @hsr_best_loc_abs = "TRIVIAL"
 
                    end      /*else*/
 
                   /* update row */
                   update hrs_ref_data
                   set hsr_best_abs= @new_file_name, /* if rft = image or table */
                       hsr_best_loc_abs = @hsr_best_loc_abs
                   where  current of abs_update_cursor
        
                  fetch abs_update_cursor into @hsr_abshfile
                  /* Don't print modes, if rft = image */
 

                end /* while more abs files */

                close abs_update_cursor

                deallocate cursor abs_update_cursor
        end /* if @ref_type = 'ABS') */


        if (@ref_type = 'DIO')
        begin
                        /* get first non-rejected file that has a */
                        /* useafter_date that is greater than the */
                        /* new files useafter_date - use for stop window */
                declare stop_date_cursor cursor for
                select  hrs_file.useafter_date
                from hrs_file hrs_file, hrs_row hrs_row
                        where hrs_row.file_name = hrs_file.file_name
                        and hrs_row.expansion_number = hrs_file.expansion_number
                        and hrs_file.reference_file_type = "DIO"
                        and hrs_file.reject_flag = "N"
                        and hrs_file.opus_flag = "Y"
                        and hrs_file.useafter_date > @useafter_date
                        and hrs_file.archive_date is not null
                        /* Print out the modes, if rft = image */
                        and hrs_row.detector = @hsr_detector
                order by hrs_file.useafter_date
                for read only

                open stop_date_cursor

                fetch stop_date_cursor into @stop_date

                if (@@sqlstatus <> 0)  /* no stop date found-use todays date*/

                        select @stop_date = getdate()

                close stop_date_cursor

                deallocate cursor stop_date_cursor


                declare dio_update_cursor cursor for
                select hsr_diohfile
                  /* Modes aren't added to the select list, if rft = image */
                from hrs_ref_data
                where hsr_expstart >= @useafter_date
                and hsr_expstart < @stop_date
                  /* Add modes to the where clause, if rft = image */
                        and hsr_detector = @hsr_detector
                for update

                open dio_update_cursor

                fetch dio_update_cursor into @hsr_diohfile
                  /* Don't add modes to the fetch statement, if rft = image */

                while (@@sqlstatus = 0) /* While more dio files */

                begin
/*++++++++++++++++++++++++++++++++++++++++++++++++++++++++++++++++++++++++++++++*/
                  if (@hsr_diohfile = NULL)  /* no file was used in pipeline */
                        select @hsr_best_loc_dio = "N/A"
                  else if (@new_file_name = @hsr_diohfile)  /* recommended = was used, if rft = image or table */
                        select @hsr_best_loc_dio = "NO CHANGE"
                  else
                        if (@equiv_sev = -1)
                        select @hsr_best_loc_dio = 'UNKNOWN'
                  else   /* recommended <> was used - compute level of change */
                    begin
                        select        @orig_equiv_sev = hrs_row.equivalence_class_severe,
                                @orig_equiv_mod = hrs_row.equivalence_class_moderate
                        from        hrs_row hrs_row
                        where        hrs_row.file_name = @hsr_diohfile
                        and hrs_row.detector = @hsr_detector
 

                        if (@orig_equiv_sev = -1)
                        select @hsr_best_loc_dio = 'UNKNOWN'
                        else if ((@equiv_sev - @orig_equiv_sev) <> 0)
                                select @hsr_best_loc_dio = "SEVERE"
                        else if ((@equiv_mod - @orig_equiv_mod) <> 0)
                                select @hsr_best_loc_dio = "MODERATE"
                             else select @hsr_best_loc_dio = "TRIVIAL"
 
                    end      /*else*/
 
                   /* update row */
                   update hrs_ref_data
                   set hsr_best_dio= @new_file_name, /* if rft = image or table */
                       hsr_best_loc_dio = @hsr_best_loc_dio
                   where  current of dio_update_cursor
        
                  fetch dio_update_cursor into @hsr_diohfile
                  /* Don't print modes, if rft = image */
 

                end /* while more dio files */

                close dio_update_cursor

                deallocate cursor dio_update_cursor
        end /* if @ref_type = 'DIO') */


        if (@ref_type = 'NET')
        begin
                        /* get first non-rejected file that has a */
                        /* useafter_date that is greater than the */
                        /* new files useafter_date - use for stop window */
                declare stop_date_cursor cursor for
                select  hrs_file.useafter_date
                from hrs_file hrs_file, hrs_row hrs_row
                        where hrs_row.file_name = hrs_file.file_name
                        and hrs_row.expansion_number = hrs_file.expansion_number
                        and hrs_file.reference_file_type = "NET"
                        and hrs_file.reject_flag = "N"
                        and hrs_file.opus_flag = "Y"
                        and hrs_file.useafter_date > @useafter_date
                        and hrs_file.archive_date is not null
                        /* Print out the modes, if rft = image */
                        and hrs_row.grating = @hsr_grating
                order by hrs_file.useafter_date
                for read only

                open stop_date_cursor

                fetch stop_date_cursor into @stop_date

                if (@@sqlstatus <> 0)  /* no stop date found-use todays date*/

                        select @stop_date = getdate()

                close stop_date_cursor

                deallocate cursor stop_date_cursor


                declare net_update_cursor cursor for
                select hsr_nethfile
                  /* Modes aren't added to the select list, if rft = image */
                from hrs_ref_data
                where hsr_expstart >= @useafter_date
                and hsr_expstart < @stop_date
                  /* Add modes to the where clause, if rft = image */
                        and hsr_grating = @hsr_grating
                for update

                open net_update_cursor

                fetch net_update_cursor into @hsr_nethfile
                  /* Don't add modes to the fetch statement, if rft = image */

                while (@@sqlstatus = 0) /* While more net files */

                begin
/*++++++++++++++++++++++++++++++++++++++++++++++++++++++++++++++++++++++++++++++*/
                  if (@hsr_nethfile = NULL)  /* no file was used in pipeline */
                        select @hsr_best_loc_net = "N/A"
                  else if (@new_file_name = @hsr_nethfile)  /* recommended = was used, if rft = image or table */
                        select @hsr_best_loc_net = "NO CHANGE"
                  else
                        if (@equiv_sev = -1)
                        select @hsr_best_loc_net = 'UNKNOWN'
                  else   /* recommended <> was used - compute level of change */
                    begin
                        select        @orig_equiv_sev = hrs_row.equivalence_class_severe,
                                @orig_equiv_mod = hrs_row.equivalence_class_moderate
                        from        hrs_row hrs_row
                        where        hrs_row.file_name = @hsr_nethfile
                        and hrs_row.grating = @hsr_grating
 

                        if (@orig_equiv_sev = -1)
                        select @hsr_best_loc_net = 'UNKNOWN'
                        else if ((@equiv_sev - @orig_equiv_sev) <> 0)
                                select @hsr_best_loc_net = "SEVERE"
                        else if ((@equiv_mod - @orig_equiv_mod) <> 0)
                                select @hsr_best_loc_net = "MODERATE"
                             else select @hsr_best_loc_net = "TRIVIAL"
 
                    end      /*else*/
 
                   /* update row */
                   update hrs_ref_data
                   set hsr_best_net= @new_file_name, /* if rft = image or table */
                       hsr_best_loc_net = @hsr_best_loc_net
                   where  current of net_update_cursor
        
                  fetch net_update_cursor into @hsr_nethfile
                  /* Don't print modes, if rft = image */
 

                end /* while more net files */

                close net_update_cursor

                deallocate cursor net_update_cursor
        end /* if @ref_type = 'NET') */


        if (@ref_type = 'PHC')
        begin
                        /* get first non-rejected file that has a */
                        /* useafter_date that is greater than the */
                        /* new files useafter_date - use for stop window */
                declare stop_date_cursor cursor for
                select  hrs_file.useafter_date
                from hrs_file hrs_file, hrs_row hrs_row
                        where hrs_row.file_name = hrs_file.file_name
                        and hrs_row.expansion_number = hrs_file.expansion_number
                        and hrs_file.reference_file_type = "PHC"
                        and hrs_file.reject_flag = "N"
                        and hrs_file.opus_flag = "Y"
                        and hrs_file.useafter_date > @useafter_date
                        and hrs_file.archive_date is not null
                        /* Print out the modes, if rft = image */
                        and hrs_row.grating = @hsr_grating
                order by hrs_file.useafter_date
                for read only

                open stop_date_cursor

                fetch stop_date_cursor into @stop_date

                if (@@sqlstatus <> 0)  /* no stop date found-use todays date*/

                        select @stop_date = getdate()

                close stop_date_cursor

                deallocate cursor stop_date_cursor


                declare phc_update_cursor cursor for
                select hsr_phchfile
                  /* Modes aren't added to the select list, if rft = image */
                from hrs_ref_data
                where hsr_expstart >= @useafter_date
                and hsr_expstart < @stop_date
                  /* Add modes to the where clause, if rft = image */
                        and hsr_grating = @hsr_grating
                for update

                open phc_update_cursor

                fetch phc_update_cursor into @hsr_phchfile
                  /* Don't add modes to the fetch statement, if rft = image */

                while (@@sqlstatus = 0) /* While more phc files */

                begin
/*++++++++++++++++++++++++++++++++++++++++++++++++++++++++++++++++++++++++++++++*/
                  if (@hsr_phchfile = NULL)  /* no file was used in pipeline */
                        select @hsr_best_loc_phc = "N/A"
                  else if (@new_file_name = @hsr_phchfile)  /* recommended = was used, if rft = image or table */
                        select @hsr_best_loc_phc = "NO CHANGE"
                  else
                        if (@equiv_sev = -1)
                        select @hsr_best_loc_phc = 'UNKNOWN'
                  else   /* recommended <> was used - compute level of change */
                    begin
                        select        @orig_equiv_sev = hrs_row.equivalence_class_severe,
                                @orig_equiv_mod = hrs_row.equivalence_class_moderate
                        from        hrs_row hrs_row
                        where        hrs_row.file_name = @hsr_phchfile
                        and hrs_row.grating = @hsr_grating
 

                        if (@orig_equiv_sev = -1)
                        select @hsr_best_loc_phc = 'UNKNOWN'
                        else if ((@equiv_sev - @orig_equiv_sev) <> 0)
                                select @hsr_best_loc_phc = "SEVERE"
                        else if ((@equiv_mod - @orig_equiv_mod) <> 0)
                                select @hsr_best_loc_phc = "MODERATE"
                             else select @hsr_best_loc_phc = "TRIVIAL"
 
                    end      /*else*/
 
                   /* update row */
                   update hrs_ref_data
                   set hsr_best_phc= @new_file_name, /* if rft = image or table */
                       hsr_best_loc_phc = @hsr_best_loc_phc
                   where  current of phc_update_cursor
        
                  fetch phc_update_cursor into @hsr_phchfile
                  /* Don't print modes, if rft = image */
 

                end /* while more phc files */

                close phc_update_cursor

                deallocate cursor phc_update_cursor
        end /* if @ref_type = 'PHC') */


        if (@ref_type = 'QIN')
        begin
                        /* get first non-rejected file that has a */
                        /* useafter_date that is greater than the */
                        /* new files useafter_date - use for stop window */
                declare stop_date_cursor cursor for
                select  hrs_file.useafter_date
                from hrs_file hrs_file, hrs_row hrs_row
                        where hrs_row.file_name = hrs_file.file_name
                        and hrs_row.expansion_number = hrs_file.expansion_number
                        and hrs_file.reference_file_type = "QIN"
                        and hrs_file.reject_flag = "N"
                        and hrs_file.opus_flag = "Y"
                        and hrs_file.useafter_date > @useafter_date
                        and hrs_file.archive_date is not null
                        /* Print out the modes, if rft = image */
                        and hrs_row.detector = @hsr_detector
                order by hrs_file.useafter_date
                for read only

                open stop_date_cursor

                fetch stop_date_cursor into @stop_date

                if (@@sqlstatus <> 0)  /* no stop date found-use todays date*/

                        select @stop_date = getdate()

                close stop_date_cursor

                deallocate cursor stop_date_cursor


                declare qin_update_cursor cursor for
                select hsr_dqihfile
                  /* Modes aren't added to the select list, if rft = image */
                from hrs_ref_data
                where hsr_expstart >= @useafter_date
                and hsr_expstart < @stop_date
                  /* Add modes to the where clause, if rft = image */
                        and hsr_detector = @hsr_detector
                for update

                open qin_update_cursor

                fetch qin_update_cursor into @hsr_dqihfile
                  /* Don't add modes to the fetch statement, if rft = image */

                while (@@sqlstatus = 0) /* While more qin files */

                begin
/*++++++++++++++++++++++++++++++++++++++++++++++++++++++++++++++++++++++++++++++*/
                  if (@hsr_dqihfile = NULL)  /* no file was used in pipeline */
                        select @hsr_best_loc_qin = "N/A"
                  else if (@new_file_name = @hsr_dqihfile)  /* recommended = was used, if rft = image or table */
                        select @hsr_best_loc_qin = "NO CHANGE"
                  else
                        if (@equiv_sev = -1)
                        select @hsr_best_loc_qin = 'UNKNOWN'
                  else   /* recommended <> was used - compute level of change */
                    begin
                        select        @orig_equiv_sev = hrs_row.equivalence_class_severe,
                                @orig_equiv_mod = hrs_row.equivalence_class_moderate
                        from        hrs_row hrs_row
                        where        hrs_row.file_name = @hsr_dqihfile
                        and hrs_row.detector = @hsr_detector
 

                        if (@orig_equiv_sev = -1)
                        select @hsr_best_loc_qin = 'UNKNOWN'
                        else if ((@equiv_sev - @orig_equiv_sev) <> 0)
                                select @hsr_best_loc_qin = "SEVERE"
                        else if ((@equiv_mod - @orig_equiv_mod) <> 0)
                                select @hsr_best_loc_qin = "MODERATE"
                             else select @hsr_best_loc_qin = "TRIVIAL"
 
                    end      /*else*/
 
                   /* update row */
                   update hrs_ref_data
                   set hsr_best_qin= @new_file_name, /* if rft = image or table */
                       hsr_best_loc_qin = @hsr_best_loc_qin
                   where  current of qin_update_cursor
        
                  fetch qin_update_cursor into @hsr_dqihfile
                  /* Don't print modes, if rft = image */
 

                end /* while more qin files */

                close qin_update_cursor

                deallocate cursor qin_update_cursor
        end /* if @ref_type = 'QIN') */


        if (@ref_type = 'SAA')
        begin
                        /* get first non-rejected file that has a */
                        /* useafter_date that is greater than the */
                        /* new files useafter_date - use for stop window */
                declare stop_date_cursor cursor for
                select  hrs_file.useafter_date
                from hrs_file hrs_file, hrs_row hrs_row
                        where hrs_row.file_name = hrs_file.file_name
                        and hrs_row.expansion_number = hrs_file.expansion_number
                        and hrs_file.reference_file_type = "SAA"
                        and hrs_file.reject_flag = "N"
                        and hrs_file.opus_flag = "Y"
                        and hrs_file.useafter_date > @useafter_date
                        and hrs_file.archive_date is not null
                        /* Print out the modes, if rft = image */
                order by hrs_file.useafter_date
                for read only

                open stop_date_cursor

                fetch stop_date_cursor into @stop_date

                if (@@sqlstatus <> 0)  /* no stop date found-use todays date*/

                        select @stop_date = getdate()

                close stop_date_cursor

                deallocate cursor stop_date_cursor


                declare saa_update_cursor cursor for
                select hsr_saahfile
                  /* Modes aren't added to the select list, if rft = image */
                from hrs_ref_data
                where hsr_expstart >= @useafter_date
                and hsr_expstart < @stop_date
                  /* Add modes to the where clause, if rft = image */
                for update

                open saa_update_cursor

                fetch saa_update_cursor into @hsr_saahfile
                  /* Don't add modes to the fetch statement, if rft = image */

                while (@@sqlstatus = 0) /* While more saa files */

                begin
/*++++++++++++++++++++++++++++++++++++++++++++++++++++++++++++++++++++++++++++++*/
                  if (@hsr_saahfile = NULL)  /* no file was used in pipeline */
                        select @hsr_best_loc_saa = "N/A"
                  else if (@new_file_name = @hsr_saahfile)  /* recommended = was used, if rft = image or table */
                        select @hsr_best_loc_saa = "NO CHANGE"
                  else
                        if (@equiv_sev = -1)
                        select @hsr_best_loc_saa = 'UNKNOWN'
                  else   /* recommended <> was used - compute level of change */
                    begin
                        select        @orig_equiv_sev = hrs_row.equivalence_class_severe,
                                @orig_equiv_mod = hrs_row.equivalence_class_moderate
                        from        hrs_row hrs_row
                        where        hrs_row.file_name = @hsr_saahfile
 

                        if (@orig_equiv_sev = -1)
                        select @hsr_best_loc_saa = 'UNKNOWN'
                        else if ((@equiv_sev - @orig_equiv_sev) <> 0)
                                select @hsr_best_loc_saa = "SEVERE"
                        else if ((@equiv_mod - @orig_equiv_mod) <> 0)
                                select @hsr_best_loc_saa = "MODERATE"
                             else select @hsr_best_loc_saa = "TRIVIAL"
 
                    end      /*else*/
 
                   /* update row */
                   update hrs_ref_data
                   set hsr_best_saa= @new_file_name, /* if rft = image or table */
                       hsr_best_loc_saa = @hsr_best_loc_saa
                   where  current of saa_update_cursor
        
                  fetch saa_update_cursor into @hsr_saahfile
                  /* Don't print modes, if rft = image */
 

                end /* while more saa files */

                close saa_update_cursor

                deallocate cursor saa_update_cursor
        end /* if @ref_type = 'SAA') */


        if (@ref_type = 'VIG')
        begin
                        /* get first non-rejected file that has a */
                        /* useafter_date that is greater than the */
                        /* new files useafter_date - use for stop window */
                declare stop_date_cursor cursor for
                select  hrs_file.useafter_date
                from hrs_file hrs_file, hrs_row hrs_row
                        where hrs_row.file_name = hrs_file.file_name
                        and hrs_row.expansion_number = hrs_file.expansion_number
                        and hrs_file.reference_file_type = "VIG"
                        and hrs_file.reject_flag = "N"
                        and hrs_file.opus_flag = "Y"
                        and hrs_file.useafter_date > @useafter_date
                        and hrs_file.archive_date is not null
                        /* Print out the modes, if rft = image */
                        and hrs_row.grating = @hsr_grating
                order by hrs_file.useafter_date
                for read only

                open stop_date_cursor

                fetch stop_date_cursor into @stop_date

                if (@@sqlstatus <> 0)  /* no stop date found-use todays date*/

                        select @stop_date = getdate()

                close stop_date_cursor

                deallocate cursor stop_date_cursor


                declare vig_update_cursor cursor for
                select hsr_vighfile
                  /* Modes aren't added to the select list, if rft = image */
                from hrs_ref_data
                where hsr_expstart >= @useafter_date
                and hsr_expstart < @stop_date
                  /* Add modes to the where clause, if rft = image */
                        and hsr_grating = @hsr_grating
                for update

                open vig_update_cursor

                fetch vig_update_cursor into @hsr_vighfile
                  /* Don't add modes to the fetch statement, if rft = image */

                while (@@sqlstatus = 0) /* While more vig files */

                begin
/*++++++++++++++++++++++++++++++++++++++++++++++++++++++++++++++++++++++++++++++*/
                  if (@hsr_vighfile = NULL)  /* no file was used in pipeline */
                        select @hsr_best_loc_vig = "N/A"
                  else if (@new_file_name = @hsr_vighfile)  /* recommended = was used, if rft = image or table */
                        select @hsr_best_loc_vig = "NO CHANGE"
                  else
                        if (@equiv_sev = -1)
                        select @hsr_best_loc_vig = 'UNKNOWN'
                  else   /* recommended <> was used - compute level of change */
                    begin
                        select        @orig_equiv_sev = hrs_row.equivalence_class_severe,
                                @orig_equiv_mod = hrs_row.equivalence_class_moderate
                        from        hrs_row hrs_row
                        where        hrs_row.file_name = @hsr_vighfile
                        and hrs_row.grating = @hsr_grating
 

                        if (@orig_equiv_sev = -1)
                        select @hsr_best_loc_vig = 'UNKNOWN'
                        else if ((@equiv_sev - @orig_equiv_sev) <> 0)
                                select @hsr_best_loc_vig = "SEVERE"
                        else if ((@equiv_mod - @orig_equiv_mod) <> 0)
                                select @hsr_best_loc_vig = "MODERATE"
                             else select @hsr_best_loc_vig = "TRIVIAL"
 
                    end      /*else*/
 
                   /* update row */
                   update hrs_ref_data
                   set hsr_best_vig= @new_file_name, /* if rft = image or table */
                       hsr_best_loc_vig = @hsr_best_loc_vig
                   where  current of vig_update_cursor
        
                  fetch vig_update_cursor into @hsr_vighfile
                  /* Don't print modes, if rft = image */
 

                end /* while more vig files */

                close vig_update_cursor

                deallocate cursor vig_update_cursor
        end /* if @ref_type = 'VIG') */

fetch new_hrs_cursor into @new_file_name, @new_expansion_number

end /* while more newly delivered calibration files */

close new_hrs_cursor

deallocate cursor new_hrs_cursor
return
go
