use dadsops
go
drop procedure new_hsp
go
create procedure new_hsp as
/* newly delivered calibration files */
declare @new_file_name varchar(50)
declare @new_expansion_number int
declare @ref_type varchar(50)
declare @useafter_date datetime
declare @stop_date datetime
/* observation start time */
declare @expstart datetime
/* data set name, to be used for error checking/handling, should extract */
/* datatype from dt_mapping rather than hardcode it here, this will do for now */
declare @data_set_name varchar(39)
/* severity level variables, to be reused for each reference file type */
declare @orig_equiv_sev int
declare @orig_equiv_mod int
declare @equiv_sev int
declare @equiv_mod int
/* used to store @@rowcount global variable */
declare @num_cal_files int
/* observation modes, calibration files used in the pipeline, */
/* best, and best_loc files */
declare @hpr_thresh int
declare @hpr_voltage int
declare @hpr_ccp0 char(18)
declare @hpr_ccp1 char(18)
declare @hpr_ccp2 char(18)
declare @hpr_ccp3 char(18)
declare @hpr_ccp4 char(18)
declare @hpr_ccp5 char(18)
declare @hpr_ccp7 char(18)
declare @hpr_ccp8 char(18)
declare @hpr_ccp9 char(18)
declare @hpr_vgaind int
declare @hpr_comptab char(18)
declare @hpr_data_typ char(7)
declare @hpr_apertobj char(10)
declare @hpr_detectob int
declare @hpr_graphtab char(18)
declare @hpr_best_ccp0 char(18)
declare @hpr_best_ccp1 char(18)
declare @hpr_best_ccp2 char(18)
declare @hpr_best_ccp3 char(18)
declare @hpr_best_ccp4 char(18)
declare @hpr_best_ccp5 char(18)
declare @hpr_best_ccp7 char(18)
declare @hpr_best_ccp8 char(18)
declare @hpr_best_ccp9 char(18)
declare @hpr_best_comptab char(18)
declare @hpr_best_graphtab char(18)
declare @hpr_best_loc_ccp0 varchar(9)
declare @hpr_best_loc_ccp1 varchar(9)
declare @hpr_best_loc_ccp2 varchar(9)
declare @hpr_best_loc_ccp3 varchar(9)
declare @hpr_best_loc_ccp4 varchar(9)
declare @hpr_best_loc_ccp5 varchar(9)
declare @hpr_best_loc_ccp7 varchar(9)
declare @hpr_best_loc_ccp8 varchar(9)
declare @hpr_best_loc_ccp9 varchar(9)

/**************************************************************************/
/************************ New   hsp ***********************/
/**************************************************************************/

declare new_hsp_cursor cursor for
        select  file_name, expansion_number
        from    new_cal_files
        where   instrument = 'HSP'
for read only

open new_hsp_cursor

fetch new_hsp_cursor into @new_file_name, @new_expansion_number

while (@@sqlstatus = 0)/* more newly delivered calibration files*/
begin

select @ref_type = hsp_file.reference_file_type,
@useafter_date = hsp_file.useafter_date,
@equiv_sev = hsp_row.equivalence_class_severe,
@equiv_mod = hsp_row.equivalence_class_moderate
,@hpr_data_typ=hsp_row.type
,@hpr_thresh=hsp_row.thresh
,@hpr_vgaind=hsp_row.vgaind
,@hpr_detectob=hsp_row.det_num
,@hpr_voltage=hsp_row.voltage
,@hpr_apertobj=hsp_row.aper_name
from hsp_file hsp_file, hsp_row hsp_row
where hsp_file.file_name = @new_file_name 
and hsp_row.file_name = @new_file_name
and hsp_file.expansion_number = @new_expansion_number
and hsp_row.expansion_number = @new_expansion_number


        if (@ref_type = 'CCP0')
        begin
                        /* get first non-rejected file that has a */
                        /* useafter_date that is greater than the */
                        /* new files useafter_date - use for stop window */
                declare stop_date_cursor cursor for
                select  hsp_file.useafter_date
                from hsp_file hsp_file, hsp_row hsp_row
                        where hsp_row.file_name = hsp_file.file_name
                        and hsp_row.expansion_number = hsp_file.expansion_number
                        and hsp_file.reference_file_type = "CCP0"
                        and hsp_file.reject_flag = "N"
                        and hsp_file.opus_flag = "Y"
                        and hsp_file.useafter_date > @useafter_date
                        and hsp_file.archive_date is not null
/* The reference file type is table, don't print out the modes */
                order by hsp_file.useafter_date
                for read only

                open stop_date_cursor

                fetch stop_date_cursor into @stop_date

                if (@@sqlstatus <> 0)  /* no stop date found-use todays date*/

                        select @stop_date = getdate()

                close stop_date_cursor

                deallocate cursor stop_date_cursor


                declare ccp0_update_cursor cursor for
                select hpr_ccp0
                  /* Add modes to the select list, if rft = table */
                ,hpr_apertobj
                from hsp_ref_data
                where hpr_expstart >= @useafter_date
                and hpr_expstart < @stop_date
                  /* Modes aren't added to the where clause, if rft = table */
                for update

                open ccp0_update_cursor

                fetch ccp0_update_cursor into @hpr_ccp0
                  /* Add modes to the fetch statement, if rft = table */
                ,@hpr_apertobj

                while (@@sqlstatus = 0) /* While more ccp0 files */

                begin
/* The following section, surrounded by ++++'s, if rft = table */
/*++++++++++++++++++++++++++++++++++++++++++++++++++++++++++++++++++++++++++++++*/
                        select @equiv_sev = hsp_row.equivalence_class_severe,
                                @equiv_mod = hsp_row.equivalence_class_moderate
                        from hsp_row hsp_row
                        where hsp_row.file_name = @new_file_name
                        and hsp_row.expansion_number = @new_expansion_number
                        and hsp_row.aper_name = @hpr_apertobj

                select @num_cal_files = @@rowcount
                if (@num_cal_files <> 0)	/* recommended file found */
                begin
/*++++++++++++++++++++++++++++++++++++++++++++++++++++++++++++++++++++++++++++++*/
                  if (@hpr_ccp0 = NULL)  /* no file was used in pipeline */
                        select @hpr_best_loc_ccp0 = "N/A"
                  else if (@new_file_name = @hpr_ccp0)  /* recommended = was used, if rft = image or table */
                        select @hpr_best_loc_ccp0 = "NO CHANGE"
                  else
                        if (@equiv_sev = -1)
                        select @hpr_best_loc_ccp0 = 'UNKNOWN'
                  else   /* recommended <> was used - compute level of change */
                    begin
                        select        @orig_equiv_sev = hsp_row.equivalence_class_severe,
                                @orig_equiv_mod = hsp_row.equivalence_class_moderate
                        from        hsp_row hsp_row
                        where        hsp_row.file_name = @hpr_ccp0
                        and hsp_row.aper_name = @hpr_apertobj
 

                        if (@orig_equiv_sev = -1)
                        select @hpr_best_loc_ccp0 = 'UNKNOWN'
                        else if ((@equiv_sev - @orig_equiv_sev) <> 0)
                                select @hpr_best_loc_ccp0 = "SEVERE"
                        else if ((@equiv_mod - @orig_equiv_mod) <> 0)
                                select @hpr_best_loc_ccp0 = "MODERATE"
                             else select @hpr_best_loc_ccp0 = "TRIVIAL"
 
                    end      /*else*/
 
                   /* update row */
                   update hsp_ref_data
                   set hpr_best_ccp0= @new_file_name, /* if rft = image or table */
                       hpr_best_loc_ccp0 = @hpr_best_loc_ccp0
                   where  current of ccp0_update_cursor
        
                 end /* if recommended file found, if rft = table */
                  fetch ccp0_update_cursor into @hpr_ccp0
                  /* Print modes, if rft = table */
                ,@hpr_apertobj
 

                end /* while more ccp0 files */

                close ccp0_update_cursor

                deallocate cursor ccp0_update_cursor
        end /* if @ref_type = 'CCP0') */


        if (@ref_type = 'CCP1')
        begin
                        /* get first non-rejected file that has a */
                        /* useafter_date that is greater than the */
                        /* new files useafter_date - use for stop window */
                declare stop_date_cursor cursor for
                select  hsp_file.useafter_date
                from hsp_file hsp_file, hsp_row hsp_row
                        where hsp_row.file_name = hsp_file.file_name
                        and hsp_row.expansion_number = hsp_file.expansion_number
                        and hsp_file.reference_file_type = "CCP1"
                        and hsp_file.reject_flag = "N"
                        and hsp_file.opus_flag = "Y"
                        and hsp_file.useafter_date > @useafter_date
                        and hsp_file.archive_date is not null
/* The reference file type is table, don't print out the modes */
                order by hsp_file.useafter_date
                for read only

                open stop_date_cursor

                fetch stop_date_cursor into @stop_date

                if (@@sqlstatus <> 0)  /* no stop date found-use todays date*/

                        select @stop_date = getdate()

                close stop_date_cursor

                deallocate cursor stop_date_cursor


                declare ccp1_update_cursor cursor for
                select hpr_ccp1
                  /* Add modes to the select list, if rft = table */
                ,hpr_data_typ
                ,hpr_voltage
                ,hpr_detectob
                from hsp_ref_data
                where hpr_expstart >= @useafter_date
                and hpr_expstart < @stop_date
                  /* Modes aren't added to the where clause, if rft = table */
                for update

                open ccp1_update_cursor

                fetch ccp1_update_cursor into @hpr_ccp1
                  /* Add modes to the fetch statement, if rft = table */
                ,@hpr_data_typ
                ,@hpr_voltage
                ,@hpr_detectob

                while (@@sqlstatus = 0) /* While more ccp1 files */

                begin
/* The following section, surrounded by ++++'s, if rft = table */
/*++++++++++++++++++++++++++++++++++++++++++++++++++++++++++++++++++++++++++++++*/
                        select @equiv_sev = hsp_row.equivalence_class_severe,
                                @equiv_mod = hsp_row.equivalence_class_moderate
                        from hsp_row hsp_row
                        where hsp_row.file_name = @new_file_name
                        and hsp_row.expansion_number = @new_expansion_number
                        and hsp_row.type = @hpr_data_typ
                        and hsp_row.voltage = @hpr_voltage
                        and hsp_row.det_num = @hpr_detectob

                select @num_cal_files = @@rowcount
                if (@num_cal_files <> 0)	/* recommended file found */
                begin
/*++++++++++++++++++++++++++++++++++++++++++++++++++++++++++++++++++++++++++++++*/
                  if (@hpr_ccp1 = NULL)  /* no file was used in pipeline */
                        select @hpr_best_loc_ccp1 = "N/A"
                  else if (@new_file_name = @hpr_ccp1)  /* recommended = was used, if rft = image or table */
                        select @hpr_best_loc_ccp1 = "NO CHANGE"
                  else
                        if (@equiv_sev = -1)
                        select @hpr_best_loc_ccp1 = 'UNKNOWN'
                  else   /* recommended <> was used - compute level of change */
                    begin
                        select        @orig_equiv_sev = hsp_row.equivalence_class_severe,
                                @orig_equiv_mod = hsp_row.equivalence_class_moderate
                        from        hsp_row hsp_row
                        where        hsp_row.file_name = @hpr_ccp1
                        and hsp_row.type = @hpr_data_typ
                        and hsp_row.voltage = @hpr_voltage
                        and hsp_row.det_num = @hpr_detectob
 

                        if (@orig_equiv_sev = -1)
                        select @hpr_best_loc_ccp1 = 'UNKNOWN'
                        else if ((@equiv_sev - @orig_equiv_sev) <> 0)
                                select @hpr_best_loc_ccp1 = "SEVERE"
                        else if ((@equiv_mod - @orig_equiv_mod) <> 0)
                                select @hpr_best_loc_ccp1 = "MODERATE"
                             else select @hpr_best_loc_ccp1 = "TRIVIAL"
 
                    end      /*else*/
 
                   /* update row */
                   update hsp_ref_data
                   set hpr_best_ccp1= @new_file_name, /* if rft = image or table */
                       hpr_best_loc_ccp1 = @hpr_best_loc_ccp1
                   where  current of ccp1_update_cursor
        
                 end /* if recommended file found, if rft = table */
                  fetch ccp1_update_cursor into @hpr_ccp1
                  /* Print modes, if rft = table */
                ,@hpr_data_typ
                ,@hpr_voltage
                ,@hpr_detectob
 

                end /* while more ccp1 files */

                close ccp1_update_cursor

                deallocate cursor ccp1_update_cursor
        end /* if @ref_type = 'CCP1') */


        if (@ref_type = 'CCP2')
        begin
                        /* get first non-rejected file that has a */
                        /* useafter_date that is greater than the */
                        /* new files useafter_date - use for stop window */
                declare stop_date_cursor cursor for
                select  hsp_file.useafter_date
                from hsp_file hsp_file, hsp_row hsp_row
                        where hsp_row.file_name = hsp_file.file_name
                        and hsp_row.expansion_number = hsp_file.expansion_number
                        and hsp_file.reference_file_type = "CCP2"
                        and hsp_file.reject_flag = "N"
                        and hsp_file.opus_flag = "Y"
                        and hsp_file.useafter_date > @useafter_date
                        and hsp_file.archive_date is not null
/* The reference file type is table, don't print out the modes */
                order by hsp_file.useafter_date
                for read only

                open stop_date_cursor

                fetch stop_date_cursor into @stop_date

                if (@@sqlstatus <> 0)  /* no stop date found-use todays date*/

                        select @stop_date = getdate()

                close stop_date_cursor

                deallocate cursor stop_date_cursor


                declare ccp2_update_cursor cursor for
                select hpr_ccp2
                  /* Add modes to the select list, if rft = table */
                ,hpr_vgaind
                ,hpr_detectob
                from hsp_ref_data
                where hpr_expstart >= @useafter_date
                and hpr_expstart < @stop_date
                  /* Modes aren't added to the where clause, if rft = table */
                for update

                open ccp2_update_cursor

                fetch ccp2_update_cursor into @hpr_ccp2
                  /* Add modes to the fetch statement, if rft = table */
                ,@hpr_vgaind
                ,@hpr_detectob

                while (@@sqlstatus = 0) /* While more ccp2 files */

                begin
/* The following section, surrounded by ++++'s, if rft = table */
/*++++++++++++++++++++++++++++++++++++++++++++++++++++++++++++++++++++++++++++++*/
                        select @equiv_sev = hsp_row.equivalence_class_severe,
                                @equiv_mod = hsp_row.equivalence_class_moderate
                        from hsp_row hsp_row
                        where hsp_row.file_name = @new_file_name
                        and hsp_row.expansion_number = @new_expansion_number
                        and hsp_row.vgaind = @hpr_vgaind
                        and hsp_row.det_num = @hpr_detectob

                select @num_cal_files = @@rowcount
                if (@num_cal_files <> 0)	/* recommended file found */
                begin
/*++++++++++++++++++++++++++++++++++++++++++++++++++++++++++++++++++++++++++++++*/
                  if (@hpr_ccp2 = NULL)  /* no file was used in pipeline */
                        select @hpr_best_loc_ccp2 = "N/A"
                  else if (@new_file_name = @hpr_ccp2)  /* recommended = was used, if rft = image or table */
                        select @hpr_best_loc_ccp2 = "NO CHANGE"
                  else
                        if (@equiv_sev = -1)
                        select @hpr_best_loc_ccp2 = 'UNKNOWN'
                  else   /* recommended <> was used - compute level of change */
                    begin
                        select        @orig_equiv_sev = hsp_row.equivalence_class_severe,
                                @orig_equiv_mod = hsp_row.equivalence_class_moderate
                        from        hsp_row hsp_row
                        where        hsp_row.file_name = @hpr_ccp2
                        and hsp_row.vgaind = @hpr_vgaind
                        and hsp_row.det_num = @hpr_detectob
 

                        if (@orig_equiv_sev = -1)
                        select @hpr_best_loc_ccp2 = 'UNKNOWN'
                        else if ((@equiv_sev - @orig_equiv_sev) <> 0)
                                select @hpr_best_loc_ccp2 = "SEVERE"
                        else if ((@equiv_mod - @orig_equiv_mod) <> 0)
                                select @hpr_best_loc_ccp2 = "MODERATE"
                             else select @hpr_best_loc_ccp2 = "TRIVIAL"
 
                    end      /*else*/
 
                   /* update row */
                   update hsp_ref_data
                   set hpr_best_ccp2= @new_file_name, /* if rft = image or table */
                       hpr_best_loc_ccp2 = @hpr_best_loc_ccp2
                   where  current of ccp2_update_cursor
        
                 end /* if recommended file found, if rft = table */
                  fetch ccp2_update_cursor into @hpr_ccp2
                  /* Print modes, if rft = table */
                ,@hpr_vgaind
                ,@hpr_detectob
 

                end /* while more ccp2 files */

                close ccp2_update_cursor

                deallocate cursor ccp2_update_cursor
        end /* if @ref_type = 'CCP2') */


        if (@ref_type = 'CCP3')
        begin
                        /* get first non-rejected file that has a */
                        /* useafter_date that is greater than the */
                        /* new files useafter_date - use for stop window */
                declare stop_date_cursor cursor for
                select  hsp_file.useafter_date
                from hsp_file hsp_file, hsp_row hsp_row
                        where hsp_row.file_name = hsp_file.file_name
                        and hsp_row.expansion_number = hsp_file.expansion_number
                        and hsp_file.reference_file_type = "CCP3"
                        and hsp_file.reject_flag = "N"
                        and hsp_file.opus_flag = "Y"
                        and hsp_file.useafter_date > @useafter_date
                        and hsp_file.archive_date is not null
/* The reference file type is table, don't print out the modes */
                order by hsp_file.useafter_date
                for read only

                open stop_date_cursor

                fetch stop_date_cursor into @stop_date

                if (@@sqlstatus <> 0)  /* no stop date found-use todays date*/

                        select @stop_date = getdate()

                close stop_date_cursor

                deallocate cursor stop_date_cursor


                declare ccp3_update_cursor cursor for
                select hpr_ccp3
                  /* Add modes to the select list, if rft = table */
                ,hpr_data_typ
                ,hpr_detectob
                from hsp_ref_data
                where hpr_expstart >= @useafter_date
                and hpr_expstart < @stop_date
                  /* Modes aren't added to the where clause, if rft = table */
                for update

                open ccp3_update_cursor

                fetch ccp3_update_cursor into @hpr_ccp3
                  /* Add modes to the fetch statement, if rft = table */
                ,@hpr_data_typ
                ,@hpr_detectob

                while (@@sqlstatus = 0) /* While more ccp3 files */

                begin
/* The following section, surrounded by ++++'s, if rft = table */
/*++++++++++++++++++++++++++++++++++++++++++++++++++++++++++++++++++++++++++++++*/
                        select @equiv_sev = hsp_row.equivalence_class_severe,
                                @equiv_mod = hsp_row.equivalence_class_moderate
                        from hsp_row hsp_row
                        where hsp_row.file_name = @new_file_name
                        and hsp_row.expansion_number = @new_expansion_number
                        and hsp_row.type = @hpr_data_typ
                        and hsp_row.det_num = @hpr_detectob

                select @num_cal_files = @@rowcount
                if (@num_cal_files <> 0)	/* recommended file found */
                begin
/*++++++++++++++++++++++++++++++++++++++++++++++++++++++++++++++++++++++++++++++*/
                  if (@hpr_ccp3 = NULL)  /* no file was used in pipeline */
                        select @hpr_best_loc_ccp3 = "N/A"
                  else if (@new_file_name = @hpr_ccp3)  /* recommended = was used, if rft = image or table */
                        select @hpr_best_loc_ccp3 = "NO CHANGE"
                  else
                        if (@equiv_sev = -1)
                        select @hpr_best_loc_ccp3 = 'UNKNOWN'
                  else   /* recommended <> was used - compute level of change */
                    begin
                        select        @orig_equiv_sev = hsp_row.equivalence_class_severe,
                                @orig_equiv_mod = hsp_row.equivalence_class_moderate
                        from        hsp_row hsp_row
                        where        hsp_row.file_name = @hpr_ccp3
                        and hsp_row.type = @hpr_data_typ
                        and hsp_row.det_num = @hpr_detectob
 

                        if (@orig_equiv_sev = -1)
                        select @hpr_best_loc_ccp3 = 'UNKNOWN'
                        else if ((@equiv_sev - @orig_equiv_sev) <> 0)
                                select @hpr_best_loc_ccp3 = "SEVERE"
                        else if ((@equiv_mod - @orig_equiv_mod) <> 0)
                                select @hpr_best_loc_ccp3 = "MODERATE"
                             else select @hpr_best_loc_ccp3 = "TRIVIAL"
 
                    end      /*else*/
 
                   /* update row */
                   update hsp_ref_data
                   set hpr_best_ccp3= @new_file_name, /* if rft = image or table */
                       hpr_best_loc_ccp3 = @hpr_best_loc_ccp3
                   where  current of ccp3_update_cursor
        
                 end /* if recommended file found, if rft = table */
                  fetch ccp3_update_cursor into @hpr_ccp3
                  /* Print modes, if rft = table */
                ,@hpr_data_typ
                ,@hpr_detectob
 

                end /* while more ccp3 files */

                close ccp3_update_cursor

                deallocate cursor ccp3_update_cursor
        end /* if @ref_type = 'CCP3') */


        if (@ref_type = 'CCP4')
        begin
                        /* get first non-rejected file that has a */
                        /* useafter_date that is greater than the */
                        /* new files useafter_date - use for stop window */
                declare stop_date_cursor cursor for
                select  hsp_file.useafter_date
                from hsp_file hsp_file, hsp_row hsp_row
                        where hsp_row.file_name = hsp_file.file_name
                        and hsp_row.expansion_number = hsp_file.expansion_number
                        and hsp_file.reference_file_type = "CCP4"
                        and hsp_file.reject_flag = "N"
                        and hsp_file.opus_flag = "Y"
                        and hsp_file.useafter_date > @useafter_date
                        and hsp_file.archive_date is not null
/* The reference file type is table, don't print out the modes */
                order by hsp_file.useafter_date
                for read only

                open stop_date_cursor

                fetch stop_date_cursor into @stop_date

                if (@@sqlstatus <> 0)  /* no stop date found-use todays date*/

                        select @stop_date = getdate()

                close stop_date_cursor

                deallocate cursor stop_date_cursor


                declare ccp4_update_cursor cursor for
                select hpr_ccp4
                  /* Add modes to the select list, if rft = table */
                ,hpr_detectob
                ,hpr_apertobj
                from hsp_ref_data
                where hpr_expstart >= @useafter_date
                and hpr_expstart < @stop_date
                  /* Modes aren't added to the where clause, if rft = table */
                for update

                open ccp4_update_cursor

                fetch ccp4_update_cursor into @hpr_ccp4
                  /* Add modes to the fetch statement, if rft = table */
                ,@hpr_detectob
                ,@hpr_apertobj

                while (@@sqlstatus = 0) /* While more ccp4 files */

                begin
/* The following section, surrounded by ++++'s, if rft = table */
/*++++++++++++++++++++++++++++++++++++++++++++++++++++++++++++++++++++++++++++++*/
                        select @equiv_sev = hsp_row.equivalence_class_severe,
                                @equiv_mod = hsp_row.equivalence_class_moderate
                        from hsp_row hsp_row
                        where hsp_row.file_name = @new_file_name
                        and hsp_row.expansion_number = @new_expansion_number
                        and hsp_row.det_num = @hpr_detectob
                        and hsp_row.aper_name = @hpr_apertobj

                select @num_cal_files = @@rowcount
                if (@num_cal_files <> 0)	/* recommended file found */
                begin
/*++++++++++++++++++++++++++++++++++++++++++++++++++++++++++++++++++++++++++++++*/
                  if (@hpr_ccp4 = NULL)  /* no file was used in pipeline */
                        select @hpr_best_loc_ccp4 = "N/A"
                  else if (@new_file_name = @hpr_ccp4)  /* recommended = was used, if rft = image or table */
                        select @hpr_best_loc_ccp4 = "NO CHANGE"
                  else
                        if (@equiv_sev = -1)
                        select @hpr_best_loc_ccp4 = 'UNKNOWN'
                  else   /* recommended <> was used - compute level of change */
                    begin
                        select        @orig_equiv_sev = hsp_row.equivalence_class_severe,
                                @orig_equiv_mod = hsp_row.equivalence_class_moderate
                        from        hsp_row hsp_row
                        where        hsp_row.file_name = @hpr_ccp4
                        and hsp_row.det_num = @hpr_detectob
                        and hsp_row.aper_name = @hpr_apertobj
 

                        if (@orig_equiv_sev = -1)
                        select @hpr_best_loc_ccp4 = 'UNKNOWN'
                        else if ((@equiv_sev - @orig_equiv_sev) <> 0)
                                select @hpr_best_loc_ccp4 = "SEVERE"
                        else if ((@equiv_mod - @orig_equiv_mod) <> 0)
                                select @hpr_best_loc_ccp4 = "MODERATE"
                             else select @hpr_best_loc_ccp4 = "TRIVIAL"
 
                    end      /*else*/
 
                   /* update row */
                   update hsp_ref_data
                   set hpr_best_ccp4= @new_file_name, /* if rft = image or table */
                       hpr_best_loc_ccp4 = @hpr_best_loc_ccp4
                   where  current of ccp4_update_cursor
        
                 end /* if recommended file found, if rft = table */
                  fetch ccp4_update_cursor into @hpr_ccp4
                  /* Print modes, if rft = table */
                ,@hpr_detectob
                ,@hpr_apertobj
 

                end /* while more ccp4 files */

                close ccp4_update_cursor

                deallocate cursor ccp4_update_cursor
        end /* if @ref_type = 'CCP4') */


        if (@ref_type = 'CCP5')
        begin
                        /* get first non-rejected file that has a */
                        /* useafter_date that is greater than the */
                        /* new files useafter_date - use for stop window */
                declare stop_date_cursor cursor for
                select  hsp_file.useafter_date
                from hsp_file hsp_file, hsp_row hsp_row
                        where hsp_row.file_name = hsp_file.file_name
                        and hsp_row.expansion_number = hsp_file.expansion_number
                        and hsp_file.reference_file_type = "CCP5"
                        and hsp_file.reject_flag = "N"
                        and hsp_file.opus_flag = "Y"
                        and hsp_file.useafter_date > @useafter_date
                        and hsp_file.archive_date is not null
/* The reference file type is table, don't print out the modes */
                order by hsp_file.useafter_date
                for read only

                open stop_date_cursor

                fetch stop_date_cursor into @stop_date

                if (@@sqlstatus <> 0)  /* no stop date found-use todays date*/

                        select @stop_date = getdate()

                close stop_date_cursor

                deallocate cursor stop_date_cursor


                declare ccp5_update_cursor cursor for
                select hpr_ccp5
                  /* Add modes to the select list, if rft = table */
                from hsp_ref_data
                where hpr_expstart >= @useafter_date
                and hpr_expstart < @stop_date
                  /* Modes aren't added to the where clause, if rft = table */
                for update

                open ccp5_update_cursor

                fetch ccp5_update_cursor into @hpr_ccp5
                  /* Add modes to the fetch statement, if rft = table */

                while (@@sqlstatus = 0) /* While more ccp5 files */

                begin
/* The following section, surrounded by ++++'s, if rft = table */
/*++++++++++++++++++++++++++++++++++++++++++++++++++++++++++++++++++++++++++++++*/
                        select @equiv_sev = hsp_row.equivalence_class_severe,
                                @equiv_mod = hsp_row.equivalence_class_moderate
                        from hsp_row hsp_row
                        where hsp_row.file_name = @new_file_name
                        and hsp_row.expansion_number = @new_expansion_number

                select @num_cal_files = @@rowcount
                if (@num_cal_files <> 0)	/* recommended file found */
                begin
/*++++++++++++++++++++++++++++++++++++++++++++++++++++++++++++++++++++++++++++++*/
                  if (@hpr_ccp5 = NULL)  /* no file was used in pipeline */
                        select @hpr_best_loc_ccp5 = "N/A"
                  else if (@new_file_name = @hpr_ccp5)  /* recommended = was used, if rft = image or table */
                        select @hpr_best_loc_ccp5 = "NO CHANGE"
                  else
                        if (@equiv_sev = -1)
                        select @hpr_best_loc_ccp5 = 'UNKNOWN'
                  else   /* recommended <> was used - compute level of change */
                    begin
                        select        @orig_equiv_sev = hsp_row.equivalence_class_severe,
                                @orig_equiv_mod = hsp_row.equivalence_class_moderate
                        from        hsp_row hsp_row
                        where        hsp_row.file_name = @hpr_ccp5
 

                        if (@orig_equiv_sev = -1)
                        select @hpr_best_loc_ccp5 = 'UNKNOWN'
                        else if ((@equiv_sev - @orig_equiv_sev) <> 0)
                                select @hpr_best_loc_ccp5 = "SEVERE"
                        else if ((@equiv_mod - @orig_equiv_mod) <> 0)
                                select @hpr_best_loc_ccp5 = "MODERATE"
                             else select @hpr_best_loc_ccp5 = "TRIVIAL"
 
                    end      /*else*/
 
                   /* update row */
                   update hsp_ref_data
                   set hpr_best_ccp5= @new_file_name, /* if rft = image or table */
                       hpr_best_loc_ccp5 = @hpr_best_loc_ccp5
                   where  current of ccp5_update_cursor
        
                 end /* if recommended file found, if rft = table */
                  fetch ccp5_update_cursor into @hpr_ccp5
                  /* Print modes, if rft = table */
 

                end /* while more ccp5 files */

                close ccp5_update_cursor

                deallocate cursor ccp5_update_cursor
        end /* if @ref_type = 'CCP5') */


        if (@ref_type = 'CCP7')
        begin
                        /* get first non-rejected file that has a */
                        /* useafter_date that is greater than the */
                        /* new files useafter_date - use for stop window */
                declare stop_date_cursor cursor for
                select  hsp_file.useafter_date
                from hsp_file hsp_file, hsp_row hsp_row
                        where hsp_row.file_name = hsp_file.file_name
                        and hsp_row.expansion_number = hsp_file.expansion_number
                        and hsp_file.reference_file_type = "CCP7"
                        and hsp_file.reject_flag = "N"
                        and hsp_file.opus_flag = "Y"
                        and hsp_file.useafter_date > @useafter_date
                        and hsp_file.archive_date is not null
/* The reference file type is table, don't print out the modes */
                order by hsp_file.useafter_date
                for read only

                open stop_date_cursor

                fetch stop_date_cursor into @stop_date

                if (@@sqlstatus <> 0)  /* no stop date found-use todays date*/

                        select @stop_date = getdate()

                close stop_date_cursor

                deallocate cursor stop_date_cursor


                declare ccp7_update_cursor cursor for
                select hpr_ccp7
                  /* Add modes to the select list, if rft = table */
                ,hpr_vgaind
                ,hpr_detectob
                from hsp_ref_data
                where hpr_expstart >= @useafter_date
                and hpr_expstart < @stop_date
                  /* Modes aren't added to the where clause, if rft = table */
                for update

                open ccp7_update_cursor

                fetch ccp7_update_cursor into @hpr_ccp7
                  /* Add modes to the fetch statement, if rft = table */
                ,@hpr_vgaind
                ,@hpr_detectob

                while (@@sqlstatus = 0) /* While more ccp7 files */

                begin
/* The following section, surrounded by ++++'s, if rft = table */
/*++++++++++++++++++++++++++++++++++++++++++++++++++++++++++++++++++++++++++++++*/
                        select @equiv_sev = hsp_row.equivalence_class_severe,
                                @equiv_mod = hsp_row.equivalence_class_moderate
                        from hsp_row hsp_row
                        where hsp_row.file_name = @new_file_name
                        and hsp_row.expansion_number = @new_expansion_number
                        and hsp_row.vgaind = @hpr_vgaind
                        and hsp_row.det_num = @hpr_detectob

                select @num_cal_files = @@rowcount
                if (@num_cal_files <> 0)	/* recommended file found */
                begin
/*++++++++++++++++++++++++++++++++++++++++++++++++++++++++++++++++++++++++++++++*/
                  if (@hpr_ccp7 = NULL)  /* no file was used in pipeline */
                        select @hpr_best_loc_ccp7 = "N/A"
                  else if (@new_file_name = @hpr_ccp7)  /* recommended = was used, if rft = image or table */
                        select @hpr_best_loc_ccp7 = "NO CHANGE"
                  else
                        if (@equiv_sev = -1)
                        select @hpr_best_loc_ccp7 = 'UNKNOWN'
                  else   /* recommended <> was used - compute level of change */
                    begin
                        select        @orig_equiv_sev = hsp_row.equivalence_class_severe,
                                @orig_equiv_mod = hsp_row.equivalence_class_moderate
                        from        hsp_row hsp_row
                        where        hsp_row.file_name = @hpr_ccp7
                        and hsp_row.vgaind = @hpr_vgaind
                        and hsp_row.det_num = @hpr_detectob
 

                        if (@orig_equiv_sev = -1)
                        select @hpr_best_loc_ccp7 = 'UNKNOWN'
                        else if ((@equiv_sev - @orig_equiv_sev) <> 0)
                                select @hpr_best_loc_ccp7 = "SEVERE"
                        else if ((@equiv_mod - @orig_equiv_mod) <> 0)
                                select @hpr_best_loc_ccp7 = "MODERATE"
                             else select @hpr_best_loc_ccp7 = "TRIVIAL"
 
                    end      /*else*/
 
                   /* update row */
                   update hsp_ref_data
                   set hpr_best_ccp7= @new_file_name, /* if rft = image or table */
                       hpr_best_loc_ccp7 = @hpr_best_loc_ccp7
                   where  current of ccp7_update_cursor
        
                 end /* if recommended file found, if rft = table */
                  fetch ccp7_update_cursor into @hpr_ccp7
                  /* Print modes, if rft = table */
                ,@hpr_vgaind
                ,@hpr_detectob
 

                end /* while more ccp7 files */

                close ccp7_update_cursor

                deallocate cursor ccp7_update_cursor
        end /* if @ref_type = 'CCP7') */


        if (@ref_type = 'CCP8')
        begin
                        /* get first non-rejected file that has a */
                        /* useafter_date that is greater than the */
                        /* new files useafter_date - use for stop window */
                declare stop_date_cursor cursor for
                select  hsp_file.useafter_date
                from hsp_file hsp_file, hsp_row hsp_row
                        where hsp_row.file_name = hsp_file.file_name
                        and hsp_row.expansion_number = hsp_file.expansion_number
                        and hsp_file.reference_file_type = "CCP8"
                        and hsp_file.reject_flag = "N"
                        and hsp_file.opus_flag = "Y"
                        and hsp_file.useafter_date > @useafter_date
                        and hsp_file.archive_date is not null
/* The reference file type is table, don't print out the modes */
                order by hsp_file.useafter_date
                for read only

                open stop_date_cursor

                fetch stop_date_cursor into @stop_date

                if (@@sqlstatus <> 0)  /* no stop date found-use todays date*/

                        select @stop_date = getdate()

                close stop_date_cursor

                deallocate cursor stop_date_cursor


                declare ccp8_update_cursor cursor for
                select hpr_ccp8
                  /* Add modes to the select list, if rft = table */
                ,hpr_thresh
                ,hpr_voltage
                ,hpr_detectob
                from hsp_ref_data
                where hpr_expstart >= @useafter_date
                and hpr_expstart < @stop_date
                  /* Modes aren't added to the where clause, if rft = table */
                for update

                open ccp8_update_cursor

                fetch ccp8_update_cursor into @hpr_ccp8
                  /* Add modes to the fetch statement, if rft = table */
                ,@hpr_thresh
                ,@hpr_voltage
                ,@hpr_detectob

                while (@@sqlstatus = 0) /* While more ccp8 files */

                begin
/* The following section, surrounded by ++++'s, if rft = table */
/*++++++++++++++++++++++++++++++++++++++++++++++++++++++++++++++++++++++++++++++*/
                        select @equiv_sev = hsp_row.equivalence_class_severe,
                                @equiv_mod = hsp_row.equivalence_class_moderate
                        from hsp_row hsp_row
                        where hsp_row.file_name = @new_file_name
                        and hsp_row.expansion_number = @new_expansion_number
                        and hsp_row.thresh = @hpr_thresh
                        and hsp_row.voltage = @hpr_voltage
                        and hsp_row.det_num = @hpr_detectob

                select @num_cal_files = @@rowcount
                if (@num_cal_files <> 0)	/* recommended file found */
                begin
/*++++++++++++++++++++++++++++++++++++++++++++++++++++++++++++++++++++++++++++++*/
                  if (@hpr_ccp8 = NULL)  /* no file was used in pipeline */
                        select @hpr_best_loc_ccp8 = "N/A"
                  else if (@new_file_name = @hpr_ccp8)  /* recommended = was used, if rft = image or table */
                        select @hpr_best_loc_ccp8 = "NO CHANGE"
                  else
                        if (@equiv_sev = -1)
                        select @hpr_best_loc_ccp8 = 'UNKNOWN'
                  else   /* recommended <> was used - compute level of change */
                    begin
                        select        @orig_equiv_sev = hsp_row.equivalence_class_severe,
                                @orig_equiv_mod = hsp_row.equivalence_class_moderate
                        from        hsp_row hsp_row
                        where        hsp_row.file_name = @hpr_ccp8
                        and hsp_row.thresh = @hpr_thresh
                        and hsp_row.voltage = @hpr_voltage
                        and hsp_row.det_num = @hpr_detectob
 

                        if (@orig_equiv_sev = -1)
                        select @hpr_best_loc_ccp8 = 'UNKNOWN'
                        else if ((@equiv_sev - @orig_equiv_sev) <> 0)
                                select @hpr_best_loc_ccp8 = "SEVERE"
                        else if ((@equiv_mod - @orig_equiv_mod) <> 0)
                                select @hpr_best_loc_ccp8 = "MODERATE"
                             else select @hpr_best_loc_ccp8 = "TRIVIAL"
 
                    end      /*else*/
 
                   /* update row */
                   update hsp_ref_data
                   set hpr_best_ccp8= @new_file_name, /* if rft = image or table */
                       hpr_best_loc_ccp8 = @hpr_best_loc_ccp8
                   where  current of ccp8_update_cursor
        
                 end /* if recommended file found, if rft = table */
                  fetch ccp8_update_cursor into @hpr_ccp8
                  /* Print modes, if rft = table */
                ,@hpr_thresh
                ,@hpr_voltage
                ,@hpr_detectob
 

                end /* while more ccp8 files */

                close ccp8_update_cursor

                deallocate cursor ccp8_update_cursor
        end /* if @ref_type = 'CCP8') */


        if (@ref_type = 'CCP9')
        begin
                        /* get first non-rejected file that has a */
                        /* useafter_date that is greater than the */
                        /* new files useafter_date - use for stop window */
                declare stop_date_cursor cursor for
                select  hsp_file.useafter_date
                from hsp_file hsp_file, hsp_row hsp_row
                        where hsp_row.file_name = hsp_file.file_name
                        and hsp_row.expansion_number = hsp_file.expansion_number
                        and hsp_file.reference_file_type = "CCP9"
                        and hsp_file.reject_flag = "N"
                        and hsp_file.opus_flag = "Y"
                        and hsp_file.useafter_date > @useafter_date
                        and hsp_file.archive_date is not null
/* The reference file type is table, don't print out the modes */
                order by hsp_file.useafter_date
                for read only

                open stop_date_cursor

                fetch stop_date_cursor into @stop_date

                if (@@sqlstatus <> 0)  /* no stop date found-use todays date*/

                        select @stop_date = getdate()

                close stop_date_cursor

                deallocate cursor stop_date_cursor


                declare ccp9_update_cursor cursor for
                select hpr_ccp9
                  /* Add modes to the select list, if rft = table */
                ,hpr_detectob
                ,hpr_apertobj
                from hsp_ref_data
                where hpr_expstart >= @useafter_date
                and hpr_expstart < @stop_date
                  /* Modes aren't added to the where clause, if rft = table */
                for update

                open ccp9_update_cursor

                fetch ccp9_update_cursor into @hpr_ccp9
                  /* Add modes to the fetch statement, if rft = table */
                ,@hpr_detectob
                ,@hpr_apertobj

                while (@@sqlstatus = 0) /* While more ccp9 files */

                begin
/* The following section, surrounded by ++++'s, if rft = table */
/*++++++++++++++++++++++++++++++++++++++++++++++++++++++++++++++++++++++++++++++*/
                        select @equiv_sev = hsp_row.equivalence_class_severe,
                                @equiv_mod = hsp_row.equivalence_class_moderate
                        from hsp_row hsp_row
                        where hsp_row.file_name = @new_file_name
                        and hsp_row.expansion_number = @new_expansion_number
                        and hsp_row.det_num = @hpr_detectob
                        and hsp_row.aper_name = @hpr_apertobj

                select @num_cal_files = @@rowcount
                if (@num_cal_files <> 0)	/* recommended file found */
                begin
/*++++++++++++++++++++++++++++++++++++++++++++++++++++++++++++++++++++++++++++++*/
                  if (@hpr_ccp9 = NULL)  /* no file was used in pipeline */
                        select @hpr_best_loc_ccp9 = "N/A"
                  else if (@new_file_name = @hpr_ccp9)  /* recommended = was used, if rft = image or table */
                        select @hpr_best_loc_ccp9 = "NO CHANGE"
                  else
                        if (@equiv_sev = -1)
                        select @hpr_best_loc_ccp9 = 'UNKNOWN'
                  else   /* recommended <> was used - compute level of change */
                    begin
                        select        @orig_equiv_sev = hsp_row.equivalence_class_severe,
                                @orig_equiv_mod = hsp_row.equivalence_class_moderate
                        from        hsp_row hsp_row
                        where        hsp_row.file_name = @hpr_ccp9
                        and hsp_row.det_num = @hpr_detectob
                        and hsp_row.aper_name = @hpr_apertobj
 

                        if (@orig_equiv_sev = -1)
                        select @hpr_best_loc_ccp9 = 'UNKNOWN'
                        else if ((@equiv_sev - @orig_equiv_sev) <> 0)
                                select @hpr_best_loc_ccp9 = "SEVERE"
                        else if ((@equiv_mod - @orig_equiv_mod) <> 0)
                                select @hpr_best_loc_ccp9 = "MODERATE"
                             else select @hpr_best_loc_ccp9 = "TRIVIAL"
 
                    end      /*else*/
 
                   /* update row */
                   update hsp_ref_data
                   set hpr_best_ccp9= @new_file_name, /* if rft = image or table */
                       hpr_best_loc_ccp9 = @hpr_best_loc_ccp9
                   where  current of ccp9_update_cursor
        
                 end /* if recommended file found, if rft = table */
                  fetch ccp9_update_cursor into @hpr_ccp9
                  /* Print modes, if rft = table */
                ,@hpr_detectob
                ,@hpr_apertobj
 

                end /* while more ccp9 files */

                close ccp9_update_cursor

                deallocate cursor ccp9_update_cursor
        end /* if @ref_type = 'CCP9') */

fetch new_hsp_cursor into @new_file_name, @new_expansion_number

end /* while more newly delivered calibration files */

close new_hsp_cursor

deallocate cursor new_hsp_cursor
 
/**************************************************************************/
/************************ New hsp : synphot *******************/
/**************************************************************************/
/* begin mod - OPR 35935 - 1/5/98 - Remove level of change computation */

declare new_synphot_cursor cursor for
        select  file_name, expansion_number
        from    new_cal_files
        where   instrument = 'SYNPHOT'
for read only

open new_synphot_cursor

fetch new_synphot_cursor into @new_file_name, @new_expansion_number

while (@@sqlstatus = 0)/* more newly delivered calibration files*/
begin

select @ref_type = synphot_file.reference_file_type,
@useafter_date = synphot_file.useafter_date
from synphot_file synphot_file
where synphot_file.file_name = @new_file_name 
and synphot_file.expansion_number = @new_expansion_number

        if (@ref_type = 'COMPTAB')
        begin
                        /* get first non-rejected file that has a */
                        /* useafter_date that is greater than the */
                        /* new files useafter_date - use for stop window */
                declare stop_date_cursor cursor for
                select synphot_file.useafter_date
                from synphot_file synphot_file, synphot_row synphot_row
                        where synphot_row.file_name = synphot_file.file_name
                        and synphot_row.expansion_number = synphot_file.expansion_number
                        and synphot_file.reference_file_type = "COMPTAB"
                        and synphot_file.reject_flag = "N"
                        and synphot_file.opus_flag = "Y"
                        and synphot_file.useafter_date > @useafter_date
                        and synphot_file.archive_date is not null
                order by synphot_file.useafter_date
                for read only

                open stop_date_cursor

                fetch stop_date_cursor into @stop_date

                if (@@sqlstatus <> 0)  /* no stop date found-use todays date*/

                        select @stop_date = getdate()

                close stop_date_cursor

                deallocate cursor stop_date_cursor


                declare comptab_update_cursor cursor for
                select hpr_comptab
                from hsp_ref_data
                where hpr_expstart >= @useafter_date
                and hpr_expstart < @stop_date
                for update

                open comptab_update_cursor

                fetch comptab_update_cursor into @hpr_comptab

                while (@@sqlstatus = 0) /* While more comptab files */
		begin

                   /* update row */
                   update hsp_ref_data
                   set hpr_best_comptab= @new_file_name
                   where  current of comptab_update_cursor
        
                  fetch comptab_update_cursor into @hpr_comptab
 
                end /* while more comptab files */

                close comptab_update_cursor

                deallocate cursor comptab_update_cursor
        end /* if @ref_type = 'COMPTAB') */


        if (@ref_type = 'GRAPHTAB')
        begin
                        /* get first non-rejected file that has a */
                        /* useafter_date that is greater than the */
                        /* new files useafter_date - use for stop window */
                declare stop_date_cursor cursor for
                select synphot_file.useafter_date
                from synphot_file synphot_file, synphot_row synphot_row
                        where synphot_row.file_name = synphot_file.file_name
                        and synphot_row.expansion_number = synphot_file.expansion_number
                        and synphot_file.reference_file_type = "GRAPHTAB"
                        and synphot_file.reject_flag = "N"
                        and synphot_file.opus_flag = "Y"
                        and synphot_file.useafter_date > @useafter_date
                        and synphot_file.archive_date is not null
                order by synphot_file.useafter_date
                for read only

                open stop_date_cursor

                fetch stop_date_cursor into @stop_date

                if (@@sqlstatus <> 0)  /* no stop date found-use todays date*/

                        select @stop_date = getdate()

                close stop_date_cursor

                deallocate cursor stop_date_cursor


                declare graphtab_update_cursor cursor for
                select hpr_graphtab
                from hsp_ref_data
                where hpr_expstart >= @useafter_date
                and hpr_expstart < @stop_date
                for update

                open graphtab_update_cursor

                fetch graphtab_update_cursor into @hpr_graphtab

                while (@@sqlstatus = 0) /* While more graphtab files */
		begin 
                   /* update row */
                   update hsp_ref_data
                   set hpr_best_graphtab= @new_file_name
                   where  current of graphtab_update_cursor
        
                  fetch graphtab_update_cursor into @hpr_graphtab

                end /* while more graphtab files */

                close graphtab_update_cursor

                deallocate cursor graphtab_update_cursor
        end /* if @ref_type = 'GRAPHTAB') */

fetch new_synphot_cursor into @new_file_name, @new_expansion_number

end /* while more newly delivered calibration files */

close new_synphot_cursor

deallocate cursor new_synphot_cursor
/* end mod */ 
return
go
