use dadsops
go
drop procedure new_nic
go
create procedure new_nic as
/* newly delivered calibration files */
declare @new_file_name varchar(50)
declare @new_expansion_number int
declare @ref_type varchar(50)
declare @useafter_date datetime
declare @stop_date datetime
/* observation start time */
declare @expstart datetime
/* data set name, to be used for error checking/handling, should extract */
/* datatype from dt_mapping rather than hardcode it here, this will do for now */
declare @data_set_name varchar(39)
/* severity level variables, to be reused for each reference file type */
declare @orig_equiv_sev int
declare @orig_equiv_mod int
declare @equiv_sev int
declare @equiv_mod int
/* used to store @@rowcount global variable */
declare @num_cal_files int
/* observation modes, calibration files used in the pipeline, */
/* best, and best_loc files */
declare @nsr_nread int
declare @nsr_camera int
declare @nsr_readout char(4)
declare @nsr_backtab char(18)
declare @nsr_phottab char(18)
declare @nsr_samp_seq char(8)
declare @nsr_darkfile char(18)
declare @nsr_filter varchar(7)
declare @nsr_flatfile char(18)
declare @nsr_illmfile char(18)
declare @nsr_maskfile char(18)
declare @nsr_nlinfile char(18)
declare @nsr_noisfile char(18)
declare @nsr_best_backtab char(18)
declare @nsr_best_phottab char(18)
declare @nsr_best_darkfile char(18)
declare @nsr_best_flatfile char(18)
declare @nsr_best_illmfile char(18)
declare @nsr_best_maskfile char(18)
declare @nsr_best_nlinfile char(18)
declare @nsr_best_noisfile char(18)
declare @nsr_best_loc_backtab varchar(9)
declare @nsr_best_loc_phottab varchar(9)
declare @nsr_best_loc_darkfile varchar(9)
declare @nsr_best_loc_flatfile varchar(9)
declare @nsr_best_loc_illmfile varchar(9)
declare @nsr_best_loc_maskfile varchar(9)
declare @nsr_best_loc_nlinfile varchar(9)
declare @nsr_best_loc_noisfile varchar(9)

/**************************************************************************/
/************************ New   nic ***********************/
/**************************************************************************/

declare new_nic_cursor cursor for
        select  file_name, expansion_number
        from    new_cal_files
        where   instrument = 'NIC'
for read only

open new_nic_cursor

fetch new_nic_cursor into @new_file_name, @new_expansion_number

while (@@sqlstatus = 0)/* more newly delivered calibration files*/
begin

select @ref_type = nic_file.reference_file_type,
@useafter_date = nic_file.useafter_date,
@equiv_sev = nic_row.equivalence_class_severe,
@equiv_mod = nic_row.equivalence_class_moderate
,@nsr_camera=nic_row.camera
,@nsr_filter=nic_row.filter
,@nsr_nread=nic_row.nread
,@nsr_readout=nic_row.readout
,@nsr_samp_seq=nic_row.samp_seq
from nic_file nic_file, nic_row nic_row
where nic_file.file_name = @new_file_name 
and nic_row.file_name = @new_file_name
and nic_file.expansion_number = @new_expansion_number
and nic_row.expansion_number = @new_expansion_number


        if (@ref_type = 'BKG')
        begin
                        /* get first non-rejected file that has a */
                        /* useafter_date that is greater than the */
                        /* new files useafter_date - use for stop window */
                declare stop_date_cursor cursor for
                select  nic_file.useafter_date
                from nic_file nic_file, nic_row nic_row
                        where nic_row.file_name = nic_file.file_name
                        and nic_row.expansion_number = nic_file.expansion_number
                        and nic_file.reference_file_type = "BKG"
                        and nic_file.reject_flag = "N"
                        and nic_file.opus_flag = "Y"
                        and nic_file.useafter_date > @useafter_date
                        and nic_file.archive_date is not null
/* The reference file type is table, don't print out the modes */
                order by nic_file.useafter_date
                for read only

                open stop_date_cursor

                fetch stop_date_cursor into @stop_date

                if (@@sqlstatus <> 0)  /* no stop date found-use todays date*/

                        select @stop_date = getdate()

                close stop_date_cursor

                deallocate cursor stop_date_cursor


                declare bkg_update_cursor cursor for
                select nsr_backtab
                  /* Add modes to the select list, if rft = table */
                ,nsr_camera
                ,nsr_filter
                from nicmos_ref_data
                where nsr_expstart >= @useafter_date
                and nsr_expstart < @stop_date
                  /* Modes aren't added to the where clause, if rft = table */
                for update

                open bkg_update_cursor

                fetch bkg_update_cursor into @nsr_backtab
                  /* Add modes to the fetch statement, if rft = table */
                ,@nsr_camera
                ,@nsr_filter

                while (@@sqlstatus = 0) /* While more bkg files */

                begin
/* The following section, surrounded by ++++'s, if rft = table */
/*++++++++++++++++++++++++++++++++++++++++++++++++++++++++++++++++++++++++++++++*/
                        select @equiv_sev = nic_row.equivalence_class_severe,
                                @equiv_mod = nic_row.equivalence_class_moderate
                        from nic_row nic_row
                        where nic_row.file_name = @new_file_name
                        and nic_row.expansion_number = @new_expansion_number
                        and nic_row.camera = @nsr_camera
                        and nic_row.filter = @nsr_filter

                select @num_cal_files = @@rowcount
                if (@num_cal_files <> 0)	/* recommended file found */
                begin
/*++++++++++++++++++++++++++++++++++++++++++++++++++++++++++++++++++++++++++++++*/
                  if (@nsr_backtab = NULL)  /* no file was used in pipeline */
                        select @nsr_best_loc_backtab = "N/A"
                  else if (@new_file_name = @nsr_backtab)  /* recommended = was used, if rft = image or table */
                        select @nsr_best_loc_backtab = "NO CHANGE"
                  else
                        if (@equiv_sev = -1)
                        select @nsr_best_loc_backtab = 'UNKNOWN'
                  else   /* recommended <> was used - compute level of change */
                    begin
                        select        @orig_equiv_sev = nic_row.equivalence_class_severe,
                                @orig_equiv_mod = nic_row.equivalence_class_moderate
                        from        nic_row nic_row
                        where        nic_row.file_name = @nsr_backtab
                        and nic_row.camera = @nsr_camera
                        and nic_row.filter = @nsr_filter
 

                        if (@orig_equiv_sev = -1)
                        select @nsr_best_loc_backtab = 'UNKNOWN'
                        else if ((@equiv_sev - @orig_equiv_sev) <> 0)
                                select @nsr_best_loc_backtab = "SEVERE"
                        else if ((@equiv_mod - @orig_equiv_mod) <> 0)
                                select @nsr_best_loc_backtab = "MODERATE"
                             else select @nsr_best_loc_backtab = "TRIVIAL"
 
                    end      /*else*/
 
                   /* update row */
                   update nicmos_ref_data
                   set nsr_best_backtab= @new_file_name, /* if rft = image or table */
                       nsr_best_loc_backtab = @nsr_best_loc_backtab
                   where  current of bkg_update_cursor
        
                 end /* if recommended file found, if rft = table */
                  fetch bkg_update_cursor into @nsr_backtab
                  /* Print modes, if rft = table */
                ,@nsr_camera
                ,@nsr_filter
 

                end /* while more bkg files */

                close bkg_update_cursor

                deallocate cursor bkg_update_cursor
        end /* if @ref_type = 'BKG') */


        if (@ref_type = 'PHT')
        begin
                        /* get first non-rejected file that has a */
                        /* useafter_date that is greater than the */
                        /* new files useafter_date - use for stop window */
                declare stop_date_cursor cursor for
                select  nic_file.useafter_date
                from nic_file nic_file, nic_row nic_row
                        where nic_row.file_name = nic_file.file_name
                        and nic_row.expansion_number = nic_file.expansion_number
                        and nic_file.reference_file_type = "PHT"
                        and nic_file.reject_flag = "N"
                        and nic_file.opus_flag = "Y"
                        and nic_file.useafter_date > @useafter_date
                        and nic_file.archive_date is not null
/* The reference file type is table, don't print out the modes */
                order by nic_file.useafter_date
                for read only

                open stop_date_cursor

                fetch stop_date_cursor into @stop_date

                if (@@sqlstatus <> 0)  /* no stop date found-use todays date*/

                        select @stop_date = getdate()

                close stop_date_cursor

                deallocate cursor stop_date_cursor


                declare pht_update_cursor cursor for
                select nsr_phottab
                  /* Add modes to the select list, if rft = table */
                from nicmos_ref_data
                where nsr_expstart >= @useafter_date
                and nsr_expstart < @stop_date
                  /* Modes aren't added to the where clause, if rft = table */
                for update

                open pht_update_cursor

                fetch pht_update_cursor into @nsr_phottab
                  /* Add modes to the fetch statement, if rft = table */

                while (@@sqlstatus = 0) /* While more pht files */

                begin
/* The following section, surrounded by ++++'s, if rft = table */
/*++++++++++++++++++++++++++++++++++++++++++++++++++++++++++++++++++++++++++++++*/
                        select @equiv_sev = nic_row.equivalence_class_severe,
                                @equiv_mod = nic_row.equivalence_class_moderate
                        from nic_row nic_row
                        where nic_row.file_name = @new_file_name
                        and nic_row.expansion_number = @new_expansion_number

                select @num_cal_files = @@rowcount
                if (@num_cal_files <> 0)	/* recommended file found */
                begin
/*++++++++++++++++++++++++++++++++++++++++++++++++++++++++++++++++++++++++++++++*/
                  if (@nsr_phottab = NULL)  /* no file was used in pipeline */
                        select @nsr_best_loc_phottab = "N/A"
                  else if (@new_file_name = @nsr_phottab)  /* recommended = was used, if rft = image or table */
                        select @nsr_best_loc_phottab = "NO CHANGE"
                  else
                        if (@equiv_sev = -1)
                        select @nsr_best_loc_phottab = 'UNKNOWN'
                  else   /* recommended <> was used - compute level of change */
                    begin
                        select        @orig_equiv_sev = nic_row.equivalence_class_severe,
                                @orig_equiv_mod = nic_row.equivalence_class_moderate
                        from        nic_row nic_row
                        where        nic_row.file_name = @nsr_phottab
 

                        if (@orig_equiv_sev = -1)
                        select @nsr_best_loc_phottab = 'UNKNOWN'
                        else if ((@equiv_sev - @orig_equiv_sev) <> 0)
                                select @nsr_best_loc_phottab = "SEVERE"
                        else if ((@equiv_mod - @orig_equiv_mod) <> 0)
                                select @nsr_best_loc_phottab = "MODERATE"
                             else select @nsr_best_loc_phottab = "TRIVIAL"
 
                    end      /*else*/
 
                   /* update row */
                   update nicmos_ref_data
                   set nsr_best_phottab= @new_file_name, /* if rft = image or table */
                       nsr_best_loc_phottab = @nsr_best_loc_phottab
                   where  current of pht_update_cursor
        
                 end /* if recommended file found, if rft = table */
                  fetch pht_update_cursor into @nsr_phottab
                  /* Print modes, if rft = table */
 

                end /* while more pht files */

                close pht_update_cursor

                deallocate cursor pht_update_cursor
        end /* if @ref_type = 'PHT') */


        if (@ref_type = 'DRK')
        begin
                        /* get first non-rejected file that has a */
                        /* useafter_date that is greater than the */
                        /* new files useafter_date - use for stop window */
                declare stop_date_cursor cursor for
                select  nic_file.useafter_date
                from nic_file nic_file, nic_row nic_row
                        where nic_row.file_name = nic_file.file_name
                        and nic_row.expansion_number = nic_file.expansion_number
                        and nic_file.reference_file_type = "DRK"
                        and nic_file.reject_flag = "N"
                        and nic_file.opus_flag = "Y"
                        and nic_file.useafter_date > @useafter_date
                        and nic_file.archive_date is not null
                        /* Print out the modes, if rft = image */
                        and nic_row.nread = @nsr_nread
                        and nic_row.camera = @nsr_camera
                        and nic_row.readout = @nsr_readout
                        and nic_row.samp_seq = @nsr_samp_seq
                order by nic_file.useafter_date
                for read only

                open stop_date_cursor

                fetch stop_date_cursor into @stop_date

                if (@@sqlstatus <> 0)  /* no stop date found-use todays date*/

                        select @stop_date = getdate()

                close stop_date_cursor

                deallocate cursor stop_date_cursor


                declare drk_update_cursor cursor for
                select nsr_darkfile
                  /* Modes aren't added to the select list, if rft = image */
                from nicmos_ref_data
                where nsr_expstart >= @useafter_date
                and nsr_expstart < @stop_date
                  /* Add modes to the where clause, if rft = image */
                        and nsr_nread = @nsr_nread
                        and nsr_camera = @nsr_camera
                        and nsr_readout = @nsr_readout
                        and nsr_samp_seq = @nsr_samp_seq
                for update

                open drk_update_cursor

                fetch drk_update_cursor into @nsr_darkfile
                  /* Don't add modes to the fetch statement, if rft = image */

                while (@@sqlstatus = 0) /* While more drk files */

                begin
/*++++++++++++++++++++++++++++++++++++++++++++++++++++++++++++++++++++++++++++++*/
                  if (@nsr_darkfile = NULL)  /* no file was used in pipeline */
                        select @nsr_best_loc_darkfile = "N/A"
                  else if (@new_file_name = @nsr_darkfile)  /* recommended = was used, if rft = image or table */
                        select @nsr_best_loc_darkfile = "NO CHANGE"
                  else
                        if (@equiv_sev = -1)
                        select @nsr_best_loc_darkfile = 'UNKNOWN'
                  else   /* recommended <> was used - compute level of change */
                    begin
                        select        @orig_equiv_sev = nic_row.equivalence_class_severe,
                                @orig_equiv_mod = nic_row.equivalence_class_moderate
                        from        nic_row nic_row
                        where        nic_row.file_name = @nsr_darkfile
                        and nic_row.nread = @nsr_nread
                        and nic_row.camera = @nsr_camera
                        and nic_row.readout = @nsr_readout
                        and nic_row.samp_seq = @nsr_samp_seq
 

                        if (@orig_equiv_sev = -1)
                        select @nsr_best_loc_darkfile = 'UNKNOWN'
                        else if ((@equiv_sev - @orig_equiv_sev) <> 0)
                                select @nsr_best_loc_darkfile = "SEVERE"
                        else if ((@equiv_mod - @orig_equiv_mod) <> 0)
                                select @nsr_best_loc_darkfile = "MODERATE"
                             else select @nsr_best_loc_darkfile = "TRIVIAL"
 
                    end      /*else*/
 
                   /* update row */
                   update nicmos_ref_data
                   set nsr_best_darkfile= @new_file_name, /* if rft = image or table */
                       nsr_best_loc_darkfile = @nsr_best_loc_darkfile
                   where  current of drk_update_cursor
        
                  fetch drk_update_cursor into @nsr_darkfile
                  /* Don't print modes, if rft = image */
 

                end /* while more drk files */

                close drk_update_cursor

                deallocate cursor drk_update_cursor
        end /* if @ref_type = 'DRK') */


        if (@ref_type = 'FLT')
        begin
                        /* get first non-rejected file that has a */
                        /* useafter_date that is greater than the */
                        /* new files useafter_date - use for stop window */
                declare stop_date_cursor cursor for
                select  nic_file.useafter_date
                from nic_file nic_file, nic_row nic_row
                        where nic_row.file_name = nic_file.file_name
                        and nic_row.expansion_number = nic_file.expansion_number
                        and nic_file.reference_file_type = "FLT"
                        and nic_file.reject_flag = "N"
                        and nic_file.opus_flag = "Y"
                        and nic_file.useafter_date > @useafter_date
                        and nic_file.archive_date is not null
                        /* Print out the modes, if rft = image */
                        and nic_row.camera = @nsr_camera
                        and nic_row.filter = @nsr_filter
                order by nic_file.useafter_date
                for read only

                open stop_date_cursor

                fetch stop_date_cursor into @stop_date

                if (@@sqlstatus <> 0)  /* no stop date found-use todays date*/

                        select @stop_date = getdate()

                close stop_date_cursor

                deallocate cursor stop_date_cursor


                declare flt_update_cursor cursor for
                select nsr_flatfile
                  /* Modes aren't added to the select list, if rft = image */
                from nicmos_ref_data
                where nsr_expstart >= @useafter_date
                and nsr_expstart < @stop_date
                  /* Add modes to the where clause, if rft = image */
                        and nsr_camera = @nsr_camera
                        and nsr_filter = @nsr_filter
                for update

                open flt_update_cursor

                fetch flt_update_cursor into @nsr_flatfile
                  /* Don't add modes to the fetch statement, if rft = image */

                while (@@sqlstatus = 0) /* While more flt files */

                begin
/*++++++++++++++++++++++++++++++++++++++++++++++++++++++++++++++++++++++++++++++*/
                  if (@nsr_flatfile = NULL)  /* no file was used in pipeline */
                        select @nsr_best_loc_flatfile = "N/A"
                  else if (@new_file_name = @nsr_flatfile)  /* recommended = was used, if rft = image or table */
                        select @nsr_best_loc_flatfile = "NO CHANGE"
                  else
                        if (@equiv_sev = -1)
                        select @nsr_best_loc_flatfile = 'UNKNOWN'
                  else   /* recommended <> was used - compute level of change */
                    begin
                        select        @orig_equiv_sev = nic_row.equivalence_class_severe,
                                @orig_equiv_mod = nic_row.equivalence_class_moderate
                        from        nic_row nic_row
                        where        nic_row.file_name = @nsr_flatfile
                        and nic_row.camera = @nsr_camera
                        and nic_row.filter = @nsr_filter
 

                        if (@orig_equiv_sev = -1)
                        select @nsr_best_loc_flatfile = 'UNKNOWN'
                        else if ((@equiv_sev - @orig_equiv_sev) <> 0)
                                select @nsr_best_loc_flatfile = "SEVERE"
                        else if ((@equiv_mod - @orig_equiv_mod) <> 0)
                                select @nsr_best_loc_flatfile = "MODERATE"
                             else select @nsr_best_loc_flatfile = "TRIVIAL"
 
                    end      /*else*/
 
                   /* update row */
                   update nicmos_ref_data
                   set nsr_best_flatfile= @new_file_name, /* if rft = image or table */
                       nsr_best_loc_flatfile = @nsr_best_loc_flatfile
                   where  current of flt_update_cursor
        
                  fetch flt_update_cursor into @nsr_flatfile
                  /* Don't print modes, if rft = image */
 

                end /* while more flt files */

                close flt_update_cursor

                deallocate cursor flt_update_cursor
        end /* if @ref_type = 'FLT') */


        if (@ref_type = 'ILM')
        begin
                        /* get first non-rejected file that has a */
                        /* useafter_date that is greater than the */
                        /* new files useafter_date - use for stop window */
                declare stop_date_cursor cursor for
                select  nic_file.useafter_date
                from nic_file nic_file, nic_row nic_row
                        where nic_row.file_name = nic_file.file_name
                        and nic_row.expansion_number = nic_file.expansion_number
                        and nic_file.reference_file_type = "ILM"
                        and nic_file.reject_flag = "N"
                        and nic_file.opus_flag = "Y"
                        and nic_file.useafter_date > @useafter_date
                        and nic_file.archive_date is not null
                        /* Print out the modes, if rft = image */
                        and nic_row.camera = @nsr_camera
                        and nic_row.filter = @nsr_filter
                order by nic_file.useafter_date
                for read only

                open stop_date_cursor

                fetch stop_date_cursor into @stop_date

                if (@@sqlstatus <> 0)  /* no stop date found-use todays date*/

                        select @stop_date = getdate()

                close stop_date_cursor

                deallocate cursor stop_date_cursor


                declare ilm_update_cursor cursor for
                select nsr_illmfile
                  /* Modes aren't added to the select list, if rft = image */
                from nicmos_ref_data
                where nsr_expstart >= @useafter_date
                and nsr_expstart < @stop_date
                  /* Add modes to the where clause, if rft = image */
                        and nsr_camera = @nsr_camera
                        and nsr_filter = @nsr_filter
                for update

                open ilm_update_cursor

                fetch ilm_update_cursor into @nsr_illmfile
                  /* Don't add modes to the fetch statement, if rft = image */

                while (@@sqlstatus = 0) /* While more ilm files */

                begin
/*++++++++++++++++++++++++++++++++++++++++++++++++++++++++++++++++++++++++++++++*/
                  if (@nsr_illmfile = NULL)  /* no file was used in pipeline */
                        select @nsr_best_loc_illmfile = "N/A"
                  else if (@new_file_name = @nsr_illmfile)  /* recommended = was used, if rft = image or table */
                        select @nsr_best_loc_illmfile = "NO CHANGE"
                  else
                        if (@equiv_sev = -1)
                        select @nsr_best_loc_illmfile = 'UNKNOWN'
                  else   /* recommended <> was used - compute level of change */
                    begin
                        select        @orig_equiv_sev = nic_row.equivalence_class_severe,
                                @orig_equiv_mod = nic_row.equivalence_class_moderate
                        from        nic_row nic_row
                        where        nic_row.file_name = @nsr_illmfile
                        and nic_row.camera = @nsr_camera
                        and nic_row.filter = @nsr_filter
 

                        if (@orig_equiv_sev = -1)
                        select @nsr_best_loc_illmfile = 'UNKNOWN'
                        else if ((@equiv_sev - @orig_equiv_sev) <> 0)
                                select @nsr_best_loc_illmfile = "SEVERE"
                        else if ((@equiv_mod - @orig_equiv_mod) <> 0)
                                select @nsr_best_loc_illmfile = "MODERATE"
                             else select @nsr_best_loc_illmfile = "TRIVIAL"
 
                    end      /*else*/
 
                   /* update row */
                   update nicmos_ref_data
                   set nsr_best_illmfile= @new_file_name, /* if rft = image or table */
                       nsr_best_loc_illmfile = @nsr_best_loc_illmfile
                   where  current of ilm_update_cursor
        
                  fetch ilm_update_cursor into @nsr_illmfile
                  /* Don't print modes, if rft = image */
 

                end /* while more ilm files */

                close ilm_update_cursor

                deallocate cursor ilm_update_cursor
        end /* if @ref_type = 'ILM') */


        if (@ref_type = 'LIN')
        begin
                        /* get first non-rejected file that has a */
                        /* useafter_date that is greater than the */
                        /* new files useafter_date - use for stop window */
                declare stop_date_cursor cursor for
                select  nic_file.useafter_date
                from nic_file nic_file, nic_row nic_row
                        where nic_row.file_name = nic_file.file_name
                        and nic_row.expansion_number = nic_file.expansion_number
                        and nic_file.reference_file_type = "LIN"
                        and nic_file.reject_flag = "N"
                        and nic_file.opus_flag = "Y"
                        and nic_file.useafter_date > @useafter_date
                        and nic_file.archive_date is not null
                        /* Print out the modes, if rft = image */
                        and nic_row.camera = @nsr_camera
                order by nic_file.useafter_date
                for read only

                open stop_date_cursor

                fetch stop_date_cursor into @stop_date

                if (@@sqlstatus <> 0)  /* no stop date found-use todays date*/

                        select @stop_date = getdate()

                close stop_date_cursor

                deallocate cursor stop_date_cursor


                declare lin_update_cursor cursor for
                select nsr_nlinfile
                  /* Modes aren't added to the select list, if rft = image */
                from nicmos_ref_data
                where nsr_expstart >= @useafter_date
                and nsr_expstart < @stop_date
                  /* Add modes to the where clause, if rft = image */
                        and nsr_camera = @nsr_camera
                for update

                open lin_update_cursor

                fetch lin_update_cursor into @nsr_nlinfile
                  /* Don't add modes to the fetch statement, if rft = image */

                while (@@sqlstatus = 0) /* While more lin files */

                begin
/*++++++++++++++++++++++++++++++++++++++++++++++++++++++++++++++++++++++++++++++*/
                  if (@nsr_nlinfile = NULL)  /* no file was used in pipeline */
                        select @nsr_best_loc_nlinfile = "N/A"
                  else if (@new_file_name = @nsr_nlinfile)  /* recommended = was used, if rft = image or table */
                        select @nsr_best_loc_nlinfile = "NO CHANGE"
                  else
                        if (@equiv_sev = -1)
                        select @nsr_best_loc_nlinfile = 'UNKNOWN'
                  else   /* recommended <> was used - compute level of change */
                    begin
                        select        @orig_equiv_sev = nic_row.equivalence_class_severe,
                                @orig_equiv_mod = nic_row.equivalence_class_moderate
                        from        nic_row nic_row
                        where        nic_row.file_name = @nsr_nlinfile
                        and nic_row.camera = @nsr_camera
 

                        if (@orig_equiv_sev = -1)
                        select @nsr_best_loc_nlinfile = 'UNKNOWN'
                        else if ((@equiv_sev - @orig_equiv_sev) <> 0)
                                select @nsr_best_loc_nlinfile = "SEVERE"
                        else if ((@equiv_mod - @orig_equiv_mod) <> 0)
                                select @nsr_best_loc_nlinfile = "MODERATE"
                             else select @nsr_best_loc_nlinfile = "TRIVIAL"
 
                    end      /*else*/
 
                   /* update row */
                   update nicmos_ref_data
                   set nsr_best_nlinfile= @new_file_name, /* if rft = image or table */
                       nsr_best_loc_nlinfile = @nsr_best_loc_nlinfile
                   where  current of lin_update_cursor
        
                  fetch lin_update_cursor into @nsr_nlinfile
                  /* Don't print modes, if rft = image */
 

                end /* while more lin files */

                close lin_update_cursor

                deallocate cursor lin_update_cursor
        end /* if @ref_type = 'LIN') */


        if (@ref_type = 'MSK')
        begin
                        /* get first non-rejected file that has a */
                        /* useafter_date that is greater than the */
                        /* new files useafter_date - use for stop window */
                declare stop_date_cursor cursor for
                select  nic_file.useafter_date
                from nic_file nic_file, nic_row nic_row
                        where nic_row.file_name = nic_file.file_name
                        and nic_row.expansion_number = nic_file.expansion_number
                        and nic_file.reference_file_type = "MSK"
                        and nic_file.reject_flag = "N"
                        and nic_file.opus_flag = "Y"
                        and nic_file.useafter_date > @useafter_date
                        and nic_file.archive_date is not null
                        /* Print out the modes, if rft = image */
                        and nic_row.camera = @nsr_camera
                order by nic_file.useafter_date
                for read only

                open stop_date_cursor

                fetch stop_date_cursor into @stop_date

                if (@@sqlstatus <> 0)  /* no stop date found-use todays date*/

                        select @stop_date = getdate()

                close stop_date_cursor

                deallocate cursor stop_date_cursor


                declare msk_update_cursor cursor for
                select nsr_maskfile
                  /* Modes aren't added to the select list, if rft = image */
                from nicmos_ref_data
                where nsr_expstart >= @useafter_date
                and nsr_expstart < @stop_date
                  /* Add modes to the where clause, if rft = image */
                        and nsr_camera = @nsr_camera
                for update

                open msk_update_cursor

                fetch msk_update_cursor into @nsr_maskfile
                  /* Don't add modes to the fetch statement, if rft = image */

                while (@@sqlstatus = 0) /* While more msk files */

                begin
/*++++++++++++++++++++++++++++++++++++++++++++++++++++++++++++++++++++++++++++++*/
                  if (@nsr_maskfile = NULL)  /* no file was used in pipeline */
                        select @nsr_best_loc_maskfile = "N/A"
                  else if (@new_file_name = @nsr_maskfile)  /* recommended = was used, if rft = image or table */
                        select @nsr_best_loc_maskfile = "NO CHANGE"
                  else
                        if (@equiv_sev = -1)
                        select @nsr_best_loc_maskfile = 'UNKNOWN'
                  else   /* recommended <> was used - compute level of change */
                    begin
                        select        @orig_equiv_sev = nic_row.equivalence_class_severe,
                                @orig_equiv_mod = nic_row.equivalence_class_moderate
                        from        nic_row nic_row
                        where        nic_row.file_name = @nsr_maskfile
                        and nic_row.camera = @nsr_camera
 

                        if (@orig_equiv_sev = -1)
                        select @nsr_best_loc_maskfile = 'UNKNOWN'
                        else if ((@equiv_sev - @orig_equiv_sev) <> 0)
                                select @nsr_best_loc_maskfile = "SEVERE"
                        else if ((@equiv_mod - @orig_equiv_mod) <> 0)
                                select @nsr_best_loc_maskfile = "MODERATE"
                             else select @nsr_best_loc_maskfile = "TRIVIAL"
 
                    end      /*else*/
 
                   /* update row */
                   update nicmos_ref_data
                   set nsr_best_maskfile= @new_file_name, /* if rft = image or table */
                       nsr_best_loc_maskfile = @nsr_best_loc_maskfile
                   where  current of msk_update_cursor
        
                  fetch msk_update_cursor into @nsr_maskfile
                  /* Don't print modes, if rft = image */
 

                end /* while more msk files */

                close msk_update_cursor

                deallocate cursor msk_update_cursor
        end /* if @ref_type = 'MSK') */


        if (@ref_type = 'NOI')
        begin
                        /* get first non-rejected file that has a */
                        /* useafter_date that is greater than the */
                        /* new files useafter_date - use for stop window */
                declare stop_date_cursor cursor for
                select  nic_file.useafter_date
                from nic_file nic_file, nic_row nic_row
                        where nic_row.file_name = nic_file.file_name
                        and nic_row.expansion_number = nic_file.expansion_number
                        and nic_file.reference_file_type = "NOI"
                        and nic_file.reject_flag = "N"
                        and nic_file.opus_flag = "Y"
                        and nic_file.useafter_date > @useafter_date
                        and nic_file.archive_date is not null
                        /* Print out the modes, if rft = image */
                        and nic_row.nread = @nsr_nread
                        and nic_row.camera = @nsr_camera
                        and nic_row.readout = @nsr_readout
                order by nic_file.useafter_date
                for read only

                open stop_date_cursor

                fetch stop_date_cursor into @stop_date

                if (@@sqlstatus <> 0)  /* no stop date found-use todays date*/

                        select @stop_date = getdate()

                close stop_date_cursor

                deallocate cursor stop_date_cursor


                declare noi_update_cursor cursor for
                select nsr_noisfile
                  /* Modes aren't added to the select list, if rft = image */
                from nicmos_ref_data
                where nsr_expstart >= @useafter_date
                and nsr_expstart < @stop_date
                  /* Add modes to the where clause, if rft = image */
                        and nsr_nread = @nsr_nread
                        and nsr_camera = @nsr_camera
                        and nsr_readout = @nsr_readout
                for update

                open noi_update_cursor

                fetch noi_update_cursor into @nsr_noisfile
                  /* Don't add modes to the fetch statement, if rft = image */

                while (@@sqlstatus = 0) /* While more noi files */

                begin
/*++++++++++++++++++++++++++++++++++++++++++++++++++++++++++++++++++++++++++++++*/
                  if (@nsr_noisfile = NULL)  /* no file was used in pipeline */
                        select @nsr_best_loc_noisfile = "N/A"
                  else if (@new_file_name = @nsr_noisfile)  /* recommended = was used, if rft = image or table */
                        select @nsr_best_loc_noisfile = "NO CHANGE"
                  else
                        if (@equiv_sev = -1)
                        select @nsr_best_loc_noisfile = 'UNKNOWN'
                  else   /* recommended <> was used - compute level of change */
                    begin
                        select        @orig_equiv_sev = nic_row.equivalence_class_severe,
                                @orig_equiv_mod = nic_row.equivalence_class_moderate
                        from        nic_row nic_row
                        where        nic_row.file_name = @nsr_noisfile
                        and nic_row.nread = @nsr_nread
                        and nic_row.camera = @nsr_camera
                        and nic_row.readout = @nsr_readout
 

                        if (@orig_equiv_sev = -1)
                        select @nsr_best_loc_noisfile = 'UNKNOWN'
                        else if ((@equiv_sev - @orig_equiv_sev) <> 0)
                                select @nsr_best_loc_noisfile = "SEVERE"
                        else if ((@equiv_mod - @orig_equiv_mod) <> 0)
                                select @nsr_best_loc_noisfile = "MODERATE"
                             else select @nsr_best_loc_noisfile = "TRIVIAL"
 
                    end      /*else*/
 
                   /* update row */
                   update nicmos_ref_data
                   set nsr_best_noisfile= @new_file_name, /* if rft = image or table */
                       nsr_best_loc_noisfile = @nsr_best_loc_noisfile
                   where  current of noi_update_cursor
        
                  fetch noi_update_cursor into @nsr_noisfile
                  /* Don't print modes, if rft = image */
 

                end /* while more noi files */

                close noi_update_cursor

                deallocate cursor noi_update_cursor
        end /* if @ref_type = 'NOI') */

fetch new_nic_cursor into @new_file_name, @new_expansion_number

end /* while more newly delivered calibration files */

close new_nic_cursor

deallocate cursor new_nic_cursor
return
go
