use dadsops
go
drop procedure new_wfpc
go
create procedure new_wfpc as
/* newly delivered calibration files */
declare @new_file_name varchar(50)
declare @new_expansion_number int
declare @ref_type varchar(50)
declare @useafter_date datetime
declare @stop_date datetime
/* observation start time */
declare @expstart datetime
/* data set name, to be used for error checking/handling, should extract */
/* datatype from dt_mapping rather than hardcode it here, this will do for now */
declare @data_set_name varchar(39)
/* severity level variables, to be reused for each reference file type */
declare @orig_equiv_sev int
declare @orig_equiv_mod int
declare @equiv_sev int
declare @equiv_mod int
/* used to store @@rowcount global variable */
declare @num_cal_files int
/* observation modes, calibration files used in the pipeline, */
/* best, and best_loc files */
declare @wcr_mode char(4)
declare @wcr_camera char(2)
declare @wcr_serials char(3)
declare @wcr_shutter char(7)
declare @wcr_filter1 int
declare @wcr_filter2 int
declare @wcr_phottab char(18)
declare @wcr_atodfile char(18)
declare @wcr_best_a2d char(18)
declare @wcr_best_bas char(18)
declare @wcr_best_drk char(18)
declare @wcr_best_flt char(18)
declare @wcr_best_msk char(18)
declare @wcr_best_prf char(18)
declare @wcr_best_pur char(18)
declare @wcr_biasfile char(18)
declare @wcr_darkfile char(18)
declare @wcr_flatfile char(18)
declare @wcr_maskfile char(18)
declare @wcr_preffile char(18)
declare @wcr_purgfile char(18)
declare @wcr_photmode_a varchar(48)  /* mod */
declare @wcr_photmode_b varchar(48)  /* mod */
declare @wcr_photmode_c varchar(48)  /* mod */
declare @wcr_photmode_d varchar(48)  /* mod */
declare @wcr_best_phottab char(18)
declare @wcr_best_loc_a2d varchar(9)
declare @wcr_best_loc_bas varchar(9)
declare @wcr_best_loc_drk varchar(9)
declare @wcr_best_loc_flt varchar(9)
declare @wcr_best_loc_msk varchar(9)
declare @wcr_best_loc_prf varchar(9)
declare @wcr_best_loc_pur varchar(9)
declare @wcr_best_loc_photmode_a varchar(9)  /*mod*/
declare @wcr_best_loc_photmode_b varchar(9)  /*mod*/
declare @wcr_best_loc_photmode_c varchar(9)  /*mod*/
declare @wcr_best_loc_photmode_d varchar(9)  /*mod*/

/**************************************************************************/
/************************ New   wfpc ***********************/
/**************************************************************************/

declare new_wfpc_cursor cursor for
        select  file_name, expansion_number
        from    new_cal_files
        where   instrument = 'WFPC'
for read only

open new_wfpc_cursor

fetch new_wfpc_cursor into @new_file_name, @new_expansion_number

while (@@sqlstatus = 0)/* more newly delivered calibration files*/
begin

select @ref_type = wfpc_file.reference_file_type,
@useafter_date = wfpc_file.useafter_date,
@equiv_sev = wfpc_row.equivalence_class_severe,
@equiv_mod = wfpc_row.equivalence_class_moderate
,@wcr_mode=wfpc_row.mode
,@wcr_serials=wfpc_row.clock
,@wcr_camera=wfpc_row.camera
,@wcr_filter1=wfpc_row.filter1
,@wcr_filter2=wfpc_row.filter2
,@wcr_shutter=wfpc_row.shutter
,@wcr_photmode_a=wfpc_row.photmode
from wfpc_file wfpc_file, wfpc_row wfpc_row
where wfpc_file.file_name = @new_file_name 
and wfpc_row.file_name = @new_file_name
and wfpc_file.expansion_number = @new_expansion_number
and wfpc_row.expansion_number = @new_expansion_number


        if (@ref_type = 'A2D')
        begin
                        /* get first non-rejected file that has a */
                        /* useafter_date that is greater than the */
                        /* new files useafter_date - use for stop window */
                declare stop_date_cursor cursor for
                select  wfpc_file.useafter_date
                from wfpc_file wfpc_file, wfpc_row wfpc_row
                        where wfpc_row.file_name = wfpc_file.file_name
                        and wfpc_row.expansion_number = wfpc_file.expansion_number
                        and wfpc_file.reference_file_type = "A2D"
                        and wfpc_file.reject_flag = "N"
                        and wfpc_file.opus_flag = "Y"
                        and wfpc_file.useafter_date > @useafter_date
                        and wfpc_file.archive_date is not null
                        /* Print out the modes, if rft = image */
                        and wfpc_row.mode = @wcr_mode
                        and wfpc_row.camera = @wcr_camera
                order by wfpc_file.useafter_date
                for read only

                open stop_date_cursor

                fetch stop_date_cursor into @stop_date

                if (@@sqlstatus <> 0)  /* no stop date found-use todays date*/

                        select @stop_date = getdate()

                close stop_date_cursor

                deallocate cursor stop_date_cursor


                declare a2d_update_cursor cursor for
                select wcr_atodfile
                  /* Modes aren't added to the select list, if rft = image */
                from wfpc_ref_data
                where wcr_expstart >= @useafter_date
                and wcr_expstart < @stop_date
                  /* Add modes to the where clause, if rft = image */
                        and wcr_mode = @wcr_mode
                        and wcr_camera = @wcr_camera
                for update

                open a2d_update_cursor

                fetch a2d_update_cursor into @wcr_atodfile
                  /* Don't add modes to the fetch statement, if rft = image */

                while (@@sqlstatus = 0) /* While more a2d files */

                begin
/*++++++++++++++++++++++++++++++++++++++++++++++++++++++++++++++++++++++++++++++*/
                  if (@wcr_atodfile = NULL)  /* no file was used in pipeline */
                        select @wcr_best_loc_a2d = "N/A"
                  else if (@new_file_name = @wcr_atodfile)  /* recommended = was used, if rft = image or table */
                        select @wcr_best_loc_a2d = "NO CHANGE"
                  else
                        if (@equiv_sev = -1)
                        select @wcr_best_loc_a2d = 'UNKNOWN'
                  else   /* recommended <> was used - compute level of change */
                    begin
                        select        @orig_equiv_sev = wfpc_row.equivalence_class_severe,
                                @orig_equiv_mod = wfpc_row.equivalence_class_moderate
                        from        wfpc_row wfpc_row
                        where        wfpc_row.file_name = @wcr_atodfile
                        and wfpc_row.mode = @wcr_mode
                        and wfpc_row.camera = @wcr_camera
 

                        if (@orig_equiv_sev = -1)
                        select @wcr_best_loc_a2d = 'UNKNOWN'
                        else if ((@equiv_sev - @orig_equiv_sev) <> 0)
                                select @wcr_best_loc_a2d = "SEVERE"
                        else if ((@equiv_mod - @orig_equiv_mod) <> 0)
                                select @wcr_best_loc_a2d = "MODERATE"
                             else select @wcr_best_loc_a2d = "TRIVIAL"
 
                    end      /*else*/
 
                   /* update row */
                   update wfpc_ref_data
                   set wcr_best_a2d= @new_file_name, /* if rft = image or table */
                       wcr_best_loc_a2d = @wcr_best_loc_a2d
                   where  current of a2d_update_cursor
        
                  fetch a2d_update_cursor into @wcr_atodfile
                  /* Don't print modes, if rft = image */
 

                end /* while more a2d files */

                close a2d_update_cursor

                deallocate cursor a2d_update_cursor
        end /* if @ref_type = 'A2D') */


        if (@ref_type = 'BAS')
        begin
                        /* get first non-rejected file that has a */
                        /* useafter_date that is greater than the */
                        /* new files useafter_date - use for stop window */
                declare stop_date_cursor cursor for
                select  wfpc_file.useafter_date
                from wfpc_file wfpc_file, wfpc_row wfpc_row
                        where wfpc_row.file_name = wfpc_file.file_name
                        and wfpc_row.expansion_number = wfpc_file.expansion_number
                        and wfpc_file.reference_file_type = "BAS"
                        and wfpc_file.reject_flag = "N"
                        and wfpc_file.opus_flag = "Y"
                        and wfpc_file.useafter_date > @useafter_date
                        and wfpc_file.archive_date is not null
                        /* Print out the modes, if rft = image */
                        and wfpc_row.mode = @wcr_mode
                        and wfpc_row.camera = @wcr_camera
                order by wfpc_file.useafter_date
                for read only

                open stop_date_cursor

                fetch stop_date_cursor into @stop_date

                if (@@sqlstatus <> 0)  /* no stop date found-use todays date*/

                        select @stop_date = getdate()

                close stop_date_cursor

                deallocate cursor stop_date_cursor


                declare bas_update_cursor cursor for
                select wcr_biasfile
                  /* Modes aren't added to the select list, if rft = image */
                from wfpc_ref_data
                where wcr_expstart >= @useafter_date
                and wcr_expstart < @stop_date
                  /* Add modes to the where clause, if rft = image */
                        and wcr_mode = @wcr_mode
                        and wcr_camera = @wcr_camera
                for update

                open bas_update_cursor

                fetch bas_update_cursor into @wcr_biasfile
                  /* Don't add modes to the fetch statement, if rft = image */

                while (@@sqlstatus = 0) /* While more bas files */

                begin
/*++++++++++++++++++++++++++++++++++++++++++++++++++++++++++++++++++++++++++++++*/
                  if (@wcr_biasfile = NULL)  /* no file was used in pipeline */
                        select @wcr_best_loc_bas = "N/A"
                  else if (@new_file_name = @wcr_biasfile)  /* recommended = was used, if rft = image or table */
                        select @wcr_best_loc_bas = "NO CHANGE"
                  else
                        if (@equiv_sev = -1)
                        select @wcr_best_loc_bas = 'UNKNOWN'
                  else   /* recommended <> was used - compute level of change */
                    begin
                        select        @orig_equiv_sev = wfpc_row.equivalence_class_severe,
                                @orig_equiv_mod = wfpc_row.equivalence_class_moderate
                        from        wfpc_row wfpc_row
                        where        wfpc_row.file_name = @wcr_biasfile
                        and wfpc_row.mode = @wcr_mode
                        and wfpc_row.camera = @wcr_camera
 

                        if (@orig_equiv_sev = -1)
                        select @wcr_best_loc_bas = 'UNKNOWN'
                        else if ((@equiv_sev - @orig_equiv_sev) <> 0)
                                select @wcr_best_loc_bas = "SEVERE"
                        else if ((@equiv_mod - @orig_equiv_mod) <> 0)
                                select @wcr_best_loc_bas = "MODERATE"
                             else select @wcr_best_loc_bas = "TRIVIAL"
 
                    end      /*else*/
 
                   /* update row */
                   update wfpc_ref_data
                   set wcr_best_bas= @new_file_name, /* if rft = image or table */
                       wcr_best_loc_bas = @wcr_best_loc_bas
                   where  current of bas_update_cursor
        
                  fetch bas_update_cursor into @wcr_biasfile
                  /* Don't print modes, if rft = image */
 

                end /* while more bas files */

                close bas_update_cursor

                deallocate cursor bas_update_cursor
        end /* if @ref_type = 'BAS') */


        if (@ref_type = 'DRK')
        begin
                        /* get first non-rejected file that has a */
                        /* useafter_date that is greater than the */
                        /* new files useafter_date - use for stop window */
                declare stop_date_cursor cursor for
                select  wfpc_file.useafter_date
                from wfpc_file wfpc_file, wfpc_row wfpc_row
                        where wfpc_row.file_name = wfpc_file.file_name
                        and wfpc_row.expansion_number = wfpc_file.expansion_number
                        and wfpc_file.reference_file_type = "DRK"
                        and wfpc_file.reject_flag = "N"
                        and wfpc_file.opus_flag = "Y"
                        and wfpc_file.useafter_date > @useafter_date
                        and wfpc_file.archive_date is not null
                        /* Print out the modes, if rft = image */
                        and wfpc_row.mode = @wcr_mode
                        and wfpc_row.camera = @wcr_camera
                        and wfpc_row.clock = @wcr_serials
                order by wfpc_file.useafter_date
                for read only

                open stop_date_cursor

                fetch stop_date_cursor into @stop_date

                if (@@sqlstatus <> 0)  /* no stop date found-use todays date*/

                        select @stop_date = getdate()

                close stop_date_cursor

                deallocate cursor stop_date_cursor


                declare drk_update_cursor cursor for
                select wcr_darkfile
                  /* Modes aren't added to the select list, if rft = image */
                from wfpc_ref_data
                where wcr_expstart >= @useafter_date
                and wcr_expstart < @stop_date
                  /* Add modes to the where clause, if rft = image */
                        and wcr_mode = @wcr_mode
                        and wcr_camera = @wcr_camera
                        and wcr_serials = @wcr_serials
                for update

                open drk_update_cursor

                fetch drk_update_cursor into @wcr_darkfile
                  /* Don't add modes to the fetch statement, if rft = image */

                while (@@sqlstatus = 0) /* While more drk files */

                begin
/*++++++++++++++++++++++++++++++++++++++++++++++++++++++++++++++++++++++++++++++*/
                  if (@wcr_darkfile = NULL)  /* no file was used in pipeline */
                        select @wcr_best_loc_drk = "N/A"
                  else if (@new_file_name = @wcr_darkfile)  /* recommended = was used, if rft = image or table */
                        select @wcr_best_loc_drk = "NO CHANGE"
                  else
                        if (@equiv_sev = -1)
                        select @wcr_best_loc_drk = 'UNKNOWN'
                  else   /* recommended <> was used - compute level of change */
                    begin
                        select        @orig_equiv_sev = wfpc_row.equivalence_class_severe,
                                @orig_equiv_mod = wfpc_row.equivalence_class_moderate
                        from        wfpc_row wfpc_row
                        where        wfpc_row.file_name = @wcr_darkfile
                        and wfpc_row.mode = @wcr_mode
                        and wfpc_row.camera = @wcr_camera
                        and wfpc_row.clock = @wcr_serials
 

                        if (@orig_equiv_sev = -1)
                        select @wcr_best_loc_drk = 'UNKNOWN'
                        else if ((@equiv_sev - @orig_equiv_sev) <> 0)
                                select @wcr_best_loc_drk = "SEVERE"
                        else if ((@equiv_mod - @orig_equiv_mod) <> 0)
                                select @wcr_best_loc_drk = "MODERATE"
                             else select @wcr_best_loc_drk = "TRIVIAL"
 
                    end      /*else*/
 
                   /* update row */
                   update wfpc_ref_data
                   set wcr_best_drk= @new_file_name, /* if rft = image or table */
                       wcr_best_loc_drk = @wcr_best_loc_drk
                   where  current of drk_update_cursor
        
                  fetch drk_update_cursor into @wcr_darkfile
                  /* Don't print modes, if rft = image */
 

                end /* while more drk files */

                close drk_update_cursor

                deallocate cursor drk_update_cursor
        end /* if @ref_type = 'DRK') */


        if (@ref_type = 'FLT')
        begin
                        /* get first non-rejected file that has a */
                        /* useafter_date that is greater than the */
                        /* new files useafter_date - use for stop window */
                declare stop_date_cursor cursor for
                select  wfpc_file.useafter_date
                from wfpc_file wfpc_file, wfpc_row wfpc_row
                        where wfpc_row.file_name = wfpc_file.file_name
                        and wfpc_row.expansion_number = wfpc_file.expansion_number
                        and wfpc_file.reference_file_type = "FLT"
                        and wfpc_file.reject_flag = "N"
                        and wfpc_file.opus_flag = "Y"
                        and wfpc_file.useafter_date > @useafter_date
                        and wfpc_file.archive_date is not null
                        /* Print out the modes, if rft = image */
                        and wfpc_row.mode = @wcr_mode
                        and wfpc_row.camera = @wcr_camera
                        and wfpc_row.filter1 = @wcr_filter1
                        and wfpc_row.filter2 = @wcr_filter2
                order by wfpc_file.useafter_date
                for read only

                open stop_date_cursor

                fetch stop_date_cursor into @stop_date

                if (@@sqlstatus <> 0)  /* no stop date found-use todays date*/

                        select @stop_date = getdate()

                close stop_date_cursor

                deallocate cursor stop_date_cursor


                declare flt_update_cursor cursor for
                select wcr_flatfile
                  /* Modes aren't added to the select list, if rft = image */
                from wfpc_ref_data
                where wcr_expstart >= @useafter_date
                and wcr_expstart < @stop_date
                  /* Add modes to the where clause, if rft = image */
                        and wcr_mode = @wcr_mode
                        and wcr_camera = @wcr_camera
                        and wcr_filter1 = @wcr_filter1
                        and wcr_filter2 = @wcr_filter2
                for update

                open flt_update_cursor

                fetch flt_update_cursor into @wcr_flatfile
                  /* Don't add modes to the fetch statement, if rft = image */

                while (@@sqlstatus = 0) /* While more flt files */

                begin
/*++++++++++++++++++++++++++++++++++++++++++++++++++++++++++++++++++++++++++++++*/
                  if (@wcr_flatfile = NULL)  /* no file was used in pipeline */
                        select @wcr_best_loc_flt = "N/A"
                  else if (@new_file_name = @wcr_flatfile)  /* recommended = was used, if rft = image or table */
                        select @wcr_best_loc_flt = "NO CHANGE"
                  else
                        if (@equiv_sev = -1)
                        select @wcr_best_loc_flt = 'UNKNOWN'
                  else   /* recommended <> was used - compute level of change */
                    begin
                        select        @orig_equiv_sev = wfpc_row.equivalence_class_severe,
                                @orig_equiv_mod = wfpc_row.equivalence_class_moderate
                        from        wfpc_row wfpc_row
                        where        wfpc_row.file_name = @wcr_flatfile
                        and wfpc_row.mode = @wcr_mode
                        and wfpc_row.camera = @wcr_camera
                        and wfpc_row.filter1 = @wcr_filter1
                        and wfpc_row.filter2 = @wcr_filter2
 

                        if (@orig_equiv_sev = -1)
                        select @wcr_best_loc_flt = 'UNKNOWN'
                        else if ((@equiv_sev - @orig_equiv_sev) <> 0)
                                select @wcr_best_loc_flt = "SEVERE"
                        else if ((@equiv_mod - @orig_equiv_mod) <> 0)
                                select @wcr_best_loc_flt = "MODERATE"
                             else select @wcr_best_loc_flt = "TRIVIAL"
 
                    end      /*else*/
 
                   /* update row */
                   update wfpc_ref_data
                   set wcr_best_flt= @new_file_name, /* if rft = image or table */
                       wcr_best_loc_flt = @wcr_best_loc_flt
                   where  current of flt_update_cursor
        
                  fetch flt_update_cursor into @wcr_flatfile
                  /* Don't print modes, if rft = image */
 

                end /* while more flt files */

                close flt_update_cursor

                deallocate cursor flt_update_cursor
        end /* if @ref_type = 'FLT') */


        if (@ref_type = 'MSK')
        begin
                        /* get first non-rejected file that has a */
                        /* useafter_date that is greater than the */
                        /* new files useafter_date - use for stop window */
                declare stop_date_cursor cursor for
                select  wfpc_file.useafter_date
                from wfpc_file wfpc_file, wfpc_row wfpc_row
                        where wfpc_row.file_name = wfpc_file.file_name
                        and wfpc_row.expansion_number = wfpc_file.expansion_number
                        and wfpc_file.reference_file_type = "MSK"
                        and wfpc_file.reject_flag = "N"
                        and wfpc_file.opus_flag = "Y"
                        and wfpc_file.useafter_date > @useafter_date
                        and wfpc_file.archive_date is not null
                        /* Print out the modes, if rft = image */
                        and wfpc_row.mode = @wcr_mode
                        and wfpc_row.camera = @wcr_camera
                order by wfpc_file.useafter_date
                for read only

                open stop_date_cursor

                fetch stop_date_cursor into @stop_date

                if (@@sqlstatus <> 0)  /* no stop date found-use todays date*/

                        select @stop_date = getdate()

                close stop_date_cursor

                deallocate cursor stop_date_cursor


                declare msk_update_cursor cursor for
                select wcr_maskfile
                  /* Modes aren't added to the select list, if rft = image */
                from wfpc_ref_data
                where wcr_expstart >= @useafter_date
                and wcr_expstart < @stop_date
                  /* Add modes to the where clause, if rft = image */
                        and wcr_mode = @wcr_mode
                        and wcr_camera = @wcr_camera
                for update

                open msk_update_cursor

                fetch msk_update_cursor into @wcr_maskfile
                  /* Don't add modes to the fetch statement, if rft = image */

                while (@@sqlstatus = 0) /* While more msk files */

                begin
/*++++++++++++++++++++++++++++++++++++++++++++++++++++++++++++++++++++++++++++++*/
                  if (@wcr_maskfile = NULL)  /* no file was used in pipeline */
                        select @wcr_best_loc_msk = "N/A"
                  else if (@new_file_name = @wcr_maskfile)  /* recommended = was used, if rft = image or table */
                        select @wcr_best_loc_msk = "NO CHANGE"
                  else
                        if (@equiv_sev = -1)
                        select @wcr_best_loc_msk = 'UNKNOWN'
                  else   /* recommended <> was used - compute level of change */
                    begin
                        select        @orig_equiv_sev = wfpc_row.equivalence_class_severe,
                                @orig_equiv_mod = wfpc_row.equivalence_class_moderate
                        from        wfpc_row wfpc_row
                        where        wfpc_row.file_name = @wcr_maskfile
                        and wfpc_row.mode = @wcr_mode
                        and wfpc_row.camera = @wcr_camera
 

                        if (@orig_equiv_sev = -1)
                        select @wcr_best_loc_msk = 'UNKNOWN'
                        else if ((@equiv_sev - @orig_equiv_sev) <> 0)
                                select @wcr_best_loc_msk = "SEVERE"
                        else if ((@equiv_mod - @orig_equiv_mod) <> 0)
                                select @wcr_best_loc_msk = "MODERATE"
                             else select @wcr_best_loc_msk = "TRIVIAL"
 
                    end      /*else*/
 
                   /* update row */
                   update wfpc_ref_data
                   set wcr_best_msk= @new_file_name, /* if rft = image or table */
                       wcr_best_loc_msk = @wcr_best_loc_msk
                   where  current of msk_update_cursor
        
                  fetch msk_update_cursor into @wcr_maskfile
                  /* Don't print modes, if rft = image */
 

                end /* while more msk files */

                close msk_update_cursor

                deallocate cursor msk_update_cursor
        end /* if @ref_type = 'MSK') */


        if (@ref_type = 'PRF')
        begin
                        /* get first non-rejected file that has a */
                        /* useafter_date that is greater than the */
                        /* new files useafter_date - use for stop window */
                declare stop_date_cursor cursor for
                select  wfpc_file.useafter_date
                from wfpc_file wfpc_file, wfpc_row wfpc_row
                        where wfpc_row.file_name = wfpc_file.file_name
                        and wfpc_row.expansion_number = wfpc_file.expansion_number
                        and wfpc_file.reference_file_type = "PRF"
                        and wfpc_file.reject_flag = "N"
                        and wfpc_file.opus_flag = "Y"
                        and wfpc_file.useafter_date > @useafter_date
                        and wfpc_file.archive_date is not null
                        /* Print out the modes, if rft = image */
                        and wfpc_row.mode = @wcr_mode
                        and wfpc_row.camera = @wcr_camera
                        and wfpc_row.shutter = @wcr_shutter
                order by wfpc_file.useafter_date
                for read only

                open stop_date_cursor

                fetch stop_date_cursor into @stop_date

                if (@@sqlstatus <> 0)  /* no stop date found-use todays date*/

                        select @stop_date = getdate()

                close stop_date_cursor

                deallocate cursor stop_date_cursor


                declare prf_update_cursor cursor for
                select wcr_preffile
                  /* Modes aren't added to the select list, if rft = image */
                from wfpc_ref_data
                where wcr_expstart >= @useafter_date
                and wcr_expstart < @stop_date
                  /* Add modes to the where clause, if rft = image */
                        and wcr_mode = @wcr_mode
                        and wcr_camera = @wcr_camera
                        and wcr_shutter = @wcr_shutter
                for update

                open prf_update_cursor

                fetch prf_update_cursor into @wcr_preffile
                  /* Don't add modes to the fetch statement, if rft = image */

                while (@@sqlstatus = 0) /* While more prf files */

                begin
/*++++++++++++++++++++++++++++++++++++++++++++++++++++++++++++++++++++++++++++++*/
                  if (@wcr_preffile = NULL)  /* no file was used in pipeline */
                        select @wcr_best_loc_prf = "N/A"
                  else if (@new_file_name = @wcr_preffile)  /* recommended = was used, if rft = image or table */
                        select @wcr_best_loc_prf = "NO CHANGE"
                  else
                        if (@equiv_sev = -1)
                        select @wcr_best_loc_prf = 'UNKNOWN'
                  else   /* recommended <> was used - compute level of change */
                    begin
                        select        @orig_equiv_sev = wfpc_row.equivalence_class_severe,
                                @orig_equiv_mod = wfpc_row.equivalence_class_moderate
                        from        wfpc_row wfpc_row
                        where        wfpc_row.file_name = @wcr_preffile
                        and wfpc_row.mode = @wcr_mode
                        and wfpc_row.camera = @wcr_camera
                        and wfpc_row.shutter = @wcr_shutter
 

                        if (@orig_equiv_sev = -1)
                        select @wcr_best_loc_prf = 'UNKNOWN'
                        else if ((@equiv_sev - @orig_equiv_sev) <> 0)
                                select @wcr_best_loc_prf = "SEVERE"
                        else if ((@equiv_mod - @orig_equiv_mod) <> 0)
                                select @wcr_best_loc_prf = "MODERATE"
                             else select @wcr_best_loc_prf = "TRIVIAL"
 
                    end      /*else*/
 
                   /* update row */
                   update wfpc_ref_data
                   set wcr_best_prf= @new_file_name, /* if rft = image or table */
                       wcr_best_loc_prf = @wcr_best_loc_prf
                   where  current of prf_update_cursor
        
                  fetch prf_update_cursor into @wcr_preffile
                  /* Don't print modes, if rft = image */
 

                end /* while more prf files */

                close prf_update_cursor

                deallocate cursor prf_update_cursor
        end /* if @ref_type = 'PRF') */


        if (@ref_type = 'PUR')
        begin
                        /* get first non-rejected file that has a */
                        /* useafter_date that is greater than the */
                        /* new files useafter_date - use for stop window */
                declare stop_date_cursor cursor for
                select  wfpc_file.useafter_date
                from wfpc_file wfpc_file, wfpc_row wfpc_row
                        where wfpc_row.file_name = wfpc_file.file_name
                        and wfpc_row.expansion_number = wfpc_file.expansion_number
                        and wfpc_file.reference_file_type = "PUR"
                        and wfpc_file.reject_flag = "N"
                        and wfpc_file.opus_flag = "Y"
                        and wfpc_file.useafter_date > @useafter_date
                        and wfpc_file.archive_date is not null
                        /* Print out the modes, if rft = image */
                        and wfpc_row.mode = @wcr_mode
                        and wfpc_row.camera = @wcr_camera
                order by wfpc_file.useafter_date
                for read only

                open stop_date_cursor

                fetch stop_date_cursor into @stop_date

                if (@@sqlstatus <> 0)  /* no stop date found-use todays date*/

                        select @stop_date = getdate()

                close stop_date_cursor

                deallocate cursor stop_date_cursor


                declare pur_update_cursor cursor for
                select wcr_purgfile
                  /* Modes aren't added to the select list, if rft = image */
                from wfpc_ref_data
                where wcr_expstart >= @useafter_date
                and wcr_expstart < @stop_date
                  /* Add modes to the where clause, if rft = image */
                        and wcr_mode = @wcr_mode
                        and wcr_camera = @wcr_camera
                for update

                open pur_update_cursor

                fetch pur_update_cursor into @wcr_purgfile
                  /* Don't add modes to the fetch statement, if rft = image */

                while (@@sqlstatus = 0) /* While more pur files */

                begin
/*++++++++++++++++++++++++++++++++++++++++++++++++++++++++++++++++++++++++++++++*/
                  if (@wcr_purgfile = NULL)  /* no file was used in pipeline */
                        select @wcr_best_loc_pur = "N/A"
                  else if (@new_file_name = @wcr_purgfile)  /* recommended = was used, if rft = image or table */
                        select @wcr_best_loc_pur = "NO CHANGE"
                  else
                        if (@equiv_sev = -1)
                        select @wcr_best_loc_pur = 'UNKNOWN'
                  else   /* recommended <> was used - compute level of change */
                    begin
                        select        @orig_equiv_sev = wfpc_row.equivalence_class_severe,
                                @orig_equiv_mod = wfpc_row.equivalence_class_moderate
                        from        wfpc_row wfpc_row
                        where        wfpc_row.file_name = @wcr_purgfile
                        and wfpc_row.mode = @wcr_mode
                        and wfpc_row.camera = @wcr_camera
 

                        if (@orig_equiv_sev = -1)
                        select @wcr_best_loc_pur = 'UNKNOWN'
                        else if ((@equiv_sev - @orig_equiv_sev) <> 0)
                                select @wcr_best_loc_pur = "SEVERE"
                        else if ((@equiv_mod - @orig_equiv_mod) <> 0)
                                select @wcr_best_loc_pur = "MODERATE"
                             else select @wcr_best_loc_pur = "TRIVIAL"
 
                    end      /*else*/
 
                   /* update row */
                   update wfpc_ref_data
                   set wcr_best_pur= @new_file_name, /* if rft = image or table */
                       wcr_best_loc_pur = @wcr_best_loc_pur
                   where  current of pur_update_cursor
        
                  fetch pur_update_cursor into @wcr_purgfile
                  /* Don't print modes, if rft = image */
 

                end /* while more pur files */

                close pur_update_cursor

                deallocate cursor pur_update_cursor
        end /* if @ref_type = 'PUR') */


        if (@ref_type = 'PHOTTAB')
        begin
/* mod - entire section */
                        /* get first non-rejected file that has a */
                        /* useafter_date that is greater than the */
                        /* new files useafter_date - use for stop window */
                declare stop_date_cursor cursor for
                select  wfpc_file.useafter_date
                from wfpc_file wfpc_file, wfpc_row wfpc_row
                        where wfpc_row.file_name = wfpc_file.file_name
                        and wfpc_row.expansion_number = wfpc_file.expansion_number
                        and wfpc_file.reference_file_type = "PHOTTAB"
                        and wfpc_file.reject_flag = "N"
                        and wfpc_file.opus_flag = "Y"
                        and wfpc_file.useafter_date > @useafter_date
                        and wfpc_file.archive_date is not null
/* The reference file type is table, don't print out the modes */
                order by wfpc_file.useafter_date
                for read only

                open stop_date_cursor

                fetch stop_date_cursor into @stop_date

                if (@@sqlstatus <> 0)  /* no stop date found-use todays date*/

                        select @stop_date = getdate()

                close stop_date_cursor

                deallocate cursor stop_date_cursor


                declare phottab_update_cursor cursor for
                select wcr_phottab
                  /* Add modes to the select list, if rft = table */
                ,wcr_photmode_a /* mod */
		,wcr_photmode_b /* mod */
		,wcr_photmode_c /* mod */
		,wcr_photmode_d /* mod */
                from wfpc_ref_data
                where wcr_expstart >= @useafter_date
                and wcr_expstart < @stop_date
                  /* Modes aren't added to the where clause, if rft = table */
                for update

                open phottab_update_cursor

                fetch phottab_update_cursor into @wcr_phottab
                  /* Add modes to the fetch statement, if rft = table */
                ,@wcr_photmode_a	/* mod */
		,@wcr_photmode_b	/* mod */
		,@wcr_photmode_c	/* mod */
		,@wcr_photmode_d	/* mod */

                while (@@sqlstatus = 0) /* While more phottab files */

                begin
/* The following section, surrounded by ++++'s, if rft = table */
/*++++++++++++++++++++++++++++++++++++++++++++++++++++++++++++++++++++++++++++++*/
                        select @equiv_sev = wfpc_row.equivalence_class_severe,
                                @equiv_mod = wfpc_row.equivalence_class_moderate
                        from wfpc_row wfpc_row
                        where wfpc_row.file_name = @new_file_name
                        and wfpc_row.expansion_number = @new_expansion_number
                        and wfpc_row.photmode = @wcr_photmode_a

                select @num_cal_files = @@rowcount
                if (@num_cal_files <> 0)	/* recommended file found */
                begin
/*++++++++++++++++++++++++++++++++++++++++++++++++++++++++++++++++++++++++++++++*/
                  if (@wcr_phottab = NULL)  /* no file was used in pipeline */
                        select @wcr_best_loc_photmode_a = "N/A", /* mod */
				 @wcr_best_loc_photmode_b = "N/A", /* mod */
				 @wcr_best_loc_photmode_c = "N/A", /* mod */
				 @wcr_best_loc_photmode_d = "N/A" /* mod */
                  else if (@new_file_name = @wcr_phottab)  /* recommended = was used, if rft = image or table */
                        select @wcr_best_loc_photmode_a = "NO CHANGE", /*mod*/
				@wcr_best_loc_photmode_b = "NO CHANGE", /*mod*/
				@wcr_best_loc_photmode_c = "NO CHANGE", /*mod*/
				@wcr_best_loc_photmode_d = "NO CHANGE" /*mod*/
                  else
                        if (@equiv_sev = -1)
                        select @wcr_best_loc_photmode_a = 'UNKNOWN', /* mod */
				@wcr_best_loc_photmode_b = 'UNKNOWN', /* mod */
				@wcr_best_loc_photmode_c = 'UNKNOWN', /* mod */
				@wcr_best_loc_photmode_d = 'UNKNOWN' /* mod */
                  else   /* recommended <> was used - compute level of change */
                    begin
                        select        @orig_equiv_sev = wfpc_row.equivalence_class_severe,
                                @orig_equiv_mod = wfpc_row.equivalence_class_moderate
                        from        wfpc_row wfpc_row
                        where        wfpc_row.file_name = @wcr_phottab
                        and wfpc_row.photmode = @wcr_photmode_a
 

                        if (@orig_equiv_sev = -1)
                        select @wcr_best_loc_photmode_a = 'UNKNOWN'
                        else if ((@equiv_sev - @orig_equiv_sev) <> 0)
                                select @wcr_best_loc_photmode_a = "SEVERE"
                        else if ((@equiv_mod - @orig_equiv_mod) <> 0)
                                select @wcr_best_loc_photmode_a = "MODERATE"
                             else select @wcr_best_loc_photmode_a = "TRIVIAL"

                        select        @orig_equiv_sev = wfpc_row.equivalence_class_severe,
                                @orig_equiv_mod = wfpc_row.equivalence_class_moderate
                        from        wfpc_row wfpc_row
                        where        wfpc_row.file_name = @wcr_phottab
                        and wfpc_row.photmode = @wcr_photmode_b
 

                        if (@orig_equiv_sev = -1)
                        select @wcr_best_loc_photmode_b = 'UNKNOWN'
                        else if ((@equiv_sev - @orig_equiv_sev) <> 0)
                                select @wcr_best_loc_photmode_b = "SEVERE"
                        else if ((@equiv_mod - @orig_equiv_mod) <> 0)
                                select @wcr_best_loc_photmode_b = "MODERATE"
                             else select @wcr_best_loc_photmode_b = "TRIVIAL"

                        select        @orig_equiv_sev = wfpc_row.equivalence_class_severe,
                                @orig_equiv_mod = wfpc_row.equivalence_class_moderate
                        from        wfpc_row wfpc_row
                        where        wfpc_row.file_name = @wcr_phottab
                        and wfpc_row.photmode = @wcr_photmode_c
 

                        if (@orig_equiv_sev = -1)
                        select @wcr_best_loc_photmode_c = 'UNKNOWN'
                        else if ((@equiv_sev - @orig_equiv_sev) <> 0)
                                select @wcr_best_loc_photmode_c = "SEVERE"
                        else if ((@equiv_mod - @orig_equiv_mod) <> 0)
                                select @wcr_best_loc_photmode_c = "MODERATE"
                             else select @wcr_best_loc_photmode_c = "TRIVIAL"

                        select        @orig_equiv_sev = wfpc_row.equivalence_class_severe,
                                @orig_equiv_mod = wfpc_row.equivalence_class_moderate
                        from        wfpc_row wfpc_row
                        where        wfpc_row.file_name = @wcr_phottab
                        and wfpc_row.photmode = @wcr_photmode_d
 

                        if (@orig_equiv_sev = -1)
                        select @wcr_best_loc_photmode_d = 'UNKNOWN'
                        else if ((@equiv_sev - @orig_equiv_sev) <> 0)
                                select @wcr_best_loc_photmode_d = "SEVERE"
                        else if ((@equiv_mod - @orig_equiv_mod) <> 0)
                                select @wcr_best_loc_photmode_d = "MODERATE"
                             else select @wcr_best_loc_photmode_d = "TRIVIAL"
 
                    end      /*else*/
 
                   /* update row */
                   update wfpc_ref_data
                   set wcr_best_phottab= @new_file_name, /* if rft = image or table */
                       wcr_best_loc_photmode_a = @wcr_best_loc_photmode_a,
                       wcr_best_loc_photmode_b = @wcr_best_loc_photmode_b,
                       wcr_best_loc_photmode_c = @wcr_best_loc_photmode_c,
                       wcr_best_loc_photmode_d = @wcr_best_loc_photmode_d
                   where  current of phottab_update_cursor
        
                 end /* if recommended file found, if rft = table */
                  fetch phottab_update_cursor into @wcr_phottab
                  /* Print modes, if rft = table */
                ,@wcr_photmode_a  /* mod */
                ,@wcr_photmode_b  /* mod */
                ,@wcr_photmode_c  /* mod */
                ,@wcr_photmode_d  /* mod */
 

 

                end /* while more phottab files */

                close phottab_update_cursor

                deallocate cursor phottab_update_cursor
        end /* if @ref_type = 'PHOTTAB') */

fetch new_wfpc_cursor into @new_file_name, @new_expansion_number

end /* while more newly delivered calibration files */

close new_wfpc_cursor

deallocate cursor new_wfpc_cursor
return
go
