use dadsops
go
drop procedure new_wfpc2
go
create procedure new_wfpc2 as
/* newly delivered calibration files */
declare @new_file_name varchar(50)
declare @new_expansion_number int
declare @ref_type varchar(50)
declare @useafter_date datetime
declare @stop_date datetime
/* observation start time */
declare @expstart datetime
/* data set name, to be used for error checking/handling, should extract */
/* datatype from dt_mapping rather than hardcode it here, this will do for now */
declare @data_set_name varchar(39)
/* severity level variables, to be reused for each reference file type */
declare @orig_equiv_sev int
declare @orig_equiv_mod int
declare @equiv_sev int
declare @equiv_mod int
/* used to store @@rowcount global variable */
declare @num_cal_files int
/* observation modes, calibration files used in the pipeline, */
/* best, and best_loc files */
declare @w2r_mode char(4)
declare @w2r_atodgain float
declare @w2r_serials char(3)
declare @w2r_shutter char(7)
declare @w2r_comptab char(18)
declare @w2r_filter1 int
declare @w2r_filter2 int
declare @w2r_atodfile char(18)
declare @w2r_best_a2d char(18)
declare @w2r_best_bas char(18)
declare @w2r_best_drk char(18)
declare @w2r_best_flt char(18)
declare @w2r_best_msk char(18)
declare @w2r_best_shd char(18)
declare @w2r_biasfile char(18)
declare @w2r_darkfile char(18)
declare @w2r_flatfile char(18)
declare @w2r_graphtab char(18)
declare @w2r_maskfile char(18)
declare @w2r_shadfile char(18)
declare @w2r_best_comptab char(18)
declare @w2r_best_graphtab char(18)
declare @w2r_best_loc_a2d varchar(9)
declare @w2r_best_loc_bas varchar(9)
declare @w2r_best_loc_drk varchar(9)
declare @w2r_best_loc_flt varchar(9)
declare @w2r_best_loc_msk varchar(9)
declare @w2r_best_loc_shd varchar(9)

/**************************************************************************/
/************************ New   wfpc2 ***********************/
/**************************************************************************/

declare new_wfpc2_cursor cursor for
        select  file_name, expansion_number
        from    new_cal_files
        where   instrument = 'WFPC2'
for read only

open new_wfpc2_cursor

fetch new_wfpc2_cursor into @new_file_name, @new_expansion_number

while (@@sqlstatus = 0)/* more newly delivered calibration files*/
begin

select @ref_type = wfpc2_file.reference_file_type,
@useafter_date = wfpc2_file.useafter_date,
@equiv_sev = wfpc2_row.equivalence_class_severe,
@equiv_mod = wfpc2_row.equivalence_class_moderate
,@w2r_mode=wfpc2_row.mode
,@w2r_filter1=wfpc2_row.filter1
,@w2r_filter2=wfpc2_row.filter2
,@w2r_serials=wfpc2_row.serials
,@w2r_shutter=wfpc2_row.shutter
,@w2r_atodgain=wfpc2_row.atodgain
from wfpc2_file wfpc2_file, wfpc2_row wfpc2_row
where wfpc2_file.file_name = @new_file_name 
and wfpc2_row.file_name = @new_file_name
and wfpc2_file.expansion_number = @new_expansion_number
and wfpc2_row.expansion_number = @new_expansion_number


        if (@ref_type = 'A2D')
        begin
                        /* get first non-rejected file that has a */
                        /* useafter_date that is greater than the */
                        /* new files useafter_date - use for stop window */
                declare stop_date_cursor cursor for
                select  wfpc2_file.useafter_date
                from wfpc2_file wfpc2_file, wfpc2_row wfpc2_row
                        where wfpc2_row.file_name = wfpc2_file.file_name
                        and wfpc2_row.expansion_number = wfpc2_file.expansion_number
                        and wfpc2_file.reference_file_type = "A2D"
                        and wfpc2_file.reject_flag = "N"
                        and wfpc2_file.opus_flag = "Y"
                        and wfpc2_file.useafter_date > @useafter_date
                        and wfpc2_file.archive_date is not null
                        /* Print out the modes, if rft = image */
                        and wfpc2_row.mode = @w2r_mode
                        and wfpc2_row.atodgain = @w2r_atodgain
                order by wfpc2_file.useafter_date
                for read only

                open stop_date_cursor

                fetch stop_date_cursor into @stop_date

                if (@@sqlstatus <> 0)  /* no stop date found-use todays date*/

                        select @stop_date = getdate()

                close stop_date_cursor

                deallocate cursor stop_date_cursor


                declare a2d_update_cursor cursor for
                select w2r_atodfile
                  /* Modes aren't added to the select list, if rft = image */
                from wfpc2_ref_data
                where w2r_expstart >= @useafter_date
                and w2r_expstart < @stop_date
                  /* Add modes to the where clause, if rft = image */
                        and w2r_mode = @w2r_mode
                        and w2r_atodgain = @w2r_atodgain
                for update

                open a2d_update_cursor

                fetch a2d_update_cursor into @w2r_atodfile
                  /* Don't add modes to the fetch statement, if rft = image */

                while (@@sqlstatus = 0) /* While more a2d files */

                begin
/*++++++++++++++++++++++++++++++++++++++++++++++++++++++++++++++++++++++++++++++*/
                  if (@w2r_atodfile = NULL)  /* no file was used in pipeline */
                        select @w2r_best_loc_a2d = "N/A"
                  else if (@new_file_name = @w2r_atodfile)  /* recommended = was used, if rft = image or table */
                        select @w2r_best_loc_a2d = "NO CHANGE"
                  else
                        if (@equiv_sev = -1)
                        select @w2r_best_loc_a2d = 'UNKNOWN'
                  else   /* recommended <> was used - compute level of change */
                    begin
                        select        @orig_equiv_sev = wfpc2_row.equivalence_class_severe,
                                @orig_equiv_mod = wfpc2_row.equivalence_class_moderate
                        from        wfpc2_row wfpc2_row
                        where        wfpc2_row.file_name = @w2r_atodfile
                        and wfpc2_row.mode = @w2r_mode
                        and wfpc2_row.atodgain = @w2r_atodgain
 

                        if (@orig_equiv_sev = -1)
                        select @w2r_best_loc_a2d = 'UNKNOWN'
                        else if ((@equiv_sev - @orig_equiv_sev) <> 0)
                                select @w2r_best_loc_a2d = "SEVERE"
                        else if ((@equiv_mod - @orig_equiv_mod) <> 0)
                                select @w2r_best_loc_a2d = "MODERATE"
                             else select @w2r_best_loc_a2d = "TRIVIAL"
 
                    end      /*else*/
 
                   /* update row */
                   update wfpc2_ref_data
                   set w2r_best_a2d= @new_file_name, /* if rft = image or table */
                       w2r_best_loc_a2d = @w2r_best_loc_a2d
                   where  current of a2d_update_cursor
        
                  fetch a2d_update_cursor into @w2r_atodfile
                  /* Don't print modes, if rft = image */
 

                end /* while more a2d files */

                close a2d_update_cursor

                deallocate cursor a2d_update_cursor
        end /* if @ref_type = 'A2D') */


        if (@ref_type = 'BAS')
        begin
                        /* get first non-rejected file that has a */
                        /* useafter_date that is greater than the */
                        /* new files useafter_date - use for stop window */
                declare stop_date_cursor cursor for
                select  wfpc2_file.useafter_date
                from wfpc2_file wfpc2_file, wfpc2_row wfpc2_row
                        where wfpc2_row.file_name = wfpc2_file.file_name
                        and wfpc2_row.expansion_number = wfpc2_file.expansion_number
                        and wfpc2_file.reference_file_type = "BAS"
                        and wfpc2_file.reject_flag = "N"
                        and wfpc2_file.opus_flag = "Y"
                        and wfpc2_file.useafter_date > @useafter_date
                        and wfpc2_file.archive_date is not null
                        /* Print out the modes, if rft = image */
                        and wfpc2_row.mode = @w2r_mode
                        and wfpc2_row.atodgain = @w2r_atodgain
                order by wfpc2_file.useafter_date
                for read only

                open stop_date_cursor

                fetch stop_date_cursor into @stop_date

                if (@@sqlstatus <> 0)  /* no stop date found-use todays date*/

                        select @stop_date = getdate()

                close stop_date_cursor

                deallocate cursor stop_date_cursor


                declare bas_update_cursor cursor for
                select w2r_biasfile
                  /* Modes aren't added to the select list, if rft = image */
                from wfpc2_ref_data
                where w2r_expstart >= @useafter_date
                and w2r_expstart < @stop_date
                  /* Add modes to the where clause, if rft = image */
                        and w2r_mode = @w2r_mode
                        and w2r_atodgain = @w2r_atodgain
                for update

                open bas_update_cursor

                fetch bas_update_cursor into @w2r_biasfile
                  /* Don't add modes to the fetch statement, if rft = image */

                while (@@sqlstatus = 0) /* While more bas files */

                begin
/*++++++++++++++++++++++++++++++++++++++++++++++++++++++++++++++++++++++++++++++*/
                  if (@w2r_biasfile = NULL)  /* no file was used in pipeline */
                        select @w2r_best_loc_bas = "N/A"
                  else if (@new_file_name = @w2r_biasfile)  /* recommended = was used, if rft = image or table */
                        select @w2r_best_loc_bas = "NO CHANGE"
                  else
                        if (@equiv_sev = -1)
                        select @w2r_best_loc_bas = 'UNKNOWN'
                  else   /* recommended <> was used - compute level of change */
                    begin
                        select        @orig_equiv_sev = wfpc2_row.equivalence_class_severe,
                                @orig_equiv_mod = wfpc2_row.equivalence_class_moderate
                        from        wfpc2_row wfpc2_row
                        where        wfpc2_row.file_name = @w2r_biasfile
                        and wfpc2_row.mode = @w2r_mode
                        and wfpc2_row.atodgain = @w2r_atodgain
 

                        if (@orig_equiv_sev = -1)
                        select @w2r_best_loc_bas = 'UNKNOWN'
                        else if ((@equiv_sev - @orig_equiv_sev) <> 0)
                                select @w2r_best_loc_bas = "SEVERE"
                        else if ((@equiv_mod - @orig_equiv_mod) <> 0)
                                select @w2r_best_loc_bas = "MODERATE"
                             else select @w2r_best_loc_bas = "TRIVIAL"
 
                    end      /*else*/
 
                   /* update row */
                   update wfpc2_ref_data
                   set w2r_best_bas= @new_file_name, /* if rft = image or table */
                       w2r_best_loc_bas = @w2r_best_loc_bas
                   where  current of bas_update_cursor
        
                  fetch bas_update_cursor into @w2r_biasfile
                  /* Don't print modes, if rft = image */
 

                end /* while more bas files */

                close bas_update_cursor

                deallocate cursor bas_update_cursor
        end /* if @ref_type = 'BAS') */


        if (@ref_type = 'DRK')
        begin
                        /* get first non-rejected file that has a */
                        /* useafter_date that is greater than the */
                        /* new files useafter_date - use for stop window */
                declare stop_date_cursor cursor for
                select  wfpc2_file.useafter_date
                from wfpc2_file wfpc2_file, wfpc2_row wfpc2_row
                        where wfpc2_row.file_name = wfpc2_file.file_name
                        and wfpc2_row.expansion_number = wfpc2_file.expansion_number
                        and wfpc2_file.reference_file_type = "DRK"
                        and wfpc2_file.reject_flag = "N"
                        and wfpc2_file.opus_flag = "Y"
                        and wfpc2_file.useafter_date > @useafter_date
                        and wfpc2_file.archive_date is not null
                        /* Print out the modes, if rft = image */
                        and wfpc2_row.mode = @w2r_mode
                        and wfpc2_row.serials = @w2r_serials
                        and wfpc2_row.atodgain = @w2r_atodgain
                order by wfpc2_file.useafter_date
                for read only

                open stop_date_cursor

                fetch stop_date_cursor into @stop_date

                if (@@sqlstatus <> 0)  /* no stop date found-use todays date*/

                        select @stop_date = getdate()

                close stop_date_cursor

                deallocate cursor stop_date_cursor


                declare drk_update_cursor cursor for
                select w2r_darkfile
                  /* Modes aren't added to the select list, if rft = image */
                from wfpc2_ref_data
                where w2r_expstart >= @useafter_date
                and w2r_expstart < @stop_date
                  /* Add modes to the where clause, if rft = image */
                        and w2r_mode = @w2r_mode
                        and w2r_serials = @w2r_serials
                        and w2r_atodgain = @w2r_atodgain
                for update

                open drk_update_cursor

                fetch drk_update_cursor into @w2r_darkfile
                  /* Don't add modes to the fetch statement, if rft = image */

                while (@@sqlstatus = 0) /* While more drk files */

                begin
/*++++++++++++++++++++++++++++++++++++++++++++++++++++++++++++++++++++++++++++++*/
                  if (@w2r_darkfile = NULL)  /* no file was used in pipeline */
                        select @w2r_best_loc_drk = "N/A"
                  else if (@new_file_name = @w2r_darkfile)  /* recommended = was used, if rft = image or table */
                        select @w2r_best_loc_drk = "NO CHANGE"
                  else
                        if (@equiv_sev = -1)
                        select @w2r_best_loc_drk = 'UNKNOWN'
                  else   /* recommended <> was used - compute level of change */
                    begin
                        select        @orig_equiv_sev = wfpc2_row.equivalence_class_severe,
                                @orig_equiv_mod = wfpc2_row.equivalence_class_moderate
                        from        wfpc2_row wfpc2_row
                        where        wfpc2_row.file_name = @w2r_darkfile
                        and wfpc2_row.mode = @w2r_mode
                        and wfpc2_row.serials = @w2r_serials
                        and wfpc2_row.atodgain = @w2r_atodgain
 

                        if (@orig_equiv_sev = -1)
                        select @w2r_best_loc_drk = 'UNKNOWN'
                        else if ((@equiv_sev - @orig_equiv_sev) <> 0)
                                select @w2r_best_loc_drk = "SEVERE"
                        else if ((@equiv_mod - @orig_equiv_mod) <> 0)
                                select @w2r_best_loc_drk = "MODERATE"
                             else select @w2r_best_loc_drk = "TRIVIAL"
 
                    end      /*else*/
 
                   /* update row */
                   update wfpc2_ref_data
                   set w2r_best_drk= @new_file_name, /* if rft = image or table */
                       w2r_best_loc_drk = @w2r_best_loc_drk
                   where  current of drk_update_cursor
        
                  fetch drk_update_cursor into @w2r_darkfile
                  /* Don't print modes, if rft = image */
 

                end /* while more drk files */

                close drk_update_cursor

                deallocate cursor drk_update_cursor
        end /* if @ref_type = 'DRK') */


        if (@ref_type = 'FLT')
        begin
/* begin mod */
/* modify to handle permutations of filter1 & 2 */

                        /* get first non-rejected file that has a */
                        /* useafter_date that is greater than the */
                        /* new files useafter_date - use for stop window */
                declare stop_date_cursor cursor for
                select  wfpc2_file.useafter_date
                from wfpc2_file wfpc2_file, wfpc2_row wfpc2_row
                        where wfpc2_row.file_name = wfpc2_file.file_name
                        and wfpc2_row.expansion_number = wfpc2_file.expansion_number
                        and wfpc2_file.reference_file_type = "FLT"
                        and wfpc2_file.reject_flag = "N"
                        and wfpc2_file.opus_flag = "Y"
                        and wfpc2_file.useafter_date > @useafter_date
                        and wfpc2_file.archive_date is not null
                        /* Print out the modes, if rft = image */
                        and wfpc2_row.mode = @w2r_mode
                        and ((wfpc2_row.filter1 = @w2r_filter1
                        and wfpc2_row.filter2 = @w2r_filter2)
                        or  (wfpc2_row.filter1 = @w2r_filter2
                        and wfpc2_row.filter2 = @w2r_filter1))
                order by wfpc2_file.useafter_date
                for read only

                open stop_date_cursor

                fetch stop_date_cursor into @stop_date

                if (@@sqlstatus <> 0)  /* no stop date found-use todays date*/

                        select @stop_date = getdate()

                close stop_date_cursor

                deallocate cursor stop_date_cursor


                declare flt_update_cursor cursor for
                select w2r_flatfile
                  /* Modes aren't added to the select list, if rft = image */
                from wfpc2_ref_data
                where w2r_expstart >= @useafter_date
                and w2r_expstart < @stop_date
                  /* Add modes to the where clause, if rft = image */
                        and w2r_mode = @w2r_mode
                        and ((w2r_filter1 = @w2r_filter1
                        and w2r_filter2 = @w2r_filter2)
                        or  (w2r_filter1 = @w2r_filter2
                        and w2r_filter2 = @w2r_filter1))
                for update

                open flt_update_cursor

                fetch flt_update_cursor into @w2r_flatfile
                  /* Don't add modes to the fetch statement, if rft = image */

                while (@@sqlstatus = 0) /* While more flt files */

                begin
/*++++++++++++++++++++++++++++++++++++++++++++++++++++++++++++++++++++++++++++++*/
                  if (@w2r_flatfile = NULL)  /* no file was used in pipeline */
                        select @w2r_best_loc_flt = "N/A"
                  else if (@new_file_name = @w2r_flatfile)  /* recommended = was used, if rft = image or table */
                        select @w2r_best_loc_flt = "NO CHANGE"
                  else
                        if (@equiv_sev = -1)
                        select @w2r_best_loc_flt = 'UNKNOWN'
                  else   /* recommended <> was used - compute level of change */
                    begin
                        select        @orig_equiv_sev = wfpc2_row.equivalence_class_severe,
                                @orig_equiv_mod = wfpc2_row.equivalence_class_moderate
                        from        wfpc2_row wfpc2_row
                        where        wfpc2_row.file_name = @w2r_flatfile
                        and wfpc2_row.mode = @w2r_mode
                        and ((wfpc2_row.filter1 = @w2r_filter1
                        and wfpc2_row.filter2 = @w2r_filter2)
                        or  (wfpc2_row.filter1 = @w2r_filter2
                        and wfpc2_row.filter2 = @w2r_filter1))
 

                        if (@orig_equiv_sev = -1)
                        select @w2r_best_loc_flt = 'UNKNOWN'
                        else if ((@equiv_sev - @orig_equiv_sev) <> 0)
                                select @w2r_best_loc_flt = "SEVERE"
                        else if ((@equiv_mod - @orig_equiv_mod) <> 0)
                                select @w2r_best_loc_flt = "MODERATE"
                             else select @w2r_best_loc_flt = "TRIVIAL"
 
                    end      /*else*/
 
                   /* update row */
                   update wfpc2_ref_data
                   set w2r_best_flt= @new_file_name, /* if rft = image or table */
                       w2r_best_loc_flt = @w2r_best_loc_flt
                   where  current of flt_update_cursor
        
                  fetch flt_update_cursor into @w2r_flatfile
                  /* Don't print modes, if rft = image */
 

                end /* while more flt files */

                close flt_update_cursor

                deallocate cursor flt_update_cursor
        end /* if @ref_type = 'FLT') */
/* end mod */

        if (@ref_type = 'MSK')
        begin
                        /* get first non-rejected file that has a */
                        /* useafter_date that is greater than the */
                        /* new files useafter_date - use for stop window */
                declare stop_date_cursor cursor for
                select  wfpc2_file.useafter_date
                from wfpc2_file wfpc2_file, wfpc2_row wfpc2_row
                        where wfpc2_row.file_name = wfpc2_file.file_name
                        and wfpc2_row.expansion_number = wfpc2_file.expansion_number
                        and wfpc2_file.reference_file_type = "MSK"
                        and wfpc2_file.reject_flag = "N"
                        and wfpc2_file.opus_flag = "Y"
                        and wfpc2_file.useafter_date > @useafter_date
                        and wfpc2_file.archive_date is not null
                        /* Print out the modes, if rft = image */
                        and wfpc2_row.mode = @w2r_mode
                order by wfpc2_file.useafter_date
                for read only

                open stop_date_cursor

                fetch stop_date_cursor into @stop_date

                if (@@sqlstatus <> 0)  /* no stop date found-use todays date*/

                        select @stop_date = getdate()

                close stop_date_cursor

                deallocate cursor stop_date_cursor


                declare msk_update_cursor cursor for
                select w2r_maskfile
                  /* Modes aren't added to the select list, if rft = image */
                from wfpc2_ref_data
                where w2r_expstart >= @useafter_date
                and w2r_expstart < @stop_date
                  /* Add modes to the where clause, if rft = image */
                        and w2r_mode = @w2r_mode
                for update

                open msk_update_cursor

                fetch msk_update_cursor into @w2r_maskfile
                  /* Don't add modes to the fetch statement, if rft = image */

                while (@@sqlstatus = 0) /* While more msk files */

                begin
/*++++++++++++++++++++++++++++++++++++++++++++++++++++++++++++++++++++++++++++++*/
                  if (@w2r_maskfile = NULL)  /* no file was used in pipeline */
                        select @w2r_best_loc_msk = "N/A"
                  else if (@new_file_name = @w2r_maskfile)  /* recommended = was used, if rft = image or table */
                        select @w2r_best_loc_msk = "NO CHANGE"
                  else
                        if (@equiv_sev = -1)
                        select @w2r_best_loc_msk = 'UNKNOWN'
                  else   /* recommended <> was used - compute level of change */
                    begin
                        select        @orig_equiv_sev = wfpc2_row.equivalence_class_severe,
                                @orig_equiv_mod = wfpc2_row.equivalence_class_moderate
                        from        wfpc2_row wfpc2_row
                        where        wfpc2_row.file_name = @w2r_maskfile
                        and wfpc2_row.mode = @w2r_mode
 

                        if (@orig_equiv_sev = -1)
                        select @w2r_best_loc_msk = 'UNKNOWN'
                        else if ((@equiv_sev - @orig_equiv_sev) <> 0)
                                select @w2r_best_loc_msk = "SEVERE"
                        else if ((@equiv_mod - @orig_equiv_mod) <> 0)
                                select @w2r_best_loc_msk = "MODERATE"
                             else select @w2r_best_loc_msk = "TRIVIAL"
 
                    end      /*else*/
 
                   /* update row */
                   update wfpc2_ref_data
                   set w2r_best_msk= @new_file_name, /* if rft = image or table */
                       w2r_best_loc_msk = @w2r_best_loc_msk
                   where  current of msk_update_cursor
        
                  fetch msk_update_cursor into @w2r_maskfile
                  /* Don't print modes, if rft = image */
 

                end /* while more msk files */

                close msk_update_cursor

                deallocate cursor msk_update_cursor
        end /* if @ref_type = 'MSK') */


        if (@ref_type = 'SHD')
        begin
                        /* get first non-rejected file that has a */
                        /* useafter_date that is greater than the */
                        /* new files useafter_date - use for stop window */
                declare stop_date_cursor cursor for
                select  wfpc2_file.useafter_date
                from wfpc2_file wfpc2_file, wfpc2_row wfpc2_row
                        where wfpc2_row.file_name = wfpc2_file.file_name
                        and wfpc2_row.expansion_number = wfpc2_file.expansion_number
                        and wfpc2_file.reference_file_type = "SHD"
                        and wfpc2_file.reject_flag = "N"
                        and wfpc2_file.opus_flag = "Y"
                        and wfpc2_file.useafter_date > @useafter_date
                        and wfpc2_file.archive_date is not null
                        /* Print out the modes, if rft = image */
                        and wfpc2_row.mode = @w2r_mode
                        and wfpc2_row.shutter = @w2r_shutter
                order by wfpc2_file.useafter_date
                for read only

                open stop_date_cursor

                fetch stop_date_cursor into @stop_date

                if (@@sqlstatus <> 0)  /* no stop date found-use todays date*/

                        select @stop_date = getdate()

                close stop_date_cursor

                deallocate cursor stop_date_cursor


                declare shd_update_cursor cursor for
                select w2r_shadfile
                  /* Modes aren't added to the select list, if rft = image */
                from wfpc2_ref_data
                where w2r_expstart >= @useafter_date
                and w2r_expstart < @stop_date
                  /* Add modes to the where clause, if rft = image */
                        and w2r_mode = @w2r_mode
                        and w2r_shutter = @w2r_shutter
                for update

                open shd_update_cursor

                fetch shd_update_cursor into @w2r_shadfile
                  /* Don't add modes to the fetch statement, if rft = image */

                while (@@sqlstatus = 0) /* While more shd files */

                begin
/*++++++++++++++++++++++++++++++++++++++++++++++++++++++++++++++++++++++++++++++*/
                  if (@w2r_shadfile = NULL)  /* no file was used in pipeline */
                        select @w2r_best_loc_shd = "N/A"
                  else if (@new_file_name = @w2r_shadfile)  /* recommended = was used, if rft = image or table */
                        select @w2r_best_loc_shd = "NO CHANGE"
                  else
                        if (@equiv_sev = -1)
                        select @w2r_best_loc_shd = 'UNKNOWN'
                  else   /* recommended <> was used - compute level of change */
                    begin
                        select        @orig_equiv_sev = wfpc2_row.equivalence_class_severe,
                                @orig_equiv_mod = wfpc2_row.equivalence_class_moderate
                        from        wfpc2_row wfpc2_row
                        where        wfpc2_row.file_name = @w2r_shadfile
                        and wfpc2_row.mode = @w2r_mode
                        and wfpc2_row.shutter = @w2r_shutter
 

                        if (@orig_equiv_sev = -1)
                        select @w2r_best_loc_shd = 'UNKNOWN'
                        else if ((@equiv_sev - @orig_equiv_sev) <> 0)
                                select @w2r_best_loc_shd = "SEVERE"
                        else if ((@equiv_mod - @orig_equiv_mod) <> 0)
                                select @w2r_best_loc_shd = "MODERATE"
                             else select @w2r_best_loc_shd = "TRIVIAL"
 
                    end      /*else*/
 
                   /* update row */
                   update wfpc2_ref_data
                   set w2r_best_shd= @new_file_name, /* if rft = image or table */
                       w2r_best_loc_shd = @w2r_best_loc_shd
                   where  current of shd_update_cursor
        
                  fetch shd_update_cursor into @w2r_shadfile
                  /* Don't print modes, if rft = image */
 

                end /* while more shd files */

                close shd_update_cursor

                deallocate cursor shd_update_cursor
        end /* if @ref_type = 'SHD') */

fetch new_wfpc2_cursor into @new_file_name, @new_expansion_number

end /* while more newly delivered calibration files */

close new_wfpc2_cursor

deallocate cursor new_wfpc2_cursor

/**************************************************************************/
/************************ New wfpc2 : synphot *******************/
/**************************************************************************/
/* modified - 12/18/97 - OPR 35596 - ignore useafter date for comptab and */
/*                                   graphtab for wfpc2, update all with  */
/*                                   latest delivered file                */
/* modified - 12/18/97 - OPR 35935 - don't compute level of change        */
/*                                                                        */
declare new_synphot_cursor cursor for
        select  file_name, expansion_number
        from    new_cal_files
        where   instrument = 'SYNPHOT'
for read only

open new_synphot_cursor

fetch new_synphot_cursor into @new_file_name, @new_expansion_number

while (@@sqlstatus = 0)/* more newly delivered calibration files*/
begin

select @ref_type = synphot_file.reference_file_type
from synphot_file synphot_file
where synphot_file.file_name = @new_file_name 

        if (@ref_type = 'COMPTAB')
		update wfpc2_ref_data set w2r_best_comptab = @new_file_name

        if (@ref_type = 'GRAPHTAB')
		update wfpc2_ref_data set w2r_best_graphtab = @new_file_name

fetch new_synphot_cursor into @new_file_name, @new_expansion_number

end /* while more newly delivered calibration files */

close new_synphot_cursor

deallocate cursor new_synphot_cursor

return
go
