use dadsops
go
drop procedure update_foc
go
create procedure update_foc as
/* observation start time */
declare @expstart datetime
/* data set name, to be used for error checking/handling */
declare @data_set_name datasetname
/* severity level variables, to be reused for each reference file type */
declare @orig_equiv_sev int
declare @orig_equiv_mod int
declare @equiv_sev int
declare @equiv_mod int
/* used to store @@rowcount global variable */
declare @num_cal_files int
/* observation modes, calibration files used in the pipeline, */
/* best, and best_loc files */
declare @fcr_lineoff float
declare @fcr_sampoff float
declare @fcr_photplam float
declare @fcr_cammode char(7)
declare @fcr_optcrly char(3)
declare @fcr_pxformt char(7)
declare @fcr_smmmode char(7)
declare @fcr_unitab char(18)
declare @fcr_comptab char(18)
declare @fcr_linepfm int
declare @fcr_optelt1 int
declare @fcr_optelt2 int
declare @fcr_samppln int
declare @fcr_bachfile char(18)
declare @fcr_best_bac char(18)
declare @fcr_best_blm char(18)
declare @fcr_best_geo char(18)
declare @fcr_best_itf char(18)
declare @fcr_best_sde char(18)
declare @fcr_best_uni char(18)
declare @fcr_blmhfile char(18)
declare @fcr_geohfile char(18)
declare @fcr_graphtab char(18)
declare @fcr_itfhfile char(18)
declare @fcr_sdehfile char(18)
declare @fcr_unihfile char(18)
declare @fcr_best_unitab char(18)
declare @fcr_best_comptab char(18)
declare @fcr_best_graphtab char(18)
declare @fcr_best_loc_bac varchar(9)
declare @fcr_best_loc_blm varchar(9)
declare @fcr_best_loc_geo varchar(9)
declare @fcr_best_loc_itf varchar(9)
declare @fcr_best_loc_sde varchar(9)
declare @fcr_best_loc_uni varchar(9)
declare @fcr_best_loc_unitab varchar(9)
declare @ratio float		/* mod */
declare @wavelength float	/* mod */
declare update_foc_cursor  cursor for
select fcr_expstart,fcr_data_set_name
,fcr_cammode
,fcr_lineoff
,fcr_linepfm
,fcr_optcrly
,fcr_optelt1
,fcr_optelt2
,fcr_pxformt
,fcr_sampoff
,fcr_samppln
,fcr_smmmode
,fcr_photplam
,fcr_bachfile
,fcr_blmhfile
,fcr_geohfile
,fcr_itfhfile
,fcr_unihfile
,fcr_unitab
,fcr_sdehfile
,fcr_comptab
,fcr_graphtab
from foc_ref_data
where fcr_best_bac is null
or fcr_best_blm is null
or fcr_best_geo is null
or fcr_best_itf is null
or fcr_best_uni is null
or fcr_best_unitab is null
or fcr_best_sde is null
or fcr_best_comptab is null
or fcr_best_graphtab is null
 for update
open update_foc_cursor 
fetch update_foc_cursor into @expstart,@data_set_name
,@fcr_cammode
,@fcr_lineoff
,@fcr_linepfm
,@fcr_optcrly
,@fcr_optelt1
,@fcr_optelt2
,@fcr_pxformt
,@fcr_sampoff
,@fcr_samppln
,@fcr_smmmode
,@fcr_photplam
,@fcr_bachfile
,@fcr_blmhfile
,@fcr_geohfile
,@fcr_itfhfile
,@fcr_unihfile
,@fcr_unitab
,@fcr_sdehfile
,@fcr_comptab
,@fcr_graphtab
/**************************************************************************/
/************************ Update foc ***********************/
/**************************************************************************/
while (@@sqlstatus = 0)
begin
select
@fcr_best_bac = null
,@fcr_best_blm = null
,@fcr_best_geo = null
,@fcr_best_itf = null
,@fcr_best_sde = null
,@fcr_best_uni = null
,@fcr_best_unitab = null
,@fcr_best_comptab = null
,@fcr_best_loc_bac = null
,@fcr_best_loc_blm = null
,@fcr_best_loc_geo = null
,@fcr_best_loc_itf = null
,@fcr_best_loc_sde = null
,@fcr_best_loc_uni = null
,@fcr_best_graphtab = null
,@fcr_best_loc_unitab = null
/**************************************************************************/
/*********** instrument foc ref file type BAC ****************/
/**************************************************************************/
select @fcr_best_bac = foc_file_1.file_name,
@equiv_sev = foc_row_1.equivalence_class_severe,
@equiv_mod = foc_row_1.equivalence_class_moderate
from foc_file foc_file_1, foc_row foc_row_1
where foc_file_1.useafter_date = 
	(select max(foc_file_2.useafter_date)
	from foc_file foc_file_2, foc_row foc_row_2
             where foc_file_2.reference_file_type = 'BAC'
             and foc_file_2.useafter_date <= @expstart
             and foc_file_2.reject_flag = 'N'
             and foc_file_2.opus_flag = 'Y'
             and foc_file_2.archive_date is not null
             and foc_file_2.file_name =foc_row_2.file_name
             and foc_file_2.expansion_number = foc_row_2.expansion_number
             and foc_row_2.optcrly = @fcr_optcrly
             and foc_row_2.pxformt = @fcr_pxformt
        )
and foc_file_1.reference_file_type = 'BAC'
and foc_file_1.reject_flag = 'N'
and foc_file_1.opus_flag = 'Y'
and foc_file_1.archive_date is not null
and foc_file_1.file_name =foc_row_1.file_name
and foc_file_1.expansion_number = foc_row_1.expansion_number
and foc_row_1.optcrly = @fcr_optcrly
and foc_row_1.pxformt = @fcr_pxformt
select @num_cal_files = @@rowcount
if (@num_cal_files = 0)    /* no recommended file found */
select @fcr_best_bac = 'N/A', @fcr_best_loc_bac = 'N/A'
else
if (@fcr_bachfile = NULL) /* no file was used in the pipeline */
select @fcr_best_loc_bac = 'N/A'
else
if (@fcr_best_bac = @fcr_bachfile) /* recommended = was used */
select @fcr_best_loc_bac = 'NO CHANGE'
else
if (@equiv_sev = -1)
	select @fcr_best_loc_bac = 'UNKNOWN'
else
begin

select @orig_equiv_sev = foc_row_1.equivalence_class_severe,
@orig_equiv_mod =  foc_row_1.equivalence_class_moderate
from foc_row foc_row_1
where foc_row_1.file_name = @fcr_bachfile
and foc_row_1.optcrly = @fcr_optcrly
and foc_row_1.pxformt = @fcr_pxformt

if (@orig_equiv_sev = -1)
	select @fcr_best_loc_bac = 'UNKNOWN'
else if ((@equiv_sev - @orig_equiv_sev) <> 0)
	select @fcr_best_loc_bac = 'SEVERE'
else if ((@equiv_mod - @orig_equiv_mod) <> 0)
		select @fcr_best_loc_bac = 'MODERATE'
     else select @fcr_best_loc_bac = 'TRIVIAL'
end
/**************************************************************************/
/*********** instrument foc ref file type BLM ****************/
/**************************************************************************/
select @fcr_best_blm = foc_file_1.file_name,
@equiv_sev = foc_row_1.equivalence_class_severe,
@equiv_mod = foc_row_1.equivalence_class_moderate
from foc_file foc_file_1, foc_row foc_row_1
where foc_file_1.useafter_date = 
	(select max(foc_file_2.useafter_date)
	from foc_file foc_file_2, foc_row foc_row_2
             where foc_file_2.reference_file_type = 'BLM'
             and foc_file_2.useafter_date <= @expstart
             and foc_file_2.reject_flag = 'N'
             and foc_file_2.opus_flag = 'Y'
             and foc_file_2.archive_date is not null
             and foc_file_2.file_name =foc_row_2.file_name
             and foc_file_2.expansion_number = foc_row_2.expansion_number
             and foc_row_2.optcrly = @fcr_optcrly
             and foc_row_2.pxformt = @fcr_pxformt
        )
and foc_file_1.reference_file_type = 'BLM'
and foc_file_1.reject_flag = 'N'
and foc_file_1.opus_flag = 'Y'
and foc_file_1.archive_date is not null
and foc_file_1.file_name =foc_row_1.file_name
and foc_file_1.expansion_number = foc_row_1.expansion_number
and foc_row_1.optcrly = @fcr_optcrly
and foc_row_1.pxformt = @fcr_pxformt
select @num_cal_files = @@rowcount
if (@num_cal_files = 0)    /* no recommended file found */
select @fcr_best_blm = 'N/A', @fcr_best_loc_blm = 'N/A'
else
if (@fcr_blmhfile = NULL) /* no file was used in the pipeline */
select @fcr_best_loc_blm = 'N/A'
else
if (@fcr_best_blm = @fcr_blmhfile) /* recommended = was used */
select @fcr_best_loc_blm = 'NO CHANGE'
else
if (@equiv_sev = -1)
	select @fcr_best_loc_blm = 'UNKNOWN'
else
begin

select @orig_equiv_sev = foc_row_1.equivalence_class_severe,
@orig_equiv_mod =  foc_row_1.equivalence_class_moderate
from foc_row foc_row_1
where foc_row_1.file_name = @fcr_blmhfile
and foc_row_1.optcrly = @fcr_optcrly
and foc_row_1.pxformt = @fcr_pxformt

if (@orig_equiv_sev = -1)
	select @fcr_best_loc_blm = 'UNKNOWN'
else if ((@equiv_sev - @orig_equiv_sev) <> 0)
	select @fcr_best_loc_blm = 'SEVERE'
else if ((@equiv_mod - @orig_equiv_mod) <> 0)
		select @fcr_best_loc_blm = 'MODERATE'
     else select @fcr_best_loc_blm = 'TRIVIAL'
end
/**************************************************************************/
/*********** instrument foc ref file type GEO ****************/
/**************************************************************************/
select @fcr_best_geo = foc_file_1.file_name,
@equiv_sev = foc_row_1.equivalence_class_severe,
@equiv_mod = foc_row_1.equivalence_class_moderate
from foc_file foc_file_1, foc_row foc_row_1
where foc_file_1.useafter_date = 
	(select max(foc_file_2.useafter_date)
	from foc_file foc_file_2, foc_row foc_row_2
             where foc_file_2.reference_file_type = 'GEO'
             and foc_file_2.useafter_date <= @expstart
             and foc_file_2.reject_flag = 'N'
             and foc_file_2.opus_flag = 'Y'
             and foc_file_2.archive_date is not null
             and foc_file_2.file_name =foc_row_2.file_name
             and foc_file_2.expansion_number = foc_row_2.expansion_number
             and foc_row_2.cammode = @fcr_cammode
             and foc_row_2.lineoff = @fcr_lineoff
             and foc_row_2.linepfm = @fcr_linepfm
             and foc_row_2.optcrly = @fcr_optcrly
             and foc_row_2.optelt1 = @fcr_optelt1
             and foc_row_2.optelt2 = @fcr_optelt2
             and foc_row_2.pxformt = @fcr_pxformt
             and foc_row_2.sampoff = @fcr_sampoff
             and foc_row_2.samppln = @fcr_samppln
             and foc_row_2.smmmode = @fcr_smmmode
        )
and foc_file_1.reference_file_type = 'GEO'
and foc_file_1.reject_flag = 'N'
and foc_file_1.opus_flag = 'Y'
and foc_file_1.archive_date is not null
and foc_file_1.file_name =foc_row_1.file_name
and foc_file_1.expansion_number = foc_row_1.expansion_number
and foc_row_1.cammode = @fcr_cammode
and foc_row_1.lineoff = @fcr_lineoff
and foc_row_1.linepfm = @fcr_linepfm
and foc_row_1.optcrly = @fcr_optcrly
and foc_row_1.optelt1 = @fcr_optelt1
and foc_row_1.optelt2 = @fcr_optelt2
and foc_row_1.pxformt = @fcr_pxformt
and foc_row_1.sampoff = @fcr_sampoff
and foc_row_1.samppln = @fcr_samppln
and foc_row_1.smmmode = @fcr_smmmode
select @num_cal_files = @@rowcount
if (@num_cal_files = 0)    /* no recommended file found */
select @fcr_best_geo = 'N/A', @fcr_best_loc_geo = 'N/A'
else
if (@fcr_geohfile = NULL) /* no file was used in the pipeline */
select @fcr_best_loc_geo = 'N/A'
else
if (@fcr_best_geo = @fcr_geohfile) /* recommended = was used */
select @fcr_best_loc_geo = 'NO CHANGE'
else
if (@equiv_sev = -1)
	select @fcr_best_loc_geo = 'UNKNOWN'
else
begin

select @orig_equiv_sev = foc_row_1.equivalence_class_severe,
@orig_equiv_mod =  foc_row_1.equivalence_class_moderate
from foc_row foc_row_1
where foc_row_1.file_name = @fcr_geohfile
and foc_row_1.cammode = @fcr_cammode
and foc_row_1.lineoff = @fcr_lineoff
and foc_row_1.linepfm = @fcr_linepfm
and foc_row_1.optcrly = @fcr_optcrly
and foc_row_1.optelt1 = @fcr_optelt1
and foc_row_1.optelt2 = @fcr_optelt2
and foc_row_1.pxformt = @fcr_pxformt
and foc_row_1.sampoff = @fcr_sampoff
and foc_row_1.samppln = @fcr_samppln
and foc_row_1.smmmode = @fcr_smmmode

if (@orig_equiv_sev = -1)
	select @fcr_best_loc_geo = 'UNKNOWN'
else if ((@equiv_sev - @orig_equiv_sev) <> 0)
	select @fcr_best_loc_geo = 'SEVERE'
else if ((@equiv_mod - @orig_equiv_mod) <> 0)
		select @fcr_best_loc_geo = 'MODERATE'
     else select @fcr_best_loc_geo = 'TRIVIAL'
end
/**************************************************************************/
/*********** instrument foc ref file type ITF ****************/
/**************************************************************************/
select @fcr_best_itf = foc_file_1.file_name,
@equiv_sev = foc_row_1.equivalence_class_severe,
@equiv_mod = foc_row_1.equivalence_class_moderate
from foc_file foc_file_1, foc_row foc_row_1
where foc_file_1.useafter_date = 
	(select max(foc_file_2.useafter_date)
	from foc_file foc_file_2, foc_row foc_row_2
             where foc_file_2.reference_file_type = 'ITF'
             and foc_file_2.useafter_date <= @expstart
             and foc_file_2.reject_flag = 'N'
             and foc_file_2.opus_flag = 'Y'
             and foc_file_2.archive_date is not null
             and foc_file_2.file_name =foc_row_2.file_name
             and foc_file_2.expansion_number = foc_row_2.expansion_number
             and foc_row_2.lineoff = @fcr_lineoff
             and foc_row_2.linepfm = @fcr_linepfm
             and foc_row_2.optcrly = @fcr_optcrly
             and foc_row_2.pxformt = @fcr_pxformt
             and foc_row_2.sampoff = @fcr_sampoff
             and foc_row_2.samppln = @fcr_samppln
        )
and foc_file_1.reference_file_type = 'ITF'
and foc_file_1.reject_flag = 'N'
and foc_file_1.opus_flag = 'Y'
and foc_file_1.archive_date is not null
and foc_file_1.file_name =foc_row_1.file_name
and foc_file_1.expansion_number = foc_row_1.expansion_number
and foc_row_1.lineoff = @fcr_lineoff
and foc_row_1.linepfm = @fcr_linepfm
and foc_row_1.optcrly = @fcr_optcrly
and foc_row_1.pxformt = @fcr_pxformt
and foc_row_1.sampoff = @fcr_sampoff
and foc_row_1.samppln = @fcr_samppln
select @num_cal_files = @@rowcount
if (@num_cal_files = 0)    /* no recommended file found */
select @fcr_best_itf = 'N/A', @fcr_best_loc_itf = 'N/A'
else
if (@fcr_itfhfile = NULL) /* no file was used in the pipeline */
select @fcr_best_loc_itf = 'N/A'
else
if (@fcr_best_itf = @fcr_itfhfile) /* recommended = was used */
select @fcr_best_loc_itf = 'NO CHANGE'
else
if (@equiv_sev = -1)
	select @fcr_best_loc_itf = 'UNKNOWN'
else
begin

select @orig_equiv_sev = foc_row_1.equivalence_class_severe,
@orig_equiv_mod =  foc_row_1.equivalence_class_moderate
from foc_row foc_row_1
where foc_row_1.file_name = @fcr_itfhfile
and foc_row_1.lineoff = @fcr_lineoff
and foc_row_1.linepfm = @fcr_linepfm
and foc_row_1.optcrly = @fcr_optcrly
and foc_row_1.pxformt = @fcr_pxformt
and foc_row_1.sampoff = @fcr_sampoff
and foc_row_1.samppln = @fcr_samppln

if (@orig_equiv_sev = -1)
	select @fcr_best_loc_itf = 'UNKNOWN'
else if ((@equiv_sev - @orig_equiv_sev) <> 0)
	select @fcr_best_loc_itf = 'SEVERE'
else if ((@equiv_mod - @orig_equiv_mod) <> 0)
		select @fcr_best_loc_itf = 'MODERATE'
     else select @fcr_best_loc_itf = 'TRIVIAL'
end
/**************************************************************************/
/*********** instrument foc ref file type SDE ****************/
/**************************************************************************/
select @fcr_best_sde = foc_file_1.file_name,
@equiv_sev = foc_row_1.equivalence_class_severe,
@equiv_mod = foc_row_1.equivalence_class_moderate
from foc_file foc_file_1, foc_row foc_row_1
where foc_file_1.useafter_date = 
	(select max(foc_file_2.useafter_date)
	from foc_file foc_file_2, foc_row foc_row_2
             where foc_file_2.reference_file_type = 'SDE'
             and foc_file_2.useafter_date <= @expstart
             and foc_file_2.reject_flag = 'N'
             and foc_file_2.opus_flag = 'Y'
             and foc_file_2.archive_date is not null
             and foc_file_2.file_name =foc_row_2.file_name
             and foc_file_2.expansion_number = foc_row_2.expansion_number
             and foc_row_2.optelt1 = @fcr_optelt1
             and foc_row_2.optelt2 = @fcr_optelt2
             and foc_row_2.pxformt = @fcr_pxformt
        )
and foc_file_1.reference_file_type = 'SDE'
and foc_file_1.reject_flag = 'N'
and foc_file_1.opus_flag = 'Y'
and foc_file_1.archive_date is not null
and foc_file_1.file_name =foc_row_1.file_name
and foc_file_1.expansion_number = foc_row_1.expansion_number
and foc_row_1.optelt1 = @fcr_optelt1
and foc_row_1.optelt2 = @fcr_optelt2
and foc_row_1.pxformt = @fcr_pxformt
select @num_cal_files = @@rowcount
if (@num_cal_files = 0)    /* no recommended file found */
select @fcr_best_sde = 'N/A', @fcr_best_loc_sde = 'N/A'
else
if (@fcr_sdehfile = NULL) /* no file was used in the pipeline */
select @fcr_best_loc_sde = 'N/A'
else
if (@fcr_best_sde = @fcr_sdehfile) /* recommended = was used */
select @fcr_best_loc_sde = 'NO CHANGE'
else
if (@equiv_sev = -1)
	select @fcr_best_loc_sde = 'UNKNOWN'
else
begin

select @orig_equiv_sev = foc_row_1.equivalence_class_severe,
@orig_equiv_mod =  foc_row_1.equivalence_class_moderate
from foc_row foc_row_1
where foc_row_1.file_name = @fcr_sdehfile
and foc_row_1.optelt1 = @fcr_optelt1
and foc_row_1.optelt2 = @fcr_optelt2
and foc_row_1.pxformt = @fcr_pxformt

if (@orig_equiv_sev = -1)
	select @fcr_best_loc_sde = 'UNKNOWN'
else if ((@equiv_sev - @orig_equiv_sev) <> 0)
	select @fcr_best_loc_sde = 'SEVERE'
else if ((@equiv_mod - @orig_equiv_mod) <> 0)
		select @fcr_best_loc_sde = 'MODERATE'
     else select @fcr_best_loc_sde = 'TRIVIAL'
end
/**************************************************************************/
/*********** instrument foc ref file type UNI and UNITAB ****************/
/**************************************************************************/
/* begin mod - whole section */
/* handle both UNITAB and UNI together since they are linked */
/* use UNITAB values rather than UNI values */

if ((@fcr_photplam = NULL) OR (@fcr_photplam <= 0))
select @fcr_best_uni = 'N/A', @fcr_best_loc_uni = 'N/A',
       @fcr_best_unitab = 'N/A', @fcr_best_loc_unitab = 'N/A'
else
begin

select @fcr_best_unitab= foc_file_1.file_name
from foc_file foc_file_1, foc_row foc_row_1
where foc_file_1.useafter_date = 
(select max(foc_file_2.useafter_date)
	from foc_file foc_file_2, foc_row foc_row_2
             where foc_file_2.reference_file_type = 'UNITAB'
             and foc_file_2.useafter_date <= @expstart
             and foc_file_2.reject_flag = 'N'
             and foc_file_2.opus_flag = 'Y'
             and foc_file_2.archive_date is not null
             and foc_file_2.file_name =foc_row_2.file_name
             and foc_file_2.expansion_number = foc_row_2.expansion_number
        )
and foc_file_1.reference_file_type = 'UNITAB'
and foc_file_1.reject_flag = 'N'
and foc_file_1.opus_flag = 'Y'
and foc_file_1.archive_date is not null
and foc_file_1.file_name =foc_row_1.file_name
and foc_file_1.expansion_number = foc_row_1.expansion_number

select foc_row_1.wavelength, foc_file_1.file_name,
foc_row_1.uni_file_name,
foc_file_1.expansion_number, foc_row_1.equivalence_class_severe,
foc_row_1.equivalence_class_moderate, ratio=0.0000000
into #temp_foc 
from foc_file foc_file_1, foc_row foc_row_1
where foc_file_1.file_name = @fcr_best_unitab
and foc_row_1.file_name = @fcr_best_unitab
and foc_row_1.optcrly = @fcr_optcrly
and foc_row_1.cammode = @fcr_cammode


create unique clustered index tempind on #temp_foc (uni_file_name,wavelength)

declare  ratio_cursor cursor for
	select wavelength from #temp_foc
for update of ratio

open ratio_cursor

fetch ratio_cursor into @wavelength

while (@@sqlstatus = 0) begin
	if (@wavelength > @fcr_photplam)
	  select @ratio = @fcr_photplam/@wavelength
	else
	  select @ratio = @wavelength/@fcr_photplam
	update #temp_foc set ratio = @ratio
	 where current of ratio_cursor
	fetch ratio_cursor into @wavelength
end /*while*/

close ratio_cursor
deallocate cursor ratio_cursor

select @fcr_best_uni = o.uni_file_name, @wavelength = o.wavelength,
 @fcr_best_unitab = o.file_name,
 @equiv_sev = o.equivalence_class_severe,
 @equiv_mod = o.equivalence_class_moderate from #temp_foc o
 where o.ratio = (select max(i.ratio) from #temp_foc i)

/* compute severity level */

select @num_cal_files = @@rowcount
if (@num_cal_files = 0)    /* no recommended file found */
select @fcr_best_uni = 'N/A', @fcr_best_loc_uni = 'N/A',
       @fcr_best_unitab = 'N/A', @fcr_best_loc_unitab = 'N/A'
else
 begin /* process UNITAB first */
  if (@fcr_best_unitab = @fcr_unitab) /* recommended = was used */
   select @fcr_best_loc_unitab = 'NO CHANGE'
  else
   if (@fcr_unitab = NULL) /* no file was used in the pipeline */
    select @fcr_best_loc_unitab = 'N/A'
   else
    if (@equiv_sev = -1)
     select @fcr_best_loc_unitab = 'UNKNOWN'
   else
    begin
     select @orig_equiv_sev = foc_row_1.equivalence_class_severe,
     @orig_equiv_mod =  foc_row_1.equivalence_class_moderate
     from foc_row foc_row_1
     where foc_row_1.file_name = @fcr_unitab
     and foc_row_1.cammode = @fcr_cammode
     and foc_row_1.optcrly = @fcr_optcrly
     and foc_row_1.wavelength = @wavelength

     if (@orig_equiv_sev = -1)
	select @fcr_best_loc_unitab = 'UNKNOWN'
     else if ((@equiv_sev - @orig_equiv_sev) <> 0)
	select @fcr_best_loc_unitab = 'SEVERE'
     else if ((@equiv_mod - @orig_equiv_mod) <> 0)
		select @fcr_best_loc_unitab = 'MODERATE'
     else select @fcr_best_loc_unitab = 'TRIVIAL'
   end
           /* now process UNI next */
  if (@fcr_best_uni = @fcr_unihfile) /* recommended = was used */
   select @fcr_best_loc_uni = 'NO CHANGE'
  else
   if (@fcr_unihfile = NULL) /* no file was used in the pipeline */
    select @fcr_best_loc_uni = 'N/A'
   else
    if (@equiv_sev = -1)
     select @fcr_best_loc_uni = 'UNKNOWN'
   else
    begin
     select @orig_equiv_sev = foc_row_1.equivalence_class_severe,
     @orig_equiv_mod =  foc_row_1.equivalence_class_moderate
     from foc_row foc_row_1
     where foc_row_1.file_name = @fcr_unihfile
     and foc_row_1.cammode = @fcr_cammode
     and foc_row_1.optcrly = @fcr_optcrly
     and foc_row_1.wavelength = @wavelength

     if (@orig_equiv_sev = -1)
	select @fcr_best_loc_uni = 'UNKNOWN'
     else if ((@equiv_sev - @orig_equiv_sev) <> 0)
	select @fcr_best_loc_uni = 'SEVERE'
     else if ((@equiv_mod - @orig_equiv_mod) <> 0)
		select @fcr_best_loc_uni = 'MODERATE'
     else select @fcr_best_loc_uni = 'TRIVIAL'
   end
end /* computing severity level */

drop table #temp_foc
end

/* end mod */

/**************************************************************************/
/*********** instrument foc ref file type COMPTAB ****************/
/**************************************************************************/
/* begin mod - OPR 35935 - 12/31/97 - remove level of change computation */

select @fcr_best_comptab = synphot_file_1.file_name,
@equiv_sev = synphot_row_1.equivalence_class_severe,
@equiv_mod = synphot_row_1.equivalence_class_moderate
from synphot_file synphot_file_1, synphot_row synphot_row_1
where synphot_file_1.useafter_date = 
	(select max(synphot_file_2.useafter_date)
	from synphot_file synphot_file_2, synphot_row synphot_row_2
             where synphot_file_2.reference_file_type = 'COMPTAB'
             and synphot_file_2.useafter_date <= @expstart
             and synphot_file_2.reject_flag = 'N'
             and synphot_file_2.opus_flag = 'Y'
             and synphot_file_2.archive_date is not null
             and synphot_file_2.file_name =synphot_row_2.file_name
             and synphot_file_2.expansion_number = synphot_row_2.expansion_number
        )
and synphot_file_1.reference_file_type = 'COMPTAB'
and synphot_file_1.reject_flag = 'N'
and synphot_file_1.opus_flag = 'Y'
and synphot_file_1.archive_date is not null
and synphot_file_1.file_name =synphot_row_1.file_name
and synphot_file_1.expansion_number = synphot_row_1.expansion_number
select @num_cal_files = @@rowcount
if (@num_cal_files = 0)    /* no recommended file found */
select @fcr_best_comptab = 'N/A'
/* end mod */

/**************************************************************************/
/*********** instrument foc ref file type GRAPHTAB ****************/
/**************************************************************************/
/* begin mod - OPR 35935 - 12/31/97 - remove level of change computation */

select @fcr_best_graphtab = synphot_file_1.file_name,
@equiv_sev = synphot_row_1.equivalence_class_severe,
@equiv_mod = synphot_row_1.equivalence_class_moderate
from synphot_file synphot_file_1, synphot_row synphot_row_1
where synphot_file_1.useafter_date = 
	(select max(synphot_file_2.useafter_date)
	from synphot_file synphot_file_2, synphot_row synphot_row_2
             where synphot_file_2.reference_file_type = 'GRAPHTAB'
             and synphot_file_2.useafter_date <= @expstart
             and synphot_file_2.reject_flag = 'N'
             and synphot_file_2.opus_flag = 'Y'
             and synphot_file_2.archive_date is not null
             and synphot_file_2.file_name =synphot_row_2.file_name
             and synphot_file_2.expansion_number = synphot_row_2.expansion_number
        )
and synphot_file_1.reference_file_type = 'GRAPHTAB'
and synphot_file_1.reject_flag = 'N'
and synphot_file_1.opus_flag = 'Y'
and synphot_file_1.archive_date is not null
and synphot_file_1.file_name =synphot_row_1.file_name
and synphot_file_1.expansion_number = synphot_row_1.expansion_number
select @num_cal_files = @@rowcount
if (@num_cal_files = 0)    /* no recommended file found */
select @fcr_best_graphtab = 'N/A'
/* end mod */

update foc_ref_data
set
fcr_best_bac = @fcr_best_bac
,fcr_best_loc_bac = @fcr_best_loc_bac
,fcr_best_blm = @fcr_best_blm
,fcr_best_loc_blm = @fcr_best_loc_blm
,fcr_best_geo = @fcr_best_geo
,fcr_best_loc_geo = @fcr_best_loc_geo
,fcr_best_itf = @fcr_best_itf
,fcr_best_loc_itf = @fcr_best_loc_itf
,fcr_best_sde = @fcr_best_sde
,fcr_best_loc_sde = @fcr_best_loc_sde
,fcr_best_uni = @fcr_best_uni
,fcr_best_loc_uni = @fcr_best_loc_uni
,fcr_best_unitab = @fcr_best_unitab
,fcr_best_loc_unitab = @fcr_best_loc_unitab
,fcr_best_comptab = @fcr_best_comptab
,fcr_best_graphtab = @fcr_best_graphtab
where current of update_foc_cursor
fetch update_foc_cursor into @expstart,@data_set_name
,@fcr_cammode
,@fcr_lineoff
,@fcr_linepfm
,@fcr_optcrly
,@fcr_optelt1
,@fcr_optelt2
,@fcr_pxformt
,@fcr_sampoff
,@fcr_samppln
,@fcr_smmmode
,@fcr_photplam
,@fcr_bachfile
,@fcr_blmhfile
,@fcr_geohfile
,@fcr_itfhfile
,@fcr_unihfile
,@fcr_unitab
,@fcr_sdehfile
,@fcr_comptab
,@fcr_graphtab
end
close update_foc_cursor 
deallocate cursor update_foc_cursor 
return
go
