use dadsops
go
drop procedure update_hsp
go
create procedure update_hsp as
/* observation start time */
declare @expstart datetime
/* data set name, to be used for error checking/handling */
declare @data_set_name datasetname
/* severity level variables, to be reused for each reference file type */
declare @orig_equiv_sev int
declare @orig_equiv_mod int
declare @equiv_sev int
declare @equiv_mod int
/* used to store @@rowcount global variable */
declare @num_cal_files int
/* observation modes, calibration files used in the pipeline, */
/* best, and best_loc files */
declare @hpr_thresh int
declare @hpr_voltage int
declare @hpr_ccp0 char(18)
declare @hpr_ccp1 char(18)
declare @hpr_ccp2 char(18)
declare @hpr_ccp3 char(18)
declare @hpr_ccp4 char(18)
declare @hpr_ccp5 char(18)
declare @hpr_ccp7 char(18)
declare @hpr_ccp8 char(18)
declare @hpr_ccp9 char(18)
declare @hpr_vgaind int
declare @hpr_comptab char(18)
declare @hpr_data_typ char(7)
declare @hpr_apertobj char(10)
declare @hpr_detectob int
declare @hpr_graphtab char(18)
declare @hpr_best_ccp0 char(18)
declare @hpr_best_ccp1 char(18)
declare @hpr_best_ccp2 char(18)
declare @hpr_best_ccp3 char(18)
declare @hpr_best_ccp4 char(18)
declare @hpr_best_ccp5 char(18)
declare @hpr_best_ccp7 char(18)
declare @hpr_best_ccp8 char(18)
declare @hpr_best_ccp9 char(18)
declare @hpr_best_comptab char(18)
declare @hpr_best_graphtab char(18)
declare @hpr_best_loc_ccp0 varchar(9)
declare @hpr_best_loc_ccp1 varchar(9)
declare @hpr_best_loc_ccp2 varchar(9)
declare @hpr_best_loc_ccp3 varchar(9)
declare @hpr_best_loc_ccp4 varchar(9)
declare @hpr_best_loc_ccp5 varchar(9)
declare @hpr_best_loc_ccp7 varchar(9)
declare @hpr_best_loc_ccp8 varchar(9)
declare @hpr_best_loc_ccp9 varchar(9)
declare update_hsp_cursor  cursor for
select hpr_expstart,hpr_data_set_name
,hpr_data_typ
,hpr_thresh
,hpr_vgaind
,hpr_detectob
,hpr_voltage
,hpr_apertobj
,hpr_ccp0
,hpr_ccp1
,hpr_ccp2
,hpr_ccp3
,hpr_ccp4
,hpr_ccp7
,hpr_ccp8
,hpr_ccp9
,hpr_ccp5
,hpr_comptab
,hpr_graphtab
from hsp_ref_data
where hpr_best_ccp0 is null
or hpr_best_ccp1 is null
or hpr_best_ccp2 is null
or hpr_best_ccp3 is null
or hpr_best_ccp4 is null
or hpr_best_ccp7 is null
or hpr_best_ccp8 is null
or hpr_best_ccp9 is null
or hpr_best_ccp5 is null
or hpr_best_comptab is null
or hpr_best_graphtab is null
 for update
open update_hsp_cursor 
fetch update_hsp_cursor into @expstart,@data_set_name
,@hpr_data_typ
,@hpr_thresh
,@hpr_vgaind
,@hpr_detectob
,@hpr_voltage
,@hpr_apertobj
,@hpr_ccp0
,@hpr_ccp1
,@hpr_ccp2
,@hpr_ccp3
,@hpr_ccp4
,@hpr_ccp7
,@hpr_ccp8
,@hpr_ccp9
,@hpr_ccp5
,@hpr_comptab
,@hpr_graphtab
/**************************************************************************/
/************************ Update hsp ***********************/
/**************************************************************************/
while (@@sqlstatus = 0)
begin
select
@hpr_best_ccp0 = null
,@hpr_best_ccp1 = null
,@hpr_best_ccp2 = null
,@hpr_best_ccp3 = null
,@hpr_best_ccp4 = null
,@hpr_best_ccp5 = null
,@hpr_best_ccp7 = null
,@hpr_best_ccp8 = null
,@hpr_best_ccp9 = null
,@hpr_best_comptab = null
,@hpr_best_graphtab = null
,@hpr_best_loc_ccp0 = null
,@hpr_best_loc_ccp1 = null
,@hpr_best_loc_ccp2 = null
,@hpr_best_loc_ccp3 = null
,@hpr_best_loc_ccp4 = null
,@hpr_best_loc_ccp5 = null
,@hpr_best_loc_ccp7 = null
,@hpr_best_loc_ccp8 = null
,@hpr_best_loc_ccp9 = null
/**************************************************************************/
/*********** instrument hsp ref file type CCP0 ****************/
/**************************************************************************/
select @hpr_best_ccp0 = hsp_file_1.file_name,
@equiv_sev = hsp_row_1.equivalence_class_severe,
@equiv_mod = hsp_row_1.equivalence_class_moderate
from hsp_file hsp_file_1, hsp_row hsp_row_1
where hsp_file_1.useafter_date = 
	(select max(hsp_file_2.useafter_date)
	from hsp_file hsp_file_2, hsp_row hsp_row_2
             where hsp_file_2.reference_file_type = 'CCP0'
             and hsp_file_2.useafter_date <= @expstart
             and hsp_file_2.reject_flag = 'N'
             and hsp_file_2.opus_flag = 'Y'
             and hsp_file_2.archive_date is not null
             and hsp_file_2.file_name =hsp_row_2.file_name
             and hsp_file_2.expansion_number = hsp_row_2.expansion_number
             and hsp_row_2.aper_name = @hpr_apertobj
        )
and hsp_file_1.reference_file_type = 'CCP0'
and hsp_file_1.reject_flag = 'N'
and hsp_file_1.opus_flag = 'Y'
and hsp_file_1.archive_date is not null
and hsp_file_1.file_name =hsp_row_1.file_name
and hsp_file_1.expansion_number = hsp_row_1.expansion_number
and hsp_row_1.aper_name = @hpr_apertobj
select @num_cal_files = @@rowcount
if (@num_cal_files = 0)    /* no recommended file found */
select @hpr_best_ccp0 = 'N/A', @hpr_best_loc_ccp0 = 'N/A'
else
if (@hpr_ccp0 = NULL) /* no file was used in the pipeline */
select @hpr_best_loc_ccp0 = 'N/A'
else
if (@hpr_best_ccp0 = @hpr_ccp0) /* recommended = was used */
select @hpr_best_loc_ccp0 = 'NO CHANGE'
else
if (@equiv_sev = -1)
	select @hpr_best_loc_ccp0 = 'UNKNOWN'
else
begin

select @orig_equiv_sev = hsp_row_1.equivalence_class_severe,
@orig_equiv_mod =  hsp_row_1.equivalence_class_moderate
from hsp_row hsp_row_1
where hsp_row_1.file_name = @hpr_ccp0
and hsp_row_1.aper_name = @hpr_apertobj

if (@orig_equiv_sev = -1)
	select @hpr_best_loc_ccp0 = 'UNKNOWN'
else if ((@equiv_sev - @orig_equiv_sev) <> 0)
	select @hpr_best_loc_ccp0 = 'SEVERE'
else if ((@equiv_mod - @orig_equiv_mod) <> 0)
		select @hpr_best_loc_ccp0 = 'MODERATE'
     else select @hpr_best_loc_ccp0 = 'TRIVIAL'
end
/**************************************************************************/
/*********** instrument hsp ref file type CCP1 ****************/
/**************************************************************************/
select @hpr_best_ccp1 = hsp_file_1.file_name,
@equiv_sev = hsp_row_1.equivalence_class_severe,
@equiv_mod = hsp_row_1.equivalence_class_moderate
from hsp_file hsp_file_1, hsp_row hsp_row_1
where hsp_file_1.useafter_date = 
	(select max(hsp_file_2.useafter_date)
	from hsp_file hsp_file_2, hsp_row hsp_row_2
             where hsp_file_2.reference_file_type = 'CCP1'
             and hsp_file_2.useafter_date <= @expstart
             and hsp_file_2.reject_flag = 'N'
             and hsp_file_2.opus_flag = 'Y'
             and hsp_file_2.archive_date is not null
             and hsp_file_2.file_name =hsp_row_2.file_name
             and hsp_file_2.expansion_number = hsp_row_2.expansion_number
             and hsp_row_2.type = @hpr_data_typ
             and hsp_row_2.voltage = @hpr_voltage
             and hsp_row_2.det_num = @hpr_detectob
        )
and hsp_file_1.reference_file_type = 'CCP1'
and hsp_file_1.reject_flag = 'N'
and hsp_file_1.opus_flag = 'Y'
and hsp_file_1.archive_date is not null
and hsp_file_1.file_name =hsp_row_1.file_name
and hsp_file_1.expansion_number = hsp_row_1.expansion_number
and hsp_row_1.type = @hpr_data_typ
and hsp_row_1.voltage = @hpr_voltage
and hsp_row_1.det_num = @hpr_detectob
select @num_cal_files = @@rowcount
if (@num_cal_files = 0)    /* no recommended file found */
select @hpr_best_ccp1 = 'N/A', @hpr_best_loc_ccp1 = 'N/A'
else
if (@hpr_ccp1 = NULL) /* no file was used in the pipeline */
select @hpr_best_loc_ccp1 = 'N/A'
else
if (@hpr_best_ccp1 = @hpr_ccp1) /* recommended = was used */
select @hpr_best_loc_ccp1 = 'NO CHANGE'
else
if (@equiv_sev = -1)
	select @hpr_best_loc_ccp1 = 'UNKNOWN'
else
begin

select @orig_equiv_sev = hsp_row_1.equivalence_class_severe,
@orig_equiv_mod =  hsp_row_1.equivalence_class_moderate
from hsp_row hsp_row_1
where hsp_row_1.file_name = @hpr_ccp1
and hsp_row_1.type = @hpr_data_typ
and hsp_row_1.voltage = @hpr_voltage
and hsp_row_1.det_num = @hpr_detectob

if (@orig_equiv_sev = -1)
	select @hpr_best_loc_ccp1 = 'UNKNOWN'
else if ((@equiv_sev - @orig_equiv_sev) <> 0)
	select @hpr_best_loc_ccp1 = 'SEVERE'
else if ((@equiv_mod - @orig_equiv_mod) <> 0)
		select @hpr_best_loc_ccp1 = 'MODERATE'
     else select @hpr_best_loc_ccp1 = 'TRIVIAL'
end
/**************************************************************************/
/*********** instrument hsp ref file type CCP2 ****************/
/**************************************************************************/
select @hpr_best_ccp2 = hsp_file_1.file_name,
@equiv_sev = hsp_row_1.equivalence_class_severe,
@equiv_mod = hsp_row_1.equivalence_class_moderate
from hsp_file hsp_file_1, hsp_row hsp_row_1
where hsp_file_1.useafter_date = 
	(select max(hsp_file_2.useafter_date)
	from hsp_file hsp_file_2, hsp_row hsp_row_2
             where hsp_file_2.reference_file_type = 'CCP2'
             and hsp_file_2.useafter_date <= @expstart
             and hsp_file_2.reject_flag = 'N'
             and hsp_file_2.opus_flag = 'Y'
             and hsp_file_2.archive_date is not null
             and hsp_file_2.file_name =hsp_row_2.file_name
             and hsp_file_2.expansion_number = hsp_row_2.expansion_number
             and hsp_row_2.vgaind = @hpr_vgaind
             and hsp_row_2.det_num = @hpr_detectob
        )
and hsp_file_1.reference_file_type = 'CCP2'
and hsp_file_1.reject_flag = 'N'
and hsp_file_1.opus_flag = 'Y'
and hsp_file_1.archive_date is not null
and hsp_file_1.file_name =hsp_row_1.file_name
and hsp_file_1.expansion_number = hsp_row_1.expansion_number
and hsp_row_1.vgaind = @hpr_vgaind
and hsp_row_1.det_num = @hpr_detectob
select @num_cal_files = @@rowcount
if (@num_cal_files = 0)    /* no recommended file found */
select @hpr_best_ccp2 = 'N/A', @hpr_best_loc_ccp2 = 'N/A'
else
if (@hpr_ccp2 = NULL) /* no file was used in the pipeline */
select @hpr_best_loc_ccp2 = 'N/A'
else
if (@hpr_best_ccp2 = @hpr_ccp2) /* recommended = was used */
select @hpr_best_loc_ccp2 = 'NO CHANGE'
else
if (@equiv_sev = -1)
	select @hpr_best_loc_ccp2 = 'UNKNOWN'
else
begin

select @orig_equiv_sev = hsp_row_1.equivalence_class_severe,
@orig_equiv_mod =  hsp_row_1.equivalence_class_moderate
from hsp_row hsp_row_1
where hsp_row_1.file_name = @hpr_ccp2
and hsp_row_1.vgaind = @hpr_vgaind
and hsp_row_1.det_num = @hpr_detectob

if (@orig_equiv_sev = -1)
	select @hpr_best_loc_ccp2 = 'UNKNOWN'
else if ((@equiv_sev - @orig_equiv_sev) <> 0)
	select @hpr_best_loc_ccp2 = 'SEVERE'
else if ((@equiv_mod - @orig_equiv_mod) <> 0)
		select @hpr_best_loc_ccp2 = 'MODERATE'
     else select @hpr_best_loc_ccp2 = 'TRIVIAL'
end
/**************************************************************************/
/*********** instrument hsp ref file type CCP3 ****************/
/**************************************************************************/
select @hpr_best_ccp3 = hsp_file_1.file_name,
@equiv_sev = hsp_row_1.equivalence_class_severe,
@equiv_mod = hsp_row_1.equivalence_class_moderate
from hsp_file hsp_file_1, hsp_row hsp_row_1
where hsp_file_1.useafter_date = 
	(select max(hsp_file_2.useafter_date)
	from hsp_file hsp_file_2, hsp_row hsp_row_2
             where hsp_file_2.reference_file_type = 'CCP3'
             and hsp_file_2.useafter_date <= @expstart
             and hsp_file_2.reject_flag = 'N'
             and hsp_file_2.opus_flag = 'Y'
             and hsp_file_2.archive_date is not null
             and hsp_file_2.file_name =hsp_row_2.file_name
             and hsp_file_2.expansion_number = hsp_row_2.expansion_number
             and hsp_row_2.type = @hpr_data_typ
             and hsp_row_2.det_num = @hpr_detectob
        )
and hsp_file_1.reference_file_type = 'CCP3'
and hsp_file_1.reject_flag = 'N'
and hsp_file_1.opus_flag = 'Y'
and hsp_file_1.archive_date is not null
and hsp_file_1.file_name =hsp_row_1.file_name
and hsp_file_1.expansion_number = hsp_row_1.expansion_number
and hsp_row_1.type = @hpr_data_typ
and hsp_row_1.det_num = @hpr_detectob
select @num_cal_files = @@rowcount
if (@num_cal_files = 0)    /* no recommended file found */
select @hpr_best_ccp3 = 'N/A', @hpr_best_loc_ccp3 = 'N/A'
else
if (@hpr_ccp3 = NULL) /* no file was used in the pipeline */
select @hpr_best_loc_ccp3 = 'N/A'
else
if (@hpr_best_ccp3 = @hpr_ccp3) /* recommended = was used */
select @hpr_best_loc_ccp3 = 'NO CHANGE'
else
if (@equiv_sev = -1)
	select @hpr_best_loc_ccp3 = 'UNKNOWN'
else
begin

select @orig_equiv_sev = hsp_row_1.equivalence_class_severe,
@orig_equiv_mod =  hsp_row_1.equivalence_class_moderate
from hsp_row hsp_row_1
where hsp_row_1.file_name = @hpr_ccp3
and hsp_row_1.type = @hpr_data_typ
and hsp_row_1.det_num = @hpr_detectob

if (@orig_equiv_sev = -1)
	select @hpr_best_loc_ccp3 = 'UNKNOWN'
else if ((@equiv_sev - @orig_equiv_sev) <> 0)
	select @hpr_best_loc_ccp3 = 'SEVERE'
else if ((@equiv_mod - @orig_equiv_mod) <> 0)
		select @hpr_best_loc_ccp3 = 'MODERATE'
     else select @hpr_best_loc_ccp3 = 'TRIVIAL'
end
/**************************************************************************/
/*********** instrument hsp ref file type CCP4 ****************/
/**************************************************************************/
select @hpr_best_ccp4 = hsp_file_1.file_name,
@equiv_sev = hsp_row_1.equivalence_class_severe,
@equiv_mod = hsp_row_1.equivalence_class_moderate
from hsp_file hsp_file_1, hsp_row hsp_row_1
where hsp_file_1.useafter_date = 
	(select max(hsp_file_2.useafter_date)
	from hsp_file hsp_file_2, hsp_row hsp_row_2
             where hsp_file_2.reference_file_type = 'CCP4'
             and hsp_file_2.useafter_date <= @expstart
             and hsp_file_2.reject_flag = 'N'
             and hsp_file_2.opus_flag = 'Y'
             and hsp_file_2.archive_date is not null
             and hsp_file_2.file_name =hsp_row_2.file_name
             and hsp_file_2.expansion_number = hsp_row_2.expansion_number
             and hsp_row_2.det_num = @hpr_detectob
             and hsp_row_2.aper_name = @hpr_apertobj
        )
and hsp_file_1.reference_file_type = 'CCP4'
and hsp_file_1.reject_flag = 'N'
and hsp_file_1.opus_flag = 'Y'
and hsp_file_1.archive_date is not null
and hsp_file_1.file_name =hsp_row_1.file_name
and hsp_file_1.expansion_number = hsp_row_1.expansion_number
and hsp_row_1.det_num = @hpr_detectob
and hsp_row_1.aper_name = @hpr_apertobj
select @num_cal_files = @@rowcount
if (@num_cal_files = 0)    /* no recommended file found */
select @hpr_best_ccp4 = 'N/A', @hpr_best_loc_ccp4 = 'N/A'
else
if (@hpr_ccp4 = NULL) /* no file was used in the pipeline */
select @hpr_best_loc_ccp4 = 'N/A'
else
if (@hpr_best_ccp4 = @hpr_ccp4) /* recommended = was used */
select @hpr_best_loc_ccp4 = 'NO CHANGE'
else
if (@equiv_sev = -1)
	select @hpr_best_loc_ccp4 = 'UNKNOWN'
else
begin

select @orig_equiv_sev = hsp_row_1.equivalence_class_severe,
@orig_equiv_mod =  hsp_row_1.equivalence_class_moderate
from hsp_row hsp_row_1
where hsp_row_1.file_name = @hpr_ccp4
and hsp_row_1.det_num = @hpr_detectob
and hsp_row_1.aper_name = @hpr_apertobj

if (@orig_equiv_sev = -1)
	select @hpr_best_loc_ccp4 = 'UNKNOWN'
else if ((@equiv_sev - @orig_equiv_sev) <> 0)
	select @hpr_best_loc_ccp4 = 'SEVERE'
else if ((@equiv_mod - @orig_equiv_mod) <> 0)
		select @hpr_best_loc_ccp4 = 'MODERATE'
     else select @hpr_best_loc_ccp4 = 'TRIVIAL'
end
/**************************************************************************/
/*********** instrument hsp ref file type CCP5 ****************/
/**************************************************************************/
select @hpr_best_ccp5 = hsp_file_1.file_name,
@equiv_sev = hsp_row_1.equivalence_class_severe,
@equiv_mod = hsp_row_1.equivalence_class_moderate
from hsp_file hsp_file_1, hsp_row hsp_row_1
where hsp_file_1.useafter_date = 
	(select max(hsp_file_2.useafter_date)
	from hsp_file hsp_file_2, hsp_row hsp_row_2
             where hsp_file_2.reference_file_type = 'CCP5'
             and hsp_file_2.useafter_date <= @expstart
             and hsp_file_2.reject_flag = 'N'
             and hsp_file_2.opus_flag = 'Y'
             and hsp_file_2.archive_date is not null
             and hsp_file_2.file_name =hsp_row_2.file_name
             and hsp_file_2.expansion_number = hsp_row_2.expansion_number
        )
and hsp_file_1.reference_file_type = 'CCP5'
and hsp_file_1.reject_flag = 'N'
and hsp_file_1.opus_flag = 'Y'
and hsp_file_1.archive_date is not null
and hsp_file_1.file_name =hsp_row_1.file_name
and hsp_file_1.expansion_number = hsp_row_1.expansion_number
select @num_cal_files = @@rowcount
if (@num_cal_files = 0)    /* no recommended file found */
select @hpr_best_ccp5 = 'N/A', @hpr_best_loc_ccp5 = 'N/A'
else
if (@hpr_ccp5 = NULL) /* no file was used in the pipeline */
select @hpr_best_loc_ccp5 = 'N/A'
else
if (@hpr_best_ccp5 = @hpr_ccp5) /* recommended = was used */
select @hpr_best_loc_ccp5 = 'NO CHANGE'
else
if (@equiv_sev = -1)
	select @hpr_best_loc_ccp5 = 'UNKNOWN'
else
begin

select @orig_equiv_sev = hsp_row_1.equivalence_class_severe,
@orig_equiv_mod =  hsp_row_1.equivalence_class_moderate
from hsp_row hsp_row_1
where hsp_row_1.file_name = @hpr_ccp5

if (@orig_equiv_sev = -1)
	select @hpr_best_loc_ccp5 = 'UNKNOWN'
else if ((@equiv_sev - @orig_equiv_sev) <> 0)
	select @hpr_best_loc_ccp5 = 'SEVERE'
else if ((@equiv_mod - @orig_equiv_mod) <> 0)
		select @hpr_best_loc_ccp5 = 'MODERATE'
     else select @hpr_best_loc_ccp5 = 'TRIVIAL'
end
/**************************************************************************/
/*********** instrument hsp ref file type CCP7 ****************/
/**************************************************************************/
select @hpr_best_ccp7 = hsp_file_1.file_name,
@equiv_sev = hsp_row_1.equivalence_class_severe,
@equiv_mod = hsp_row_1.equivalence_class_moderate
from hsp_file hsp_file_1, hsp_row hsp_row_1
where hsp_file_1.useafter_date = 
	(select max(hsp_file_2.useafter_date)
	from hsp_file hsp_file_2, hsp_row hsp_row_2
             where hsp_file_2.reference_file_type = 'CCP7'
             and hsp_file_2.useafter_date <= @expstart
             and hsp_file_2.reject_flag = 'N'
             and hsp_file_2.opus_flag = 'Y'
             and hsp_file_2.archive_date is not null
             and hsp_file_2.file_name =hsp_row_2.file_name
             and hsp_file_2.expansion_number = hsp_row_2.expansion_number
             and hsp_row_2.vgaind = @hpr_vgaind
             and hsp_row_2.det_num = @hpr_detectob
        )
and hsp_file_1.reference_file_type = 'CCP7'
and hsp_file_1.reject_flag = 'N'
and hsp_file_1.opus_flag = 'Y'
and hsp_file_1.archive_date is not null
and hsp_file_1.file_name =hsp_row_1.file_name
and hsp_file_1.expansion_number = hsp_row_1.expansion_number
and hsp_row_1.vgaind = @hpr_vgaind
and hsp_row_1.det_num = @hpr_detectob
select @num_cal_files = @@rowcount
if (@num_cal_files = 0)    /* no recommended file found */
select @hpr_best_ccp7 = 'N/A', @hpr_best_loc_ccp7 = 'N/A'
else
if (@hpr_ccp7 = NULL) /* no file was used in the pipeline */
select @hpr_best_loc_ccp7 = 'N/A'
else
if (@hpr_best_ccp7 = @hpr_ccp7) /* recommended = was used */
select @hpr_best_loc_ccp7 = 'NO CHANGE'
else
if (@equiv_sev = -1)
	select @hpr_best_loc_ccp7 = 'UNKNOWN'
else
begin

select @orig_equiv_sev = hsp_row_1.equivalence_class_severe,
@orig_equiv_mod =  hsp_row_1.equivalence_class_moderate
from hsp_row hsp_row_1
where hsp_row_1.file_name = @hpr_ccp7
and hsp_row_1.vgaind = @hpr_vgaind
and hsp_row_1.det_num = @hpr_detectob

if (@orig_equiv_sev = -1)
	select @hpr_best_loc_ccp7 = 'UNKNOWN'
else if ((@equiv_sev - @orig_equiv_sev) <> 0)
	select @hpr_best_loc_ccp7 = 'SEVERE'
else if ((@equiv_mod - @orig_equiv_mod) <> 0)
		select @hpr_best_loc_ccp7 = 'MODERATE'
     else select @hpr_best_loc_ccp7 = 'TRIVIAL'
end
/**************************************************************************/
/*********** instrument hsp ref file type CCP8 ****************/
/**************************************************************************/
select @hpr_best_ccp8 = hsp_file_1.file_name,
@equiv_sev = hsp_row_1.equivalence_class_severe,
@equiv_mod = hsp_row_1.equivalence_class_moderate
from hsp_file hsp_file_1, hsp_row hsp_row_1
where hsp_file_1.useafter_date = 
	(select max(hsp_file_2.useafter_date)
	from hsp_file hsp_file_2, hsp_row hsp_row_2
             where hsp_file_2.reference_file_type = 'CCP8'
             and hsp_file_2.useafter_date <= @expstart
             and hsp_file_2.reject_flag = 'N'
             and hsp_file_2.opus_flag = 'Y'
             and hsp_file_2.archive_date is not null
             and hsp_file_2.file_name =hsp_row_2.file_name
             and hsp_file_2.expansion_number = hsp_row_2.expansion_number
             and hsp_row_2.thresh = @hpr_thresh
             and hsp_row_2.voltage = @hpr_voltage
             and hsp_row_2.det_num = @hpr_detectob
        )
and hsp_file_1.reference_file_type = 'CCP8'
and hsp_file_1.reject_flag = 'N'
and hsp_file_1.opus_flag = 'Y'
and hsp_file_1.archive_date is not null
and hsp_file_1.file_name =hsp_row_1.file_name
and hsp_file_1.expansion_number = hsp_row_1.expansion_number
and hsp_row_1.thresh = @hpr_thresh
and hsp_row_1.voltage = @hpr_voltage
and hsp_row_1.det_num = @hpr_detectob
select @num_cal_files = @@rowcount
if (@num_cal_files = 0)    /* no recommended file found */
select @hpr_best_ccp8 = 'N/A', @hpr_best_loc_ccp8 = 'N/A'
else
if (@hpr_ccp8 = NULL) /* no file was used in the pipeline */
select @hpr_best_loc_ccp8 = 'N/A'
else
if (@hpr_best_ccp8 = @hpr_ccp8) /* recommended = was used */
select @hpr_best_loc_ccp8 = 'NO CHANGE'
else
if (@equiv_sev = -1)
	select @hpr_best_loc_ccp8 = 'UNKNOWN'
else
begin

select @orig_equiv_sev = hsp_row_1.equivalence_class_severe,
@orig_equiv_mod =  hsp_row_1.equivalence_class_moderate
from hsp_row hsp_row_1
where hsp_row_1.file_name = @hpr_ccp8
and hsp_row_1.thresh = @hpr_thresh
and hsp_row_1.voltage = @hpr_voltage
and hsp_row_1.det_num = @hpr_detectob

if (@orig_equiv_sev = -1)
	select @hpr_best_loc_ccp8 = 'UNKNOWN'
else if ((@equiv_sev - @orig_equiv_sev) <> 0)
	select @hpr_best_loc_ccp8 = 'SEVERE'
else if ((@equiv_mod - @orig_equiv_mod) <> 0)
		select @hpr_best_loc_ccp8 = 'MODERATE'
     else select @hpr_best_loc_ccp8 = 'TRIVIAL'
end
/**************************************************************************/
/*********** instrument hsp ref file type CCP9 ****************/
/**************************************************************************/
select @hpr_best_ccp9 = hsp_file_1.file_name,
@equiv_sev = hsp_row_1.equivalence_class_severe,
@equiv_mod = hsp_row_1.equivalence_class_moderate
from hsp_file hsp_file_1, hsp_row hsp_row_1
where hsp_file_1.useafter_date = 
	(select max(hsp_file_2.useafter_date)
	from hsp_file hsp_file_2, hsp_row hsp_row_2
             where hsp_file_2.reference_file_type = 'CCP9'
             and hsp_file_2.useafter_date <= @expstart
             and hsp_file_2.reject_flag = 'N'
             and hsp_file_2.opus_flag = 'Y'
             and hsp_file_2.archive_date is not null
             and hsp_file_2.file_name =hsp_row_2.file_name
             and hsp_file_2.expansion_number = hsp_row_2.expansion_number
             and hsp_row_2.det_num = @hpr_detectob
             and hsp_row_2.aper_name = @hpr_apertobj
        )
and hsp_file_1.reference_file_type = 'CCP9'
and hsp_file_1.reject_flag = 'N'
and hsp_file_1.opus_flag = 'Y'
and hsp_file_1.archive_date is not null
and hsp_file_1.file_name =hsp_row_1.file_name
and hsp_file_1.expansion_number = hsp_row_1.expansion_number
and hsp_row_1.det_num = @hpr_detectob
and hsp_row_1.aper_name = @hpr_apertobj
select @num_cal_files = @@rowcount
if (@num_cal_files = 0)    /* no recommended file found */
select @hpr_best_ccp9 = 'N/A', @hpr_best_loc_ccp9 = 'N/A'
else
if (@hpr_ccp9 = NULL) /* no file was used in the pipeline */
select @hpr_best_loc_ccp9 = 'N/A'
else
if (@hpr_best_ccp9 = @hpr_ccp9) /* recommended = was used */
select @hpr_best_loc_ccp9 = 'NO CHANGE'
else
if (@equiv_sev = -1)
	select @hpr_best_loc_ccp9 = 'UNKNOWN'
else
begin

select @orig_equiv_sev = hsp_row_1.equivalence_class_severe,
@orig_equiv_mod =  hsp_row_1.equivalence_class_moderate
from hsp_row hsp_row_1
where hsp_row_1.file_name = @hpr_ccp9
and hsp_row_1.det_num = @hpr_detectob
and hsp_row_1.aper_name = @hpr_apertobj

if (@orig_equiv_sev = -1)
	select @hpr_best_loc_ccp9 = 'UNKNOWN'
else if ((@equiv_sev - @orig_equiv_sev) <> 0)
	select @hpr_best_loc_ccp9 = 'SEVERE'
else if ((@equiv_mod - @orig_equiv_mod) <> 0)
		select @hpr_best_loc_ccp9 = 'MODERATE'
     else select @hpr_best_loc_ccp9 = 'TRIVIAL'
end
/**************************************************************************/
/*********** instrument hsp ref file type COMPTAB ****************/
/**************************************************************************/
/* begin mod - OPR 35935 - 12/31/97 - remove level of change computation */

select @hpr_best_comptab = synphot_file_1.file_name,
@equiv_sev = synphot_row_1.equivalence_class_severe,
@equiv_mod = synphot_row_1.equivalence_class_moderate
from synphot_file synphot_file_1, synphot_row synphot_row_1
where synphot_file_1.useafter_date = 
	(select max(synphot_file_2.useafter_date)
	from synphot_file synphot_file_2, synphot_row synphot_row_2
             where synphot_file_2.reference_file_type = 'COMPTAB'
             and synphot_file_2.useafter_date <= @expstart
             and synphot_file_2.reject_flag = 'N'
             and synphot_file_2.opus_flag = 'Y'
             and synphot_file_2.archive_date is not null
             and synphot_file_2.file_name =synphot_row_2.file_name
           and synphot_file_2.expansion_number = synphot_row_2.expansion_number
        )
and synphot_file_1.reference_file_type = 'COMPTAB'
and synphot_file_1.reject_flag = 'N'
and synphot_file_1.opus_flag = 'Y'
and synphot_file_1.archive_date is not null
and synphot_file_1.file_name =synphot_row_1.file_name
and synphot_file_1.expansion_number = synphot_row_1.expansion_number
select @num_cal_files = @@rowcount
if (@num_cal_files = 0)    /* no recommended file found */
select @hpr_best_comptab = 'N/A'
/* end mod */

/**************************************************************************/
/*********** instrument hsp ref file type GRAPHTAB ****************/
/**************************************************************************/
/* begin mod - OPR 35935 - 12/31/97 - remove level of change computation */

select @hpr_best_graphtab = synphot_file_1.file_name,
@equiv_sev = synphot_row_1.equivalence_class_severe,
@equiv_mod = synphot_row_1.equivalence_class_moderate
from synphot_file synphot_file_1, synphot_row synphot_row_1
where synphot_file_1.useafter_date = 
	(select max(synphot_file_2.useafter_date)
	from synphot_file synphot_file_2, synphot_row synphot_row_2
             where synphot_file_2.reference_file_type = 'GRAPHTAB'
             and synphot_file_2.useafter_date <= @expstart
             and synphot_file_2.reject_flag = 'N'
             and synphot_file_2.opus_flag = 'Y'
             and synphot_file_2.archive_date is not null
             and synphot_file_2.file_name =synphot_row_2.file_name
           and synphot_file_2.expansion_number = synphot_row_2.expansion_number
        )
and synphot_file_1.reference_file_type = 'GRAPHTAB'
and synphot_file_1.reject_flag = 'N'
and synphot_file_1.opus_flag = 'Y'
and synphot_file_1.archive_date is not null
and synphot_file_1.file_name =synphot_row_1.file_name
and synphot_file_1.expansion_number = synphot_row_1.expansion_number
select @num_cal_files = @@rowcount
if (@num_cal_files = 0)    /* no recommended file found */
select @hpr_best_graphtab = 'N/A'
/* end mod */

update hsp_ref_data
set
hpr_best_ccp0 = @hpr_best_ccp0
,hpr_best_loc_ccp0 = @hpr_best_loc_ccp0
,hpr_best_ccp1 = @hpr_best_ccp1
,hpr_best_loc_ccp1 = @hpr_best_loc_ccp1
,hpr_best_ccp2 = @hpr_best_ccp2
,hpr_best_loc_ccp2 = @hpr_best_loc_ccp2
,hpr_best_ccp3 = @hpr_best_ccp3
,hpr_best_loc_ccp3 = @hpr_best_loc_ccp3
,hpr_best_ccp4 = @hpr_best_ccp4
,hpr_best_loc_ccp4 = @hpr_best_loc_ccp4
,hpr_best_ccp5 = @hpr_best_ccp5
,hpr_best_loc_ccp5 = @hpr_best_loc_ccp5
,hpr_best_ccp7 = @hpr_best_ccp7
,hpr_best_loc_ccp7 = @hpr_best_loc_ccp7
,hpr_best_ccp8 = @hpr_best_ccp8
,hpr_best_loc_ccp8 = @hpr_best_loc_ccp8
,hpr_best_ccp9 = @hpr_best_ccp9
,hpr_best_loc_ccp9 = @hpr_best_loc_ccp9
,hpr_best_comptab = @hpr_best_comptab
,hpr_best_graphtab = @hpr_best_graphtab
where current of update_hsp_cursor
fetch update_hsp_cursor into @expstart,@data_set_name
,@hpr_data_typ
,@hpr_thresh
,@hpr_vgaind
,@hpr_detectob
,@hpr_voltage
,@hpr_apertobj
,@hpr_ccp0
,@hpr_ccp1
,@hpr_ccp2
,@hpr_ccp3
,@hpr_ccp4
,@hpr_ccp7
,@hpr_ccp8
,@hpr_ccp9
,@hpr_ccp5
,@hpr_comptab
,@hpr_graphtab
end
close update_hsp_cursor 
deallocate cursor update_hsp_cursor 
return
go
