use dadsops
go
drop procedure update_nic
go
create procedure update_nic as
/* observation start time */
declare @expstart datetime
/* data set name, to be used for error checking/handling */
declare @data_set_name datasetname
/* severity level variables, to be reused for each reference file type */
declare @orig_equiv_sev int
declare @orig_equiv_mod int
declare @equiv_sev int
declare @equiv_mod int
/* used to store @@rowcount global variable */
declare @num_cal_files int
/* observation modes, calibration files used in the pipeline, */
/* best, and best_loc files */
declare @nsr_nread int
declare @nsr_camera int
declare @nsr_readout char(4)
declare @nsr_backtab char(18)
declare @nsr_phottab char(18)
declare @nsr_samp_seq char(8)
declare @nsr_darkfile char(18)
declare @nsr_filter varchar(7)
declare @nsr_flatfile char(18)
declare @nsr_illmfile char(18)
declare @nsr_maskfile char(18)
declare @nsr_nlinfile char(18)
declare @nsr_noisfile char(18)
declare @nsr_best_backtab char(18)
declare @nsr_best_phottab char(18)
declare @nsr_best_darkfile char(18)
declare @nsr_best_flatfile char(18)
declare @nsr_best_illmfile char(18)
declare @nsr_best_maskfile char(18)
declare @nsr_best_nlinfile char(18)
declare @nsr_best_noisfile char(18)
declare @nsr_best_loc_backtab varchar(9)
declare @nsr_best_loc_phottab varchar(9)
declare @nsr_best_loc_darkfile varchar(9)
declare @nsr_best_loc_flatfile varchar(9)
declare @nsr_best_loc_illmfile varchar(9)
declare @nsr_best_loc_maskfile varchar(9)
declare @nsr_best_loc_nlinfile varchar(9)
declare @nsr_best_loc_noisfile varchar(9)
declare update_nic_cursor  cursor for
select nsr_expstart,nsr_data_set_name
,nsr_camera
,nsr_filter
,nsr_nread
,nsr_readout
,nsr_samp_seq
,nsr_backtab
,nsr_darkfile
,nsr_flatfile
,nsr_illmfile
,nsr_nlinfile
,nsr_maskfile
,nsr_noisfile
,nsr_phottab
from nicmos_ref_data
where nsr_best_backtab is null
or nsr_best_darkfile is null
or nsr_best_flatfile is null
or nsr_best_illmfile is null
or nsr_best_nlinfile is null
or nsr_best_maskfile is null
or nsr_best_noisfile is null
or nsr_best_phottab is null
 for update
open update_nic_cursor 
fetch update_nic_cursor into @expstart,@data_set_name
,@nsr_camera
,@nsr_filter
,@nsr_nread
,@nsr_readout
,@nsr_samp_seq
,@nsr_backtab
,@nsr_darkfile
,@nsr_flatfile
,@nsr_illmfile
,@nsr_nlinfile
,@nsr_maskfile
,@nsr_noisfile
,@nsr_phottab
/**************************************************************************/
/************************ Update nic ***********************/
/**************************************************************************/
while (@@sqlstatus = 0)
begin
select
@nsr_best_backtab = null
,@nsr_best_phottab = null
,@nsr_best_darkfile = null
,@nsr_best_flatfile = null
,@nsr_best_illmfile = null
,@nsr_best_maskfile = null
,@nsr_best_nlinfile = null
,@nsr_best_noisfile = null
,@nsr_best_loc_backtab = null
,@nsr_best_loc_phottab = null
,@nsr_best_loc_darkfile = null
,@nsr_best_loc_flatfile = null
,@nsr_best_loc_illmfile = null
,@nsr_best_loc_maskfile = null
,@nsr_best_loc_nlinfile = null
,@nsr_best_loc_noisfile = null
/**************************************************************************/
/*********** instrument nic ref file type BKG ****************/
/**************************************************************************/
select @nsr_best_backtab = nic_file_1.file_name,
@equiv_sev = nic_row_1.equivalence_class_severe,
@equiv_mod = nic_row_1.equivalence_class_moderate
from nic_file nic_file_1, nic_row nic_row_1
where nic_file_1.useafter_date = 
	(select max(nic_file_2.useafter_date)
	from nic_file nic_file_2, nic_row nic_row_2
             where nic_file_2.reference_file_type = 'BKG'
             and nic_file_2.useafter_date <= @expstart
             and nic_file_2.reject_flag = 'N'
             and nic_file_2.opus_flag = 'Y'
             and nic_file_2.archive_date is not null
             and nic_file_2.file_name =nic_row_2.file_name
             and nic_file_2.expansion_number = nic_row_2.expansion_number
             and nic_row_2.camera = @nsr_camera
             and nic_row_2.filter = @nsr_filter
        )
and nic_file_1.reference_file_type = 'BKG'
and nic_file_1.reject_flag = 'N'
and nic_file_1.opus_flag = 'Y'
and nic_file_1.archive_date is not null
and nic_file_1.file_name =nic_row_1.file_name
and nic_file_1.expansion_number = nic_row_1.expansion_number
and nic_row_1.camera = @nsr_camera
and nic_row_1.filter = @nsr_filter
select @num_cal_files = @@rowcount
if (@num_cal_files = 0)    /* no recommended file found */
select @nsr_best_backtab = 'N/A', @nsr_best_loc_backtab = 'N/A'
else
if (@nsr_backtab = NULL) /* no file was used in the pipeline */
select @nsr_best_loc_backtab = 'N/A'
else
if (@nsr_best_backtab = @nsr_backtab) /* recommended = was used */
select @nsr_best_loc_backtab = 'NO CHANGE'
else
if (@equiv_sev = -1)
	select @nsr_best_loc_backtab = 'UNKNOWN'
else
begin

select @orig_equiv_sev = nic_row_1.equivalence_class_severe,
@orig_equiv_mod =  nic_row_1.equivalence_class_moderate
from nic_row nic_row_1
where nic_row_1.file_name = @nsr_backtab
and nic_row_1.camera = @nsr_camera
and nic_row_1.filter = @nsr_filter

if (@orig_equiv_sev = -1)
	select @nsr_best_loc_backtab = 'UNKNOWN'
else if ((@equiv_sev - @orig_equiv_sev) <> 0)
	select @nsr_best_loc_backtab = 'SEVERE'
else if ((@equiv_mod - @orig_equiv_mod) <> 0)
		select @nsr_best_loc_backtab = 'MODERATE'
     else select @nsr_best_loc_backtab = 'TRIVIAL'
end
/**************************************************************************/
/*********** instrument nic ref file type PHT ****************/
/**************************************************************************/
select @nsr_best_phottab = nic_file_1.file_name,
@equiv_sev = nic_row_1.equivalence_class_severe,
@equiv_mod = nic_row_1.equivalence_class_moderate
from nic_file nic_file_1, nic_row nic_row_1
where nic_file_1.useafter_date = 
	(select max(nic_file_2.useafter_date)
	from nic_file nic_file_2, nic_row nic_row_2
             where nic_file_2.reference_file_type = 'PHT'
             and nic_file_2.useafter_date <= @expstart
             and nic_file_2.reject_flag = 'N'
             and nic_file_2.opus_flag = 'Y'
             and nic_file_2.archive_date is not null
             and nic_file_2.file_name =nic_row_2.file_name
             and nic_file_2.expansion_number = nic_row_2.expansion_number
        )
and nic_file_1.reference_file_type = 'PHT'
and nic_file_1.reject_flag = 'N'
and nic_file_1.opus_flag = 'Y'
and nic_file_1.archive_date is not null
and nic_file_1.file_name =nic_row_1.file_name
and nic_file_1.expansion_number = nic_row_1.expansion_number
select @num_cal_files = @@rowcount
if (@num_cal_files = 0)    /* no recommended file found */
select @nsr_best_phottab = 'N/A', @nsr_best_loc_phottab = 'N/A'
else
if (@nsr_phottab = NULL) /* no file was used in the pipeline */
select @nsr_best_loc_phottab = 'N/A'
else
if (@nsr_best_phottab = @nsr_phottab) /* recommended = was used */
select @nsr_best_loc_phottab = 'NO CHANGE'
else
if (@equiv_sev = -1)
	select @nsr_best_loc_phottab = 'UNKNOWN'
else
begin

select @orig_equiv_sev = nic_row_1.equivalence_class_severe,
@orig_equiv_mod =  nic_row_1.equivalence_class_moderate
from nic_row nic_row_1
where nic_row_1.file_name = @nsr_phottab

if (@orig_equiv_sev = -1)
	select @nsr_best_loc_phottab = 'UNKNOWN'
else if ((@equiv_sev - @orig_equiv_sev) <> 0)
	select @nsr_best_loc_phottab = 'SEVERE'
else if ((@equiv_mod - @orig_equiv_mod) <> 0)
		select @nsr_best_loc_phottab = 'MODERATE'
     else select @nsr_best_loc_phottab = 'TRIVIAL'
end
/**************************************************************************/
/*********** instrument nic ref file type DRK ****************/
/**************************************************************************/
select @nsr_best_darkfile = nic_file_1.file_name,
@equiv_sev = nic_row_1.equivalence_class_severe,
@equiv_mod = nic_row_1.equivalence_class_moderate
from nic_file nic_file_1, nic_row nic_row_1
where nic_file_1.useafter_date = 
	(select max(nic_file_2.useafter_date)
	from nic_file nic_file_2, nic_row nic_row_2
             where nic_file_2.reference_file_type = 'DRK'
             and nic_file_2.useafter_date <= @expstart
             and nic_file_2.reject_flag = 'N'
             and nic_file_2.opus_flag = 'Y'
             and nic_file_2.archive_date is not null
             and nic_file_2.file_name =nic_row_2.file_name
             and nic_file_2.expansion_number = nic_row_2.expansion_number
             and nic_row_2.nread = @nsr_nread
             and nic_row_2.camera = @nsr_camera
             and nic_row_2.readout = @nsr_readout
             and nic_row_2.samp_seq = @nsr_samp_seq
        )
and nic_file_1.reference_file_type = 'DRK'
and nic_file_1.reject_flag = 'N'
and nic_file_1.opus_flag = 'Y'
and nic_file_1.archive_date is not null
and nic_file_1.file_name =nic_row_1.file_name
and nic_file_1.expansion_number = nic_row_1.expansion_number
and nic_row_1.nread = @nsr_nread
and nic_row_1.camera = @nsr_camera
and nic_row_1.readout = @nsr_readout
and nic_row_1.samp_seq = @nsr_samp_seq
select @num_cal_files = @@rowcount
if (@num_cal_files = 0)    /* no recommended file found */
select @nsr_best_darkfile = 'N/A', @nsr_best_loc_darkfile = 'N/A'
else
if (@nsr_darkfile = NULL) /* no file was used in the pipeline */
select @nsr_best_loc_darkfile = 'N/A'
else
if (@nsr_best_darkfile = @nsr_darkfile) /* recommended = was used */
select @nsr_best_loc_darkfile = 'NO CHANGE'
else
if (@equiv_sev = -1)
	select @nsr_best_loc_darkfile = 'UNKNOWN'
else
begin

select @orig_equiv_sev = nic_row_1.equivalence_class_severe,
@orig_equiv_mod =  nic_row_1.equivalence_class_moderate
from nic_row nic_row_1
where nic_row_1.file_name = @nsr_darkfile
and nic_row_1.nread = @nsr_nread
and nic_row_1.camera = @nsr_camera
and nic_row_1.readout = @nsr_readout
and nic_row_1.samp_seq = @nsr_samp_seq

if (@orig_equiv_sev = -1)
	select @nsr_best_loc_darkfile = 'UNKNOWN'
else if ((@equiv_sev - @orig_equiv_sev) <> 0)
	select @nsr_best_loc_darkfile = 'SEVERE'
else if ((@equiv_mod - @orig_equiv_mod) <> 0)
		select @nsr_best_loc_darkfile = 'MODERATE'
     else select @nsr_best_loc_darkfile = 'TRIVIAL'
end
/**************************************************************************/
/*********** instrument nic ref file type FLT ****************/
/**************************************************************************/
select @nsr_best_flatfile = nic_file_1.file_name,
@equiv_sev = nic_row_1.equivalence_class_severe,
@equiv_mod = nic_row_1.equivalence_class_moderate
from nic_file nic_file_1, nic_row nic_row_1
where nic_file_1.useafter_date = 
	(select max(nic_file_2.useafter_date)
	from nic_file nic_file_2, nic_row nic_row_2
             where nic_file_2.reference_file_type = 'FLT'
             and nic_file_2.useafter_date <= @expstart
             and nic_file_2.reject_flag = 'N'
             and nic_file_2.opus_flag = 'Y'
             and nic_file_2.archive_date is not null
             and nic_file_2.file_name =nic_row_2.file_name
             and nic_file_2.expansion_number = nic_row_2.expansion_number
             and nic_row_2.camera = @nsr_camera
             and nic_row_2.filter = @nsr_filter
        )
and nic_file_1.reference_file_type = 'FLT'
and nic_file_1.reject_flag = 'N'
and nic_file_1.opus_flag = 'Y'
and nic_file_1.archive_date is not null
and nic_file_1.file_name =nic_row_1.file_name
and nic_file_1.expansion_number = nic_row_1.expansion_number
and nic_row_1.camera = @nsr_camera
and nic_row_1.filter = @nsr_filter
select @num_cal_files = @@rowcount
if (@num_cal_files = 0)    /* no recommended file found */
select @nsr_best_flatfile = 'N/A', @nsr_best_loc_flatfile = 'N/A'
else
if (@nsr_flatfile = NULL) /* no file was used in the pipeline */
select @nsr_best_loc_flatfile = 'N/A'
else
if (@nsr_best_flatfile = @nsr_flatfile) /* recommended = was used */
select @nsr_best_loc_flatfile = 'NO CHANGE'
else
if (@equiv_sev = -1)
	select @nsr_best_loc_flatfile = 'UNKNOWN'
else
begin

select @orig_equiv_sev = nic_row_1.equivalence_class_severe,
@orig_equiv_mod =  nic_row_1.equivalence_class_moderate
from nic_row nic_row_1
where nic_row_1.file_name = @nsr_flatfile
and nic_row_1.camera = @nsr_camera
and nic_row_1.filter = @nsr_filter

if (@orig_equiv_sev = -1)
	select @nsr_best_loc_flatfile = 'UNKNOWN'
else if ((@equiv_sev - @orig_equiv_sev) <> 0)
	select @nsr_best_loc_flatfile = 'SEVERE'
else if ((@equiv_mod - @orig_equiv_mod) <> 0)
		select @nsr_best_loc_flatfile = 'MODERATE'
     else select @nsr_best_loc_flatfile = 'TRIVIAL'
end
/**************************************************************************/
/*********** instrument nic ref file type ILM ****************/
/**************************************************************************/
select @nsr_best_illmfile = nic_file_1.file_name,
@equiv_sev = nic_row_1.equivalence_class_severe,
@equiv_mod = nic_row_1.equivalence_class_moderate
from nic_file nic_file_1, nic_row nic_row_1
where nic_file_1.useafter_date = 
	(select max(nic_file_2.useafter_date)
	from nic_file nic_file_2, nic_row nic_row_2
             where nic_file_2.reference_file_type = 'ILM'
             and nic_file_2.useafter_date <= @expstart
             and nic_file_2.reject_flag = 'N'
             and nic_file_2.opus_flag = 'Y'
             and nic_file_2.archive_date is not null
             and nic_file_2.file_name =nic_row_2.file_name
             and nic_file_2.expansion_number = nic_row_2.expansion_number
             and nic_row_2.camera = @nsr_camera
             and nic_row_2.filter = @nsr_filter
        )
and nic_file_1.reference_file_type = 'ILM'
and nic_file_1.reject_flag = 'N'
and nic_file_1.opus_flag = 'Y'
and nic_file_1.archive_date is not null
and nic_file_1.file_name =nic_row_1.file_name
and nic_file_1.expansion_number = nic_row_1.expansion_number
and nic_row_1.camera = @nsr_camera
and nic_row_1.filter = @nsr_filter
select @num_cal_files = @@rowcount
if (@num_cal_files = 0)    /* no recommended file found */
select @nsr_best_illmfile = 'N/A', @nsr_best_loc_illmfile = 'N/A'
else
if (@nsr_illmfile = NULL) /* no file was used in the pipeline */
select @nsr_best_loc_illmfile = 'N/A'
else
if (@nsr_best_illmfile = @nsr_illmfile) /* recommended = was used */
select @nsr_best_loc_illmfile = 'NO CHANGE'
else
if (@equiv_sev = -1)
	select @nsr_best_loc_illmfile = 'UNKNOWN'
else
begin

select @orig_equiv_sev = nic_row_1.equivalence_class_severe,
@orig_equiv_mod =  nic_row_1.equivalence_class_moderate
from nic_row nic_row_1
where nic_row_1.file_name = @nsr_illmfile
and nic_row_1.camera = @nsr_camera
and nic_row_1.filter = @nsr_filter

if (@orig_equiv_sev = -1)
	select @nsr_best_loc_illmfile = 'UNKNOWN'
else if ((@equiv_sev - @orig_equiv_sev) <> 0)
	select @nsr_best_loc_illmfile = 'SEVERE'
else if ((@equiv_mod - @orig_equiv_mod) <> 0)
		select @nsr_best_loc_illmfile = 'MODERATE'
     else select @nsr_best_loc_illmfile = 'TRIVIAL'
end
/**************************************************************************/
/*********** instrument nic ref file type LIN ****************/
/**************************************************************************/
select @nsr_best_nlinfile = nic_file_1.file_name,
@equiv_sev = nic_row_1.equivalence_class_severe,
@equiv_mod = nic_row_1.equivalence_class_moderate
from nic_file nic_file_1, nic_row nic_row_1
where nic_file_1.useafter_date = 
	(select max(nic_file_2.useafter_date)
	from nic_file nic_file_2, nic_row nic_row_2
             where nic_file_2.reference_file_type = 'LIN'
             and nic_file_2.useafter_date <= @expstart
             and nic_file_2.reject_flag = 'N'
             and nic_file_2.opus_flag = 'Y'
             and nic_file_2.archive_date is not null
             and nic_file_2.file_name =nic_row_2.file_name
             and nic_file_2.expansion_number = nic_row_2.expansion_number
             and nic_row_2.camera = @nsr_camera
        )
and nic_file_1.reference_file_type = 'LIN'
and nic_file_1.reject_flag = 'N'
and nic_file_1.opus_flag = 'Y'
and nic_file_1.archive_date is not null
and nic_file_1.file_name =nic_row_1.file_name
and nic_file_1.expansion_number = nic_row_1.expansion_number
and nic_row_1.camera = @nsr_camera
select @num_cal_files = @@rowcount
if (@num_cal_files = 0)    /* no recommended file found */
select @nsr_best_nlinfile = 'N/A', @nsr_best_loc_nlinfile = 'N/A'
else
if (@nsr_nlinfile = NULL) /* no file was used in the pipeline */
select @nsr_best_loc_nlinfile = 'N/A'
else
if (@nsr_best_nlinfile = @nsr_nlinfile) /* recommended = was used */
select @nsr_best_loc_nlinfile = 'NO CHANGE'
else
if (@equiv_sev = -1)
	select @nsr_best_loc_nlinfile = 'UNKNOWN'
else
begin

select @orig_equiv_sev = nic_row_1.equivalence_class_severe,
@orig_equiv_mod =  nic_row_1.equivalence_class_moderate
from nic_row nic_row_1
where nic_row_1.file_name = @nsr_nlinfile
and nic_row_1.camera = @nsr_camera

if (@orig_equiv_sev = -1)
	select @nsr_best_loc_nlinfile = 'UNKNOWN'
else if ((@equiv_sev - @orig_equiv_sev) <> 0)
	select @nsr_best_loc_nlinfile = 'SEVERE'
else if ((@equiv_mod - @orig_equiv_mod) <> 0)
		select @nsr_best_loc_nlinfile = 'MODERATE'
     else select @nsr_best_loc_nlinfile = 'TRIVIAL'
end
/**************************************************************************/
/*********** instrument nic ref file type MSK ****************/
/**************************************************************************/
select @nsr_best_maskfile = nic_file_1.file_name,
@equiv_sev = nic_row_1.equivalence_class_severe,
@equiv_mod = nic_row_1.equivalence_class_moderate
from nic_file nic_file_1, nic_row nic_row_1
where nic_file_1.useafter_date = 
	(select max(nic_file_2.useafter_date)
	from nic_file nic_file_2, nic_row nic_row_2
             where nic_file_2.reference_file_type = 'MSK'
             and nic_file_2.useafter_date <= @expstart
             and nic_file_2.reject_flag = 'N'
             and nic_file_2.opus_flag = 'Y'
             and nic_file_2.archive_date is not null
             and nic_file_2.file_name =nic_row_2.file_name
             and nic_file_2.expansion_number = nic_row_2.expansion_number
             and nic_row_2.camera = @nsr_camera
        )
and nic_file_1.reference_file_type = 'MSK'
and nic_file_1.reject_flag = 'N'
and nic_file_1.opus_flag = 'Y'
and nic_file_1.archive_date is not null
and nic_file_1.file_name =nic_row_1.file_name
and nic_file_1.expansion_number = nic_row_1.expansion_number
and nic_row_1.camera = @nsr_camera
select @num_cal_files = @@rowcount
if (@num_cal_files = 0)    /* no recommended file found */
select @nsr_best_maskfile = 'N/A', @nsr_best_loc_maskfile = 'N/A'
else
if (@nsr_maskfile = NULL) /* no file was used in the pipeline */
select @nsr_best_loc_maskfile = 'N/A'
else
if (@nsr_best_maskfile = @nsr_maskfile) /* recommended = was used */
select @nsr_best_loc_maskfile = 'NO CHANGE'
else
if (@equiv_sev = -1)
	select @nsr_best_loc_maskfile = 'UNKNOWN'
else
begin

select @orig_equiv_sev = nic_row_1.equivalence_class_severe,
@orig_equiv_mod =  nic_row_1.equivalence_class_moderate
from nic_row nic_row_1
where nic_row_1.file_name = @nsr_maskfile
and nic_row_1.camera = @nsr_camera

if (@orig_equiv_sev = -1)
	select @nsr_best_loc_maskfile = 'UNKNOWN'
else if ((@equiv_sev - @orig_equiv_sev) <> 0)
	select @nsr_best_loc_maskfile = 'SEVERE'
else if ((@equiv_mod - @orig_equiv_mod) <> 0)
		select @nsr_best_loc_maskfile = 'MODERATE'
     else select @nsr_best_loc_maskfile = 'TRIVIAL'
end
/**************************************************************************/
/*********** instrument nic ref file type NOI ****************/
/**************************************************************************/
select @nsr_best_noisfile = nic_file_1.file_name,
@equiv_sev = nic_row_1.equivalence_class_severe,
@equiv_mod = nic_row_1.equivalence_class_moderate
from nic_file nic_file_1, nic_row nic_row_1
where nic_file_1.useafter_date = 
	(select max(nic_file_2.useafter_date)
	from nic_file nic_file_2, nic_row nic_row_2
             where nic_file_2.reference_file_type = 'NOI'
             and nic_file_2.useafter_date <= @expstart
             and nic_file_2.reject_flag = 'N'
             and nic_file_2.opus_flag = 'Y'
             and nic_file_2.archive_date is not null
             and nic_file_2.file_name =nic_row_2.file_name
             and nic_file_2.expansion_number = nic_row_2.expansion_number
             and nic_row_2.nread = @nsr_nread
             and nic_row_2.camera = @nsr_camera
             and nic_row_2.readout = @nsr_readout
        )
and nic_file_1.reference_file_type = 'NOI'
and nic_file_1.reject_flag = 'N'
and nic_file_1.opus_flag = 'Y'
and nic_file_1.archive_date is not null
and nic_file_1.file_name =nic_row_1.file_name
and nic_file_1.expansion_number = nic_row_1.expansion_number
and nic_row_1.nread = @nsr_nread
and nic_row_1.camera = @nsr_camera
and nic_row_1.readout = @nsr_readout
select @num_cal_files = @@rowcount
if (@num_cal_files = 0)    /* no recommended file found */
select @nsr_best_noisfile = 'N/A', @nsr_best_loc_noisfile = 'N/A'
else
if (@nsr_noisfile = NULL) /* no file was used in the pipeline */
select @nsr_best_loc_noisfile = 'N/A'
else
if (@nsr_best_noisfile = @nsr_noisfile) /* recommended = was used */
select @nsr_best_loc_noisfile = 'NO CHANGE'
else
if (@equiv_sev = -1)
	select @nsr_best_loc_noisfile = 'UNKNOWN'
else
begin

select @orig_equiv_sev = nic_row_1.equivalence_class_severe,
@orig_equiv_mod =  nic_row_1.equivalence_class_moderate
from nic_row nic_row_1
where nic_row_1.file_name = @nsr_noisfile
and nic_row_1.nread = @nsr_nread
and nic_row_1.camera = @nsr_camera
and nic_row_1.readout = @nsr_readout

if (@orig_equiv_sev = -1)
	select @nsr_best_loc_noisfile = 'UNKNOWN'
else if ((@equiv_sev - @orig_equiv_sev) <> 0)
	select @nsr_best_loc_noisfile = 'SEVERE'
else if ((@equiv_mod - @orig_equiv_mod) <> 0)
		select @nsr_best_loc_noisfile = 'MODERATE'
     else select @nsr_best_loc_noisfile = 'TRIVIAL'
end

update nicmos_ref_data
set
nsr_best_backtab = @nsr_best_backtab
,nsr_best_loc_backtab = @nsr_best_loc_backtab
,nsr_best_phottab = @nsr_best_phottab
,nsr_best_loc_phottab = @nsr_best_loc_phottab
,nsr_best_darkfile = @nsr_best_darkfile
,nsr_best_loc_darkfile = @nsr_best_loc_darkfile
,nsr_best_flatfile = @nsr_best_flatfile
,nsr_best_loc_flatfile = @nsr_best_loc_flatfile
,nsr_best_illmfile = @nsr_best_illmfile
,nsr_best_loc_illmfile = @nsr_best_loc_illmfile
,nsr_best_nlinfile = @nsr_best_nlinfile
,nsr_best_loc_nlinfile = @nsr_best_loc_nlinfile
,nsr_best_maskfile = @nsr_best_maskfile
,nsr_best_loc_maskfile = @nsr_best_loc_maskfile
,nsr_best_noisfile = @nsr_best_noisfile
,nsr_best_loc_noisfile = @nsr_best_loc_noisfile
where current of update_nic_cursor
fetch update_nic_cursor into @expstart,@data_set_name
,@nsr_camera
,@nsr_filter
,@nsr_nread
,@nsr_readout
,@nsr_samp_seq
,@nsr_backtab
,@nsr_darkfile
,@nsr_flatfile
,@nsr_illmfile
,@nsr_nlinfile
,@nsr_maskfile
,@nsr_noisfile
,@nsr_phottab
end
close update_nic_cursor 
deallocate cursor update_nic_cursor 
return
go
