use dadsops
go
drop procedure update_wfpc
go
create procedure update_wfpc as
/* observation start time */
declare @expstart datetime
/* data set name, to be used for error checking/handling */
declare @data_set_name datasetname
/* severity level variables, to be reused for each reference file type */
declare @orig_equiv_sev int
declare @orig_equiv_mod int
declare @equiv_sev int
declare @equiv_mod int
/* used to store @@rowcount global variable */
declare @num_cal_files int
/* observation modes, calibration files used in the pipeline, */
/* best, and best_loc files */
declare @wcr_mode char(4)
declare @wcr_camera char(2)
declare @wcr_serials char(3)
declare @wcr_shutter char(7)
declare @wcr_filter1 int
declare @wcr_filter2 int
declare @wcr_phottab char(18)
declare @wcr_atodfile char(18)
declare @wcr_best_a2d char(18)
declare @wcr_best_bas char(18)
declare @wcr_best_drk char(18)
declare @wcr_best_flt char(18)
declare @wcr_best_msk char(18)
declare @wcr_best_prf char(18)
declare @wcr_best_pur char(18)
declare @wcr_biasfile char(18)
declare @wcr_darkfile char(18)
declare @wcr_flatfile char(18)
declare @wcr_maskfile char(18)
declare @wcr_preffile char(18)
declare @wcr_purgfile char(18)
declare @wcr_photmode_a varchar(48)  /* mod */
declare @wcr_photmode_b varchar(48)  /* mod */
declare @wcr_photmode_c varchar(48)  /* mod */
declare @wcr_photmode_d varchar(48)  /* mod */
declare @wcr_best_phottab char(18)
declare @wcr_best_loc_a2d varchar(9)
declare @wcr_best_loc_bas varchar(9)
declare @wcr_best_loc_drk varchar(9)
declare @wcr_best_loc_flt varchar(9)
declare @wcr_best_loc_msk varchar(9)
declare @wcr_best_loc_prf varchar(9)
declare @wcr_best_loc_pur varchar(9)
declare @wcr_best_loc_photmode_a varchar(9)  /*mod*/
declare @wcr_best_loc_photmode_b varchar(9)  /*mod*/
declare @wcr_best_loc_photmode_c varchar(9)  /*mod*/
declare @wcr_best_loc_photmode_d varchar(9)  /*mod*/
declare update_wfpc_cursor  cursor for
select wcr_expstart,wcr_data_set_name
,wcr_mode
,wcr_serials
,wcr_camera
,wcr_filter1
,wcr_filter2
,wcr_shutter
,wcr_photmode_a  /*mod*/
,wcr_photmode_b  /*mod*/
,wcr_photmode_c  /*mod*/
,wcr_photmode_d  /*mod*/
,wcr_atodfile
,wcr_biasfile
,wcr_darkfile
,wcr_flatfile
,wcr_maskfile
,wcr_preffile
,wcr_purgfile
,wcr_phottab
from wfpc_ref_data
where wcr_best_a2d is null
or wcr_best_bas is null
or wcr_best_drk is null
or wcr_best_flt is null
or wcr_best_msk is null
or wcr_best_prf is null
or wcr_best_pur is null
or wcr_best_phottab is null
 for update
open update_wfpc_cursor 
fetch update_wfpc_cursor into @expstart,@data_set_name
,@wcr_mode
,@wcr_serials
,@wcr_camera
,@wcr_filter1
,@wcr_filter2
,@wcr_shutter
,@wcr_photmode_a  /*mod*/
,@wcr_photmode_b  /*mod*/
,@wcr_photmode_c  /*mod*/
,@wcr_photmode_d  /*mod*/
,@wcr_atodfile
,@wcr_biasfile
,@wcr_darkfile
,@wcr_flatfile
,@wcr_maskfile
,@wcr_preffile
,@wcr_purgfile
,@wcr_phottab
/**************************************************************************/
/************************ Update wfpc ***********************/
/**************************************************************************/
while (@@sqlstatus = 0)
begin
select
@wcr_best_a2d = null
,@wcr_best_bas = null
,@wcr_best_drk = null
,@wcr_best_flt = null
,@wcr_best_msk = null
,@wcr_best_prf = null
,@wcr_best_pur = null
,@wcr_best_loc_a2d = null
,@wcr_best_loc_bas = null
,@wcr_best_loc_drk = null
,@wcr_best_loc_flt = null
,@wcr_best_loc_msk = null
,@wcr_best_loc_prf = null
,@wcr_best_loc_pur = null
,@wcr_best_phottab = null
,@wcr_best_loc_photmode_a = null	/* mod */
,@wcr_best_loc_photmode_b = null	/* mod */
,@wcr_best_loc_photmode_c = null	/* mod */
,@wcr_best_loc_photmode_d = null	/* mod */

/**************************************************************************/
/*********** instrument wfpc ref file type A2D ****************/
/**************************************************************************/
select @wcr_best_a2d = wfpc_file_1.file_name,
@equiv_sev = wfpc_row_1.equivalence_class_severe,
@equiv_mod = wfpc_row_1.equivalence_class_moderate
from wfpc_file wfpc_file_1, wfpc_row wfpc_row_1
where wfpc_file_1.useafter_date = 
	(select max(wfpc_file_2.useafter_date)
	from wfpc_file wfpc_file_2, wfpc_row wfpc_row_2
             where wfpc_file_2.reference_file_type = 'A2D'
             and wfpc_file_2.useafter_date <= @expstart
             and wfpc_file_2.reject_flag = 'N'
             and wfpc_file_2.opus_flag = 'Y'
             and wfpc_file_2.archive_date is not null
             and wfpc_file_2.file_name =wfpc_row_2.file_name
             and wfpc_file_2.expansion_number = wfpc_row_2.expansion_number
             and wfpc_row_2.mode = @wcr_mode
             and wfpc_row_2.camera = @wcr_camera
        )
and wfpc_file_1.reference_file_type = 'A2D'
and wfpc_file_1.reject_flag = 'N'
and wfpc_file_1.opus_flag = 'Y'
and wfpc_file_1.archive_date is not null
and wfpc_file_1.file_name =wfpc_row_1.file_name
and wfpc_file_1.expansion_number = wfpc_row_1.expansion_number
and wfpc_row_1.mode = @wcr_mode
and wfpc_row_1.camera = @wcr_camera
select @num_cal_files = @@rowcount
if (@num_cal_files = 0)    /* no recommended file found */
select @wcr_best_a2d = 'N/A', @wcr_best_loc_a2d = 'N/A'
else
if (@wcr_atodfile = NULL) /* no file was used in the pipeline */
select @wcr_best_loc_a2d = 'N/A'
else
if (@wcr_best_a2d = @wcr_atodfile) /* recommended = was used */
select @wcr_best_loc_a2d = 'NO CHANGE'
else
if (@equiv_sev = -1)
	select @wcr_best_loc_a2d = 'UNKNOWN'
else
begin

select @orig_equiv_sev = wfpc_row_1.equivalence_class_severe,
@orig_equiv_mod =  wfpc_row_1.equivalence_class_moderate
from wfpc_row wfpc_row_1
where wfpc_row_1.file_name = @wcr_atodfile
and wfpc_row_1.mode = @wcr_mode
and wfpc_row_1.camera = @wcr_camera

if (@orig_equiv_sev = -1)
	select @wcr_best_loc_a2d = 'UNKNOWN'
else if ((@equiv_sev - @orig_equiv_sev) <> 0)
	select @wcr_best_loc_a2d = 'SEVERE'
else if ((@equiv_mod - @orig_equiv_mod) <> 0)
		select @wcr_best_loc_a2d = 'MODERATE'
     else select @wcr_best_loc_a2d = 'TRIVIAL'
end
/**************************************************************************/
/*********** instrument wfpc ref file type BAS ****************/
/**************************************************************************/
select @wcr_best_bas = wfpc_file_1.file_name,
@equiv_sev = wfpc_row_1.equivalence_class_severe,
@equiv_mod = wfpc_row_1.equivalence_class_moderate
from wfpc_file wfpc_file_1, wfpc_row wfpc_row_1
where wfpc_file_1.useafter_date = 
	(select max(wfpc_file_2.useafter_date)
	from wfpc_file wfpc_file_2, wfpc_row wfpc_row_2
             where wfpc_file_2.reference_file_type = 'BAS'
             and wfpc_file_2.useafter_date <= @expstart
             and wfpc_file_2.reject_flag = 'N'
             and wfpc_file_2.opus_flag = 'Y'
             and wfpc_file_2.archive_date is not null
             and wfpc_file_2.file_name =wfpc_row_2.file_name
             and wfpc_file_2.expansion_number = wfpc_row_2.expansion_number
             and wfpc_row_2.mode = @wcr_mode
             and wfpc_row_2.camera = @wcr_camera
        )
and wfpc_file_1.reference_file_type = 'BAS'
and wfpc_file_1.reject_flag = 'N'
and wfpc_file_1.opus_flag = 'Y'
and wfpc_file_1.archive_date is not null
and wfpc_file_1.file_name =wfpc_row_1.file_name
and wfpc_file_1.expansion_number = wfpc_row_1.expansion_number
and wfpc_row_1.mode = @wcr_mode
and wfpc_row_1.camera = @wcr_camera
select @num_cal_files = @@rowcount
if (@num_cal_files = 0)    /* no recommended file found */
select @wcr_best_bas = 'N/A', @wcr_best_loc_bas = 'N/A'
else
if (@wcr_biasfile = NULL) /* no file was used in the pipeline */
select @wcr_best_loc_bas = 'N/A'
else
if (@wcr_best_bas = @wcr_biasfile) /* recommended = was used */
select @wcr_best_loc_bas = 'NO CHANGE'
else
if (@equiv_sev = -1)
	select @wcr_best_loc_bas = 'UNKNOWN'
else
begin

select @orig_equiv_sev = wfpc_row_1.equivalence_class_severe,
@orig_equiv_mod =  wfpc_row_1.equivalence_class_moderate
from wfpc_row wfpc_row_1
where wfpc_row_1.file_name = @wcr_biasfile
and wfpc_row_1.mode = @wcr_mode
and wfpc_row_1.camera = @wcr_camera

if (@orig_equiv_sev = -1)
	select @wcr_best_loc_bas = 'UNKNOWN'
else if ((@equiv_sev - @orig_equiv_sev) <> 0)
	select @wcr_best_loc_bas = 'SEVERE'
else if ((@equiv_mod - @orig_equiv_mod) <> 0)
		select @wcr_best_loc_bas = 'MODERATE'
     else select @wcr_best_loc_bas = 'TRIVIAL'
end
/**************************************************************************/
/*********** instrument wfpc ref file type DRK ****************/
/**************************************************************************/
select @wcr_best_drk = wfpc_file_1.file_name,
@equiv_sev = wfpc_row_1.equivalence_class_severe,
@equiv_mod = wfpc_row_1.equivalence_class_moderate
from wfpc_file wfpc_file_1, wfpc_row wfpc_row_1
where wfpc_file_1.useafter_date = 
	(select max(wfpc_file_2.useafter_date)
	from wfpc_file wfpc_file_2, wfpc_row wfpc_row_2
             where wfpc_file_2.reference_file_type = 'DRK'
             and wfpc_file_2.useafter_date <= @expstart
             and wfpc_file_2.reject_flag = 'N'
             and wfpc_file_2.opus_flag = 'Y'
             and wfpc_file_2.archive_date is not null
             and wfpc_file_2.file_name =wfpc_row_2.file_name
             and wfpc_file_2.expansion_number = wfpc_row_2.expansion_number
             and wfpc_row_2.mode = @wcr_mode
             and wfpc_row_2.camera = @wcr_camera
             and wfpc_row_2.clock = @wcr_serials
        )
and wfpc_file_1.reference_file_type = 'DRK'
and wfpc_file_1.reject_flag = 'N'
and wfpc_file_1.opus_flag = 'Y'
and wfpc_file_1.archive_date is not null
and wfpc_file_1.file_name =wfpc_row_1.file_name
and wfpc_file_1.expansion_number = wfpc_row_1.expansion_number
and wfpc_row_1.mode = @wcr_mode
and wfpc_row_1.camera = @wcr_camera
and wfpc_row_1.clock = @wcr_serials
select @num_cal_files = @@rowcount
if (@num_cal_files = 0)    /* no recommended file found */
select @wcr_best_drk = 'N/A', @wcr_best_loc_drk = 'N/A'
else
if (@wcr_darkfile = NULL) /* no file was used in the pipeline */
select @wcr_best_loc_drk = 'N/A'
else
if (@wcr_best_drk = @wcr_darkfile) /* recommended = was used */
select @wcr_best_loc_drk = 'NO CHANGE'
else
if (@equiv_sev = -1)
	select @wcr_best_loc_drk = 'UNKNOWN'
else
begin

select @orig_equiv_sev = wfpc_row_1.equivalence_class_severe,
@orig_equiv_mod =  wfpc_row_1.equivalence_class_moderate
from wfpc_row wfpc_row_1
where wfpc_row_1.file_name = @wcr_darkfile
and wfpc_row_1.mode = @wcr_mode
and wfpc_row_1.camera = @wcr_camera
and wfpc_row_1.clock = @wcr_serials

if (@orig_equiv_sev = -1)
	select @wcr_best_loc_drk = 'UNKNOWN'
else if ((@equiv_sev - @orig_equiv_sev) <> 0)
	select @wcr_best_loc_drk = 'SEVERE'
else if ((@equiv_mod - @orig_equiv_mod) <> 0)
		select @wcr_best_loc_drk = 'MODERATE'
     else select @wcr_best_loc_drk = 'TRIVIAL'
end
/**************************************************************************/
/*********** instrument wfpc ref file type FLT ****************/
/**************************************************************************/
select @wcr_best_flt = wfpc_file_1.file_name,
@equiv_sev = wfpc_row_1.equivalence_class_severe,
@equiv_mod = wfpc_row_1.equivalence_class_moderate
from wfpc_file wfpc_file_1, wfpc_row wfpc_row_1
where wfpc_file_1.useafter_date = 
	(select max(wfpc_file_2.useafter_date)
	from wfpc_file wfpc_file_2, wfpc_row wfpc_row_2
             where wfpc_file_2.reference_file_type = 'FLT'
             and wfpc_file_2.useafter_date <= @expstart
             and wfpc_file_2.reject_flag = 'N'
             and wfpc_file_2.opus_flag = 'Y'
             and wfpc_file_2.archive_date is not null
             and wfpc_file_2.file_name =wfpc_row_2.file_name
             and wfpc_file_2.expansion_number = wfpc_row_2.expansion_number
             and wfpc_row_2.mode = @wcr_mode
             and wfpc_row_2.camera = @wcr_camera
             and wfpc_row_2.filter1 = @wcr_filter1
             and wfpc_row_2.filter2 = @wcr_filter2
        )
and wfpc_file_1.reference_file_type = 'FLT'
and wfpc_file_1.reject_flag = 'N'
and wfpc_file_1.opus_flag = 'Y'
and wfpc_file_1.archive_date is not null
and wfpc_file_1.file_name =wfpc_row_1.file_name
and wfpc_file_1.expansion_number = wfpc_row_1.expansion_number
and wfpc_row_1.mode = @wcr_mode
and wfpc_row_1.camera = @wcr_camera
and wfpc_row_1.filter1 = @wcr_filter1
and wfpc_row_1.filter2 = @wcr_filter2
select @num_cal_files = @@rowcount
if (@num_cal_files = 0)    /* no recommended file found */
select @wcr_best_flt = 'N/A', @wcr_best_loc_flt = 'N/A'
else
if (@wcr_flatfile = NULL) /* no file was used in the pipeline */
select @wcr_best_loc_flt = 'N/A'
else
if (@wcr_best_flt = @wcr_flatfile) /* recommended = was used */
select @wcr_best_loc_flt = 'NO CHANGE'
else
if (@equiv_sev = -1)
	select @wcr_best_loc_flt = 'UNKNOWN'
else
begin

select @orig_equiv_sev = wfpc_row_1.equivalence_class_severe,
@orig_equiv_mod =  wfpc_row_1.equivalence_class_moderate
from wfpc_row wfpc_row_1
where wfpc_row_1.file_name = @wcr_flatfile
and wfpc_row_1.mode = @wcr_mode
and wfpc_row_1.camera = @wcr_camera
and wfpc_row_1.filter1 = @wcr_filter1
and wfpc_row_1.filter2 = @wcr_filter2

if (@orig_equiv_sev = -1)
	select @wcr_best_loc_flt = 'UNKNOWN'
else if ((@equiv_sev - @orig_equiv_sev) <> 0)
	select @wcr_best_loc_flt = 'SEVERE'
else if ((@equiv_mod - @orig_equiv_mod) <> 0)
		select @wcr_best_loc_flt = 'MODERATE'
     else select @wcr_best_loc_flt = 'TRIVIAL'
end
/**************************************************************************/
/*********** instrument wfpc ref file type MSK ****************/
/**************************************************************************/
select @wcr_best_msk = wfpc_file_1.file_name,
@equiv_sev = wfpc_row_1.equivalence_class_severe,
@equiv_mod = wfpc_row_1.equivalence_class_moderate
from wfpc_file wfpc_file_1, wfpc_row wfpc_row_1
where wfpc_file_1.useafter_date = 
	(select max(wfpc_file_2.useafter_date)
	from wfpc_file wfpc_file_2, wfpc_row wfpc_row_2
             where wfpc_file_2.reference_file_type = 'MSK'
             and wfpc_file_2.useafter_date <= @expstart
             and wfpc_file_2.reject_flag = 'N'
             and wfpc_file_2.opus_flag = 'Y'
             and wfpc_file_2.archive_date is not null
             and wfpc_file_2.file_name =wfpc_row_2.file_name
             and wfpc_file_2.expansion_number = wfpc_row_2.expansion_number
             and wfpc_row_2.mode = @wcr_mode
             and wfpc_row_2.camera = @wcr_camera
        )
and wfpc_file_1.reference_file_type = 'MSK'
and wfpc_file_1.reject_flag = 'N'
and wfpc_file_1.opus_flag = 'Y'
and wfpc_file_1.archive_date is not null
and wfpc_file_1.file_name =wfpc_row_1.file_name
and wfpc_file_1.expansion_number = wfpc_row_1.expansion_number
and wfpc_row_1.mode = @wcr_mode
and wfpc_row_1.camera = @wcr_camera
select @num_cal_files = @@rowcount
if (@num_cal_files = 0)    /* no recommended file found */
select @wcr_best_msk = 'N/A', @wcr_best_loc_msk = 'N/A'
else
if (@wcr_maskfile = NULL) /* no file was used in the pipeline */
select @wcr_best_loc_msk = 'N/A'
else
if (@wcr_best_msk = @wcr_maskfile) /* recommended = was used */
select @wcr_best_loc_msk = 'NO CHANGE'
else
if (@equiv_sev = -1)
	select @wcr_best_loc_msk = 'UNKNOWN'
else
begin

select @orig_equiv_sev = wfpc_row_1.equivalence_class_severe,
@orig_equiv_mod =  wfpc_row_1.equivalence_class_moderate
from wfpc_row wfpc_row_1
where wfpc_row_1.file_name = @wcr_maskfile
and wfpc_row_1.mode = @wcr_mode
and wfpc_row_1.camera = @wcr_camera

if (@orig_equiv_sev = -1)
	select @wcr_best_loc_msk = 'UNKNOWN'
else if ((@equiv_sev - @orig_equiv_sev) <> 0)
	select @wcr_best_loc_msk = 'SEVERE'
else if ((@equiv_mod - @orig_equiv_mod) <> 0)
		select @wcr_best_loc_msk = 'MODERATE'
     else select @wcr_best_loc_msk = 'TRIVIAL'
end
/**************************************************************************/
/*********** instrument wfpc ref file type PRF ****************/
/**************************************************************************/
select @wcr_best_prf = wfpc_file_1.file_name,
@equiv_sev = wfpc_row_1.equivalence_class_severe,
@equiv_mod = wfpc_row_1.equivalence_class_moderate
from wfpc_file wfpc_file_1, wfpc_row wfpc_row_1
where wfpc_file_1.useafter_date = 
	(select max(wfpc_file_2.useafter_date)
	from wfpc_file wfpc_file_2, wfpc_row wfpc_row_2
             where wfpc_file_2.reference_file_type = 'PRF'
             and wfpc_file_2.useafter_date <= @expstart
             and wfpc_file_2.reject_flag = 'N'
             and wfpc_file_2.opus_flag = 'Y'
             and wfpc_file_2.archive_date is not null
             and wfpc_file_2.file_name =wfpc_row_2.file_name
             and wfpc_file_2.expansion_number = wfpc_row_2.expansion_number
             and wfpc_row_2.mode = @wcr_mode
             and wfpc_row_2.camera = @wcr_camera
             and wfpc_row_2.shutter = @wcr_shutter
        )
and wfpc_file_1.reference_file_type = 'PRF'
and wfpc_file_1.reject_flag = 'N'
and wfpc_file_1.opus_flag = 'Y'
and wfpc_file_1.archive_date is not null
and wfpc_file_1.file_name =wfpc_row_1.file_name
and wfpc_file_1.expansion_number = wfpc_row_1.expansion_number
and wfpc_row_1.mode = @wcr_mode
and wfpc_row_1.camera = @wcr_camera
and wfpc_row_1.shutter = @wcr_shutter
select @num_cal_files = @@rowcount
if (@num_cal_files = 0)    /* no recommended file found */
select @wcr_best_prf = 'N/A', @wcr_best_loc_prf = 'N/A'
else
if (@wcr_preffile = NULL) /* no file was used in the pipeline */
select @wcr_best_loc_prf = 'N/A'
else
if (@wcr_best_prf = @wcr_preffile) /* recommended = was used */
select @wcr_best_loc_prf = 'NO CHANGE'
else
if (@equiv_sev = -1)
	select @wcr_best_loc_prf = 'UNKNOWN'
else
begin

select @orig_equiv_sev = wfpc_row_1.equivalence_class_severe,
@orig_equiv_mod =  wfpc_row_1.equivalence_class_moderate
from wfpc_row wfpc_row_1
where wfpc_row_1.file_name = @wcr_preffile
and wfpc_row_1.mode = @wcr_mode
and wfpc_row_1.camera = @wcr_camera
and wfpc_row_1.shutter = @wcr_shutter

if (@orig_equiv_sev = -1)
	select @wcr_best_loc_prf = 'UNKNOWN'
else if ((@equiv_sev - @orig_equiv_sev) <> 0)
	select @wcr_best_loc_prf = 'SEVERE'
else if ((@equiv_mod - @orig_equiv_mod) <> 0)
		select @wcr_best_loc_prf = 'MODERATE'
     else select @wcr_best_loc_prf = 'TRIVIAL'
end
/**************************************************************************/
/*********** instrument wfpc ref file type PUR ****************/
/**************************************************************************/
select @wcr_best_pur = wfpc_file_1.file_name,
@equiv_sev = wfpc_row_1.equivalence_class_severe,
@equiv_mod = wfpc_row_1.equivalence_class_moderate
from wfpc_file wfpc_file_1, wfpc_row wfpc_row_1
where wfpc_file_1.useafter_date = 
	(select max(wfpc_file_2.useafter_date)
	from wfpc_file wfpc_file_2, wfpc_row wfpc_row_2
             where wfpc_file_2.reference_file_type = 'PUR'
             and wfpc_file_2.useafter_date <= @expstart
             and wfpc_file_2.reject_flag = 'N'
             and wfpc_file_2.opus_flag = 'Y'
             and wfpc_file_2.archive_date is not null
             and wfpc_file_2.file_name =wfpc_row_2.file_name
             and wfpc_file_2.expansion_number = wfpc_row_2.expansion_number
             and wfpc_row_2.mode = @wcr_mode
             and wfpc_row_2.camera = @wcr_camera
        )
and wfpc_file_1.reference_file_type = 'PUR'
and wfpc_file_1.reject_flag = 'N'
and wfpc_file_1.opus_flag = 'Y'
and wfpc_file_1.archive_date is not null
and wfpc_file_1.file_name =wfpc_row_1.file_name
and wfpc_file_1.expansion_number = wfpc_row_1.expansion_number
and wfpc_row_1.mode = @wcr_mode
and wfpc_row_1.camera = @wcr_camera
select @num_cal_files = @@rowcount
if (@num_cal_files = 0)    /* no recommended file found */
select @wcr_best_pur = 'N/A', @wcr_best_loc_pur = 'N/A'
else
if (@wcr_purgfile = NULL) /* no file was used in the pipeline */
select @wcr_best_loc_pur = 'N/A'
else
if (@wcr_best_pur = @wcr_purgfile) /* recommended = was used */
select @wcr_best_loc_pur = 'NO CHANGE'
else
if (@equiv_sev = -1)
	select @wcr_best_loc_pur = 'UNKNOWN'
else
begin

select @orig_equiv_sev = wfpc_row_1.equivalence_class_severe,
@orig_equiv_mod =  wfpc_row_1.equivalence_class_moderate
from wfpc_row wfpc_row_1
where wfpc_row_1.file_name = @wcr_purgfile
and wfpc_row_1.mode = @wcr_mode
and wfpc_row_1.camera = @wcr_camera

if (@orig_equiv_sev = -1)
	select @wcr_best_loc_pur = 'UNKNOWN'
else if ((@equiv_sev - @orig_equiv_sev) <> 0)
	select @wcr_best_loc_pur = 'SEVERE'
else if ((@equiv_mod - @orig_equiv_mod) <> 0)
		select @wcr_best_loc_pur = 'MODERATE'
     else select @wcr_best_loc_pur = 'TRIVIAL'
end
/**************************************************************************/
/*********** instrument wfpc ref file type PHOTTAB ****************/
/**************************************************************************/
/* mod - whole section */
select @wcr_best_phottab = wfpc_file_1.file_name,
@equiv_sev =
wfpc_row_1.equivalence_class_severe,
@equiv_mod =
wfpc_row_1.equivalence_class_moderate
from wfpc_file wfpc_file_1, wfpc_row wfpc_row_1
where wfpc_file_1.useafter_date
= 
	(select max(wfpc_file_2.useafter_date)
	from wfpc_file wfpc_file_2, wfpc_row wfpc_row_2
             where wfpc_file_2.reference_file_type = 'PHOTTAB'
             and wfpc_file_2.useafter_date <= @expstart
             and wfpc_file_2.reject_flag = 'N'
             and wfpc_file_2.opus_flag = 'Y'
             and wfpc_file_2.archive_date is not null
             and wfpc_file_2.file_name =wfpc_row_2.file_name
             and wfpc_file_2.expansion_number = wfpc_row_2.expansion_number
             and wfpc_row_2.photmode = @wcr_photmode_a
        )
and wfpc_file_1.reference_file_type = 'PHOTTAB'
and wfpc_file_1.reject_flag = 'N'
and wfpc_file_1.opus_flag = 'Y'
and wfpc_file_1.archive_date is not null
and wfpc_file_1.file_name =wfpc_row_1.file_name
and wfpc_file_1.expansion_number = wfpc_row_1.expansion_number
and wfpc_row_1.photmode = @wcr_photmode_a

select @num_cal_files = @@rowcount
if (@num_cal_files = 0)    /* no recommended file found */
select @wcr_best_phottab = 'N/A', @wcr_best_loc_photmode_a = 'N/A'
, @wcr_best_loc_photmode_b = 'N/A', @wcr_best_loc_photmode_c = 'N/A'
, @wcr_best_loc_photmode_d = 'N/A'
else
if (@wcr_phottab = NULL) /* no file was used in the pipeline */
select @wcr_best_loc_photmode_a = 'N/A',@wcr_best_loc_photmode_b = 'N/A',
@wcr_best_loc_photmode_c = 'N/A',@wcr_best_loc_photmode_d = 'N/A'
else
if (@wcr_best_phottab = @wcr_phottab) /* recommended = was used */
select @wcr_best_loc_photmode_a = 'NO CHANGE',
@wcr_best_loc_photmode_b = 'NO CHANGE',
@wcr_best_loc_photmode_c = 'NO CHANGE',
@wcr_best_loc_photmode_d = 'NO CHANGE'
else
if (@equiv_sev = -1)
	select @wcr_best_loc_photmode_a = 'UNKNOWN',
	       @wcr_best_loc_photmode_b = 'UNKNOWN',
	       @wcr_best_loc_photmode_c = 'UNKNOWN',
	       @wcr_best_loc_photmode_d = 'UNKNOWN'
else
begin

select @orig_equiv_sev = wfpc_row_1.equivalence_class_severe,
@orig_equiv_mod =  wfpc_row_1.equivalence_class_moderate
from wfpc_row wfpc_row_1
where wfpc_row_1.file_name = @wcr_phottab
and wfpc_row_1.photmode = @wcr_photmode_a

if (@orig_equiv_sev = -1)
	select @wcr_best_loc_photmode_a = 'UNKNOWN'
else
if ((@equiv_sev - @orig_equiv_sev) <> 0)
	select @wcr_best_loc_photmode_a = 'SEVERE'
else if ((@equiv_mod - @orig_equiv_mod) <> 0)
		select @wcr_best_loc_photmode_a = 'MODERATE'
     else select @wcr_best_loc_photmode_a = 'TRIVIAL'

select @orig_equiv_sev = wfpc_row_1.equivalence_class_severe,
@orig_equiv_mod =  wfpc_row_1.equivalence_class_moderate
from wfpc_row wfpc_row_1
where wfpc_row_1.file_name = @wcr_phottab
and wfpc_row_1.photmode = @wcr_photmode_b

if (@orig_equiv_sev = -1)
	select @wcr_best_loc_photmode_b = 'UNKNOWN'
else
if ((@equiv_sev - @orig_equiv_sev) <> 0)
	select @wcr_best_loc_photmode_b = 'SEVERE'
else if ((@equiv_mod - @orig_equiv_mod) <> 0)
		select @wcr_best_loc_photmode_b = 'MODERATE'
     else select @wcr_best_loc_photmode_b = 'TRIVIAL'

select @orig_equiv_sev = wfpc_row_1.equivalence_class_severe,
@orig_equiv_mod =  wfpc_row_1.equivalence_class_moderate
from wfpc_row wfpc_row_1
where wfpc_row_1.file_name = @wcr_phottab
and wfpc_row_1.photmode = @wcr_photmode_c

if (@orig_equiv_sev = -1)
	select @wcr_best_loc_photmode_c = 'UNKNOWN'
else
if ((@equiv_sev - @orig_equiv_sev) <> 0)
	select @wcr_best_loc_photmode_c = 'SEVERE'
else if ((@equiv_mod - @orig_equiv_mod) <> 0)
		select @wcr_best_loc_photmode_c = 'MODERATE'
     else select @wcr_best_loc_photmode_c = 'TRIVIAL'

select @orig_equiv_sev = wfpc_row_1.equivalence_class_severe,
@orig_equiv_mod =  wfpc_row_1.equivalence_class_moderate
from wfpc_row wfpc_row_1
where wfpc_row_1.file_name = @wcr_phottab
and wfpc_row_1.photmode = @wcr_photmode_d

if (@orig_equiv_sev = -1)
	select @wcr_best_loc_photmode_d = 'UNKNOWN'
else
if ((@equiv_sev - @orig_equiv_sev) <> 0)
	select @wcr_best_loc_photmode_d = 'SEVERE'
else if ((@equiv_mod - @orig_equiv_mod) <> 0)
		select @wcr_best_loc_photmode_d = 'MODERATE'
     else select @wcr_best_loc_photmode_d = 'TRIVIAL'

end
/* end mod */




update wfpc_ref_data
set
wcr_best_a2d = @wcr_best_a2d
,wcr_best_loc_a2d = @wcr_best_loc_a2d
,wcr_best_bas = @wcr_best_bas
,wcr_best_loc_bas = @wcr_best_loc_bas
,wcr_best_drk = @wcr_best_drk
,wcr_best_loc_drk = @wcr_best_loc_drk
,wcr_best_flt = @wcr_best_flt
,wcr_best_loc_flt = @wcr_best_loc_flt
,wcr_best_msk = @wcr_best_msk
,wcr_best_loc_msk = @wcr_best_loc_msk
,wcr_best_prf = @wcr_best_prf
,wcr_best_loc_prf = @wcr_best_loc_prf
,wcr_best_pur = @wcr_best_pur
,wcr_best_loc_pur = @wcr_best_loc_pur
,wcr_best_phottab = @wcr_best_phottab
,wcr_best_loc_photmode_a = @wcr_best_loc_photmode_a	/* mod */
,wcr_best_loc_photmode_b = @wcr_best_loc_photmode_b	/* mod */
,wcr_best_loc_photmode_c = @wcr_best_loc_photmode_c	/* mod */
,wcr_best_loc_photmode_d = @wcr_best_loc_photmode_d	/* mod */
where current of update_wfpc_cursor
fetch update_wfpc_cursor into @expstart,@data_set_name
,@wcr_mode
,@wcr_serials
,@wcr_camera
,@wcr_filter1
,@wcr_filter2
,@wcr_shutter
,@wcr_photmode_a  /*mod*/
,@wcr_photmode_b  /*mod*/
,@wcr_photmode_c  /*mod*/
,@wcr_photmode_d  /*mod*/
,@wcr_atodfile
,@wcr_biasfile
,@wcr_darkfile
,@wcr_flatfile
,@wcr_maskfile
,@wcr_preffile
,@wcr_purgfile
,@wcr_phottab
end
close update_wfpc_cursor 
deallocate cursor update_wfpc_cursor 
return
go
