use dadsops
go
drop procedure update_wfpc2
go
create procedure update_wfpc2 as
/* observation start time */
declare @expstart datetime
/* data set name, to be used for error checking/handling */
declare @data_set_name datasetname
/* severity level variables, to be reused for each reference file type */
declare @orig_equiv_sev int
declare @orig_equiv_mod int
declare @equiv_sev int
declare @equiv_mod int
/* used to store @@rowcount global variable */
declare @num_cal_files int
/* observation modes, calibration files used in the pipeline, */
/* best, and best_loc files */
declare @w2r_mode char(4)
declare @w2r_atodgain float
declare @w2r_serials char(3)
declare @w2r_shutter char(7)
declare @w2r_comptab char(18)
declare @w2r_filter1 int
declare @w2r_filter2 int
declare @w2r_atodfile char(18)
declare @w2r_best_a2d char(18)
declare @w2r_best_bas char(18)
declare @w2r_best_drk char(18)
declare @w2r_best_flt char(18)
declare @w2r_best_msk char(18)
declare @w2r_best_shd char(18)
declare @w2r_biasfile char(18)
declare @w2r_darkfile char(18)
declare @w2r_flatfile char(18)
declare @w2r_graphtab char(18)
declare @w2r_maskfile char(18)
declare @w2r_shadfile char(18)
declare @w2r_best_comptab char(18)
declare @w2r_best_graphtab char(18)
declare @w2r_best_loc_a2d varchar(9)
declare @w2r_best_loc_bas varchar(9)
declare @w2r_best_loc_drk varchar(9)
declare @w2r_best_loc_flt varchar(9)
declare @w2r_best_loc_msk varchar(9)
declare @w2r_best_loc_shd varchar(9)
declare update_wfpc2_cursor  cursor for
select w2r_expstart,w2r_data_set_name
,w2r_mode
,w2r_filter1
,w2r_filter2
,w2r_serials
,w2r_shutter
,w2r_atodgain
,w2r_atodfile
,w2r_darkfile
,w2r_flatfile
,w2r_maskfile
,w2r_shadfile
,w2r_biasfile
,w2r_comptab
,w2r_graphtab
from wfpc2_ref_data
where w2r_best_a2d is null
or w2r_best_drk is null
or w2r_best_flt is null
or w2r_best_msk is null
or w2r_best_shd is null
or w2r_best_bas is null
or w2r_best_comptab is null
or w2r_best_graphtab is null
 for update
open update_wfpc2_cursor 
fetch update_wfpc2_cursor into @expstart,@data_set_name
,@w2r_mode
,@w2r_filter1
,@w2r_filter2
,@w2r_serials
,@w2r_shutter
,@w2r_atodgain
,@w2r_atodfile
,@w2r_darkfile
,@w2r_flatfile
,@w2r_maskfile
,@w2r_shadfile
,@w2r_biasfile
,@w2r_comptab
,@w2r_graphtab
/**************************************************************************/
/************************ Update wfpc2 ***********************/
/**************************************************************************/
while (@@sqlstatus = 0)
begin
select
@w2r_best_a2d = null
,@w2r_best_bas = null
,@w2r_best_drk = null
,@w2r_best_flt = null
,@w2r_best_msk = null
,@w2r_best_shd = null
,@w2r_best_comptab = null
,@w2r_best_loc_a2d = null
,@w2r_best_loc_bas = null
,@w2r_best_loc_drk = null
,@w2r_best_loc_flt = null
,@w2r_best_loc_msk = null
,@w2r_best_loc_shd = null
,@w2r_best_graphtab = null

/**************************************************************************/
/*********** instrument wfpc2 ref file type A2D ****************/
/**************************************************************************/
select @w2r_best_a2d = wfpc2_file_1.file_name,
@equiv_sev = wfpc2_row_1.equivalence_class_severe,
@equiv_mod = wfpc2_row_1.equivalence_class_moderate
from wfpc2_file wfpc2_file_1, wfpc2_row wfpc2_row_1
where wfpc2_file_1.useafter_date = 
	(select max(wfpc2_file_2.useafter_date)
	from wfpc2_file wfpc2_file_2, wfpc2_row wfpc2_row_2
             where wfpc2_file_2.reference_file_type = 'A2D'
             and wfpc2_file_2.useafter_date <= @expstart
             and wfpc2_file_2.reject_flag = 'N'
             and wfpc2_file_2.opus_flag = 'Y'
             and wfpc2_file_2.archive_date is not null
             and wfpc2_file_2.file_name =wfpc2_row_2.file_name
             and wfpc2_file_2.expansion_number = wfpc2_row_2.expansion_number
             and wfpc2_row_2.mode = @w2r_mode
             and wfpc2_row_2.atodgain = @w2r_atodgain
        )
and wfpc2_file_1.reference_file_type = 'A2D'
and wfpc2_file_1.reject_flag = 'N'
and wfpc2_file_1.opus_flag = 'Y'
and wfpc2_file_1.archive_date is not null
and wfpc2_file_1.file_name =wfpc2_row_1.file_name
and wfpc2_file_1.expansion_number = wfpc2_row_1.expansion_number
and wfpc2_row_1.mode = @w2r_mode
and wfpc2_row_1.atodgain = @w2r_atodgain
select @num_cal_files = @@rowcount
if (@num_cal_files = 0)    /* no recommended file found */
select @w2r_best_a2d = 'N/A', @w2r_best_loc_a2d = 'N/A'
else
if (@w2r_atodfile = NULL) /* no file was used in the pipeline */
select @w2r_best_loc_a2d = 'N/A'
else
if (@w2r_best_a2d = @w2r_atodfile) /* recommended = was used */
select @w2r_best_loc_a2d = 'NO CHANGE'
else
if (@equiv_sev = -1)
	select @w2r_best_loc_a2d = 'UNKNOWN'
else
begin

select @orig_equiv_sev = wfpc2_row_1.equivalence_class_severe,
@orig_equiv_mod =  wfpc2_row_1.equivalence_class_moderate
from wfpc2_row wfpc2_row_1
where wfpc2_row_1.file_name = @w2r_atodfile
and wfpc2_row_1.mode = @w2r_mode
and wfpc2_row_1.atodgain = @w2r_atodgain

if (@orig_equiv_sev = -1)
	select @w2r_best_loc_a2d = 'UNKNOWN'
else if ((@equiv_sev - @orig_equiv_sev) <> 0)
	select @w2r_best_loc_a2d = 'SEVERE'
else if ((@equiv_mod - @orig_equiv_mod) <> 0)
		select @w2r_best_loc_a2d = 'MODERATE'
     else select @w2r_best_loc_a2d = 'TRIVIAL'
end
/**************************************************************************/
/*********** instrument wfpc2 ref file type BAS ****************/
/**************************************************************************/
select @w2r_best_bas = wfpc2_file_1.file_name,
@equiv_sev = wfpc2_row_1.equivalence_class_severe,
@equiv_mod = wfpc2_row_1.equivalence_class_moderate
from wfpc2_file wfpc2_file_1, wfpc2_row wfpc2_row_1
where wfpc2_file_1.useafter_date = 
	(select max(wfpc2_file_2.useafter_date)
	from wfpc2_file wfpc2_file_2, wfpc2_row wfpc2_row_2
             where wfpc2_file_2.reference_file_type = 'BAS'
             and wfpc2_file_2.useafter_date <= @expstart
             and wfpc2_file_2.reject_flag = 'N'
             and wfpc2_file_2.opus_flag = 'Y'
             and wfpc2_file_2.archive_date is not null
             and wfpc2_file_2.file_name =wfpc2_row_2.file_name
             and wfpc2_file_2.expansion_number = wfpc2_row_2.expansion_number
             and wfpc2_row_2.mode = @w2r_mode
             and wfpc2_row_2.atodgain = @w2r_atodgain
        )
and wfpc2_file_1.reference_file_type = 'BAS'
and wfpc2_file_1.reject_flag = 'N'
and wfpc2_file_1.opus_flag = 'Y'
and wfpc2_file_1.archive_date is not null
and wfpc2_file_1.file_name =wfpc2_row_1.file_name
and wfpc2_file_1.expansion_number = wfpc2_row_1.expansion_number
and wfpc2_row_1.mode = @w2r_mode
and wfpc2_row_1.atodgain = @w2r_atodgain
select @num_cal_files = @@rowcount
if (@num_cal_files = 0)    /* no recommended file found */
select @w2r_best_bas = 'N/A', @w2r_best_loc_bas = 'N/A'
else
if (@w2r_biasfile = NULL) /* no file was used in the pipeline */
select @w2r_best_loc_bas = 'N/A'
else
if (@w2r_best_bas = @w2r_biasfile) /* recommended = was used */
select @w2r_best_loc_bas = 'NO CHANGE'
else
if (@equiv_sev = -1)
	select @w2r_best_loc_bas = 'UNKNOWN'
else
begin

select @orig_equiv_sev = wfpc2_row_1.equivalence_class_severe,
@orig_equiv_mod =  wfpc2_row_1.equivalence_class_moderate
from wfpc2_row wfpc2_row_1
where wfpc2_row_1.file_name = @w2r_biasfile
and wfpc2_row_1.mode = @w2r_mode
and wfpc2_row_1.atodgain = @w2r_atodgain

if (@orig_equiv_sev = -1)
	select @w2r_best_loc_bas = 'UNKNOWN'
else if ((@equiv_sev - @orig_equiv_sev) <> 0)
	select @w2r_best_loc_bas = 'SEVERE'
else if ((@equiv_mod - @orig_equiv_mod) <> 0)
		select @w2r_best_loc_bas = 'MODERATE'
     else select @w2r_best_loc_bas = 'TRIVIAL'
end
/**************************************************************************/
/*********** instrument wfpc2 ref file type DRK ****************/
/**************************************************************************/
select @w2r_best_drk = wfpc2_file_1.file_name,
@equiv_sev = wfpc2_row_1.equivalence_class_severe,
@equiv_mod = wfpc2_row_1.equivalence_class_moderate
from wfpc2_file wfpc2_file_1, wfpc2_row wfpc2_row_1
where wfpc2_file_1.useafter_date = 
	(select max(wfpc2_file_2.useafter_date)
	from wfpc2_file wfpc2_file_2, wfpc2_row wfpc2_row_2
             where wfpc2_file_2.reference_file_type = 'DRK'
             and wfpc2_file_2.useafter_date <= @expstart
             and wfpc2_file_2.reject_flag = 'N'
             and wfpc2_file_2.opus_flag = 'Y'
             and wfpc2_file_2.archive_date is not null
             and wfpc2_file_2.file_name =wfpc2_row_2.file_name
             and wfpc2_file_2.expansion_number = wfpc2_row_2.expansion_number
             and wfpc2_row_2.mode = @w2r_mode
             and wfpc2_row_2.serials = @w2r_serials
             and wfpc2_row_2.atodgain = @w2r_atodgain
        )
and wfpc2_file_1.reference_file_type = 'DRK'
and wfpc2_file_1.reject_flag = 'N'
and wfpc2_file_1.opus_flag = 'Y'
and wfpc2_file_1.archive_date is not null
and wfpc2_file_1.file_name =wfpc2_row_1.file_name
and wfpc2_file_1.expansion_number = wfpc2_row_1.expansion_number
and wfpc2_row_1.mode = @w2r_mode
and wfpc2_row_1.serials = @w2r_serials
and wfpc2_row_1.atodgain = @w2r_atodgain
select @num_cal_files = @@rowcount
if (@num_cal_files = 0)    /* no recommended file found */
select @w2r_best_drk = 'N/A', @w2r_best_loc_drk = 'N/A'
else
if (@w2r_darkfile = NULL) /* no file was used in the pipeline */
select @w2r_best_loc_drk = 'N/A'
else
if (@w2r_best_drk = @w2r_darkfile) /* recommended = was used */
select @w2r_best_loc_drk = 'NO CHANGE'
else
if (@equiv_sev = -1)
	select @w2r_best_loc_drk = 'UNKNOWN'
else
begin

select @orig_equiv_sev = wfpc2_row_1.equivalence_class_severe,
@orig_equiv_mod =  wfpc2_row_1.equivalence_class_moderate
from wfpc2_row wfpc2_row_1
where wfpc2_row_1.file_name = @w2r_darkfile
and wfpc2_row_1.mode = @w2r_mode
and wfpc2_row_1.serials = @w2r_serials
and wfpc2_row_1.atodgain = @w2r_atodgain

if (@orig_equiv_sev = -1)
	select @w2r_best_loc_drk = 'UNKNOWN'
else if ((@equiv_sev - @orig_equiv_sev) <> 0)
	select @w2r_best_loc_drk = 'SEVERE'
else if ((@equiv_mod - @orig_equiv_mod) <> 0)
		select @w2r_best_loc_drk = 'MODERATE'
     else select @w2r_best_loc_drk = 'TRIVIAL'
end
/**************************************************************************/
/*********** instrument wfpc2 ref file type FLT ****************/
/**************************************************************************/
/* begin mod */
/* modified to allow for different permutations of filter 1 and 2 */

select @w2r_best_flt = wfpc2_file_1.file_name,
@equiv_sev = wfpc2_row_1.equivalence_class_severe,
@equiv_mod = wfpc2_row_1.equivalence_class_moderate
from wfpc2_file wfpc2_file_1, wfpc2_row wfpc2_row_1
where wfpc2_file_1.useafter_date = 
	(select max(wfpc2_file_2.useafter_date)
	from wfpc2_file wfpc2_file_2, wfpc2_row wfpc2_row_2
             where wfpc2_file_2.reference_file_type = 'FLT'
             and wfpc2_file_2.useafter_date <= @expstart
             and wfpc2_file_2.reject_flag = 'N'
             and wfpc2_file_2.opus_flag = 'Y'
             and wfpc2_file_2.archive_date is not null
             and wfpc2_file_2.file_name =wfpc2_row_2.file_name
             and wfpc2_file_2.expansion_number = wfpc2_row_2.expansion_number
             and wfpc2_row_2.mode = @w2r_mode
             and ((wfpc2_row_2.filter1 = @w2r_filter1
             and wfpc2_row_2.filter2 = @w2r_filter2)
	     or  (wfpc2_row_2.filter1 = @w2r_filter2
	     and wfpc2_row_2.filter2 = @w2r_filter1))
        )
and wfpc2_file_1.reference_file_type = 'FLT'
and wfpc2_file_1.reject_flag = 'N'
and wfpc2_file_1.opus_flag = 'Y'
and wfpc2_file_1.archive_date is not null
and wfpc2_file_1.file_name =wfpc2_row_1.file_name
and wfpc2_file_1.expansion_number = wfpc2_row_1.expansion_number
and wfpc2_row_1.mode = @w2r_mode
and ((wfpc2_row_1.filter1 = @w2r_filter1
and wfpc2_row_1.filter2 = @w2r_filter2)
or  (wfpc2_row_1.filter1 = @w2r_filter2
and wfpc2_row_1.filter2 = @w2r_filter1))

select @num_cal_files = @@rowcount
if (@num_cal_files = 0)    /* no recommended file found */
select @w2r_best_flt = 'N/A', @w2r_best_loc_flt = 'N/A'
else
if (@w2r_flatfile = NULL) /* no file was used in the pipeline */
select @w2r_best_loc_flt = 'N/A'
else
if (@w2r_best_flt = @w2r_flatfile) /* recommended = was used */
select @w2r_best_loc_flt = 'NO CHANGE'
else
if (@equiv_sev = -1)
	select @w2r_best_loc_flt = 'UNKNOWN'
else
begin

select @orig_equiv_sev = wfpc2_row_1.equivalence_class_severe,
@orig_equiv_mod =  wfpc2_row_1.equivalence_class_moderate
from wfpc2_row wfpc2_row_1
where wfpc2_row_1.file_name = @w2r_flatfile
and wfpc2_row_1.mode = @w2r_mode
and ((wfpc2_row_1.filter1 = @w2r_filter1
and wfpc2_row_1.filter2 = @w2r_filter2)
or  (wfpc2_row_1.filter1 = @w2r_filter2
and wfpc2_row_1.filter2 = @w2r_filter1))


if (@orig_equiv_sev = -1)
	select @w2r_best_loc_flt = 'UNKNOWN'
else if ((@equiv_sev - @orig_equiv_sev) <> 0)
	select @w2r_best_loc_flt = 'SEVERE'
else if ((@equiv_mod - @orig_equiv_mod) <> 0)
		select @w2r_best_loc_flt = 'MODERATE'
     else select @w2r_best_loc_flt = 'TRIVIAL'
end

/* end mod */
/**************************************************************************/
/*********** instrument wfpc2 ref file type MSK ****************/
/**************************************************************************/
select @w2r_best_msk = wfpc2_file_1.file_name,
@equiv_sev = wfpc2_row_1.equivalence_class_severe,
@equiv_mod = wfpc2_row_1.equivalence_class_moderate
from wfpc2_file wfpc2_file_1, wfpc2_row wfpc2_row_1
where wfpc2_file_1.useafter_date = 
	(select max(wfpc2_file_2.useafter_date)
	from wfpc2_file wfpc2_file_2, wfpc2_row wfpc2_row_2
             where wfpc2_file_2.reference_file_type = 'MSK'
             and wfpc2_file_2.useafter_date <= @expstart
             and wfpc2_file_2.reject_flag = 'N'
             and wfpc2_file_2.opus_flag = 'Y'
             and wfpc2_file_2.archive_date is not null
             and wfpc2_file_2.file_name =wfpc2_row_2.file_name
             and wfpc2_file_2.expansion_number = wfpc2_row_2.expansion_number
             and wfpc2_row_2.mode = @w2r_mode
        )
and wfpc2_file_1.reference_file_type = 'MSK'
and wfpc2_file_1.reject_flag = 'N'
and wfpc2_file_1.opus_flag = 'Y'
and wfpc2_file_1.archive_date is not null
and wfpc2_file_1.file_name =wfpc2_row_1.file_name
and wfpc2_file_1.expansion_number = wfpc2_row_1.expansion_number
and wfpc2_row_1.mode = @w2r_mode
select @num_cal_files = @@rowcount
if (@num_cal_files = 0)    /* no recommended file found */
select @w2r_best_msk = 'N/A', @w2r_best_loc_msk = 'N/A'
else
if (@w2r_maskfile = NULL) /* no file was used in the pipeline */
select @w2r_best_loc_msk = 'N/A'
else
if (@w2r_best_msk = @w2r_maskfile) /* recommended = was used */
select @w2r_best_loc_msk = 'NO CHANGE'
else
if (@equiv_sev = -1)
	select @w2r_best_loc_msk = 'UNKNOWN'
else
begin

select @orig_equiv_sev = wfpc2_row_1.equivalence_class_severe,
@orig_equiv_mod =  wfpc2_row_1.equivalence_class_moderate
from wfpc2_row wfpc2_row_1
where wfpc2_row_1.file_name = @w2r_maskfile
and wfpc2_row_1.mode = @w2r_mode

if (@orig_equiv_sev = -1)
	select @w2r_best_loc_msk = 'UNKNOWN'
else if ((@equiv_sev - @orig_equiv_sev) <> 0)
	select @w2r_best_loc_msk = 'SEVERE'
else if ((@equiv_mod - @orig_equiv_mod) <> 0)
		select @w2r_best_loc_msk = 'MODERATE'
     else select @w2r_best_loc_msk = 'TRIVIAL'
end
/**************************************************************************/
/*********** instrument wfpc2 ref file type SHD ****************/
/**************************************************************************/
select @w2r_best_shd = wfpc2_file_1.file_name,
@equiv_sev = wfpc2_row_1.equivalence_class_severe,
@equiv_mod = wfpc2_row_1.equivalence_class_moderate
from wfpc2_file wfpc2_file_1, wfpc2_row wfpc2_row_1
where wfpc2_file_1.useafter_date = 
	(select max(wfpc2_file_2.useafter_date)
	from wfpc2_file wfpc2_file_2, wfpc2_row wfpc2_row_2
             where wfpc2_file_2.reference_file_type = 'SHD'
             and wfpc2_file_2.useafter_date <= @expstart
             and wfpc2_file_2.reject_flag = 'N'
             and wfpc2_file_2.opus_flag = 'Y'
             and wfpc2_file_2.archive_date is not null
             and wfpc2_file_2.file_name =wfpc2_row_2.file_name
             and wfpc2_file_2.expansion_number = wfpc2_row_2.expansion_number
             and wfpc2_row_2.mode = @w2r_mode
             and wfpc2_row_2.shutter = @w2r_shutter
        )
and wfpc2_file_1.reference_file_type = 'SHD'
and wfpc2_file_1.reject_flag = 'N'
and wfpc2_file_1.opus_flag = 'Y'
and wfpc2_file_1.archive_date is not null
and wfpc2_file_1.file_name =wfpc2_row_1.file_name
and wfpc2_file_1.expansion_number = wfpc2_row_1.expansion_number
and wfpc2_row_1.mode = @w2r_mode
and wfpc2_row_1.shutter = @w2r_shutter
select @num_cal_files = @@rowcount
if (@num_cal_files = 0)    /* no recommended file found */
select @w2r_best_shd = 'N/A', @w2r_best_loc_shd = 'N/A'
else
if (@w2r_shadfile = NULL) /* no file was used in the pipeline */
select @w2r_best_loc_shd = 'N/A'
else
if (@w2r_best_shd = @w2r_shadfile) /* recommended = was used */
select @w2r_best_loc_shd = 'NO CHANGE'
else
if (@equiv_sev = -1)
	select @w2r_best_loc_shd = 'UNKNOWN'
else
begin

select @orig_equiv_sev = wfpc2_row_1.equivalence_class_severe,
@orig_equiv_mod =  wfpc2_row_1.equivalence_class_moderate
from wfpc2_row wfpc2_row_1
where wfpc2_row_1.file_name = @w2r_shadfile
and wfpc2_row_1.mode = @w2r_mode
and wfpc2_row_1.shutter = @w2r_shutter

if (@orig_equiv_sev = -1)
	select @w2r_best_loc_shd = 'UNKNOWN'
else if ((@equiv_sev - @orig_equiv_sev) <> 0)
	select @w2r_best_loc_shd = 'SEVERE'
else if ((@equiv_mod - @orig_equiv_mod) <> 0)
		select @w2r_best_loc_shd = 'MODERATE'
     else select @w2r_best_loc_shd = 'TRIVIAL'
end
/**************************************************************************/
/*********** instrument wfpc2 ref file type COMPTAB ****************/
/**************************************************************************/
/* begin mod - OPR 35596 - only select latest version of COMPTAB */
/*             OPR 35935 - don't compute level of change         */

select @w2r_best_comptab = synphot_file_1.file_name
from synphot_file synphot_file_1
where synphot_file_1.general_availability_date = 
	(select max(synphot_file_2.general_availability_date)
	from synphot_file synphot_file_2
             where synphot_file_2.reference_file_type = 'COMPTAB'
             and synphot_file_2.reject_flag = 'N'
             and synphot_file_2.opus_flag = 'Y'
             and synphot_file_2.archive_date is not null
        )
and synphot_file_1.reference_file_type = 'COMPTAB'
and synphot_file_1.reject_flag = 'N'
and synphot_file_1.opus_flag = 'Y'
and synphot_file_1.archive_date is not null

select @num_cal_files = @@rowcount
if (@num_cal_files = 0)    /* no recommended file found */
select @w2r_best_comptab = 'N/A'

/* end mod */

/**************************************************************************/
/*********** instrument wfpc2 ref file type GRAPHTAB ****************/
/**************************************************************************/
/* begin mod - OPR 35596 - only select latest version of GRAPHTAB */
/*             OPR 35935 - don't compute level of change         */

select @w2r_best_graphtab = synphot_file_1.file_name
from synphot_file synphot_file_1
where synphot_file_1.general_availability_date = 
	(select max(synphot_file_2.general_availability_date)
	from synphot_file synphot_file_2
             where synphot_file_2.reference_file_type = 'GRAPHTAB'
             and synphot_file_2.reject_flag = 'N'
             and synphot_file_2.opus_flag = 'Y'
             and synphot_file_2.archive_date is not null
        )
and synphot_file_1.reference_file_type = 'GRAPHTAB'
and synphot_file_1.reject_flag = 'N'
and synphot_file_1.opus_flag = 'Y'
and synphot_file_1.archive_date is not null


select @num_cal_files = @@rowcount
if (@num_cal_files = 0)    /* no recommended file found */
select @w2r_best_graphtab = 'N/A'

/* end mod */

update wfpc2_ref_data
set
w2r_best_a2d = @w2r_best_a2d
,w2r_best_loc_a2d = @w2r_best_loc_a2d
,w2r_best_bas = @w2r_best_bas
,w2r_best_loc_bas = @w2r_best_loc_bas
,w2r_best_drk = @w2r_best_drk
,w2r_best_loc_drk = @w2r_best_loc_drk
,w2r_best_flt = @w2r_best_flt
,w2r_best_loc_flt = @w2r_best_loc_flt
,w2r_best_msk = @w2r_best_msk
,w2r_best_loc_msk = @w2r_best_loc_msk
,w2r_best_shd = @w2r_best_shd
,w2r_best_loc_shd = @w2r_best_loc_shd
,w2r_best_comptab = @w2r_best_comptab
,w2r_best_graphtab = @w2r_best_graphtab
where current of update_wfpc2_cursor
fetch update_wfpc2_cursor into @expstart,@data_set_name
,@w2r_mode
,@w2r_filter1
,@w2r_filter2
,@w2r_serials
,@w2r_shutter
,@w2r_atodgain
,@w2r_atodfile
,@w2r_darkfile
,@w2r_flatfile
,@w2r_maskfile
,@w2r_shadfile
,@w2r_biasfile
,@w2r_comptab
,@w2r_graphtab
end
close update_wfpc2_cursor 
deallocate cursor update_wfpc2_cursor 
return
go
