#include <string.h>
#include <stdlib.h>
#include "ostdb.h"
#include "cdbslib.h"
#include "config.h"
#include "loadfile.h"
#include "dbquery.h"

#define  SZ_TEXT	16000

/* COMPFILE_QRY -- Query database for comparison file
 *
 * i: inst	instrument name
 * i: reftype	reference file type
 * i: usedate	useafter date
 * i: obsmode	observation mode clause
 * i: reffile	reference file for which comparison file is sought
 * o: compfile	comparison file name
 * o: useafter	useafter date
 */

void compfile_qry (char *inst, char *reftype, char *usedate, 
		   char *obsmode, char *compfile, char *useafter, int maxch)
{
    static char *nomode_compfile_qry = 
"select distinct a.file_name, a.useafter_date from ^_file a \
where a.reference_file_type = ^ and a.reject_flag = 'N' and \
a.file_name in (select a.file_name from ^_file a where \
a.useafter_date = (select max(a.useafter_date) from ^_file \
a where a.reference_file_type = ^ and \
a.reject_flag = 'N' and a.useafter_date <= ^) )";

    static char *mode_compfile_qry = 
"select distinct a.file_name, a.useafter_date from ^_file a, \
^_row b where a.reference_file_type = ^ and \
a.file_name = b.file_name and a.expansion_number = \
b.expansion_number and a.reject_flag = 'N' and ^ and \
a.file_name in (select a.file_name from ^_file a where \
a.useafter_date = (select max(a.useafter_date) from ^_file \
a, ^_row b where a.reference_file_type = ^ and \
a.file_name = b.file_name and a.expansion_number = \
b.expansion_number and a.reject_flag = 'N' and a.useafter_date <= \
^ and ^) )";

    context 	*qry;
    char	*type, *cutoff;
    char	fname[SZ_FNAME+1], date[SZ_STRING+1];

    /* Initialize query and bind output variables */

    qry = init_query ();
    ostdb_query_setup (qry->connection, "compname_qry", 1, STDB_SQL, 
		       qry->server, qry->cdbs_db, NULL);

    stdb_bind_string (qry->connection, "file_name", fname, SZ_FNAME);
    stdb_bind_string (qry->connection, "useafter_date", date, SZ_STRING);

    /* Create quoted versions of input strings */

    cutoff = strclone (enquote (usedate));
    type = strclone (strucase (enquote (reftype)));

    /* Send query after filling in variables */

    if (obsmode[0] == EOS) {
	build_qry (qry->connection, nomode_compfile_qry, inst, 
		   type, inst, inst, type, cutoff);
    } else {
	build_qry (qry->connection, mode_compfile_qry, inst, inst, type, 
		   obsmode, inst, inst, inst, type, cutoff, obsmode);
    }

    /* Execute query */

    compfile[0] = EOS;
    useafter[0] = EOS;
    while (ostdb_get_exec (qry->connection) == STDB_CONTINUE) {
	if (build_list (fname, compfile, maxch) == ERR)
	    break;

	if (build_list (date, useafter, maxch) == ERR)
	    break;
    }

    stdb_close_query (qry->connection);
    free_query (qry);
    free (cutoff);
    free (type);

}

