#include <string.h>
#include <stdlib.h>
#include "error.h"
#include "config.h"
#include "reffile.h"
#include "loadfile.h"
#include "cdbslib.h"
#include "dbquery.h"
#include "hashtab.h"

#define  NONE		0
#define  ONCE		1
#define  MANY		2

static void		parse_pedigree (char *, char *, char *, char *, int);

/* MKLOAD_BODY -- Write the body of the loadfile table
 * 
 * u: tab		loadfile table descriptor
 * i: ref		reference file descriptor
 * i: instrument 	instrument name
 * i: reftype		reference file type
 */

void mkload_body (table * tab, reffile *ref, char *instrument, char *reftype)
{
    static char change_level[] = "CHANGE_LEVEL";
    static char	pedigree[] = "PEDIGREE";
    static char obstart[] = "OBSERVATION_BEGIN_DATE";
    static char obsend[] = "OBSERVATION_END_DATE";
    static char comment[] = "COMMENT";

    hashtab     *hash;
    textbuf	obsmode, obsvals;
    int		irow, jrow, nrow, ikey, number;
    char	*keyword, *keyval;
    char	value[SZ_STRING+1], source[SZ_STRING+1];
    char	start_date[SZ_STRING+1], end_date[SZ_STRING+1];

    /* Create non-obsmode columns to be filled later */

    add_tab_col (tab, change_level);
    add_tab_col (tab, pedigree);
    add_tab_col (tab, obstart);
    add_tab_col (tab, obsend);
    add_tab_col (tab, comment);

    /* Read list of observation mode fields from the database */

    obsmode_qry (instrument, reftype, &obsmode);

    /* Search header for observation mode values */

    read_header (ref, &obsmode, &obsvals);

    if (kind_reffile(ref) == IMAGE) {
      /* Write observation mode keywords */

	for (ikey = 0; keyword = get_text (&obsmode, ikey); ikey ++) {
	    keyval = get_text (&obsvals, ikey);
	    if (keyval[0] != '\n') {
		put_tab_cell (tab, keyword, 0, keyval);
	    } else {
	        cdbs_error (NOHDRKEY, "%s[%s]", name_reffile(ref), keyword);
	    }
	}

	/* Pedigree keywords */

	if (get_hdr_reffile (ref, pedigree, value, SZ_STRING) != ERR) {
	    strucase (value);

	    parse_pedigree (value, source, start_date, end_date, SZ_STRING);

	    put_tab_cell (tab, pedigree, 0, source);
	    put_tab_cell (tab, obstart, 0, start_date);
	    put_tab_cell (tab, obsend, 0, end_date);
	}

    } else {
        /* Find the location of the pedigree keyword */

        if (get_body_reffile (ref, pedigree, 0, value, SZ_STRING) != ERR) {
	    number = MANY;
	    
	} else if (get_hdr_reffile (ref, pedigree, value, SZ_STRING) != ERR) {
	    parse_pedigree (value, source, start_date, end_date, SZ_STRING);
	    number = ONCE;

	} else {
	    number = NONE;
	}

	/* Copy the info to each row of the table */

        jrow = 0;
	nrow = nrow_reffile (ref);
        hash = init_hash (nrow);

	for (irow = 0; irow < nrow; irow ++) {

	  /* Observation mode */

	    for (ikey = 0; keyword = get_text (&obsmode, ikey); ikey ++) {
	        keyval = get_text (&obsvals, ikey);

		if (get_body_reffile (ref, keyword, irow, 
				      value, SZ_STRING) != ERR) {
		    put_tab_cell (tab, keyword, jrow, value);

		} else if (keyval[0] != '\n') {
		    put_tab_cell (tab, keyword, jrow, keyval);

		} else {
		    cdbs_error (NOHDRKEY, "%s[%s]", 
				name_reffile(ref), keyword);
		}
	    }

	    /* Pedigree */

	    if (number == MANY) {
	        get_body_reffile (ref, pedigree, irow, value, SZ_STRING);
		parse_pedigree (value, source, start_date, 
				end_date, SZ_STRING);
	    }

	    if (number != NONE) {
	        put_tab_cell (tab, pedigree, jrow, source);
		put_tab_cell (tab, obstart, jrow, start_date);
		put_tab_cell (tab, obsend, jrow, end_date);
	    }

	    /* Check if observation mode is unique */

	    if (find_hash (hash, &obsmode, tab, jrow) == NO) {
	        jrow ++;
	    } else if (irow == nrow - 1) {
	        trunc_table (tab, jrow);
	    }
	}

	free_hash (hash);
    }

    free_text (&obsmode);
    free_text (&obsvals);

}

/* PARSE_PEDIGREE -- Break the pedigree keywords up into its fields
 *
 * i: pedigree		the value of the pedigree keyword
 * o: field		its component fields
 * i: nfield		the number of fields
 */

static void parse_pedigree (char *pedigree, char *source, char *start_date, 
			    char *end_date, int maxch)
{
    char 	*dash, *field[3];

    if ((dash = strchr (pedigree, '-')) != NULL)
        *dash = ' ';

    strsplit (' ', pedigree, field, 3);
    if (field[2][0] == EOS)
        field[2] = field[1];

    safecopy (source, field[0], maxch);
    mkload_date (field[1], start_date, maxch);
    mkload_date (field[2], end_date, maxch);
}
