/*****************************************************************************/
/*                                                                           */
/*  File name :   stis_row.sql                                               */
/*                                                                           */
/*  Description : instrucment "stis" row level table                         */
/*                associated file level table : stis_file                    */
/*                                                                           */
/*  Note :        for any given delivery, row level data should be inserted  */
/*                to "stis_row" prior insert file level data to "stis_file"  */
/*                                                                           */
/*  Modification History:                                                    */
/*                                                                           */
/*    Date       OPR      Who                       Reason                   */
/*  --------   -------    ---   -------------------------------------------  */
/*  07/08/96               sk   Original                                     */
/*  02/19/97               sk   change smallint mode to int                  */
/*  04/22/97   33869       sk   change detector, opt_elem, sclamp size       */
/*                                                                           */
/*****************************************************************************/
 
create table stis_row (
   file_name                   varchar(50) not null,
   expansion_number            int         not null,
   delivery_number             int         not null,

   /* observation_mode  */
   detector                    varchar(10) not null, 
   ccdamp                      varchar(3)  not null,
   ccdgain                     int         not null,
   ccdoffst                    int         not null,
   binaxis1                    int         not null,
   binaxis2                    int         not null,
   crsplit                     int         not null,
   opt_elem                    varchar(8)  not null,
   obstype                     varchar(14) not null,
   aperture                    varchar(16) not null, 
   cenwave                     int         not null,
   sclamp                      varchar(9)  not null,
   lampset                     varchar(6)  not null,

   /* equivalence_class */
   equivalence_class_severe    int         not null,
   equivalence_class_moderate  int         not null,

   pedigree                    varchar(50) not null,
   observation_begin_date      datetime    null,
   observation_end_date        datetime    null,
   comment                     text        null)
go

sp_bindefault cdbs_char_default, 'stis_row.detector'
go
sp_bindefault cdbs_char_default, 'stis_row.ccdamp'
go
sp_bindefault cdbs_int_default, 'stis_row.ccdgain'
go
sp_bindefault cdbs_int_default, 'stis_row.ccdoffst'
go
sp_bindefault cdbs_int_default, 'stis_row.binaxis1'
go
sp_bindefault cdbs_int_default, 'stis_row.binaxis2'
go
sp_bindefault cdbs_int_default, 'stis_row.crsplit'
go
sp_bindefault cdbs_char_default, 'stis_row.opt_elem'
go
sp_bindefault cdbs_char_default, 'stis_row.obstype'
go
sp_bindefault cdbs_char_default, 'stis_row.aperture'
go
sp_bindefault cdbs_int_default, 'stis_row.cenwave'
go
sp_bindefault cdbs_char_default, 'stis_row.sclamp'
go
sp_bindefault cdbs_char_default, 'stis_row.lampset'
go
