#include <stdlib.h>
#include <stdarg.h>
#include <stdio.h>
#include "cdbslib.h"
#include "config.h"
#include "error.h"
#include "system.h"
#include "errormsg.h"

#define  ERRORLOG	stdout	/* file error messages are printed to */

int	cdbs_errorflag = NO;
void	(*cdbs_errhandler)(int, const char *) = NULL;

/* CDBS_ERROR -- Print cdbs error message and exit
 *
 * i: code	error code
 * i: fmt	format for arguments
 */

void cdbs_error (const int code, const char *fmt, ...)
{
    va_list	ptr;
    char	message[SZ_LINE+1], arglist[SZ_LINE+1];

    /* Check for out of bounds error codes */

    if (code < 0 || code > MAXERR)
	cdbs_error (UNKNOWN, "%d", code);

    /* Format message arguments as a string */

    va_start (ptr, fmt);
    vsprintf (arglist, fmt, ptr);
    va_end (ptr);

    /* Write message to output */

    safecopy (message, error_msg[code], SZ_LINE);
    safecat (message, " (", SZ_LINE);
    safecat (message, arglist, SZ_LINE);
    safecat (message, ")\n", SZ_LINE);

    cdbs_message (ERROR_MSG, message);
}

/* CDBS_WARN -- Print cdbs warning message to output file
 *
 * i: code	error code
 * i: fmt	format for arguments
 */

void cdbs_warn (const int code, const char *fmt, ...)

{
    va_list	ptr;
    char	message[SZ_LINE+1], arglist[SZ_LINE+1];

    /* Check for out of bounds error codes */

    if (code < 0 || code > MAXERR)
	cdbs_error (UNKNOWN, "%d", code);

    /* Format message arguments as a string */

    va_start (ptr, fmt);
    vsprintf (arglist, fmt, ptr);
    va_end (ptr);

    /* Write message to output */

    safecopy (message, error_msg[code], SZ_LINE);
    safecat (message, " (", SZ_LINE);
    safecat (message, arglist, SZ_LINE);
    safecat (message, ")\n", SZ_LINE);

    cdbs_message (WARN_MSG, message);
}

/* CDBS_INFO -- Print cdbs informational message
 *
 * i: code	error code
 * i: fmt	format for arguments
 */

void cdbs_info (const int code, const char *fmt, ...)
{
    va_list	ptr;
    char	message[SZ_LINE+1], arglist[SZ_LINE+1];

    /* Check for out of bounds error codes */

    if (code < 0 || code > MAXERR)
	cdbs_error (UNKNOWN, "%d", code);

    /* Format message arguments as a string */

    va_start (ptr, fmt);
    vsprintf (arglist, fmt, ptr);
    va_end (ptr);

    /* Write message to output */

    safecopy (message, error_msg[code], SZ_LINE);
    safecat (message, " (", SZ_LINE);
    safecat (message, arglist, SZ_LINE);
    safecat (message, ")\n", SZ_LINE);

    cdbs_message (INFO_MSG, message);
}

/* CDBS_MESSAGE -- Print cdbs message to stdout
 *
 * i: code	error code
 * i: fmt	format for arguments
 */

void cdbs_message (const int flag, const char *message)
{
    if (cdbs_errhandler == NULL) {
	fputs (message, ERRORLOG);
    } else {
	(*cdbs_errhandler) (flag, message);
    }

    if (flag == WARN_MSG)
        cdbs_errorflag = YES;

    if (flag == ERROR_MSG)
        exit (ERROR_EXIT);

}
