#include <stdlib.h>
#include "error.h"
#include "system.h"
#include "c_iraf.h"
#include "config.h"
#include "cdbslib.h"

static void expand_param (int, char **);
static void free_param (void);

/* These variables contain the expanded command line argument list */

static int	nparam;
static char	*param[MAXPARAM+1];

/* MAIN -- Dummy main routine
 *
 * i: argc	number of command line arguments
 * i: argv	array of ptrs to command line arguments
 */

MAIN_TYPE main (int argc, char ** argv)
{
    int		status;

    c_irafinit (argc, argv);
    init_option ();

    expand_param (argc, argv);
    print_ver();

    atexit (free_option);
    atexit (free_param);

    task (nparam, param);
    if (cdbs_errorflag == NO) {
        status = NORMAL_EXIT;
    } else {
        status = ERROR_EXIT;
    }

    MAIN_RETURN (status);
}

/* EXPAND_PARAM -- Expand wildcards in input argument list
 *
 * Output is placed in the static variables nparam and param
 *
 * i: argc	number of command line arguments
 * i: argv	array of ptrs to command line arguments
 */

static void expand_param (int argc, char ** argv)
{
    int		iarg, ipar;

    param[0] = strclone (argv[0]);

    ipar = 1;
    for (iarg = 1; iarg < argc; iarg ++) {
	if (is_option(argv[iarg]) == NO) {
	    wild_expand (argv[iarg], MAXPARAM, &ipar, param);
	} else {
	    put_option (argv[iarg]);
	}
    }

    param[ipar] = NULL;
    nparam = ipar;

}

/* FREE_PARAM -- Free input argument list */

static void free_param (void)
{
    int		ipar;

    for (ipar = 0; ipar < nparam; ipar ++)
	free (param[ipar]);

    nparam = 0;
}
