#include <stdlib.h>
#include <string.h>
#include "alist.h"
#include "error.h"
#include "config.h"
#include "cdbslib.h"

#define  NDEFAULT	50

alist	*options = NULL;

/* DEF_OPTION -- Set default values for options
 *
 * i:	defaults	comma separated list of default options
 */

void def_option (char *defaults)
{
    int		idef;
    char	*buf, *field[NDEFAULT];

    buf = strclone (defaults);
    strsplit (',', buf, field, NDEFAULT);

    for (idef = 0; idef < NDEFAULT && field[idef][0] != EOS; idef++)
	put_option (field[idef]);

    free (buf);
}

/* EACH_OPTION -- Return each option in the list 
 *
 * i: index	index into option array
 * o: key	pointer to keyword name
 * o: value	pointer to keyword value
 */

int each_option (int index, char **key, char **value) 
{
    return (each_alist (options, index, key, value));
}

/* FREE_OPTION -- Free the option list
 *
 */

void free_option (void)
{
    free_alist (options);
}

/* GET_OPTION -- Retrieve an option from the list of optional arguments
 *
 * i: name	option name
 */

char *get_option (char *name)
{
    char	*value;

    value = find_alist (options, name);
    if (value == NULL)
	cdbs_error (NOOPT, "%s", name);

    return (value);
}

/* INIT_OPTION -- Create the empty option list
 *
 */

void init_option (void)
{
    options = create_alist ();
}

/* IS_OPTION -- Check to see if command argument is an optional argument
 *
 * i: arg	command line argument
 *
 */

int is_option (char *arg) 
{
    int		nc;

    /* Optional arguments contain an equals sign and no blanks*/

    if (strchr (arg, '=') != NULL && strchr (arg, ' ') == NULL)
	return (YES);

    /* Or their last character is a plus or minus */

    nc = strlen (arg);
    if (nc > 0 && (arg[nc-1] == '+' || arg[nc-1] == '-'))
	return (YES);

    return (NO);
}

/* PUT_OPTION -- Parse an option argument and add it to the list
 *
 * i: arg	argument name
 */

void put_option (char *arg)
{
    int		nc;
    char	*buf, *peq, *field[2];

    buf = strclone (arg);
    nc = strlen (buf);

    /* Most options are name=value pairs. Boolean options my be specified 
     * by the option name followed by a plus or minus. Only the first
     * occurrence of an option is stored.
     */

    peq = strchr (buf, '='); 
    if (peq != NULL) {
	*peq = EOS;
	field[0] = buf;
	field[1] = peq + 1;

	if (find_alist (options, field[0]) == NULL)
	    add_alist (options, field[0], field[1]);

    } else if (buf[nc-1] == '+') {
	buf[nc-1] = EOS;
	if (find_alist (options, buf) == NULL)
	    add_alist (options, buf, "yes");

    } else if (buf[nc-1] == '-') {
	buf[nc-1] = EOS;
	if (find_alist (options, buf) == NULL)
	    add_alist (options, buf, "no");

    } else {
	cdbs_warn (BADOPT, "%s", buf);
    }

    free (buf);
}
