#include <stdio.h>
#include <ctype.h>
#include <string.h>
#include <stdlib.h>
#include "ostdb.h"
#include "cdbslib.h"
#include "config.h"
#include "reffile.h"
#include "loadfile.h"
#include "error.h"
#include "alist.h"
#include "query.h"

#define  SZ_TEXT	16000

static void	fill_query (context *, char *, alist *);
static int	send_query (context *, int, char *);

/* COMPFILE_QUERY -- Query database for comparison file
 *
 * i: qry	database server and name
 * i: dbvars	list of variables to substitute into the query
 * i: reffile	reference file for which comparison file is sought
 * o: compfile	comparison file name
 * o: useafter	useafter date
 */

void compfile_query (alist *dbvars, char *compfile, 
		     char *useafter, int maxch)
{
    static char *mode_compfile_qry = 
"select distinct a.file_name, a.useafter_date from $inst_file a, \
$inst_row b where a.reference_file_type = $reftype and \
a.file_name = b.file_name and a.expansion_number = \
b.expansion_number and a.reject_flag = 'N' and $obsmode and \
a.file_name in (select a.file_name from $inst_file a where \
a.useafter_date = (select max(a.useafter_date) from $inst_file \
a, $inst_row b where a.reference_file_type = $reftype and \
a.file_name = b.file_name and a.expansion_number = \
b.expansion_number and a.reject_flag = 'N' and a.useafter_date <= \
$useafter and $obsmode) )";

    static char *nomode_compfile_qry = 
"select distinct a.file_name, a.useafter_date from $inst_file a \
where a.reference_file_type = $reftype and a.reject_flag = 'N' and \
a.file_name in (select a.file_name from $inst_file a where \
a.useafter_date = (select max(a.useafter_date) from $inst_file \
a where a.reference_file_type = $reftype and \
a.reject_flag = 'N' and a.useafter_date <= $useafter) )";

    context 	*qry;
    char	fname[SZ_FNAME+1], date[SZ_STRING+1];

    /* Initialize query and bind output variables */

    qry = init_query ();
    ostdb_query_setup (qry->connection, "compname_query", 1, STDB_SQL, 
		       qry->server, qry->cdbs_db, NULL);

    stdb_bind_string (qry->connection, "file_name", fname, SZ_FNAME);
    stdb_bind_string (qry->connection, "useafter_date", date, SZ_STRING);

    /* Send query after filling in variables */

    if (find_alist (dbvars, "obsmode") != NULL) {
	fill_query (qry, mode_compfile_qry, dbvars);
    } else {
	fill_query (qry, nomode_compfile_qry, dbvars);
    }

    /* Execute query */

    compfile[0] = EOS;
    useafter[0] = EOS;
    while (ostdb_get_exec (qry->connection) == STDB_CONTINUE) {
	if (build_list (fname, compfile, maxch) == ERR)
	    break;

	if (build_list (date, useafter, maxch) == ERR)
	    break;
    }

    stdb_close_query (qry->connection);
    free_query (qry);
}

/* COMPTAB_QUERY -- Read component lookup table from database
 *
 * i: qry	database server and name
 * i: dbvars	list of variables to substitute into query
 * i: ncols	number of columns in component lookup table
 * i: dbcols	list of database column names
 * i: tabcols	corresponding list of table column names
 * u: comptab	component lookup table
 */

void comptab_query (context *qry, alist *dbvars, int ncols, char *dbcols, 
		    char *tabcols, table *comptab)
		    
{
    static char	*comptab_query1 =
"select distinct max(a.useafter_date) useafter_date, compname into #temp1 \
from synphot_file a, synphot_row b where a.useafter_date < $useafter and \
a.reference_file_type = 'THROUGHPUT' and a.file_name = b.file_name and \
a.reject_flag = 'N' group by b.compname";

    static char	*comptab_query2 =
"create unique nonclustered index tmp_i on #temp1(compname, useafter_date)";

    static char *comptab_query3 = 
"select a.general_availability_date availability_date, a.file_name file_name, \
a.useafter_date useafter_date, a.comment comment, b.compname compname \
from synphot_file a, synphot_row b, #temp1 t where a.reference_file_type = \
'THROUGHPUT' and a.file_name = b.file_name and a.reject_flag = 'N' and \
t.compname = b.compname and t.useafter_date = a.useafter_date order by \
b.compname";

    static char *comptab_query4 = "drop table #temp1";

    int		irow, icol, lentext;
    double	date, maxdate;
    char	*dblist, *tablist, *useafter, **dbfield, **tabfield, **dbvalue;

    /* Send query to create temporary table of useafter dates and compnames*/

    ostdb_query_setup (qry->connection, "comptab_query", 1, STDB_SQL, 
		       qry->server, qry->cdbs_db, NULL);

    fill_query (qry, comptab_query1, dbvars);

    ostdb_get_exec (qry->connection);

    stdb_close_query (qry->connection);

    /* Send second query to create index on temporary table */

    ostdb_query_setup (qry->connection, "comptab_query", 2, STDB_SQL, 
		       qry->server, qry->cdbs_db, NULL);

    fill_query (qry, comptab_query2, NULL);

    ostdb_get_exec (qry->connection);

    stdb_close_query (qry->connection);

    /* Send third query to retrieve throughput table info */

    ostdb_query_setup (qry->connection, "comptab_query", 3, STDB_SQL, 
		       qry->server, qry->cdbs_db, NULL);

    fill_query (qry, comptab_query3, NULL);

    /* Bind column names to output variables */

    dblist = strclone (dbcols);
    dbfield = (char **) malloc (ncols * sizeof (char *));

    tablist = strclone (tabcols);
    tabfield = (char **) malloc (ncols * sizeof (char *));

    dbvalue = (char **) malloc (ncols * sizeof (char *));

    strsplit (',', dblist, dbfield, ncols);
    strsplit (',', tablist, tabfield, ncols);

    for (icol = 0; icol < ncols; icol ++) {
	if (strcmp (dbfield[icol], "comment") == 0) {
	    dbvalue[icol] = (char *) malloc (SZ_TEXT+1);
	    stdb_bind_text (qry->connection, dbfield[icol], 
			      dbvalue[icol], &lentext);

	} else {
	    dbvalue[icol] = (char *) malloc (SZ_STRING+1);
	    stdb_bind_string (qry->connection, dbfield[icol], 
			      dbvalue[icol], SZ_STRING);
	}

    }

    /* Bind useafter date */

    useafter = (char *) malloc (SZ_STRING+1);
    stdb_bind_string (qry->connection, "useafter_date", useafter, SZ_STRING);

    /* Build table from results of third query */

    maxdate = -1.0;
    for (irow = 0; ostdb_get_exec (qry->connection) == STDB_CONTINUE; irow++) {
	for (icol = 0; icol < ncols; icol ++) {
	    strclean (dbvalue[icol]);
	    strlcase (dbvalue[icol]);
	    put_tab_cell (comptab, tabfield[icol], irow, dbvalue[icol]);
	}

	date = get_sybase_date (useafter);
	if (date > maxdate)
	    maxdate = date;
    }

    stdb_close_query (qry->connection);

    /* Add useafter date to table header */

    if (maxdate > 0.0) {
	put_sybase_date (maxdate, useafter, SZ_STRING);
	put_tab_key (comptab, "USEAFTER", useafter);
    }

    /* Send fourth query to free temporary table */

    ostdb_query_setup (qry->connection, "comptab_query", 4, STDB_SQL, 
		       qry->server, qry->cdbs_db, NULL);

    fill_query (qry, comptab_query4, NULL);

    ostdb_get_exec (qry->connection);

    stdb_close_query (qry->connection);

    /* Check to see if any rows were fetched from database */

    if (irow == 0)
	cdbs_error (NODBROWS, "%s", "synphot_file");

    /* Free allocated memory */

    for (icol = 0; icol < ncols; icol ++)
	free (dbvalue[icol]);

    free (useafter);
    free (dbvalue);
    free (dblist);
    free (dbfield);
    free (tablist);
    free (tabfield);

}

/* FILL_QUERY -- Fill variables in query and send to database
 *
 * i: qry	query context
 * i: dbquery	database query containing variables
 * i: dbvars	variable list
 */

void fill_query (context *qry, char *dbquery, alist *dbvars)
{
    char	*value;
    int		ic, jc, kc, lc, mc, state;
    char	line[SZ_QRYLINE+1], name[SZ_QRYLINE+1];

    jc = 0;
    kc = -1;
    state = 0;

    for (ic = 0; ! (dbquery[ic] == EOS && state == 0); ic ++) {
	switch (state) {
	case 0:		/* in query text */
	    /* Copy chars to query line while variable is not seen
	     * if line is full, send to database, reseting line
	     */

	    if (dbquery[ic] == '$') {
		state = 1;
		lc = 0;
	    } else if (jc >= SZ_QRYLINE) {
		line[jc] = EOS;
		jc = send_query (qry, kc, line);
		kc = -1;
		ic --;
	    } else {
		line[jc++] = dbquery[ic];
		if (dbquery[ic] <= ' ')
		    kc = jc - 1;
	    }
	    break;

	case 1:		/* in variable name */
	    /* All characters up to the first non-alphanumeric are
	     * part of the variable name.
	     */

	    if (! isalnum (dbquery[ic])) {
		name[lc] = EOS;
		state = 2;
		ic --;
	    } else {
		name[lc++] = dbquery[ic];
	    }
	    break;

	case 2:		/* in variable value */
	    /* Read variable from list and copy its value to the query line */

	    value = find_alist (dbvars, name);
	    if (value == NULL)
		cdbs_error (NOVAR, "%s", name);

	    for (mc = 0; value[mc] != EOS; mc ++) {
		if (jc >= SZ_QRYLINE) {
		    line[jc] = EOS;
		    jc = send_query (qry, kc, line);
		    kc = -1;
		    mc --;

		} else {
		    line[jc++] = value[mc];
		    if (value[mc] <= ' ')
			kc = jc - 1;
		}
	    }

	    ic --;
	    state = 0;
	    break;
	}
    }

    /* Send remainder of query to database */

    kc = jc;
    line[jc] = EOS;
    send_query (qry, kc, line);

}

/* FREE_QUERY -- Free the query context and database connection
 *
 * i: qry	query context
 */

void free_query (context *qry)
{
    free (qry);
}

/* INIT_QUERY -- Initialize the query context
 *
 */

context *init_query (void)
{
    context	*qry;
    char	*server, *cdbs_db, *dads_db, *user;

    qry = (context *) malloc (sizeof (context));

    qry->connection = STDB_CONN_1;

    server = getenv ("CDBS_SERVER");
    if (server == NULL) {
	safecopy (qry->server, CDBS_SERVER, SZ_STRING);
    } else {
	safecopy (qry->server, server, SZ_STRING);
    }

    cdbs_db = getenv ("CDBS_DB");
    if (cdbs_db == NULL) {
	safecopy (qry->cdbs_db, CDBS_DB, SZ_STRING);
    } else {
	safecopy (qry->cdbs_db, cdbs_db, SZ_STRING);
    }

    dads_db = getenv ("DADS_DB");
    if (dads_db == NULL) {
	safecopy (qry->dads_db, DADS_DB, SZ_STRING);
    } else {
	safecopy (qry->dads_db, dads_db, SZ_STRING);
    }

    user = getenv ("CDBS_USER");
    if (user == NULL || strcmp (user, CDBS_USER) == 0) {
	ostdb_setup (qry->connection, STDB_USERNAME, CDBS_USER);
	ostdb_setup (qry->connection, STDB_PASSWORD, CDBS_PASSWORD);
    } else {
	ostdb_setup (qry->connection, STDB_USERNAME, user);
    }

    return (qry);
}

/* OBSMODE_QUERY -- Retrieve observation mode from the database
 *
 * i: dbvars	variable values to substitute into query
 * o: obsmode	list of mode fields
 */

void obsmode_query (char *instrument, char *reftype, textbuf *obsmode)
{
    static char *obsmode_qry = 
"select a.modes from cdbs_mode a where (a.instrument = $inst or \
a.instrument = $uinst) and a.reference_file_type = $type";

    alist	*dbvars;
    context	*qry;
    char	*inst, *uinst;
    char	field[SZ_STRING+1];

    /* Initialize query and bind mode field variable */

    qry = init_query ();
    ostdb_query_setup (qry->connection, "obsmode_query", 1, STDB_SQL, 
		       qry->server, qry->cdbs_db, NULL);

    stdb_bind_string (qry->connection, "modes", field, SZ_STRING);

    /* Build query and send to database */

    /* Checking for the instrument in both upper and lower case
     * is a temporary kludge that will be removed when the instrument
     * field in cdbs_mode is fixedand put in all upper case
     */

    inst = enquote (instrument);
    uinst = strclone (inst);
    strlcase (uinst);

    dbvars = create_alist ();
    add_alist (dbvars, "inst", inst);
    add_alist (dbvars, "uinst", uinst);
    add_alist (dbvars, "type", enquote (reftype));

    fill_query (qry, obsmode_qry, dbvars);
    free (uinst);

    /* Retrieve list of mode fields from database and store in text buffer */

    init_text (obsmode, 20, 200);
    while (ostdb_get_exec (qry->connection) == STDB_CONTINUE) {
        strclean (field);
        strucase (field);
	add_text (obsmode, field);
    }

    /* Close database connection and free memory */

    stdb_close_query (qry->connection);
    free_alist (dbvars);

    free_query (qry);
}

/* SEND_QUERY -- Send a query to the database
 *
 * i: qry	database server and name
 * i: kc	number of chars in query to be sent
 * u: line	line containing query
 */

int send_query (context *qry, int kc, char *line)
{
    int		ic;

    /* Check to see if the line can be split at a blank */

    if (kc < 0) {
	line[20] = EOS;
	cdbs_error (QRYLEN, "%s ...", line);
    }

    /* Terminate line at last blank */

    if (line[kc] != EOS)
	line[kc++] = EOS;

    /* Diagnostic print of line */

    Q(fprintf (stderr, "QUERY: %s\n", line);)

    /* Send query to database */

    stdb_query (qry->connection, line);

    /* Copy remainder of query to front of line 
     * Return number of chars in query
     */

    ic = 0;
    while (line[kc] != EOS)
	line[ic++] = line[kc++];

    line[ic] = EOS;
    return (ic);
}
