#include <string.h>
#include <stdlib.h>
#include "cdbslib.h"
#include "loadfile.h"

static int	common_length (char *, char *, char *, char *);

/* SIMILAR -- Compute the number of common characters between two strings
 *
 * i: str1	first string
 * i: str2	second string
 */

int similar (char *str1, char *str2)
{
    int		len1, len2, score;
    char	*word1, *word2;

    /* Trivial case if one string has zero length */

    len1 = strlen (str1);
    len2 = strlen (str2);
    if (len1 == 0 || len2 == 0)
	return (0);

    /* Compare lower case versions of the string */

    word1 = strclone (str1);
    word2 = strclone (str2);

    strlcase (word1);
    strlcase (word2);

    /* This recursive routine does all the computation */

    score = common_length (word1, &word1[len1-1], word2, &word2[len2-1]);

    free (word1);
    free (word2);

    return (score);
}

static int common_length (char *start1, char *end1, char *start2, char *end2)
{
    int		maxch, nc;
    char	*s1, *s2, *ch1, *ch2; 
    char	*newstart1, *newstart2, *newend1, *newend2;

    /* Find the longest match between the substrings */

    maxch = 0;
    for (s1 = start1; s1 <= end1 - maxch; s1 ++) {
	for (s2 = start2; s2 <= end2 - maxch; s2 ++) {
	    if (*s1 == *s2) {
		/* Compute the length of the match 
		 * starting at these two chars 
		 */

		ch1 = s1;
		ch2 = s2;

		while (*ch1 == *ch2) {
		    if (ch1 ++ == end1 || ch2 ++ == end2)
			break;
		}

		/* If this is the longest match so far, 
		 * save the length and start and end chars
		 */

		nc = ch1 - s1;
		if (nc > maxch) {
		    maxch = nc;
		    newstart1 = s1;
		    newstart2 = s2;
		    newend1 = s1 + nc - 1;
		    newend2 = s2 + nc - 1;
		}

		/* Skip over the matched chars */

		s2 = s2 + nc - 1;
	    }
	}
    }

    /* Compute the longest match in the substrings preceding and following
     * the matched string and add them to the total number of characters
     * matched.
     */

    if (maxch > 0) {
	if (start1 != newstart1 && start2 != newstart2)
	    maxch += common_length (start1, newstart1-1, start2, newstart2-1);

	if (end1 != newend1 && end2 != newend2)
	    maxch += common_length (newend1+1, end1, newend2+1, end2);
    }

    return (maxch);
}
