#include <stdlib.h>
#include "config.h"
#include "cdbslib.h"
#include "loadfile.h"
#include "error.h"

/* STRABBREV -- Find index of string in dictionary which matches abbreviation
 *
 * i: input	abbreviated string
 * i: dict	dictionary
 */

int strabbrev (const char *input, const char *dict)
{
    char	*str;
    int		ic, jc, state, match, index;

    /* Make lower case copy of input for case independent match */

    str = strclone (input);
    strlcase (str);

    jc = 0;
    state = 0;
    match = 0;		/* string in dictionary which matches input */
    index = 1;		/* current string in dictionary */

    /* Two states:
     * 0 = matching input to dictionary
     * 1 = skipping dictionary chars until next string
     */

    for (ic = 0; dict[ic] != EOS; ic ++) {
	/* Save index of dictionary string which matches input
	 * Multiple matches are not allowed
	 */

	if (str[jc] == EOS) {
	    if (match != 0) {
	        /* Ambiguous match */
	        free (str);
		return (0);
	    }

	    jc = 0;
	    state = 1;
	    match = index;
	}

	if (dict[ic] == '|') {
	    /* Check for end of dictionary entry */

	    jc = 0;
	    index ++;
	    state = 0;

	} else if (state == 0) {
	    /* Match input against dictionary 
	     * If no match, skip to next entry
	     */

	    if (dict[ic] == str[jc]) {
		jc ++;
	    } else {
		jc = 0;
		state = 1;
	    }
	}
    }

    /* Check for match with last word in dictionary list */

    if (str[jc] == EOS) {
	if (match != 0) {
	    /* Ambiguous match */
	    free (str);
	    return (0);
	}

	match = index;
    }

    free (str);
    return (match);
}
