#include "config.h"

/* STRSPLIT -- Split a string into fields
 *
 * i: sep	character separating fields in the string
 * u: str	string containing fields
 * o: field	array of pointers to fields in string
 * i: nfield	number of fields in string
 */

void strsplit (const int sep, char *str, char **field, const int nfield)
{
    char	*pch;
    int		state, stop, ifield;

    state = 0;
    ifield = 0;

    for (pch = str; *pch != EOS; pch ++) {
	/* Convert whitespace to all blanks for easier parsing */

	if (*pch < ' ')
	    *pch = ' ';

	/* Two states: 
	 * 0 = searching for start of field
	 * 1 = searching for end of field
	 */

	if (state == 0) {
	    if (*pch != sep) {
		state = 1;

		/* If first char is a quote, string continues until next quote
		 * else string continues until separator
		 *
		 * If first char is a quote, field begins after quote
		 */

		if (*pch == '"' || *pch == '\'') {
		    stop = *pch;
		    field[ifield ++] = pch + 1;

		} else {
		    stop = sep;
		    field[ifield ++] = pch;
		}
	    }

	} else {
	    /* Write EOS to terminate the field */

	    if (*pch == stop) {
		state = 0;
		*pch = EOS;

		if (ifield >= nfield)
		    break;
	    }
	}
    }

    /* Set remaining fields to trailing EOS char */

    for ( ; ifield < nfield; ifield ++)
	field[ifield] = pch;
}
