#include <stdio.h>
#include "error.h"
#include "config.h"
#include "cdbslib.h"
#include "loadfile.h"
#include "reffile.h"
#include "certify.h"
#include "template.h"

/* CERTIFY -- Check the information in a reference file
 *
 * i: look	lookup file descriptor
 * i: file	reference file name
 * u: oldtpl	cached template descriptor
 */

void certify (table *look, char *file, tpl_file *oldtpl)
{
    tpl_file	*tpl;
    reffile	*ref;
    tpl_record	*rule;
    int		row, irow, nrow;
    char	*tplfile, *type;
    char	tplname[SZ_FNAME+1], message[SZ_LINE+1];

    /* Print message identifying the file */

    sprintf (message, "== Checking %s ==\n", file);
    cdbs_message (INFO_MSG, message);

    /* Find what template file goes with this filename */
    if ((row = find_lookup (look, file)) == ERR) {
	cdbs_warn (NOLOOK, "%s", file);
	return;
    }

    tplfile = get_tab_cell (look, "tplfile", row);
    type = get_tab_cell (look, "filetype", row);

    /* Add the tpl catalog's directory to the template file name */
    pathname (tplname, name_lookup (look), tplfile, SZ_FNAME);
	
    /* Open calibration and template files. 
     * Template file is cached in oldtpl,
     * so same file is not opened repeatedly
     */

    tpl = open_template (tplname, oldtpl);
    oldtpl = tpl;

    ref = open_reffile (file, type, "r");
    if (ref == NULL) {
	cdbs_warn (NOTOPEN, "%s", file);
	return;
    }

    /* Check header keywords. Optimize body keywords for faster checking */

    rule = NULL;
    while ((rule = next_template (tpl, rule)) != NULL) {
	if (body_rule (rule)) {
	    study_rule (rule);
	} else {
	    check_rule (rule, ref, 0);
	}
    }

    /* Check body keywords. Take exit if no keywords left to check */

    irow = 0;
    nrow = 0;
    while (skip_template (tpl) == NO) {
        /* Nrow is only evaluated conditionally and once
         * because it is an expensive operation for fits images
	 */

        if (nrow == 0)
	    nrow = nrow_reffile (ref);

	if (irow >= nrow)
	    break;

	rule = NULL;
	while ((rule = next_template (tpl, rule)) != NULL)
	    check_rule (rule, ref, irow);

	irow ++;
    }

    close_reffile (ref);
}
