#include <stdlib.h>
#include <string.h>
#include <stdio.h>
#include "config.h"
#include "error.h"
#include "cdbslib.h"
#include "template.h"

/* CLOSE_TEMPLATE -- Release memory allocated to hold template info
 *
 * i: tpl	template descriptor
 */

void close_template (tpl_file *tpl)
{
    tpl_record	*rec, *nxt;

    if (tpl == NULL)
	return;

    for (rec = tpl->header; rec != NULL; rec = nxt) {
	free_rule (rec->rule);
	nxt = rec->next;
	free (rec);
    }

    free (tpl);
}

/* NEXT_TEMPLATE -- Retrieve next rule from the template file
 *
 * i: tpl	template file descriptor
 * i: rule	pointer to current rule
 */

tpl_record * next_template (tpl_file *tpl, tpl_record *temp)
{
    tpl_record	*rec;

    if (temp == NULL) {
	rec = tpl->header;
    } else {
	rec = temp->next; 
    }

    while (rec != NULL && rec->skip == YES)
	rec = rec->next;

    return (rec);
}

/* OPEN_TEMPLATE -- Read the template file into a structure
 *
 * i: file	template file name
 */

tpl_file * open_template (const char * file, tpl_file *oldtpl)
{
    char	buf[SZ_RULE+1];
    tpl_file	*tpl;
    tpl_record	*old, *rec;
    FILE	*fd;

    /* Check to see if filename matches oldtpl */

    if (oldtpl != NULL && strcmp ( file, oldtpl->name) == 0) {
	for (rec = oldtpl->header; rec != NULL; rec = rec->next)
	    rec->skip = NO;

	return (oldtpl);

    } else {
	close_template (oldtpl);
    }

    /* Open the template file */

    fd = fopen (file, "r");
    if (fd == NULL)
	cdbs_error (NOTOPEN, "%s", file);

    /* Allocate and initialize template structure */

    tpl = (tpl_file *) malloc (sizeof (tpl_file));

    old = NULL;
    tpl->header = NULL;
    safecopy (tpl->name, file, SZ_FNAME);

    /* Read each rule from the file */

    while (rdlines (fd, buf, SZ_RULE) == OK) {

	/* Parse the rule and add it to the template descriptor */

	rec = (tpl_record *) malloc (sizeof (tpl_record));
	rec->rule = parse_rule (buf);
	rec->skip = NO;

	/* Fix the linked list pointers for the record */

	if (old == NULL) {
	    tpl->header = rec;
	} else {
	    old->next = rec;
	}

	rec->next = NULL;
	old = rec;
    }

    fclose (fd);
    return (tpl);
}
 
/* SKIP_TEMPLATE -- Return YES if all records are marked as skip
 *
 * i: tpl	template descriptor
 */

int skip_template (tpl_file *tpl)
{
    tpl_record	*rec;

    for (rec = tpl->header; rec != NULL; rec = rec->next) {
	if (rec->skip == NO)
	    return (NO);
    }

    return (YES);
}
