#! /bin/sh
isql -S$CDBS_SERVER << EOF 
use $CDBS_DB
go

/* Check that no two file-level records with the same */
/* mode, type, opus_flag and useafter_date are unrejected */

if exists (select * from hrs_row r1, hrs_row r2, 
           hrs_file f1, hrs_file f2
     where
      r1.detector = r2.detector and 
      r1.grating = r2.grating and 
      r1.aperture= r2.aperture and
      r1.sporder = r2.sporder and
      r1.targetid = r2.targetid and
      f1.file_name = r1.file_name and
      f1.expansion_number = r1.expansion_number and
      f2.file_name = r2.file_name and
      f2.expansion_number = r2.expansion_number and
      f1.useafter_date = f2.useafter_date and 
      f1.reject_flag = "N" and
      f2.reject_flag = "N" and
      f1.opus_flag = f2.opus_flag and
      f1.reference_file_type = f2.reference_file_type and
      $1 = f1.delivery_number and
      $1 > f2.delivery_number)
begin
 print "-> CDBS ERROR:"
 print "->  2 unrejected hrs files with the same type, mode, opus_flag, and useafter date"
 select distinct "->", f1.file_name, f2.file_name from hrs_row r1, hrs_row r2, 
           hrs_file f1, hrs_file f2
     where
      r1.detector = r2.detector and 
      r1.detector = r2.detector and 
      r1.grating = r2.grating and 
      r1.aperture= r2.aperture and
      r1.sporder = r2.sporder and
      r1.targetid = r2.targetid and
      f1.file_name = r1.file_name and
      f1.expansion_number = r1.expansion_number and
      f2.file_name = r2.file_name and
      f2.expansion_number = r2.expansion_number and
      f1.useafter_date = f2.useafter_date and 
      f1.reject_flag = "N" and
      f2.reject_flag = "N" and
      f1.opus_flag = f2.opus_flag and
      f1.reference_file_type = f2.reference_file_type and
      $1 = f1.delivery_number and
      $1 > f2.delivery_number
end
go

if exists (select * from stis_row r1, stis_row r2, 
           stis_file f1, stis_file f2
     where
      r1.detector = r2.detector and 
      r1.ccdamp = r2.ccdamp and 
      r1.ccdgain = r2.ccdgain and
      r1.ccdoffst = r2.ccdoffst and
      r1.binaxis1 = r2.binaxis1 and
      r1.binaxis2 = r2.binaxis2 and
      r1.crsplit = r2.crsplit and
      r1.opt_elem  = r2.opt_elem  and
      r1.obstype = r2.obstype and
      r1.aperture= r2.aperture and
      r1.cenwave = r2.cenwave and
      r1.sclamp = r2.sclamp and
      r1.lampset = r2.lampset and
      f1.file_name = r1.file_name and
      f1.expansion_number = r1.expansion_number and
      f2.file_name = r2.file_name and
      f2.expansion_number = r2.expansion_number and
      f1.useafter_date = f2.useafter_date and 
      f1.reject_flag = "N" and
      f2.reject_flag = "N" and
      f1.opus_flag = f2.opus_flag and
      f1.reference_file_type = f2.reference_file_type and
      $1 = f1.delivery_number and
      $1 > f2.delivery_number)
begin
 print "-> CDBS ERROR:"
 print "->  2 unrejected stis files with the same type, mode, opus_flag, and useafter date"
 select distinct "->", f1.file_name, f2.file_name from stis_row r1, stis_row r2, 
           stis_file f1, stis_file f2
     where
      r1.detector = r2.detector and 
      r1.ccdamp = r2.ccdamp and 
      r1.ccdgain = r2.ccdgain and
      r1.ccdoffst = r2.ccdoffst and
      r1.binaxis1 = r2.binaxis1 and
      r1.binaxis2 = r2.binaxis2 and
      r1.crsplit = r2.crsplit and
      r1.opt_elem  = r2.opt_elem  and
      r1.obstype = r2.obstype and
      r1.aperture= r2.aperture and
      r1.cenwave = r2.cenwave and
      r1.sclamp = r2.sclamp and
      r1.lampset = r2.lampset and
      f1.file_name = r1.file_name and
      f1.expansion_number = r1.expansion_number and
      f2.file_name = r2.file_name and
      f2.expansion_number = r2.expansion_number and
      f1.useafter_date = f2.useafter_date and 
      f1.reject_flag = "N" and
      f2.reject_flag = "N" and
      f1.opus_flag = f2.opus_flag and
      f1.reference_file_type = f2.reference_file_type and
      $1 = f1.delivery_number and
      $1 > f2.delivery_number
end
go

if exists (select * from foc_row r1, foc_row r2, 
           foc_file f1, foc_file f2
     where
      r1.optcrly = r2.optcrly and 
      r1.pxformt = r2.pxformt and 
      r1.optelt1 = r2.optelt1 and
      r1.optelt2 = r2.optelt2 and
      r1.sampoff = r2.sampoff and
      r1.samppln = r2.samppln and
      r1.lineoff = r2.lineoff and
      r1.linepfm  = r2.linepfm and
      r1.cammode = r2.cammode and
      r1.smmmode = r2.smmmode and
      r1.wavelength = r2.wavelength and
      f1.file_name = r1.file_name and
      f1.expansion_number = r1.expansion_number and
      f2.file_name = r2.file_name and
      f2.expansion_number = r2.expansion_number and
      f1.useafter_date = f2.useafter_date and 
      f1.reject_flag = "N" and
      f2.reject_flag = "N" and
      f1.opus_flag = f2.opus_flag and
      f1.reference_file_type = f2.reference_file_type and
      $1 = f1.delivery_number and
      $1 > f2.delivery_number)
begin
 print "-> CDBS ERROR:"
 print "->  2 unrejected foc files with the same type, mode, opus_flag, and useafter date"
 select distinct "->", f1.file_name, f2.file_name from foc_row r1, foc_row r2, 
           foc_file f1, foc_file f2
     where
      r1.optcrly = r2.optcrly and 
      r1.pxformt = r2.pxformt and 
      r1.optelt1 = r2.optelt1 and
      r1.optelt2 = r2.optelt2 and
      r1.sampoff = r2.sampoff and
      r1.samppln = r2.samppln and
      r1.lineoff = r2.lineoff and
      r1.linepfm  = r2.linepfm and
      r1.cammode = r2.cammode and
      r1.smmmode = r2.smmmode and
      r1.wavelength = r2.wavelength and
      f1.file_name = r1.file_name and
      f1.expansion_number = r1.expansion_number and
      f2.file_name = r2.file_name and
      f2.expansion_number = r2.expansion_number and
      f1.useafter_date = f2.useafter_date and 
      f1.reject_flag = "N" and
      f2.reject_flag = "N" and
      f1.opus_flag = f2.opus_flag and
      f1.reference_file_type = f2.reference_file_type and
      $1 = f1.delivery_number and
      $1 > f2.delivery_number
end
go

if exists (select * from hsp_row r1, hsp_row r2, 
           hsp_file f1, hsp_file f2
     where
      r1.aper_name = r2.aper_name and 
      r1.det_num = r2.det_num and 
      r1.type = r2.type and
      r1.voltage = r2.voltage and
      r1.vgaind = r2.vgaind and
      r1.thresh = r2.thresh and
      f1.file_name = r1.file_name and
      f1.expansion_number = r1.expansion_number and
      f2.file_name = r2.file_name and
      f2.expansion_number = r2.expansion_number and
      f1.useafter_date = f2.useafter_date and 
      f1.reject_flag = "N" and
      f2.reject_flag = "N" and
      f1.opus_flag = f2.opus_flag and
      f1.reference_file_type = f2.reference_file_type and
      $1 = f1.delivery_number and
      $1 > f2.delivery_number)
begin
 print "-> CDBS ERROR:"
 print "->  2 unrejected hsp files with the same type, mode, opus_flag, and useafter date"
 select distinct "->", f1.file_name, f2.file_name from hsp_row r1, hsp_row r2, 
           hsp_file f1, hsp_file f2
     where
      r1.aper_name = r2.aper_name and 
      r1.det_num = r2.det_num and 
      r1.type = r2.type and
      r1.voltage = r2.voltage and
      r1.vgaind = r2.vgaind and
      r1.thresh = r2.thresh and
      f1.file_name = r1.file_name and
      f1.expansion_number = r1.expansion_number and
      f2.file_name = r2.file_name and
      f2.expansion_number = r2.expansion_number and
      f1.useafter_date = f2.useafter_date and 
      f1.reject_flag = "N" and
      f2.reject_flag = "N" and
      f1.opus_flag = f2.opus_flag and
      f1.reference_file_type = f2.reference_file_type and
      $1 = f1.delivery_number and
      $1 > f2.delivery_number
end
go

if exists (select * from fos_row r1, fos_row r2, 
           fos_file f1, fos_file f2
     where
      r1.detector = r2.detector and 
      r1.overscan = r2.overscan and 
      r1.aper_id = r2.aper_id and
      r1.aper_pos = r2.aper_pos and
      r1.polar_id = r2.polar_id and
      r1.fgwa_id = r2.fgwa_id and
      r1.pass_dir = r2.pass_dir and
      r1.fchnl  = r2.fchnl  and
      r1.nxsteps = r2.nxsteps and
      r1.wavelength = r2.wavelength and
      f1.file_name = r1.file_name and
      f1.expansion_number = r1.expansion_number and
      f2.file_name = r2.file_name and
      f2.expansion_number = r2.expansion_number and
      f1.useafter_date = f2.useafter_date and 
      f1.reject_flag = "N" and
      f2.reject_flag = "N" and
      f1.opus_flag = f2.opus_flag and
      f1.reference_file_type = f2.reference_file_type and
      $1 = f1.delivery_number and
      $1 > f2.delivery_number)
begin
 print "-> CDBS ERROR:"
 print "->  2 unrejected fos files with the same type, mode, opus_flag, and useafter date"
 select distinct "->", f1.file_name, f2.file_name from fos_row r1, fos_row r2, 
           fos_file f1, fos_file f2
     where
      r1.detector = r2.detector and 
      r1.overscan = r2.overscan and 
      r1.aper_id = r2.aper_id and
      r1.aper_pos = r2.aper_pos and
      r1.polar_id = r2.polar_id and
      r1.fgwa_id = r2.fgwa_id and
      r1.pass_dir = r2.pass_dir and
      r1.fchnl  = r2.fchnl  and
      r1.nxsteps = r2.nxsteps and
      r1.wavelength = r2.wavelength and
      f1.file_name = r1.file_name and
      f1.expansion_number = r1.expansion_number and
      f2.file_name = r2.file_name and
      f2.expansion_number = r2.expansion_number and
      f1.useafter_date = f2.useafter_date and 
      f1.reject_flag = "N" and
      f2.reject_flag = "N" and
      f1.opus_flag = f2.opus_flag and
      f1.reference_file_type = f2.reference_file_type and
      $1 = f1.delivery_number and
      $1 > f2.delivery_number
end
go

if exists (select * from wfpc2_row r1, wfpc2_row r2, 
           wfpc2_file f1, wfpc2_file f2
     where
      r1.atodgain = r2.atodgain and 
      r1.mode = r2.mode and 
      r1.serials = r2.serials and
      r1.shutter = r2.shutter and
      r1.filter1 = r2.filter1 and
      r1.filter2 = r2.filter2 and
      f1.file_name = r1.file_name and
      f1.expansion_number = r1.expansion_number and
      f2.file_name = r2.file_name and
      f2.expansion_number = r2.expansion_number and
      f1.useafter_date = f2.useafter_date and 
      f1.reject_flag = "N" and
      f2.reject_flag = "N" and
      f1.opus_flag = f2.opus_flag and
      f1.reference_file_type = f2.reference_file_type and
      $1 = f1.delivery_number and
      $1 > f2.delivery_number)
begin
 print "-> CDBS ERROR:"
 print "->  2 unrejected wfpc2 files with the same type, mode, opus_flag, and useafter date"
 select distinct "->", f1.file_name, f2.file_name from wfpc2_row r1, wfpc2_row r2, 
           wfpc2_file f1, wfpc2_file f2
     where
      r1.atodgain = r2.atodgain and 
      r1.mode = r2.mode and 
      r1.serials = r2.serials and
      r1.shutter = r2.shutter and
      r1.filter1 = r2.filter1 and
      r1.filter2 = r2.filter2 and
      f1.file_name = r1.file_name and
      f1.expansion_number = r1.expansion_number and
      f2.file_name = r2.file_name and
      f2.expansion_number = r2.expansion_number and
      f1.useafter_date = f2.useafter_date and 
      f1.reject_flag = "N" and
      f2.reject_flag = "N" and
      f1.opus_flag = f2.opus_flag and
      f1.reference_file_type = f2.reference_file_type and
      $1 = f1.delivery_number and
      $1 > f2.delivery_number
end
go

if exists (select * from wfpc_row r1, wfpc_row r2, 
           wfpc_file f1, wfpc_file f2
     where
      r1.camera = r2.camera and 
      r1.mode = r2.mode and 
      r1.clock = r2.clock and
      r1.filter1 = r2.filter1 and
      r1.filter2 = r2.filter2 and
      r1.filtnam1 = r2.filtnam1 and
      r1.filtnam2 = r2.filtnam2 and
      r1.shutter = r2.shutter and
      r1.photmode = r2.photmode and
      f1.file_name = r1.file_name and
      f1.expansion_number = r1.expansion_number and
      f2.file_name = r2.file_name and
      f2.expansion_number = r2.expansion_number and
      f1.useafter_date = f2.useafter_date and 
      f1.reject_flag = "N" and
      f2.reject_flag = "N" and
      f1.opus_flag = f2.opus_flag and
      f1.reference_file_type = f2.reference_file_type and
      $1 = f1.delivery_number and
      $1 > f2.delivery_number)
begin
 print "-> CDBS ERROR:"
 print "->  2 unrejected wfpc files with the same type, mode, opus_flag, and useafter date"
 select distinct "->", f1.file_name, f2.file_name from wfpc_row r1, wfpc_row r2, 
           wfpc_file f1, wfpc_file f2
     where
      r1.camera = r2.camera and 
      r1.mode = r2.mode and 
      r1.clock = r2.clock and
      r1.filter1 = r2.filter1 and
      r1.filter2 = r2.filter2 and
      r1.filtnam1 = r2.filtnam1 and
      r1.filtnam2 = r2.filtnam2 and
      r1.shutter = r2.shutter and
      r1.photmode = r2.photmode and
      f1.file_name = r1.file_name and
      f1.expansion_number = r1.expansion_number and
      f2.file_name = r2.file_name and
      f2.expansion_number = r2.expansion_number and
      f1.useafter_date = f2.useafter_date and 
      f1.reject_flag = "N" and
      f2.reject_flag = "N" and
      f1.opus_flag = f2.opus_flag and
      f1.reference_file_type = f2.reference_file_type and
      $1 = f1.delivery_number and
      $1 > f2.delivery_number
end
go

if exists (select * from nic_row r1, nic_row r2, 
           nic_file f1, nic_file f2
     where
      r1.camera = r2.camera and 
      r1.filter = r2.filter and 
      r1.readout = r2.readout and
      r1.nread = r2.nread and
      r1.samp_seq = r2.samp_seq and
      f1.file_name = r1.file_name and
      f1.expansion_number = r1.expansion_number and
      f2.file_name = r2.file_name and
      f2.expansion_number = r2.expansion_number and
      f1.useafter_date = f2.useafter_date and 
      f1.reject_flag = "N" and
      f2.reject_flag = "N" and
      f1.opus_flag = f2.opus_flag and
      f1.reference_file_type = f2.reference_file_type and
      $1 = f1.delivery_number and
      $1 > f2.delivery_number)
begin
 print "-> CDBS ERROR:"
 print "->  2 unrejected nic files with the same type, mode, opus_flag, and useafter date"
 select distinct "->", f1.file_name, f2.file_name from nic_row r1, nic_row r2, 
           nic_file f1, nic_file f2
     where
      r1.camera = r2.camera and 
      r1.filter = r2.filter and 
      r1.readout = r2.readout and
      r1.nread = r2.nread and
      r1.samp_seq = r2.samp_seq and
      f1.file_name = r1.file_name and
      f1.expansion_number = r1.expansion_number and
      f2.file_name = r2.file_name and
      f2.expansion_number = r2.expansion_number and
      f1.useafter_date = f2.useafter_date and 
      f1.reject_flag = "N" and
      f2.reject_flag = "N" and
      f1.opus_flag = f2.opus_flag and
      f1.reference_file_type = f2.reference_file_type and
      $1 = f1.delivery_number and
      $1 > f2.delivery_number
end
go

if exists (select * from synphot_row r1, synphot_row r2, 
           synphot_file f1, synphot_file f2
     where
      r1.compname = r2.compname and 
      f1.file_name = r1.file_name and
      f1.expansion_number = r1.expansion_number and
      f2.file_name = r2.file_name and
      f2.expansion_number = r2.expansion_number and
      f1.useafter_date = f2.useafter_date and 
      f1.reject_flag = "N" and
      f2.reject_flag = "N" and
      f1.opus_flag = f2.opus_flag and
      f1.reference_file_type = f2.reference_file_type and
      $1 = f1.delivery_number and
      $1 > f2.delivery_number)
begin
 print "-> CDBS ERROR:"
 print "->  2 unrejected synphot files with the same type, mode, opus_flag, and useafter date"
 select distinct "->", f1.file_name, f2.file_name from synphot_row r1, synphot_row r2, 
           synphot_file f1, synphot_file f2
     where
      r1.compname = r2.compname and 
      f1.file_name = r1.file_name and
      f1.expansion_number = r1.expansion_number and
      f2.file_name = r2.file_name and
      f2.expansion_number = r2.expansion_number and
      f1.useafter_date = f2.useafter_date and 
      f1.reject_flag = "N" and
      f2.reject_flag = "N" and
      f1.opus_flag = f2.opus_flag and
      f1.reference_file_type = f2.reference_file_type and
      $1 = f1.delivery_number and
      $1 > f2.delivery_number
end
go

if exists (select * from multi_row r1, multi_row r2, 
           multi_file f1, multi_file f2
     where
      r1.targetid = r2.targetid and 
      r1.fld_name = r2.fld_name and 
      r1.obsmode = r2.obsmode and 
      f1.file_name = r1.file_name and
      f1.expansion_number = r1.expansion_number and
      f2.file_name = r2.file_name and
      f2.expansion_number = r2.expansion_number and
      f1.useafter_date = f2.useafter_date and 
      f1.reject_flag = "N" and
      f2.reject_flag = "N" and
      f1.opus_flag = f2.opus_flag and
      f1.reference_file_type = f2.reference_file_type and
      $1 = f1.delivery_number and
      $1 > f2.delivery_number)
begin
 print "-> CDBS ERROR:"
 print "->  2 unrejected multi files with the same type, mode, opus_flag, and useafter date"
 select distinct "->", f1.file_name, f2.file_name from multi_row r1, multi_row r2, 
           multi_file f1, multi_file f2
     where
      r1.targetid = r2.targetid and 
      r1.fld_name = r2.fld_name and 
      r1.obsmode = r2.obsmode and 
      f1.file_name = r1.file_name and
      f1.expansion_number = r1.expansion_number and
      f2.file_name = r2.file_name and
      f2.expansion_number = r2.expansion_number and
      f1.useafter_date = f2.useafter_date and 
      f1.reject_flag = "N" and
      f2.reject_flag = "N" and
      f1.opus_flag = f2.opus_flag and
      f1.reference_file_type = f2.reference_file_type and
      $1 = f1.delivery_number and
      $1 > f2.delivery_number
end
go



