#include <string.h>
#include "config.h"
#include "cdbslib.h"
#include "loadfile.h"
#include "expload.h"

/* FIND_RULE -- Find the rule in the target table that matches the top work row
 *
 * u: target	target table descriptor
 * u: work 	work table descriptor
 */

int find_rule (table * target, table *work)
{
    int		wrow, trow, urow, wcol, tcol, match;
    char	*tval, *wval, *uval, *colname;

    /* If there are no rows in the work table, there is nothing to expand */

    wrow = nrow_table(work) - 1;
    if (wrow < 0)
        return (ERR);

    /* If a work row is currently being expand by a rule, 
     * return the row number of the rule
     */

    wval = get_tab_cell (work, "_TARGET", wrow);
    if (wval[0] != EOS)
        return (atoi (wval));

    /* Read use value, used to prevent recursive expansion of rows */

    uval = get_tab_cell (work, "_USED", wrow);
    if (uval[0] == EOS) {
        urow = -1;
    } else {
        urow = atoi (uval);
    }

    /* Search for the target for a rule to match the top work row */

    match = NO;

    for (trow = 0; trow < nrow_table(target); trow ++) {
        /* Skip row in target if it has previously been used 
	 * to expand row in the work table
	 */

        if (trow == urow)
	    continue;

        /* Compare each non-blank target column to work table
	 * Exit when match not found
	 */

        match = NO;

	for (tcol = 0; tcol < ncol_table(target); tcol ++) {
	    tval = get_tab_cell_bynum (target, tcol, trow);

	    if (tval[0] != EOS) {
	        colname = get_tab_colname (target, tcol);

		if ((wcol = get_tab_colnum (work, colname)) != BAD) {
		    wval = get_tab_cell_bynum (work, wcol, wrow);

		    if (strcmp (tval, wval) == 0) {
		        match = YES;
		    } else {
		        match = NO;
			break;
		    }
		}
	    }
	}

	/* If match found, set control columns in work and target tables */

	if (match == YES) {
	    tval = get_tab_cell (target, "_FIRST", trow);
	    put_tab_cell (work, "_INDEX", wrow, tval);
	    put_tab_cell (work, "_TARGET", wrow, itoa (trow));
	    break;
	}
    }

    /* Return row number of matched row or ERR if no row matched */

    if (match == NO) {
        return (ERR);
    } else {
        return (trow);
    }
}
