#include <string.h>
#include "getobsmode.h"

/* GETFOCMODE -- Get the observation mode for an foc observation
 *
 *  This code is based on calfoc/calphot.x and should track changes
 * in that code.
 *
 * i: root	observation rootname
 * o: obsmode	observation mode
 */

void getfocmode (char *root, char *obsmode)
{
    int		relay, samppln, linepfm, sampoff, lineoff;
    char	field[SZ_FIELD+1], optcrly[SZ_FIELD+1];
    char	smmmode[SZ_FIELD+1], cammode[SZ_FIELD+1];
    char	kxdeploy[SZ_FIELD+1], filtnam1[SZ_FIELD+1];
    char	filtnam2[SZ_FIELD+1], filtnam3[SZ_FIELD+1];
    char	filtnam4[SZ_FIELD+1], pxformt[SZ_FIELD+1];

    if (qryfocmode (root, optcrly, smmmode, cammode, kxdeploy, 
		    filtnam1, filtnam2, filtnam3, filtnam4, pxformt, 
		    &samppln, &linepfm, &sampoff, &lineoff) == NOMATCH) {
	obsmode[0] = '\0';

    } else {
	/* Copy instrument mode to obsmode string */

	strcpy (obsmode, "FOC");

	/* Add the relay */

	if (strcmp (optcrly, "F48") == 0) {
	    relay = 48;
	    strcat (obsmode, ",F/48");

	    if (strcmp (smmmode, "INBEAM") == 0)
		strcat (obsmode, ",SPEC");

	} else if (strcmp (optcrly, "F96") == 0) {
	    if (strcmp (smmmode, "INBEAM") == 0) {
		relay = 288;
		strcat (obsmode, ",F/288");
	    } else {
		relay = 96;
		strcat (obsmode, ",F/96");
	    }
	}

	/* Add the costar string */

	if (kxdeploy[0] == 'T')
	    strcat (obsmode, ",COSTAR");
	else 
	    strcat (obsmode, ",NOCOSTAR");

	/* Add the filters */

	if (filtnam1[0] != '\0' && strncmp (filtnam1, "CLEAR", 5) != 0) {
	    strcat (obsmode, ",");
	    strcat (obsmode, filtnam1);
	}

	if (filtnam2[0] != '\0' && strncmp (filtnam2, "CLEAR", 5) != 0) {
	    strcat (obsmode, ",");
	    strcat (obsmode, filtnam2);
	}

	if (filtnam3[0] != '\0' && strncmp (filtnam3, "CLEAR", 5) != 0) {
	    strcat (obsmode, ",");
	    strcat (obsmode, filtnam3);
	}

	if (filtnam4[0] != '\0' && strncmp (filtnam4, "CLEAR", 5) != 0) {
	    strcat (obsmode, ",");
	    strcat (obsmode, filtnam4);
	}

	/* Add the aperture */

	if (relay == 48)
	    strcpy (field, ",X48");
	else if (relay == 96)
	    strcpy (field, ",X96");
	else if (relay == 288)
	    strcpy (field, ",X28");

	if (strcmp (pxformt, "ZOOM") == 0)
	    strcat (field, "Z");
	else 
	    strcat (field, "N");

	if (samppln == 512 && linepfm == 1024)
	    strcat (field, "LRG");
	else if (samppln == 256 && linepfm == 1024)
	    strcat (field, "REC");
	else if (samppln == 512 && linepfm == 512)
	    strcat (field, "512");
	else if (samppln == 256 && linepfm == 256)
	    strcat (field, "256");
	else if (samppln == 256 && linepfm == 128)
	    strcat (field, "256D");
	else if (samppln == 128 && linepfm == 128)
	    strcat (field, "128");
	else
	    return;

	if (relay == 48) {
	    if (strcmp (smmmode, "INBEAM") == 0) {
		if (sampoff == 512 && lineoff == 0)
		    strcat (field, "_CD");
		else
		    strcat (field, "S");
	    }

	} else if (relay == 96) {
	    if (samppln == 512 && linepfm == 512) {
		if (sampoff == 0 && lineoff == 512)
		    strcat (field, "_4");
		else if (sampoff == 421 && lineoff == 0)
		    strcat (field, "_8");
		else if (sampoff == 256 && lineoff == 0)
		    strcat (field, "_UF");
		else if (sampoff == 256 && lineoff == 512)
		    strcat (field, "_DF");
	    }

	} else if (relay == 288) {
	    if (sampoff == 152 && lineoff == 460)
		strcat (field, "_4");
	    else if (sampoff == 280 && lineoff == 588)
		strcat (field, "_4");
	}

	strcat (obsmode, field);
    }
}

