#include <string.h>
#include "getobsmode.h"

/* GETHSPMODE -- Get the observation mode for a hsp observation
 *
 * This code is based on calhsp/vsynph.f and should track changes (ha !)
 * in that code
 *
 * i: root	observation rootname
 * o: obsmode	observation mode
 */

void gethspmode (char *root, char *obsmode)
{
    int		detector, ifilt;
    char	aperture[SZ_FIELD+1], apname[SZ_FIELD+1];

    char 	*filter[] = {"F122M", "F135W", "F145M", "F152M", "F179M",
			     "F184W", "F216M", "F218M", "F220W", "F237M",
			     "F240W", "F248M", "F262M", "F277M", "F278N",
			     "F284M", "F327M", "F355M", "F419N", "F450W",
			     "F551W", "F620W", "F140LP", "F160LP", "F400LP",
			     "F320N", "F750W", ""};

    if (qryhspmode (root, &detector, aperture) == NOMATCH) {
	obsmode[0] = '\0';

    } else if (aperture[0] == '\0') {
	obsmode[0] = '\0';

    } else {
        strcpy (obsmode, "HSP");

        /* Check for beam splitters */

        if (strcmp (aperture, "VF135U1_A") == 0) {
            strcat (obsmode, ",UV1,PRISM,BLUE");
        } else if (strcmp (aperture, "VF248U1_A") == 0) {
            strcat (obsmode, ",UV1,PRISM,RED");
        } else if (strcmp (aperture, "VF145U2_A") == 0) {
            strcat (obsmode, ",UV2,PRISM,BLUE");
        } else if (strcmp (aperture, "VF262U2_A") == 0) {
            strcat (obsmode, ",UV2,PRISM,RED");
        } else if (strcmp (aperture, "VF240V_A") == 0) {
            strcat (obsmode, ",VIS,PRISM,BLUE");
        } else if (strcmp (aperture, "VF551V_A") == 0) {
            strcat (obsmode, ",VIS,PRISM,RED");

        /* PMT */

        } else if (strcmp (aperture, "VF750_F320") == 0) {
            if (detector == 3)
                strcat (obsmode, ",PMT,BLUE");
            else
                strcat (obsmode, ",PMT,RED");

        /* Clear Apertures */

        } else if (strncmp (aperture, "VCLR", 4) == 0) {
            apname[0] = '\0';
            apname[1] = '\0';

            if (aperture[4] == 'P') {
                strcat (obsmode, ",POL,F160LP");
                apname[0] = aperture[7];
            } else if (aperture[4] == 'V') {
                strcat (obsmode, ",VIS,F160LP");
                apname[0] = aperture[7];
            } else if (aperture[4] == 'U' && aperture[5] == '1') {
                strcat (obsmode, ",UV1,F140LP");
                apname[0] = aperture[8];
            } else if (aperture[4] == 'U' && aperture[5] == '2') {
                strcat (obsmode, ",UV2,F140LP");
                apname[0] = aperture[8];
            }

            if (apname[0] != '\0') {
                strcat (obsmode, ",");
                strcat(obsmode, apname);
            }

        /* Regular Cases */

        } else if (aperture[1] == 'F') {
            apname[0] = '\0';
            apname[1] = '\0';

            if (aperture[5] == 'P') {
                strcat (obsmode, ",POL");
                strcpy (apname, &aperture[6]);
            } else if (aperture[5] == 'V') {
                strcat (obsmode, ",VIS");
                apname[0] = aperture[7];
            } else if (aperture[5] == 'U' && aperture[6] == '1') {
                strcat (obsmode, ",UV1");
                apname[0] = aperture[8];
            } else if (aperture[5] == 'U' && aperture[6] == '2') {
                strcat (obsmode, ",UV2");
                apname[0] = aperture[8];
            }

            if (apname[0] != '\0') {
                strcat (obsmode, ",");
                strcat(obsmode, apname);
            }

            for (ifilt = 0; filter[ifilt][0] != '\0'; ifilt ++) {
                if (strncmp (&filter[ifilt][1], &aperture[2], 3) == 0)
                    break;
            }

            if (filter[ifilt][0] != '\0') {
                strcat (obsmode, ",");
                strcat (obsmode, filter[ifilt]);
            }

        } else {
	    obsmode[0] = '\0';
	}
    }
}

