#include <string.h>
#include "ostdb.h"
#include "getobsmode.h"

/* QRYSTISMODE -- Query the database for the stis observation mode fields
 *
 * i: root	observation rootname
 * o: detector	detector used
 * o: aperture	stis aperture
 * o: opt_elem	stis optical element
 * o: obstype	stis observation type
 * o: ccdgain	amplifier gain
 * o: cenwave	central wavelength
 */

int qrystismode (char *root, char *detector, char *aperture, char *opt_elem,
		 char *obstype, int *ccdgain, int *cenwave)
{
    int		status;
    char	query[SZ_COMMAND+1];

    char	qryformat[] = "select a.ssr_detector, a.ssr_aperture, "
	"a.ssr_opt_elem, a.ssr_obstype, a.ssr_ccdgain, a.ssr_cenwave "
	"from stis_ref_data a where a.ssr_data_set_name = '%s'\n";

    /* Start query and bind output variables */

    ostdb_query_setup (OBS_CHANNEL, "qrystismode", 1, STDB_SQL,  
		       OBS_SERVER, OBS_DBNAME, NULL);

    stdb_bind_string (OBS_CHANNEL, "ssr_detector", detector, SZ_FIELD);
    stdb_bind_string (OBS_CHANNEL, "ssr_aperture", aperture, SZ_FIELD);
    stdb_bind_string (OBS_CHANNEL, "ssr_opt_elem", opt_elem, SZ_FIELD);
    stdb_bind_string (OBS_CHANNEL, "ssr_obstype", obstype, SZ_FIELD);
    stdb_bind_int (OBS_CHANNEL, "ssr_ccdgain", ccdgain);
    stdb_bind_int (OBS_CHANNEL, "ssr_cenwave", cenwave);

    /* Build query */

    sprintf (query, qryformat, root);
    stdb_query (OBS_CHANNEL, query);
    
    /* Execute query, saving results in bound variables */

    if (ostdb_get_exec(OBS_CHANNEL) == STDB_CONTINUE) {
	trim_qryfield (detector);
	trim_qryfield (aperture);
	trim_qryfield (opt_elem);
	trim_qryfield (obstype);
	status = MATCH;
    } else {
	status = NOMATCH;
    }

    /* Clean up after query */

    stdb_close_query (OBS_CHANNEL);
    return (status);
}
