#include <stdarg.h>
#include "error.h"
#include "query.h"
#include "config.h"
#include "cdbslib.h"
#include "getref.h"

#define  MAXSTACK	8
#define  MAXLOOP	999

/* BUILD_QRY -- Fill a query format and send query to database
 *
 * i: db	database connection number
 * i: format	the query format
 */

void build_qry (int db, char *format, ...)
{
    int		top, ic, jc, done;
    va_list	argptr, arglast;
    char	query[SZ_LINE], *str, **strptr;

    struct {
	int	ic;
	int	loop;
	va_list	arg;
    } stack[MAXSTACK];

    top = -1;
    ic = jc = 0;
    va_start (argptr, format);

    while (format[ic] != EOS) {
	switch (format[ic]) {
	case '\\':
	    /* Escape character: process next char as ordinary char */

	    if (format[ic++] != EOS)
		query[jc++] = format[ic++];
	    break;

	case ' ':
	    /* Blank: flush query text to database if buffer is full */

	    query[jc++] = format[ic++];

	    if (jc > SZ_QRYLINE) {
		query[jc] = EOS;
		stdb_query (db, query);
		Q(fprintf (stderr, "QUERY: %s\n", query);)
		jc = 0;
	    }
	    break;

	case '[':
	    /* Left bracket: optional text skipped on first pass */

	    if (stack[top].loop == 0) {
		while (format[ic++] != ']')
		    ;
	    } else {
		ic ++;
	    }
	    break;

	case ']':
	    /* Right bracket: marks end of optional text */

	    ic ++;
	    break;

	case '{':
	    /* Left brace: start format loop */

	    ic ++;
	    if (++ top == MAXSTACK)
		cdbs_error (BADQRYFMT, "%s", format);

	    /* Push current state on stack */

	    stack[top].ic = ic;
	    stack[top].loop = 0;
	    stack[top].arg = argptr;
	    break;

	case '}':
	    /* Right brace: Loop by setting state to state on stack */

	    if (top < 0 || stack[top].loop > MAXLOOP)
		cdbs_error (BADQRYFMT, "%s", format);


	    /* Increment field indicating trips through loop */

	    stack[top].loop ++;

	    /* Check for loop termination */

	    done = NO;
	    arglast = argptr;
	    argptr = stack[top].arg;

	    while (argptr != arglast) {
		strptr = va_arg (argptr, char **);
		str = strptr[stack[top].loop];

		/* Loop termination criterion is a null string
		 * in any array referenced in this loop
		 */

		if (str[0] == EOS) {
		    done = YES;
		    break;
		}
	    }

	    /* If no termination, reset state to stack
	     * otherwise move past end of loop in format
	     * and pop stack
	     */

	    if (done == NO) {
		ic = stack[top].ic;
		argptr = stack[top].arg;
	    } else {
		ic ++;
		top --;
		argptr = arglast;
	    }
	    break;

	case '^':
	    /* Caret: marks location of substituted variables */

	    if (top < 0) {
		/* If not in braces, the variable is a scalar */

		str = va_arg (argptr, char *);
		while ((query[jc++] = *str++ ) != EOS)
		    ;

	    } else {
		/* In braces, variable is a vector, fetch new element
		 * each time thru the loop
		 */

		strptr = va_arg (argptr, char **);
		str = strptr[stack[top].loop];

		/* Copy the array element */

		while ((query[jc++] = *str++ ) != EOS)
		    ;
	    }
	    ic ++;
	    jc --;
	    break;

	default:
	    /* Ordinary character, copy to the query */

	    query[jc++] = format[ic++];
	}
    }

    /* Flush remaining text in buffer */

    query[jc] = EOS;
    stdb_query (db, query);
    Q(fprintf (stderr, "QUERY: %s\n", query);)

    va_end (argptr);
}
