#include "ostdb.h"
#include "error.h"
#include "dbquery.h"
#include "config.h"
#include "loadfile.h"
#include "cdbslib.h"
#include "getref.h"
#include "readroot.h"

/* GETREF_ALL -- Get summary information on all reference files
 *
 */

table *getref_all (void)
{
    rooter	*rp;
    table 	*tab;
    context	*qry;
    int		code, iqry, irow, ivar, text;
    char	*root, *obset, **bestvar, **oldvar;

    static char	*allqryfmt = "select {[, ]^}, {[, ]^} from ^ where ^ = ^\n";

    qry = init_query ();
    tab = create_table();

    /* Loop over each ovservation set rootname in the list  */

    iqry = 1;
    irow = 0;
    root = get_option ("root");
    text = yorn (get_option ("text"));

    rp = start_read_root (root);
    while ((obset = read_root (rp)) != NULL) {
	/* Initialize query for this observation set */

	ostdb_query_setup (qry->connection, "getref_all", iqry++, STDB_SQL,
			   qry->server, qry->dads_db, db_error);

	/* Bind variables receiving query results */

	code = get_icode_obs (obset);
	oldvar = bind_qryvars (qry->connection, oldref[code]);
	bestvar = bind_qryvars (qry->connection, bestref[code]);


	/* Build the query and send to database */

	build_qry (qry->connection, allqryfmt, oldref[code], bestref[code], 
		   dadstab[code], obsfield[code], strucase (enquote (obset)));

	/* Execute query and write results to table */

	while (ostdb_get_exec (qry->connection) == STDB_CONTINUE) {
	    for (ivar = 0; bestref[code][ivar][0] != EOS; ivar ++) {
		clean_data (bestvar[ivar]);
		clean_data (oldvar[ivar]);

		put_tab_cell (tab, "ROOTNAME", irow, obset);
		put_tab_cell (tab, "KEYWORD", irow, keyword[code][ivar]);

		if (text == YES || is_reffile(bestvar[ivar]) == NO ) {
		    put_tab_cell (tab, "FILENAME", irow, bestvar[ivar]);

		} else {
		    put_tab_cell (tab, "FILENAME", irow, 
				  mkanchor (bestvar[ivar], obset, 
					    bestvar[ivar], ""));
		}

		if (text == YES || is_reffile(oldvar[ivar]) == NO) {
		    put_tab_cell (tab, "OLDNAME", irow, oldvar[ivar]);

		} else {
		    put_tab_cell (tab, "OLDNAME", irow, 
				  mkanchor (oldvar[ivar], obset, 
					    oldvar[ivar], ""));
		}

		irow ++;
	    }
	}

	/* Free memory and close query */

	free_qryvars (bestvar);
	free_qryvars (oldvar);
	stdb_close_query (qry->connection);
    }

    end_read_root (rp);
    free_query (qry);

    if (irow == 0) 
	cdbs_error (NOROOT, "%s", root);

    return (tab);
}
