#include "ostdb.h"
#include "dbquery.h"
#include "loadfile.h"
#include "cdbslib.h"
#include "getref.h"

/* QRY_NOMODE -- Perform a detail query when there is no observation mode
 *
 * i: qry	database connection info
 * i: root	observation set root name
 * i: reffile	reference file name
 */

table *qry_nomode (context *qry, char *root, char *reffile) 
{
    table	*tab;
    char	*refname, **alist, **blist;
    int		code, irow, ivar, text;

    static char *nomodefmt = "select {[, ]a.^}, {[, ]b.^} from ^ a, ^ b "
	"where a.file_name = ^ and b.file_name = ^ and a.expansion_number = "
	"b.expansion_number order by a.expansion_number";

    code = get_icode_ref (reffile);
    refname = strucase (enquote (reffile));

    /* Set up the query */

    ostdb_query_setup (qry->connection, "qry_nomode", 1, STDB_SQL,
		       qry->server, qry->cdbs_db, db_error);

    alist = bind_qryvars (qry->connection, detail_filecol);
    blist = bind_qryvars (qry->connection, detail_rowcol);

    build_qry (qry->connection, nomodefmt, detail_filecol, detail_rowcol, 
	       cdbsfile[code], cdbsrow[code], refname, refname);

    /* Execute query and store results in output table */

    tab = create_table ();

    irow = 0;
    text = yorn (get_option ("text"));

    if (ostdb_get_exec (qry->connection) == STDB_CONTINUE) {
	/* Write fields from file level relation */

	for (ivar = 0; detail_filecol[ivar][0] != EOS; ivar ++) {

	    clean_data (alist[ivar]);
	    put_tab_cell (tab, "FIELDNAME", irow, detail_filecol[ivar]);

	    if (text == NO && 
		strcmp (detail_filecol[ivar], "comparison_file_name") == 0 &&
		is_reffile (alist[ivar]) == YES) {
		put_tab_cell (tab, "VALUE", irow, 
			      mkanchor (alist[ivar], root, alist[ivar], ""));
		    
	    } else {
		put_tab_cell (tab, "VALUE", irow, alist[ivar]);
	    }
	    irow ++;
	}

	/* Write fields from row level relation */

	for (ivar = 0; detail_rowcol[ivar][0] != EOS; ivar ++) {
	    clean_data (blist[ivar]);

	    put_tab_cell (tab, "FIELDNAME", irow, detail_rowcol[ivar]);
	    put_tab_cell (tab, "VALUE", irow, blist[ivar]);
	    irow ++;
	}

    }

    /* Free memory and close query */

    free_qryvars (alist);
    free_qryvars (blist);
    stdb_close_query (qry->connection);

    return (tab);
}


