#include "ostdb.h"
#include "dbquery.h"
#include "loadfile.h"
#include "cdbslib.h"
#include "getref.h"

/* QRY_NOROOT -- Perform a detail query when there is no rootname
 *
 * i: qry	database connection info
 * i: reffile	reference file name
 * i: cdbsname	observation mode fields in the cdbs database
 */

table *qry_noroot (context *qry, char *reffile, char **cdbsname) 
{
    table	*tab;
    int		code, irow, ivar, text;
    char	*refname, **alist, **blist, **mlist;

    static char *norootfmt = "select {[, ]a.^}, {[, ]b.^}, {[, ] b.^} from "
	"^ a, ^ b where a.file_name = ^ and b.file_name = ^ and "
	"a.expansion_number = b.expansion_number order by a.expansion_number";

    code = get_icode_ref (reffile);
    refname = strucase (enquote (reffile));

    /* Set up the query */

    ostdb_query_setup (qry->connection, "qry_noroot", 1, STDB_SQL,
		       qry->server, qry->cdbs_db, db_error);

    alist = bind_qryvars (qry->connection, detail_filecol);
    blist = bind_qryvars (qry->connection, detail_rowcol);
    mlist = bind_qryvars (qry->connection, cdbsname);

    build_qry (qry->connection, norootfmt, detail_filecol, cdbsname, 
	       detail_rowcol, cdbsfile[code], cdbsrow[code], refname, 
	       refname);

    /* Execute query and store results in output table */

    tab = create_table ();

    irow = 0;
    text = yorn (get_option ("text"));

    if (ostdb_get_exec (qry->connection) == STDB_CONTINUE) {
	/* Write fields from file level relation */

	for (ivar = 0; detail_filecol[ivar][0] != EOS; ivar ++) {
	    clean_data (alist[ivar]);
	    put_tab_cell (tab, "FIELDNAME", irow, detail_filecol[ivar]);

	    if (text == NO && 
		strcmp (detail_filecol[ivar], "comparison_file_name") == 0 &&
		is_reffile (alist[ivar]) == YES) {
		put_tab_cell (tab, "VALUE", irow, 
			      mkanchor (alist[ivar], "", alist[ivar], ""));
		    
	    } else {
		put_tab_cell (tab, "VALUE", irow, alist[ivar]);
	    }
	    irow ++;
	}

	/* Write observation mode fields */

	for (ivar = 0; cdbsname[ivar][0] != EOS; ivar ++) {
	    clean_data (mlist[ivar]);

	    put_tab_cell (tab, "FIELDNAME", irow, cdbsname[ivar]);
	    put_tab_cell (tab, "VALUE", irow, mlist[ivar]);
	    irow ++;
	}

	/* Write fields from row level relation */

	for (ivar = 0; detail_rowcol[ivar][0] != EOS; ivar ++) {
	    clean_data (blist[ivar]);

	    put_tab_cell (tab, "FIELDNAME", irow, detail_rowcol[ivar]);
	    put_tab_cell (tab, "VALUE", irow, blist[ivar]);
	    irow ++;
	}
    }

    /* Free memory and close query */

    free_qryvars (alist);
    free_qryvars (blist);
    free_qryvars (mlist);
    stdb_close_query (qry->connection);

    return (tab);
}


