#include <string.h>
#include <stdlib.h>
#include "ostdb.h"
#include "error.h"
#include "dbquery.h"
#include "cdbslib.h"
#include "loadfile.h"
#include "getref.h"

/* QRY_OBSMODE -- Query the database for the observation mode
 *
 */

void qry_obsmode (context *qry, char *reffile, char **cdbsname, 
		    char **dadsname, int maxname)
{
    int		code, iname, imode;
    char	*inst, *refname;
    char	obsmode[SZ_DBFIELD+1];

    char	*modefmt = "select a.modes from cdbs_mode a where "
	"a.instrument = ^ and a.file_select = 'Y' and a.reference_file_type "
	"in (select distinct b.reference_file_type from ^ b where b.file_name "
	"= ^)";

    /* Determine the instrument from the reference file name */

    code = get_icode_ref (reffile);

    /* Set up the query */

    ostdb_query_setup (qry->connection, "qry_obsmode", 1, STDB_SQL,
		       qry->server, qry->cdbs_db, db_error);

    stdb_bind_string (qry->connection, "modes", obsmode, SZ_DBFIELD);

    inst = strclone (strucase (enquote (instrument)));
    refname = strclone (strucase (enquote (reffile)));

    safecopy (inst, enquote (instrument[code]), SZ_STRING);
    build_qry (qry->connection, modefmt, inst, cdbsfile[code], 
	       refname);

    /* Get the names of the observation mode fields from the database */

    iname = 0;
    while (ostdb_get_exec (qry->connection) == STDB_CONTINUE && 
	   iname < maxname-1) {

	clean_data (obsmode);

	/* Find the corresponding field name in the dads database */

	for (imode = 0; cdbsmode[code][imode][0] != EOS; imode ++) {
	    if (strcmp (cdbsmode[code][imode], obsmode) == 0)
		break;
	}

	if (cdbsmode[code][imode][0] == EOS)
	    cdbs_error (NOMODE, "%s", obsmode);

	/* Copy pointers to the field names into the output arrays */

	cdbsname[iname] = cdbsmode[code][imode];
	dadsname[iname] = dadsmode[code][imode];
	iname ++;
    }

    stdb_close_query (qry->connection);

    /* Signal the end of the array with a null string */

    cdbsname[iname] = cdbsmode[code][MAXMODE-1];
    dadsname[iname] = dadsmode[code][MAXMODE-1];

    /* Free dynamically allocated memory */

    free (inst);
    free (refname);
}
