#include <stdlib.h>
#include <string.h>
#include "loadfile.h"
#define  DEFAULT_SIZE		100

/* The functions in this file implement the abstraction of an ubounded array.
 * Whenever the calling function writes beyond the end of the current array,
 * memory is reallocated to hold the larger array. No holes are allowed in the
 * array. The only place where writing is allowed is just past the end of
 * the current array
 */

/* INIT_CHAR_BUF -- Initialize a new buffer that holds character strings
 *
 * i: buf	buffer to initialize
 * i: size	amount of memory to allocate
 */

void init_char_buf (charbuf *buf, int size)
{
    if (size < 1)
	size = DEFAULT_SIZE;

    buf->info = (char *) malloc (size);
    buf->next = 0;
    buf->size = size;
    buf->increment = size;
}

/* INIT_INT_BUF -- Initialize a new buffer that holds integers
 *
 * i: buf	buffer to initialize
 * i: size	amount of memory to allocate
 */

void init_int_buf (intbuf *buf, int size)
{

    if (size < 1)
	size = DEFAULT_SIZE;

    buf->info = (int *) malloc (size * sizeof (int));
    buf->next = 0;
    buf->size = size;
    buf->increment = size;
}

/* PUT_CHAR_BUF -- Store a string in a character buffer
 *
 * i: buf	buffer pointer
 * i: data	value to store
 */

int put_char_buf (charbuf *buf, char *data)
{
    char	*temp;
    int		index = buf->next;

    do {
	if (buf->next == buf->size) {
	  /* DEBUG
	    temp = (char *) malloc (buf->size);
	    memcpy (temp, buf->info, buf->size);
	    memset (buf->info, '?', buf->size);
	    buf->info = (char *) malloc (buf->size+buf->increment);
	    memcpy (buf->info, temp, buf->size);
	    buf->size += buf->increment;
	    free (temp);
	   */
	    buf->size += buf->increment;
	    buf->info = (char *) realloc (buf->info, buf->size);
	}

	buf->info[buf->next++] = *data;

    } while (*data ++ != '\0');

    return (index);
}

/* PUT_INT_BUF -- Store an integer in an integer buffer
 *
 * i: buf	buffer pointer
 * i: data	value to store
 */

int put_int_buf (intbuf *buf, int data)
{
    int		index;

    if (buf->next == buf->size) {
	buf->size += buf->increment;
	buf->info = (int *) realloc (buf->info, buf->size * sizeof (int));
    }

    index = buf->next ++;
    buf->info[index] = data;

    return (index);
}

/* TOP_CHAR_BUF -- Determine if string is at the end of the char buffer
 *
 * i: buf	buffer pointer
 * i: index	index of start of string
 */

int top_char_buf (charbuf *buf, int index)
{
    while (buf->info[index++] != '\0')
	;

    if (index == buf->next) {
	return (index - 1);
    } else {
	return (BAD);
    }
}
