#include <stdio.h>
#include <string.h>
#include <stdlib.h>
#include "ostdb.h"

#ifndef TRUE
#define TRUE 1
#endif
#ifndef FALSE
#define FALSE 0
#endif

/*
*******************************************************************************
*
* Function: UpCase
*
* Purpose: Converts an input string to uppercase
*
*******************************************************************************
*/

char *UpCase(char *str){
  
  char *ptr;
  
  ptr = str;

  for (ptr=str; *ptr!='\0'; ptr++){
      *ptr = toupper(*ptr);
  }

  return(str); 
}


/*
*******************************************************************************
*
* Function: LowCase
*
* Purpose: Converts the input string to lowercase
*
*******************************************************************************
*/

char *LowCase(char *str){
  
  char *ptr;
  
  ptr = str;

  for (ptr=str; *ptr!='\0'; ptr++){
      *ptr = tolower(*ptr);
  }

  return(str); 
}


/*
 ******************************************************************************
 *
 * Function:     QuotedField
 *
 * Purpose:      Determines if the value of a field needs to be quoted when
 *               being inserted into the database or being used in a where
 *               clause. Datatypes that need to be quoted are char, varchar, 
 *               datetime and text. The determinatiopn is made by querying the
 *               database for the datatype of the field. 
 *
 * Returns:      TRUE or FALSE
 *
 ******************************************************************************
*/
int QuotedField(char *server, char *db, char *table,  char *column){

  char type[32];

  ostdb_query_setup(STDB_CONN_3, "QuotedField", 2, STDB_SQL, server, db, NULL);
  stdb_bind_string(STDB_CONN_3, "type", type, 0);
  stdb_string_param(STDB_CONN_3, "table", table);
  stdb_string_param(STDB_CONN_3, "column", column);
  stdb_query(STDB_CONN_3, "select t.name type from systypes t,");
  stdb_query(STDB_CONN_3, "syscolumns c where c.id = object_id(@table)");
  stdb_query(STDB_CONN_3, "and c.name = @column and c.type=t.type");

  while(ostdb_get_exec(STDB_CONN_3) == STDB_CONTINUE){
  }

  stdb_close_query(STDB_CONN_3);
  if ((strstr(type, "char") != NULL) ||
      (strcmp(type, "text") == 0) ||
      (strncmp(type, "datetim", 7) == 0)){
    return(TRUE);
  }else{
    return(FALSE);
  }
}

/*
*******************************************************************************
*
* Function: TransformQuotes
*
* Purpose: Changes all double quotes to single quotes in the input string
*
*******************************************************************************
*/

char *TransformQuotes(char *str){
  
  char *cptr;
  
  for (cptr=str; *cptr!='\0'; cptr++){
    if (*cptr == '"')
      *cptr = '\'';
  }

  return(str); 
}


/*
*******************************************************************************
*
* Function: NotBlank
*
* Purpose: Returns FALSE if a string is NULL or has nothing but white space
*          or punctuation.
*
*******************************************************************************
*/

int NotBlank(char *str){
  
  char *cptr;

  if ((str == NULL) || (str[0] == '\0'))
    return FALSE;
  
  for (cptr=str; *cptr !='\0'; cptr++){
    if (isalnum(*cptr))
      return TRUE;
  }

  return FALSE; 
}
