#include <string.h>
#include <stdlib.h>
#include "ostdb.h"
#include "error.h"
#include "dbquery.h"
#include "cdbslib.h"
#include "loadfile.h"
#include "config.h"
#include "mkcomptab.h"

#define  SZ_TEXT	16000

/* COMPTAB_QRY -- Read component lookup table from database
 *
 * i: useafter	useafter date
 * i: ncols	number of columns in component lookup table
 * i: dbcols	list of database column names
 * i: tabcols	corresponding list of table column names
 * u: comptab	component lookup table
 */

void comptab_qry (char *useafter, int ncols, char *dbcols, 
		  char *tabcols, table *comptab)
{
    static char	*comptab_query1 =
"select distinct max(a.useafter_date) useafter_date, compname into #temp1 \
from synphot_file a, synphot_row b where a.useafter_date < ^ and \
a.reference_file_type = 'THROUGHPUT' and a.file_name = b.file_name and \
a.reject_flag = 'N' group by b.compname";

    static char	*comptab_query2 =
"create unique nonclustered index tmp_i on #temp1(compname, useafter_date)";

    static char *comptab_query3 = 
"select a.general_availability_date availability_date, a.file_name file_name, \
a.useafter_date useafter_date, a.comment comment, b.compname compname \
from synphot_file a, synphot_row b, #temp1 t where a.reference_file_type = \
'THROUGHPUT' and a.file_name = b.file_name and a.reject_flag = 'N' and \
t.compname = b.compname and t.useafter_date = a.useafter_date order by \
b.compname";

    static char *comptab_query4 = "drop table #temp1";

    context	*qry;
    double	date, maxdate;
    int		irow, icol, lentext;
    char	*dblist, *tablist, *usedate;
    char	**dbfield, **tabfield, **dbvalue;

    /* Set up the connection to the database */

    qry = init_query ();

    /* Send query to create temporary table of useafter dates and compnames*/

    ostdb_query_setup (qry->connection, "comptab_qry", 1, STDB_SQL, 
		       qry->server, qry->cdbs_db, NULL);

    build_qry (qry->connection, comptab_query1, enquote(useafter));

    ostdb_get_exec (qry->connection);

    stdb_close_query (qry->connection);

    /* Send second query to create index on temporary table */

    ostdb_query_setup (qry->connection, "comptab_qry", 2, STDB_SQL, 
		       qry->server, qry->cdbs_db, NULL);

    build_qry (qry->connection, comptab_query2);

    ostdb_get_exec (qry->connection);

    stdb_close_query (qry->connection);

    /* Send third query to retrieve throughput table info */

    ostdb_query_setup (qry->connection, "comptab_qry", 3, STDB_SQL, 
		       qry->server, qry->cdbs_db, NULL);

    build_qry (qry->connection, comptab_query3);

    /* Bind column names to output variables */

    dblist = strclone (dbcols);
    dbfield = (char **) malloc (ncols * sizeof (char *));

    tablist = strclone (tabcols);
    tabfield = (char **) malloc (ncols * sizeof (char *));

    dbvalue = (char **) malloc (ncols * sizeof (char *));

    strsplit (',', dblist, dbfield, ncols);
    strsplit (',', tablist, tabfield, ncols);

    for (icol = 0; icol < ncols; icol ++) {
	if (strcmp (dbfield[icol], "comment") == 0) {
	    dbvalue[icol] = (char *) malloc (SZ_TEXT+1);
	    stdb_bind_text (qry->connection, dbfield[icol], 
			      dbvalue[icol], &lentext);

	} else {
	    dbvalue[icol] = (char *) malloc (SZ_STRING+1);
	    stdb_bind_string (qry->connection, dbfield[icol], 
			      dbvalue[icol], SZ_STRING);
	}

    }

    /* Bind useafter date */

    usedate = (char *) malloc (SZ_STRING+1);
    stdb_bind_string (qry->connection, "useafter_date", usedate, SZ_STRING);

    /* Build table from results of third query */

    maxdate = -1.0;
    for (irow = 0; ostdb_get_exec (qry->connection) == STDB_CONTINUE; irow++) {
	for (icol = 0; icol < ncols; icol ++) {
	    strclean (dbvalue[icol]);
	    strlcase (dbvalue[icol]);
	    put_tab_cell (comptab, tabfield[icol], irow, dbvalue[icol]);
	}

	date = get_sybase_date (usedate);
	if (date > maxdate)
	    maxdate = date;
    }

    stdb_close_query (qry->connection);

    /* Add useafter date to table header */

    if (maxdate > 0.0) {
	put_sybase_date (maxdate, usedate, SZ_STRING);
	put_tab_key (comptab, "USEAFTER", usedate);
    }

    /* Send fourth query to free temporary table */

    ostdb_query_setup (qry->connection, "comptab_qry", 4, STDB_SQL, 
		       qry->server, qry->cdbs_db, NULL);

    build_qry (qry->connection, comptab_query4);

    ostdb_get_exec (qry->connection);

    stdb_close_query (qry->connection);

    /* Check to see if any rows were fetched from database */

    if (irow == 0)
	cdbs_error (NODBROWS, "%s", "synphot_file");

    /* Free allocated memory */

    free_query (qry);

    for (icol = 0; icol < ncols; icol ++)
	free (dbvalue[icol]);

    free (usedate);
    free (dbvalue);
    free (dblist);
    free (dbfield);
    free (tablist);
    free (tabfield);

}

