#include <string.h>
#include "error.h"
#include "config.h"
#include "cdbslib.h"
#include "query.h"
#include "qrylex.h"

/* FTN_TO_SQL -- Convert fortran syntax expression to sql syntax
 *
 * i: tablist	list of table namee
 * i: ftnexp	fortran expression string
 * o: sqlexp	sql expression string
 * i: maxch	max length of sql expression
 */

void ftn_to_sql (char ** tablist, char *ftnexp, char *sqlexp, int maxch)
{
    static char ftnoper[] = ".eq.|.ne.|.lt.|.gt.|.le.|.ge.|.and.|.or.|.not.";
    static char sqloper[] = "=|!=|<|>|<=|>=|and|or|not";

    static char keywords[] = "all|and|any|as|asc|avg|between|by|count|desc|"
        "exists|from|having|in|is|like|max|min|not|null|or|order|select|some|"
        "sum|unique|where";

    int		ic, jc, ntab, more, likeflag, fromflag, iop;
    char	token[SZ_LINE+1];
    qlexer	*lx;

    /* Count number of tables */

    for (ntab = 0; tablist[ntab][0] != EOS; ntab ++)
        ;

    ic = 0;
    more = YES;
    likeflag = NO;
    fromflag = NO;
    sqlexp[0] = EOS;

    /* The lexer grabs one token at a time and specifies its type */

    lx = qrylex_init (ftnexp);

    while (more == YES) {
        switch (qrylex_next (lx, token, SZ_LINE)) {
	case QRY_END:
	    more = NO;
	    break;

	case QRY_STRING:
	    /* Convert quoted strings to upper case 
	     * and usual wildcards to sql
	     */

	    str_to_sql (likeflag, token);
	    copy_token (token, &ic, sqlexp, maxch);
	    likeflag = NO;
	    break;

	case QRY_CONSTANT:
	    /* Numeric constants are copied as is */

	    copy_token (token, &ic, sqlexp, maxch);
	    break;

	case QRY_IDENT:
	    /* Identifiers are keywords or column names
	     * prefix the latter eith the table alias
	     */

	    if (strchr (token, '.') == NULL) {
	        if (strmatch (token, keywords) > 0) {
		    likeflag = streq (token, "like");
		    fromflag = streq (token, "from");

		} else if (fromflag == NO) {
		    if (ntab > 1)
		        cdbs_error (AMBIGCOL, "%s", token);

		    for (jc = strlen (token); jc >= 0; jc --)
		        token[jc+2] = token[jc];

		    token[0] = 'a';
		    token[1] = '.';
		}
	    }
	    copy_token (token, &ic, sqlexp, maxch);
	    break;

	case QRY_SYMBOL:
	    /* Operators are translated from their fortran to sql form */

	    if (fromflag == YES && streq (token, ")") == NO)
	        fromflag = NO;

	    if (token[0] == '.') {
	        iop = strmatch (token, ftnoper);
		if (iop == 0)
		    cdbs_error (NODICT, "%s", token);

		safecopy (token, strxtract(sqloper, iop), SZ_LINE);
	    }
	    copy_token (token, &ic, sqlexp, maxch);
	    break;
	}
    }

    qrylex_close (lx);
}
