#include <stdlib.h>
#include "config.h"
#include "cdbslib.h"
#include "error.h"
#include "query.h"

/* GET_COLLIST -- Get a list of column names for a table matching a pattern
 *
 * i: qry		db query descriptor
 * i: dbase		database containing tables
 * i: tabname		comma separated list of table names
 * i: columns		comma separated list of column names
 */

char ** get_collist (context *qry, char *dbase, char *tabname, char *columns)
{
    char	*tlist, *clist, **qcollist, **allcols;
    char	*tfield[MAXTABLES+1], *cfield[MAXCOLUMNS+1];
    int		negate, ntab, ncol, itab;

    /* Copy input strings so they are not modified */

    tlist = strclone (tabname);
    clist = strclone (columns);

    strclean (tlist);
    strclean (clist);

    /* See of column list starts with negation and if so, remove it */

    negate = is_negated (clist);

    /* Split comma separated names into individual strings */

    strsplit (',', tlist, tfield, MAXTABLES);
    strsplit (',', clist, cfield, MAXCOLUMNS);

    /* No more tables than letters in alphabet !*/

    ntab = count_zlist (tfield);

    if (ntab > 26)
        cdbs_error (MANYTAB, "%s", tabname);

    qcollist = (char **) malloc (ntab * MAXCOLUMNS * sizeof (char *));

    /* Read all database columns from table and 
     * match column names in list
     */

    ncol = 0;
    for (itab = 0; itab < ntab; itab ++) {
        allcols = read_dbcols (qry, dbase, tfield[itab]);

	match_dbcols (allcols, cfield, negate, itab, &ncol, qcollist);
	free_zlist (allcols);
    }

    /* Terminate list with zero length string */

    qcollist[ncol] = strclone ("");

    /* Reallocate list to use less memory */

    qcollist = (char **) realloc (qcollist, (ncol + 1) * sizeof (char *));

    free (tlist);
    free (clist);

    /* Check for no columns matched */

    if (ncol == 0) {
        free_zlist (qcollist);
	cdbs_error (NODBCOLS, "%s", columns);
    }

    /* Return list of column names */

    return (qcollist);
}
