#include <string.h>
#include "config.h"
#include "loadfile.h"
#include "cdbslib.h"
#include "query.h"

/* QRYOUT_TEXT -- Produce ascii output from a table
 *
 * i: tab	table descriptor
 */

void qryout_text (table *tab)
{
    char	*value;
    static char	*quotes = "\"\"";
    int		*colwidth;
    int		html, title, icol, linelen, irow, width;

    if (tab == NULL)
	return;

    /* Get task parameters */

    html = yorn (get_option ("HTML"));
    title = yorn (get_option ("title"));

    /* Calculate the width of the widest column */

    colwidth = (int *) malloc (ncol_table(tab) * sizeof (int));

    for (icol = 0; icol < ncol_table (tab); icol ++) {
        if (title == NO) {
	    colwidth[icol] = 0;
	} else {
	    colwidth[icol] = strlen (get_tab_colname (tab, icol)) + 2;
	}

	for (irow = 0; irow < nrow_table(tab); irow ++) {
	    width = strlen (get_tab_cell_bynum (tab, icol, irow)) + 1;
	    if (width > colwidth[icol])
		colwidth[icol] = width;
	}
    }

    /* Compute line breaks. Mark them by negating column width */

    linelen = 0;
    for (icol = 0; icol < ncol_table (tab); icol ++) {
        linelen += colwidth[icol];
	if (linelen > PAGEWIDTH) {
	    if (icol > 0) {
	        colwidth[icol-1] = - colwidth[icol-1];
	    }
	    linelen = colwidth[icol];
	}
    }

    /* Print the html response header if called as a cgi script */

    if (html == YES)
	printf ("Content-type: text/plain\n\n");

    /* Print the title line */

    if (title == YES) {
        printf ("#");
	for (icol = 0; icol < ncol_table(tab); icol ++) {
	    width = abs(colwidth[icol]);
	    if (icol == 0 || colwidth[icol-1] < 0)
	        width = width - 1;

	    printf ("%-*s", width, get_tab_colname (tab, icol));

	    if (colwidth[icol] < 0)
	        printf ("\\\n#");

	}
	printf ("\n");
    }

    /* Print the cells in the table */

    for (irow = 0; irow < nrow_table(tab); irow ++) {
	for (icol = 0; icol < ncol_table(tab); icol ++) {
	    value = get_tab_cell_bynum (tab, icol, irow);
	    if (value[0] == EOS)
		value = quotes;

	    printf ("%-*s", abs(colwidth[icol]), value);

	    if (colwidth[icol] < 0)
	        printf ("\\\n");
	}
	printf ("\n");
    }

    free (colwidth);
}
