#include <stdio.h>
#include "config.h"
#include "error.h"
#include "cdbslib.h"
#include "query.h"

static void tocomma (char *, char *, int);

/* READ_COLLIST -- Read a list of columns (possibly) stored in a file
 *
 * i: columns	list of columns or column file
 * o: colbuf	output buffer containing column list
 * i: maxch	max length output buffer
 */

void read_collist (char * columns, char *colbuf, int maxch)
{
    int		ic;
    FILE	*fd;
    char	line[SZ_LINE+1];

    /* Look for prefix character */

    colbuf[0] = EOS;
    ic = first_char (columns);

    /* If the column list is not a file, copy it to output and return */

    if (columns[ic] != '@') {
        tocomma (columns, colbuf, maxch);
	return;
    }

    /* Open the list file readonly */

    fd = fopen (&columns[ic+1], "r");
    if (fd == NULL)
        cdbs_error (NOTOPEN, "%s", &columns[ic+1]);

    /* Read each line in file */

    while (fgets (line, SZ_LINE, fd) != NULL)
	tocomma (line, colbuf, maxch);

    fclose (fd);
}

/* TOCOMMA -- Replace blank separated strings with comma separated strings
 *
 * i: line	line with blank separated strings
 * u: colbuf	buffer of comma separated strings
 * i: maxch	max length of output buffer
 */

static void tocomma (char *line, char *colbuf, int maxch)
{
    char	*col[MAXCOLUMNS+1];
    int		icol;

    strsplit (' ', line, col, MAXCOLUMNS);

    for (icol = 0; col[icol][0] != EOS; icol ++) {
	if (colbuf[0] != EOS)
	    safecat (colbuf, ",", maxch);

	safecat (colbuf, col[icol], maxch);
    }
}
