#include <string.h>
#include <stdlib.h>
#include "ostdb.h"
#include "config.h"
#include "cdbslib.h"
#include "loadfile.h"
#include "dbquery.h"
#include "query.h"

/* READ_DBCOLS -- Read the complete list of columns in a database table
 *
 * i: qry	datbase query descriptor
 * i: dbase	database containing table
 * i: table	database table name
 */

char **read_dbcols (context *qry, char *dbase, char *table)
{
    static char	colqryfmt[] = "select distinct b.name colname from "
      "sysobjects a, syscolumns b where a.type = 'U' and b.type not in "
      "(34, 35, 37, 45) and a.id = b.id and a.name = ^ order by "
      "b.id, b.colid";

    int		icol;
    char	colname[SZ_STRING+1];
    char	*buffer, *dot, *dbname, *tabname, **allcols;

    /* Allocate array to hold list of column names */

    allcols = (char **) malloc ((MAXCOLUMNS + 1) * sizeof (char *));

    /* If the table name contains an explicit database reference
     * that database needs to be searched instead of the database
     * passed as function argument 
     */

    buffer = strclone (table);
    dot = strchr (buffer, '.');

    if (dot == NULL) {
        dbname = dbase;
	tabname = table;

    } else {
        /* Split the buffer at the dot into database and table names */

        *dot = EOS;
	while (*(++ dot) == '.')  /*Check for consecutive dots */
	    ;

	dbname = buffer;
	tabname = dot;
    }

    /* Initialize query */

    ostdb_query_setup (qry->connection, "read_dbcols", 1, STDB_SQL,
		       qry->server, dbname, db_error);

    stdb_bind_string (qry->connection, "colname", colname, SZ_STRING);

    /* Build the query */

    build_qry (qry->connection, colqryfmt, enquote (tabname));

    /* Execute query and save results in array */

    icol = 0;
    while (ostdb_get_exec (qry->connection) == STDB_CONTINUE) {
        strclean (colname);
	allcols[icol++] = strclone (colname);
    }

    /* Terminate list of column names with zero length string */

    allcols[icol] = strclone ("");

    /* Return array of column names */

    free (buffer);
    stdb_close_query (qry->connection);

    return (allcols);
}
