#include <time.h>
#include <stdlib.h>
#include "system.h"
#include "config.h"

#define base36(x)	((x)<10 ? (x)+'0' : ((x)-10)+'a')

static void base100 (int, char *, int *);

/* MAKEID -- Create a unique identifier from the current time
 *
 * o: ident	identifier (length >= 8)
 */

void makeid (char *ident)
{
    static time_t	oldtick = 0;
    time_t		tick;
    struct tm		*now;
    int			ic;

    /* Make sure two seconds have elapsed since the last call so that
     * the identifier returned is unique
     */

    tick = time (NULL);
    while (tick - oldtick < 2) {
	sleep (1);		/* POSIX function */
	tick = time (NULL);
    }

    oldtick = tick;
    now = localtime (&tick);

    /* Create an identifier with the format YMDHHMMS
     *
     *   Y denotes the year (1-z, where 1981 = 1)
     *   M denotes the month of the year (1-c, where January = 1)
     *   D denotes the day (1-v, where first day of month = 1)
     *   HH denotes the hour (00-23)
     *   MM denotes the minutes (00-59)
     *   S  denotes (seconds/2)  (0 - t)
     */

    ic = 0;
    ident[ic++] = base36 (now->tm_year - 80);
    ident[ic++] = base36 (now->tm_mon + 1);
    ident[ic++] = base36 (now->tm_mday);

    base100 (now->tm_hour, ident, &ic);
    base100 (now->tm_min, ident, &ic);

    ident[ic++] = base36 (now->tm_sec / 2);
    ident[ic] = EOS;
}

/* BASE100 -- Convert a number less than 100 to 2 characters
 *
 * i: num	number to convert
 * u: str	string written to
 * u: ic	index of first char in string
 */

static void base100 (int num, char *str, int *ic)
{
    int		tens, units;

    tens = num / 10;
    units = num - 10 * tens;

    str[(*ic)++] = tens + '0';
    str[(*ic)++] = units + '0';
}
