#include <string.h>
#include "cdbslib.h"
#include "config.h"
#include "uniqname.h"

/* NEWINSTNAME -- Calculate a unique name for the new (post-97) instruments
 *
 * i: reftype		reference file type
 * i: cdbsdir		the directory the reference file will be stored in
 * i: code		the instrument code number
 * o: newroot		the unique root name
 * i: maxch		maximum length of calculated name
 */

void newinstname (char *reftype, char *cdbsdir, int code, 
		  char *newroot, int maxch)
{
    static char	*icode = ICODES;

    char	trailer[SZ_FNAME+1], cdbsname[SZ_FNAME+1];
    char	cdbsroot[SZ_FNAME+1];
    char	*suffix;


    /* The instrument code plus the reference file type
     * combined with the extension forms the "trailer"
     */

    trailer[0] = icode[code-1];
    trailer[1] = '_';
    trailer[2] = EOS;

    safecat (trailer, reftype, SZ_FNAME);
    safecat (trailer, ".*", SZ_FNAME);
	
    /* Loop until we create a new file name root not already 
     * in the cdbs directories
     */

    do {
        makeid (newroot);

	safecopy (cdbsname, cdbsdir, SZ_FNAME);
	safecat (cdbsname, newroot, SZ_FNAME);
	safecat (cdbsname, trailer, SZ_FNAME);

	lastfile (cdbsname, cdbsroot, SZ_FNAME);
    } while (strcmp (cdbsname, cdbsroot) != 0);
	
    suffix = strrchr (trailer, '.');
    *suffix = EOS;

    safecat (newroot, trailer, SZ_FNAME);
}
