#include <string.h>
#include <stdio.h>
#include <stdlib.h>
#include "cdbslib.h"
#include "error.h"
#include "config.h"
#include "uniqname.h"

/* THRUNAME -- Calculate a new unique name for a throughput file
 *
 * i: ref		reference file descriptor
 * i: reftype		reference file type
 * i: cdbsdir		the directory the reference file will be stored in
 * o: newroot		the unique root name
 * i: maxch		maximum length of calculated name
 */

void thruname (reffile *ref, char *reftype, char *cdbsdir, 
	       char *newroot, int maxch)
{
    char	trailer[SZ_FNAME+1], cdbsname[SZ_FNAME+1];
    char	cdbsroot[SZ_FNAME+1];
    char	*suffix;
    int		count;

    /* Get the root prefix from information 
     * in the reference file header 
     */

    getsynroot (ref, reftype, newroot, SZ_FNAME);

    /* The other synphot reference file types calculate their root 
     * name according to the method in the rest of this function
     */

    safecat (newroot, "_???", SZ_FNAME);

    /* Get the last filename with the root prefix
     * and use it to compute the root suffix
     */

    safecopy (cdbsname, cdbsdir, SZ_FNAME);
    safecat (cdbsname, newroot, SZ_FNAME);
    safecat (cdbsname, ".tab", SZ_FNAME);

    lastfile (cdbsname, cdbsroot, SZ_FNAME);

    if (strcmp (cdbsname, cdbsroot) == 0) {
        safecopy (trailer, "_001", SZ_FNAME);

    } else {
        suffix = strrchr (cdbsroot, '_') + 1;
	count = atoi (suffix);
	sprintf (trailer, "_%03d", count + 1);
    }

    /* Compute the new root name */

    suffix = strrchr (newroot, '_');
    *suffix = EOS;

    safecat (newroot, trailer, SZ_FNAME);
}
