#include <stdio.h>
#include <stdlib.h>
#include "error.h"
#include "cdbslib.h"
#include "loadfile.h"
#include "config.h"
#include "alist.h"

/* ADD_ALIST -- Add a key/value pair to the associative list
 *
 * u: list	list structure
 * i: key	associative list key
 * i: value	associative list value
 */

void add_alist (alist *list, char *key, char *value)
{
    int		index;

    if ((index = find_text (&list->key, key)) == BAD) {
	add_text (&list->key, key);
	add_text (&list->value, value);
    } else {
	put_text (&list->value, index, value);
    }
}

/* CREATE_ALIST -- Create a new associative list
 *
 */

alist * create_alist (void)
{
    alist	*list;

    list = (alist *) malloc (sizeof (alist));
    init_text (&list->key, 10, 100);
    init_text (&list->value, 10, 100);

    return (list);
}

/* EACH_ALIST -- Retrieve a (key, value) pair by index
 *
 * i: index	index into the associative array
 * o: key	pointer to keyword name
 * o: value	pointer to keyword value
 */

int each_alist (alist *list, int index, char **key, char **value)
{
    *key = get_text (&list->key, index);
    *value = get_text (&list->value, index);

    return (*key != NULL ? OK : ERR);
}

/* FIND_ALIST -- Find a value in the associative list given the key
 *
 * i: list	list structure
 * i: key	associative list key
 */

char * find_alist (alist *list, char *key)
{
    int		index;

    if ((index = find_text (&list->key, key)) == BAD) {
	return (NULL);
    } else {
	return (get_text (&list->value, index));
    }
}

/* FREE_ALIST -- Free the associative list
 *
 * i: list	list structure
 */

void free_alist (alist *list)
{
    free_text (&list->key);
    free_text (&list->value);
    free (list);
}

/* MATCH_ALIST -- Search a list with a pattern for a match
 *
 * i: list	list structure
 * i: pattern	pattern string
 * u: line	place to begin search
 */

char * match_alist (alist *list, char *pattern, int *line)
{
    int	       index;

    while (*line < list->key.nline) {
	index = list->key.line.info[*line];

	if (patmatch (pattern, &list->key.string.info[index]))
	    return (get_text (&list->value, *line++));

	*line ++;
    }

    return (NULL);
}

/* PATMATCH_ALIST -- Search a list containing patterns for a match
 *
 * i: list	list structure
 * i: str	string
 */

char * patmatch_alist (alist *list, char *str)
{
    int	       line, index;

    for (line = 0; line < list->key.nline; line ++) {
	index = list->key.line.info[line];

	if (patmatch (&list->key.string.info[index], str))
	    return (get_text (&list->value, line));
    }

    return (NULL);
}

/* READ_ALIST -- Read a two column file into an associative list
 *
 * i: fname	file name
 */

alist *read_alist (char *fname)
{
    FILE	*fd;
    alist	*list;
    char	*field[2];
    char	buf[SZ_LINE+1];

    /* Open the file */

    fd = fopen (fname, "r");
    if (fd == NULL)
	cdbs_error (NOTOPEN, "%s", fname);

    list = create_alist ();

    /* Each line is split into two fields on whitespace. 
     * The first field is the key, the second, the value
     */

    while (rdlines (fd, buf, SZ_LINE) == OK) {
        strsplit (' ', buf, field, 2);
	add_alist (list, field[0], field[1]);
    }

    fclose (fd);
    return (list);
}
