#include "config.h"
#include "cdbslib.h"

#define  _F		1	
#define  _E		2	
#define  _V		3	
#define  _D		4	

/* BREAKFNAME -- Break a filename into its component parts */

void breakfname (const char *file, char *dir, char *root, char *ext, int maxch)
{
    static char chartype[] = {
	_D,	_D,	_D,	_D,	_D,	_D,	_D,	_D,
	_D,	_D,	_D,	_D,	_D,	_D,	_D,	_D,
	_D,	_D,	_D,	_D,	_D,	_D,	_D,	_D,
	_D,	_D,	_D,	_D,	_D,	_D,	_D,	_D,
	_D,	_D,	_D,	_D,	_D,	_D,	_D,	_D,
	_D,	_D,	_F,	_D,	_D,	_F,	_E,	_D,
	_F,	_F,	_F,	_F,	_F,	_F,	_F,	_F,
	_F,	_F,	_D,	_V,	_D,	_D,	_D,	_F,
	_D,	_F,	_F,	_F,	_F,	_F,	_F,	_F,
	_F,	_F,	_F,	_F,	_F,	_F,	_F,	_F,
	_F,	_F,	_F,	_F,	_F,	_F,	_F,	_F,
	_F,	_F,	_F,	_D,	_D,	_D,	_D,	_F,
	_D,	_F,	_F,	_F,	_F,	_F,	_F,	_F,
	_F,	_F,	_F,	_F,	_F,	_F,	_F,	_F,
	_F,	_F,	_F,	_F,	_F,	_F,	_F,	_F,
	_F,	_F,	_F,	_D,	_D,	_D,	_D,	_D
    };

    int		rpos, epos, vpos, ic, nc;

    /* Find characters which mark beginning of parts of filename */

    rpos = 0;
    epos = 0;
    vpos = 0;

    for (ic = 0; file[ic] != EOS; ic ++) {
	switch (chartype[file[ic]]) {
	case _F: 	/* Filename character (A-Z,a-z,0-9,_,-,?,*) */
	    break;
	case _E:	/* Start of extension character (.) */
	    epos = ic;
	    break;
	case _V:	/* Start of version character (;) */
	    vpos = ic;
	    break;
	case _D:	/* End of directory character (anything else) */
	    rpos = ic;
	    break;
	}
    }

    /* Adjust so that position pointers point to first char in section 
     * or the null byte at the end of the string
     */

    if (vpos <= rpos || vpos <= epos)
	vpos = ic;

    if (epos <= rpos || (epos + 1) == vpos)
	epos = ic;

    if (rpos > 0)
	rpos += 1;

    /* Copy filename parts to output strings */

    if (dir != NULL) {
	nc = rpos;
	nc = nc < maxch ? nc : maxch;
	safecopy (dir, file, nc);
    }

    if (root != NULL) {
	nc = epos - rpos;
	nc = nc < maxch ? nc : maxch;
	safecopy (root, &file[rpos], nc);
    }

    if (ext != NULL) {
	nc = vpos - epos;
	nc = nc < maxch ? nc : maxch;
	safecopy (ext, &file[epos], nc);
    }

}
