#include "error.h"
#include "config.h"
#include "system.h"
#include "reffile.h"
#include "cdbslib.h"
#include "synfile.h"

/* GETIRAFDIR -- Get iraf directory that contains online copy of reffile
 *
 * i: ref		reference file descriptor
 * i: instrument	instrument name
 * i: reftype		reference file type
 * i: type		file type (image or table)
 * o: irafdir		iraf directory name
 * i: maxch		length of directory name
 */

int getirafdir (reffile *ref, char *instrument, char *reftype, 
		char *type, char *irafdir, int maxch)
{
    static char		*icode = ICODES;

    int			code, typecode;
    char		inst[SZ_STRING+1];

    irafdir[0] = EOS;
    code = strmatch (instrument, INSTRUMENTS);

    if (code != SYNPHOT) {
	/* All non-synphot files are put in a directory indicated
	 * by the instrument code and file type
	 */

	irafdir[0] = icode[code-1];
	irafdir[1] = EOS;

	typecode = strmatch (type, FILETYPE_NAMES);
	if (typecode == IMAGE) {
	    safecat (irafdir, "ref$", maxch);
	} else if (typecode == TABLE) {
	    safecat (irafdir, "tab$", maxch);
	} else {
	    cdbs_warn (NOIRAF, "%s", name_reffile(ref));
	    return (ERR);
	}

    } else {
	/* Synphot files are put in a directory indicated by
	 * their reference file types.
	 */

	typecode = strmatch (reftype, SYNTYPES);
	switch (typecode) {
	case SPECOBS:
	    safecopy (irafdir, "crcalobs$", maxch);
	    break;
	case SPECTRUM:
	    safecopy (irafdir, "crcalspec$", maxch);
	    break;
	case THRU:
	    get_hdr_reffile (ref, "INSTRUME", inst, SZ_STRING);
	    safecopy (irafdir, "cr", maxch);
	    safecat (irafdir, inst, maxch);
	    safecat (irafdir, "comp$", maxch);
	    break;
	case PHOFLDS:
	    safecopy (irafdir, "crfields$", maxch);
	    break;
	case PHOTOBS:
	    safecopy (irafdir, "crcalobs$", maxch);
	    break;
	case POLAROBS:
	    safecopy (irafdir, "crcalobs$", maxch);
	    break;
	case WAVECAL:
	    safecopy (irafdir, "crwave$", maxch);
	    break;
	case CLUSTERPOS:
	    safecopy (irafdir, "crcalobs$", maxch);
	    break;
	case GRAPHTAB:
	case COMPTAB:
	    safecopy (irafdir, "mtab$", maxch);
	    break;
	default:
	    cdbs_warn (BADREF, "%s", reftype);
	    return (ERR);
	}
    }

    return (OK);
}
