#include <stdio.h>
#include <string.h>
#include "config.h"
#include "error.h"
#include "cdbslib.h"

/* RDLINES -- Read one or more lines from a text file 
 *
 * i: fd	test file descriptor
 * o: buf	buffer to hold line
 * i: maxbuf	max length of buffer
 */

int rdlines (FILE *fd, char * buf, int maxbuf)
{
    int		ic, more, comment, status;
    char	line[SZ_LINE+1];

    more = NO;
    buf[0] = EOS;

    /* Loop until we have a complete line. We return if both
     * comment and more are YES or NO. 
     */

    do {
	if (fgets (line, SZ_LINE, fd) == NULL)
	    break;

	if (strchr (line, '\n') == NULL) {
	    line[40] = EOS;
	    cdbs_error (TOOLONG, "%s ...", line);
	}

	ic = first_char (line);

	/* Skip blank and comment lines */
	if (line[ic] == EOS || line[ic] == '#') {
	    comment = YES;

	} else {
	    comment = NO;

	    /* Only strip leading whitespace from continued lines */
	    if (more == NO)
		ic = 0;

	    /* Check for continuation char and delete if found */
	    more = is_continued (line);

	    /* Concatenate line to buffer */
	    safecat (buf, &line[ic], maxbuf);
	}

    } while ( more != comment);

    /* Return EOF if no lines read */
    if (buf[0] == EOS) {
	status = EOF;
    } else {
	status = OK;
    }

    return (status);
}
