#include <string.h>
#include "config.h"
#include "cdbslib.h"
#include "loadfile.h"

#ifdef __VMS
#include <string.h>
#include <ssdef.h>
#include <stsdef.h>
#include <rms.h>
#include <starlet.h>

#else
#include <dirent.h>

#endif

static void	vms_fixname (char *, char *);

/* WILD_EXPAND -- Expand an pattern containing filename wildcards
 *
 * The bulk of this routine is the VMS search function, which finds
 * all filenames matching a pattern. The expansion on Unix machines 
 * is a simple copy, as the Unix shell does the expansion for us.
 *
 * i: pattern	wildcard pattern to be expanded
 * i: maxlist	maximum number if expanded pattern
 * u: ilist	next slot in list of expanded patterns
 * o: list	list of expanded patterns
 */

void wild_expand (const char *pattern, const int maxlist, 
		  int *ilist, char ** list)
{
#ifdef __VMS
    char	ibuf[SZ_FNAME+1];
    char	obuf[SZ_FNAME+1];
    char	fbuf[SZ_FNAME+1];
    char	xbuf[SZ_FNAME+1];
    
    struct FAB 	filfab;    /* FAB for $PARSE and $SEARCH */
    struct NAM 	filnam;    /* NAM for $PARSE and $SEARCH */

#else    
    DIR			*fd;
    struct dirent	*entry;
    char		*name;

#endif

    int		olist = *ilist;
    char	dir[SZ_FNAME+1], root[SZ_FNAME+1], ext[SZ_FNAME+1];

    /* No need for expansion if no wild cards in pattern */

    if (strchr (pattern, '?') == NULL && strchr (pattern, '*') == NULL && 
	*ilist < maxlist) {

	list[(*ilist)++] = strclone (pattern);
	return;
    }

    breakfname (pattern, dir, root, ext, SZ_FNAME);
    strcat (root, ext);


#ifdef __VMS

    /* Set up the VMS i/o blocks */

    filfab = cc$rms_fab;		/* Get a FAB */

    filfab.fab$l_fna = ibuf;		/* Parse filename from IBUF */
    filfab.fab$b_fac = FAB$M_GET; 	/* Only allow $GETs */
    filfab.fab$l_fop = FAB$M_NAM; 	/* Use the NAM block for filename */
    filfab.fab$l_nam = &filnam; 	/* -> NAM block */

    filnam = cc$rms_nam;		/* Get a NAM block */
    filnam.nam$l_esa = xbuf;		/* -> Expanded filespec buffer */
    filnam.nam$b_ess = SZ_FNAME;	/* Expanded filespec buffer length */
    filnam.nam$l_rsa = fbuf;		/* -> Resultant filespec buffer */
    filnam.nam$b_rss = SZ_FNAME;	/* Resultant filespec buffer length */

    /* Validate filename pattern */

    strcpy (ibuf, pattern);
    filfab.fab$b_fns = strlen(ibuf);

    if (sys$parse(&filfab) & STS$M_SUCCESS) {

	/* Look for filenames that match the pattern */

	while (sys$search(&filfab) & STS$M_SUCCESS) {
	    fbuf[filnam.nam$b_rsl] = EOS;

	    if (*ilist < maxlist) {
		vms_fixname (dir, fbuf);
		list[(*ilist)++] = strclone (fbuf);
	    }
	}
    }

#else

    if ((fd = opendir (dir)) != NULL) {
	while (entry  = readdir (fd)) {
	    name = entry->d_name;
	    if (patmatch (root, name))
		list [(*ilist)++] = strclone (name);
	}

	closedir (fd);
    }

#endif

    /* Copy pattern if no expansions performed */

    if (*ilist == olist && *ilist < maxlist)
	list[(*ilist)++] = strclone (pattern);
}

/* VMS_FIXNAME -- Remove directory and change to lower case
 *
 * i: olddir	original directory
 * u: fname	file name
 */

static void vms_fixname (char *olddir, char *fname)
{
    char	dir[SZ_FNAME+1], root[SZ_FNAME+1], ext[SZ_FNAME+1];

    strlcase (fname);
    breakfname (fname, dir, root, ext, SZ_FNAME);

    strcpy (fname, olddir);
    strcat (fname, root);
    strcat (fname, ext);
}
