#include <stdlib.h>
#include "error.h"
#include "c_iraf.h"
#include "xtables.h"
#include "loadfile.h"
#include "cdbslib.h"

/* WRITE_SDASTAB -- Write a load file as an sdas table 
 *
 * i: tab	loadfile table descriptor
 * i: width	width of each column
 * i: output	sdas table name
 */

void write_sdastab (table *tab, int nwidth, int *width, char *output)
{
    IRAFPointer	*tabcol, tp;
    int		nkey, ikey, irow, icol;
    char	*cname, *cval, *keyname, *keyval;

    static char *nilstr = "";

    nkey = nkey_table (tab);
    if (ncol_table (tab) != nwidth)
	cdbs_error (BADWIDTH, "%d", nwidth);

    /* Create sdas table */

    tp = c_tbtopn (output, IRAF_NEW_FILE, 0);
    c_tbpset (tp, TBL_MAXPAR, nkey+5);

    tabcol = (IRAFPointer *) malloc (nwidth * sizeof (IRAFPointer *));

    for (icol = 0; icol < ncol_table (tab); icol ++) {
	cname = get_tab_colname (tab, icol);
	c_tbcdef1 (tp, &tabcol[icol], cname, nilstr, nilstr, -width[icol], 1);
    }

    c_tbtcre (tp);

    /* Copy loadfile header to table */

    for (ikey = 0; ikey < nkey_table (tab); ikey ++) {
	keyname = get_tab_keyname_bynum (tab, ikey);
	keyval = get_tab_keyval_bynum (tab, ikey);
	c_tbhadt (tp, keyname, keyval);
    }

    /* Copy loadfile body to table */

    for (irow = 0; irow < nrow_table (tab); irow ++) {
	for (icol = 0; icol < ncol_table (tab); icol ++) {
	    cval = get_tab_cell_bynum (tab, icol, irow);
	    c_tbeptt (tp, tabcol[icol], irow+1, cval);
	}
    }

    /* Close table */

    c_tbtclo (tp);
    free (tabcol);
}
