#include <string.h>
#include "alist.h"
#include "error.h"
#include "config.h"
#include "system.h"
#include "cdbslib.h"

#define  MAXITER		8

static alist	*xlate_init (char *);

/* XLATE_FNAME -- Translate an iraf virtual file name into an OS file name
 *
 * i: fname	iraf file name
 * o: osfn	operating system file name
 * i: maxch	maximum length of os file name
 */

void xlate_fname (char *fname, char *osfn, int maxch)
{
    int			iter;
    char		*dollar, *newname;
    char		name1[SZ_FNAME+1], name2[SZ_FNAME+1];
    char		dir[SZ_FNAME+1], root[SZ_FNAME+1], ext[SZ_FNAME+1];

    static char		*directory = DIRECTORY_NAME;
    static alist	*dirlist = NULL;

    /* Read the directory translation file 
     * on the first pass thru this function
     */

    if (dirlist == NULL)
	dirlist = xlate_init (directory);

    /* If a filename contains a dollar sign, everything in front of
     * of the dollar sign gets translated by looking up the string 
     * in the directory translation file. This is done repeatedly 
     * until no more translations are found or the maximum number
     * of iterations is exceeded
     */

    iter = 0;
    safecopy (name1, fname, SZ_FNAME);

    while ((dollar = strchr (name1, '$')) != NULL) {
	/* Check number of iterations */

	iter ++;
	if (iter > MAXITER)
	    cdbs_error (MAXDEF, "%s", fname);

	/* Look up translation */

	*dollar = EOS;
	newname = find_alist (dirlist, name1);
	if (newname == NULL)
	    cdbs_error (NOTRANS, "%s", name1);

	/* Copy translation to new string and append everything 
	 * following the translation
	 */

	safecopy (name2, newname, SZ_FNAME);
	safecat (name2, dollar+1, SZ_FNAME);

	safecopy (name1, name2, SZ_FNAME);
    }

    /* If the file name is a relative file name, make it a
     * subdirectory of the top level cdbs directory
     */

    if (name1[0] == '/') {
	safecopy (osfn, name1, maxch);
    } else {
	breakfname (name1, dir, root, ext, SZ_FNAME);
	addsubdir (CDBSDIR, dir, osfn, maxch);
	safecat (osfn, root, maxch);
	safecat (osfn, ext, maxch);
    }
}

/* XLATE_INIT -- Read the directory file inot an associative list
 *
 * i: directory		directory file name
 */

static alist *xlate_init (char *directory)
{
    FILE	*fd;
    alist	*list;
    char	*field[2];
    char	buf[SZ_LINE+1];

    /* Open the directory file */

    fd = fopen (directory, "r");
    if (fd == NULL)
	cdbs_error (NOTOPEN, "%s", directory);

    /* Read each line and split it into two fields
     * The first field is the logical name and
     * the second is the translation
     */

    list = create_alist ();
    while (rdlines (fd, buf, SZ_LINE) == OK) {
	strsplit (' ', buf, field, 2);
	if (field[1] != EOS)
	    add_alist (list, field[0], field[1]);
    }

    fclose (fd);
    return (list);
}
