#include "error.h"
#include "cdbslib.h"
#include "loadfile.h"
#include "expload.h"

/* TASK -- Main routine for the expload task */

void task (int argc, char **argv)
{
    char	*input, *output, *rules;
    table	*itab, *otab, *target, *action;

    /* Check number of arguments and assign to program variables */

    if (argc != 4)
        cdbs_error (USAGE, "%d", argc-1);

    input = argv[1];
    output = argv[2];
    rules = argv[3];

    /* Read input loadfile. Create ouput loadfile 
     * with the same layout and header
     */

    itab = read_loadfile (input);
    if (get_tab_colnum (itab, "EXPANSION_NUMBER") >= 0)
        cdbs_error (EXPANDED, "%s", input);

    otab = create_table ();

    copy_layout (itab, otab, "EXPANSION_NUMBER");
    copy_header (itab, otab);

    /* Create the target and action table from the rules file.
     * The target table contains the fields that match the input table.
     * The action table contains the rows used to expand a row in the
     * input table when a match is found.
     */

    target = create_table ();
    action = create_table ();

    parse_rules (rules, itab, target, action);

    /* Use the target and action tables to expand the rows in the input
     * table into the output table
     */

    use_rules (itab, otab, target, action);

    /* Write the output file */

    write_loadfile (output, otab);

    free_table (target);
    free_table (action);
}
 
