%{
#include <stdlib.h>
#include "config.h"
#include "error.h"
#include "cdbslib.h"
#include "loadfile.h"
#include "parse.h"

/* Global variables used by the parser */

int	xline; 			/* Current line number in rule file */
table	*xtarget, *xaction;	/* Target and action table descriptors */

/* YYPARSE -- Parser for rule file grammar */

static int	first = 0;
static int	ntarget = 0;
static int	naction = 0;
static int	missing = NO;

%}

%union {
    char *strval;
    int  intval;
}

%token	<intval> IMPLY END OR AND EQUALS STRING BADTOK
%type	<strval> name

%%

file: 	rule |
	file rule {
		; 
	}
	;

rule:	tgt_phrase IMPLY act_clause END {
		if (missing == NO) {
		    put_tab_cell (xtarget, "_FIRST", ntarget, itoa (first));
		    put_tab_cell (xtarget, "_LAST", ntarget, itoa (naction-1));

		    first = naction;
		    ntarget ++;
		} else {
		    missing = NO;
		    trunc_table (xtarget, ntarget);
		    trunc_table (xaction, first);
		}
	}
	;

act_clause: act_phrase |
	act_clause OR act_phrase {
		;
	}
	;


act_phrase: act_term |
	 act_phrase AND act_term {
		if (missing == NO) {
		    move_tabrow (xaction, naction, xaction, naction - 1);
		    trunc_table (xaction, naction);
		    naction --;
		}
	}
	;

act_term: name EQUALS name {
		if (get_tab_colnum (xaction, $1) == ERR) {
		    missing = YES;
		} else if (missing == NO) {
		    put_tab_cell (xaction, $1, naction, $3);
		    naction ++;
		}
		free ($1);
		free ($3);
	}
	;
	
tgt_phrase: tgt_term |
	tgt_phrase AND tgt_term {
		;
	}
	;

tgt_term: name EQUALS name {
		if (get_tab_colnum (xtarget, $1) == ERR) {
		    missing = YES;
		} else if (missing == NO) {
		    put_tab_cell (xtarget, $1, ntarget, $3);
		}
		free ($1); 
		free ($3);
	}
	;

name:	STRING {
		$$ = strclone (yytext);
		unquote ($$);
		strucase ($$);
	}
	;

%%

yyerror (const char *msg)
{
    cdbs_error (SYNTAX, "Last token read (%s) on line %d", 
		yytext, xline);
}

