#include <string.h>
#include "getobsmode.h"

/* GETSTISMODE -- Get the observation mode for a stis observation
 *
 * This code is base on calstis/cs1/photmode.c and should track
 * changes in it.
 *
 * i: root	observation rootname
 * o: obsmode	observation mode
 */

void getstismode (char *root, char *obsmode)
{
    int		ccdgain, cenwave;
    char	field[SZ_FIELD+1];
    char	detector[SZ_FIELD+1], aperture[SZ_FIELD+1];
    char	opt_elem[SZ_FIELD+1], obstype[SZ_FIELD+1];

    /* Retrieve observation mode fields from the database */

    if (qrystismode (root, detector, aperture, opt_elem, obstype, 
		     &ccdgain, &cenwave) == NOMATCH) {
	obsmode[0] = '\0';

    } else {
	/* Put the instrument name and the aperture in the obsmode */

	strcpy (obsmode, "STIS,");
	strcat (obsmode, aperture);

	/* If the detector is a ccd, add the gain to the obsmode */

	if (strcmp (detector, "CCD") == 0) {
	    sprintf (field, ",A2D%d", ccdgain);
	    strcat (obsmode, field);
	}

	/* If the optical element is a mirror, add it to the obsmode */

	if (strncmp (opt_elem, "MIR", 3) != 0) {
	    strcat (obsmode, ",");
	    strcat (obsmode, opt_elem);
	}

	/* Add the appropriate detector string to the obsmode */

	if (strcmp (detector, "CCD") == 0)
	    strcat (obsmode, ",CCD");
	else if (strcmp (detector, "NUV-MAMA") == 0)
	    strcat (obsmode, ",NUVMAMA");
	else if (strcmp (detector, "FUV-MAMA") == 0)
	    strcat (obsmode, ",FUVMAMA");

	/*  Add the central wavelength if this is a spectroscopic mode */

	if (strcmp (obstype, "SPECTROSCOPIC") == 0) {
	    sprintf (field, ",C%d", cenwave);
	    strcat (obsmode, field);
	}
    }
}
