#include <string.h>
#include "error.h"
#include "datafile.h"
#include "config.h"
#include "cdbslib.h"
#include "loadfile.h"
#include "getref.h"

#define  OUTPUT		1
#define  TOPLINK	2
#define  SUMLINK	3
#define  TXTLINK	4
#define  TASKURL	5

/* OUTPUT_HTML -- Produce html output from a table
 *
 * i: tab	table descriptor
 */

void output_html (char *template, table *tab)
{
    FILE	*fp;
    char	*var;
    int		html, icol, irow;
    char	*root, *reffile, *value;

    static char *nbsp = "&nbsp";
    static char	*varlist = "output|toplink|sumlink|txtlink|taskurl";

    fp = fopen (template, "r");
    if (fp == NULL)
	cdbs_error (NOTOPEN, "%s", template);

    root = get_option ("root");
    html = yorn (get_option ("HTML"));
    reffile = get_option ("reffile");

    /* Print the html response header if called as a cgi script */

    if (html == YES)
	printf ("Content-type: text/html\n\n");

    while ((var = html_template (fp)) != NULL) {
	switch (strmatch (var, varlist)) {
	case OUTPUT:
	    /* Print output in html table format */

	    printf ("<TABLE BORDER CELLPADDING=10> \n");

	    /* Print the title line */

	    for (icol = 0; icol < ncol_table(tab); icol ++)
		printf ("<TH> %s </TH> \n", get_tab_colname (tab, icol));

	    /* Print the cells in the table */

	    for (irow = 0; irow < nrow_table(tab); irow ++) {
		printf ("<TR> \n");
		for (icol = 0; icol < ncol_table(tab); icol ++) {
		    value = get_tab_cell_bynum (tab, icol, irow);
		    if (value[0] == EOS)
			value = nbsp;

		    printf ("<TD> %s </TD> \n", value);
		}

		printf ("</TR> \n");
	    }

	    printf ("</TABLE>");
	    break;

	case TOPLINK:
	    /* Print an anchor that will generate the top level form */

	    printf (mkanchor ("", "", "", ""));
	    break;

	case SUMLINK:
	    /* Print an anchor that will perform the summary query */

	    printf (mkanchor ("", root, "", ""));
	    break;

	case TXTLINK:
	    /* Print an anchor that will produce ascii output */

	    printf (mkanchor ("", root, reffile, "yes"));
	    break;
	case TASKURL:
	    /* Print the url of this task */

	    printf (GETREFURL);
	    break;
	} 
    }

    fclose (fp);
}
