#include "ostdb.h"
#include "dbquery.h"
#include "loadfile.h"
#include "cdbslib.h"
#include "getref.h"

/* QRY_HASROOT -- Perform a detail query when there is a rootname
 *
 * i: qry	database connection info
 * i: root	observation name root
 * i: reffile	reference file name
 * i: cdbsname	observation mode fields in the cdbs database
 * i: dadsname	observation mode fields in the cdbs database
 */

table *qry_hasroot (context *qry, char *root, char *reffile, 
		    char **cdbsname, char **dadsname) 
{
    table	*tab;
    int		code, irow, ivar, text;
    char	**alist, **blist, **mlist;
    char	dir[SZ_FNAME+1], body[SZ_FNAME+1], ext[SZ_FNAME+1];
    char	obset[SZ_FNAME+1], refname[SZ_FNAME+1];

    static char *hasrootfmt = "select {[, ]a.^}, {[, ]b.^}, {[, ] b.^} from "
	"^ a, ^ b, ^..^ c where a.file_name = ^ and b.file_name = ^ and "
	"a.expansion_number = b.expansion_number {and b.^ = c.^ }and "
	"c.^ = ^ order by a.expansion_number";

    code = get_icode_ref (reffile);
    safecopy (refname, strucase (enquote (reffile)), SZ_FNAME);

    breakfname (root, dir, body, ext, SZ_FNAME);
    safecopy (obset, strucase (enquote(body)), SZ_FNAME);

    /* Set up the query */

    ostdb_query_setup (qry->connection, "qry_hasroot", 1, STDB_SQL,
		       qry->server, qry->cdbs_db, db_error);

    alist = bind_qryvars (qry->connection, detail_filecol);
    blist = bind_qryvars (qry->connection, detail_rowcol);
    mlist = bind_qryvars (qry->connection, cdbsname);

    build_qry (qry->connection, hasrootfmt, detail_filecol, cdbsname, 
	       detail_rowcol, cdbsfile[code], cdbsrow[code], qry->dads_db, 
	       dadstab[code], refname, refname, cdbsname, dadsname, 
	       obsfield[code], obset);

    /* Execute query and store results in output table */

    tab = create_table ();

    irow = 0;
    text = yorn (get_option ("text"));

    if (ostdb_get_exec (qry->connection) == STDB_CONTINUE) {
	/* Write fields from file level relation */

	for (ivar = 0; detail_filecol[ivar][0] != EOS; ivar ++) {
	    clean_data (alist[ivar]);

	    put_tab_cell (tab, "FIELDNAME", irow, detail_filecol[ivar]);

	    if (text == NO && 
		strcmp (detail_filecol[ivar], "comparison_file_name") == 0 &&
		is_reffile (alist[ivar]) == YES) {
		put_tab_cell (tab, "VALUE", irow, 
			      mkanchor (alist[ivar], root, alist[ivar], ""));
		    
	    } else {
		put_tab_cell (tab, "VALUE", irow, alist[ivar]);
	    }
	    irow ++;
	}

	/* Write observation mode fields */

	for (ivar = 0; cdbsname[ivar][0] != EOS; ivar ++) {
	    clean_data (mlist[ivar]);

	    put_tab_cell (tab, "FIELDNAME", irow, cdbsname[ivar]);
	    put_tab_cell (tab, "VALUE", irow, mlist[ivar]);
	    irow ++;
	}

	/* Write fields from row level relation */

	for (ivar = 0; detail_rowcol[ivar][0] != EOS; ivar ++) {
	    clean_data (blist[ivar]);

	    put_tab_cell (tab, "FIELDNAME", irow, detail_rowcol[ivar]);
	    put_tab_cell (tab, "VALUE", irow, blist[ivar]);
	    irow ++;
	}
    }

    /* Free memory and close query */

    free_qryvars (alist);
    free_qryvars (blist);
    free_qryvars (mlist);
    stdb_close_query (qry->connection);

    return (tab);
}


