#include <stdlib.h>
#include "error.h"
#include "config.h"
#include "cdbslib.h"
#include "loadfile.h"
#include "readroot.h"

/* START_READ_ROOT -- Create an iterator to loop over list of root names
 *
 * i: root	Value of the root parameter
 */

rooter *start_read_root (char *root)
{
    rooter	*rp;

    rp = malloc (sizeof (rooter));

    if (root[0] == '@') {
	rp->type = IN_FILE;
	rp->ptr.file = fopen (&root[1], "r");
	if (rp->ptr.file == NULL)
	    cdbs_error (NOTOPEN, "%s", &root[1]);

    } else {
	rp->type = IN_STRING;
	rp->ptr.str = root;
    }

    return (rp);
}

/* END_READ_ROOT -- Free root iterator structure
 *
 * u: rp	root iterator
 */

void end_read_root (rooter *rp)
{
    if (rp->type == IN_FILE) 
	fclose (rp->ptr.file);

    free (rp);
}

/* READ_ROOT -- Read the next observation set from the root structure
 *
 * u: rp	root iterator
 */

char *read_root (rooter *rp)
{
    int		ic;
    static char	root[SZ_FNAME+1];
    char	param[SZ_FNAME+1];

    if (rp->type == IN_FILE) {
	/* Read the observation set name from a file */

	if (rdlines (rp->ptr.file, param, SZ_FNAME) == EOF)
	    return (NULL);

	strclean (param);

    } else {
	/* Skip leading delimeters */

	while (IS_DELIM(*rp->ptr.str) && *rp->ptr.str != EOS)
	    rp->ptr.str ++;

	/* Copy characters into buffer until delimeter is seen */

	for (ic = 0; ! IS_DELIM(*rp->ptr.str); ic ++)
	    param[ic] = *(rp->ptr.str ++);

	param[ic] = EOS;

	/* Check for end of string */

	if (ic == 0)
	    return (NULL);
    }

    /* Remove any extension a clueless user may have put on the root name */

    xtract_root (param, root, SZ_FNAME);
    strlcase (root);
    return (root);
}
