#include <string.h>
#include "c_iraf.h"
#include "xtables.h"
#include "error.h"
#include "config.h"
#include "cdbslib.h"
#include "loadfile.h"
#include "mkcomptab.h"

/* GETTHRULIST -- Create a list of throughput column names
 *
 * i: fname	throughput table name
 * o: collist	list of throughput columns
 */

void getthrulist (char *fname, textbuf *collist) 
{
    IRAFPointer	tp, cp;
    int		icol, ic, nc;
    char	*hash, *s1, *s2;
    char	osfn[SZ_FNAME+1], colname[SZ_STRING+1];

    xlate_fname (fname, osfn, SZ_FNAME);
    tp = c_tbtopn (osfn, IRAF_READ_ONLY, 0);
    if (c_iraferr() != 0)
	cdbs_error (NOTOPEN, "%s", fname);

    /* Look at each column in the table. 
     * Save the throughput columns in the list
     */

    for (icol = 1; (cp = c_tbcnum (tp, icol)) != 0; icol ++) {
	c_tbcigt (cp, TBL_COL_NAME, colname, SZ_STRING);
	strlcase (colname);

	/* Skip wavelength and error columns */

	if (strcmp (colname, "wavelength") == 0)
	    continue;

	if (strcmp (colname, "error") == 0)
	    continue;

	/* More detailed check for error columns in multi-throughput
	 * tables. Non-parameterized error columns end in "_err"
	 */

	hash = strchr (colname, '#');
	if (hash == NULL) {
	    ic = strlen (colname);
	    if (ic >= 4) {
		ic = ic - 4;
		if (strcmp (&colname[ic], "_err") == 0)
		    continue;
	    }

	} else {
	    /* Squeeze out the parameters in parameterized columns */

	    s2 = hash + 1;
	    for (s1 = s2; *s1 != EOS; s1 ++) {
		if (*s1 == '#')
		    *(s2 ++) = '#';
	    }
	    *s2 = EOS;

	    /* Check for error column */

	    nc = s2 - hash;
	    nc = nc + 4;
	    ic = strlen (colname);
	    if (ic >= nc) {
		ic = ic - nc;
		if (strncmp (&colname[ic], "_err###", nc) == 0)
		    continue;
	    }
	}

	/* Don't add throughput column if already on the list */

	if (find_text (collist, colname) != BAD)
	    continue;

	/* If throughput column not on the list, add it */

	add_text (collist, colname);
    }

    c_tbtclo (tp);
}
