#include <stdio.h>
#include "error.h"
#include "config.h"
#include "cdbslib.h"
#include "loadfile.h"
#include "reffile.h"
#include "mkload.h"

/* MKLOAD -- Create a load file from a reference file 
 *
 * i: fname	reference file name
 */

void mkload (table *look, char *fname)
{
    table	*tab;
    reffile	*ref;
    int		row;
    char	ldname[SZ_FNAME+1];
    char	*type, *reftype, *instrument;

    /* Read podps type and instrument fro the lookup table */

    if ((row = find_lookup (look, fname)) == ERR) {
	cdbs_warn (NOLOOK, "%s", fname);
	return;
    }

    instrument = get_tab_cell (look, "instrument", row);
    reftype = get_tab_cell (look, "reftype", row);
    type = get_tab_cell (look, "filetype", row);

    ref = open_reffile (fname, type, "r");
    if (ref == NULL) {
	cdbs_warn (NOTOPEN, "%s", fname);
	return;
    }

    if (kind_reffile (ref) == LOADFILE) {
	cdbs_warn (NOLOAD, "%s", fname);

    } else {
	tab = create_table ();

	mkload_header (tab, ref, instrument, reftype);
	mkload_body (tab, ref, instrument, reftype);
	mkload_compfile (tab, ref, instrument, reftype);

	mkload_name (ldname, fname, SZ_FNAME);
	if (write_loadfile (ldname, tab) == BAD) {
	    cdbs_warn (NOWRITE, "%s", ldname);
	} else {
	    cdbs_info (WFILE, "%s", ldname);
	}
	free_table (tab);
    }

    close_reffile (ref);
}
