#include <stdlib.h>
#include "config.h"
#include "alist.h"
#include "reffile.h"
#include "cdbslib.h"
#include "loadfile.h"
#include "query.h"
#include "mkload.h"

#define  SZ_OBSMODE	500

/* MKLOAD_COMPFILE -- Write comparson file and useafter date to header
 *
 * i: tab		table descriptor
 * i: ref		reference file descriptor
 * i: instrument	instrument name
 * i: reftype		reference file type
 */

void mkload_compfile (table *tab, reffile *ref, 
		      char *instrument, char *reftype)
{
    double	now;
    char	*useafter;
    int		hasdate;
    context	*qry;
    alist	*obsmode, *dbvars;
    char	obsquery[SZ_OBSMODE+1];
    char	compfile[SZ_FNAME+1], date[SZ_FNAME+1];

    obsmode = create_alist ();
    dbvars = create_alist ();

    /* Set the strings to be used in the database query */

    add_alist (dbvars, "inst", instrument);
    add_alist (dbvars, "reftype", enquote(reftype));

    /* Read the useafter date from the table. 
     * If not found, set it to the current time
     */

    useafter = get_tab_key (tab, "USEAFTER_DATE");
    if (useafter == NULL || useafter[0] == EOS) {
	hasdate = NO;
	useafter = (char *) malloc (SZ_STRING+1);

	now = get_now ();
	put_sybase_date (now, useafter, SZ_STRING);
	add_alist (dbvars, "useafter", enquote(useafter));
	free (useafter);
    } else {
	hasdate = YES;
	add_alist (dbvars, "useafter",  enquote(useafter));
    }

    /* Read the observation mode from the table into an associative array 
     * then convert it into a query string
     */

    read_obsmode (tab, obsmode);
    if (length_alist (obsmode) > 0) {
	set_obsquery (obsmode, "b", obsquery, SZ_OBSMODE);
	add_alist (dbvars, "obsmode", obsquery);
    }

    /* Query the database for the comparison file and its useafter date */

    compfile_query (dbvars, compfile, date, SZ_FNAME);

    /* Write to the table, if found */

    if (compfile[0] != EOS) {
        strlcase (compfile);
	put_tab_key (tab, "COMPARISON_FILE", compfile);

	if (hasdate == NO)
	    put_tab_key (tab, "USEAFTER_DATE", date);
    }

    free_alist (obsmode);
    free_alist (dbvars);
}
