#include <string.h>
#include <stdlib.h>
#include "ostdb.h"
#include "dbquery.h"
#include "cdbslib.h"
#include "loadfile.h"
#include "config.h"
#include "mkload.h"

/* OBSMODE_QRY -- Retrieve observation mode from the database
 *
 * i: instrument	instrument name
 * i: reftype		reference file type
 * o: obsmode		list of mode fields
 */

void obsmode_qry (char *instrument, char *reftype, textbuf *obsmode)
{
    static char *obsmode_fmt = 
"select a.modes from cdbs_mode a where a.instrument = ^ \
and a.reference_file_type = ^";

    context	*qry;
    char	*inst, *type;
    char	field[SZ_STRING+1];

    /* Initialize query and bind mode field variable */

    qry = init_query ();
    ostdb_query_setup (qry->connection, "obsmode_qry", 1, STDB_SQL, 
		       qry->server, qry->cdbs_db, NULL);

    stdb_bind_string (qry->connection, "modes", field, SZ_STRING);

    /* Build query and send to database */

    /* Checking for the instrument in both upper and lower case
     * is a temporary kludge that will be removed when the instrument
     * field in cdbs_mode is fixedand put in all upper case
     */

    inst = strclone (strucase (enquote (instrument)));
    type = strclone (strucase (enquote (reftype)));

    build_qry (qry->connection, obsmode_fmt, inst, type);

    /* Retrieve list of mode fields from database and store in text buffer */

    init_text (obsmode, 20, 200);
    while (ostdb_get_exec (qry->connection) == STDB_CONTINUE) {
        strclean (field);
        strucase (field);
	add_text (obsmode, field);
    }

    /* Close database connection and free memory */

    stdb_close_query (qry->connection);
    free_query (qry);
    free (inst);
    free (type);

}

