#include <stdio.h>
#include <stdlib.h>
#include "alist.h"
#include "cdbslib.h"
#include "loadfile.h"
#include "config.h"
#include "mkload.h"

/* SET_OBSQUERY -- Convert obsmode list into a query
 *
 * i: obsmode	observation mode list
 * i: dbtable	database table name
 * o: obsquery	where clause of sql query
 * i: maxch	maximum query length
 */

void set_obsquery (alist *obsmode, char *dbtable, char *obsquery, int maxch)
{
    int		ivar;
    char	*term, *key, *value, *obscol, *obsval;

    /* The query is a series of terms joined by "and".
     * Each term in the query has the form "<dbtable>.<obscol> = <value>".
     */

    obsquery[0] = EOS;
    term = (char *) malloc (maxch + 1);

    for (ivar = 0; each_alist (obsmode, ivar, &key, &value) == OK; ivar ++) {
	/* The colun name is in lower case. The value is in upper case */

	obscol = strclone (key);
	obsval = strclone (value);

	strlcase (obscol);
	strucase (obsval);

	/* Join terms with "and" */

	if (ivar > 0)
	    safecat (obsquery, " and ", maxch);

	/* String values are enclosed in quotes */

	if (is_number (obsval) == NO) {
	    sprintf (term, "%s.%s = '%s\'", dbtable, obscol, obsval);
	} else {
	    sprintf (term, "%s.%s = %s", dbtable, obscol, obsval);
	}

	safecat (obsquery, term, maxch);

	free (obscol);
	free (obsval);
    }

    free (term);
}
