#include <stdlib.h>
#include <string.h>
#include "config.h"
#include "cdbslib.h"
#include "query.h"

/* MATCH_DBCOLS -- Find database columns matching a list of patterns
 * 
 * i: allcols	array of database columns to be matched
 * i: cfield	list of patterns
 * i: negate	reverse sense of match?
 * i: itab	index of table columns are from
 * u: ncol	number of matched columns
 * u: qcollist	array of matched column names
 */

void match_dbcols (char **allcols, char **cfield, int negate, 
		  int itab, int *ncol, char **qcollist)
{
    char	alias[2];
    char	*pattern[2];
    char	column[SZ_STRING+1];
    int		ifield, icol, mcol, *match;

    if (count_zlist (cfield) == 0) {
      /* If the pattern list is empty, copy all columns to output arrat */

        for (icol = 0; allcols[icol][0] != EOS; icol ++)
	    qcollist[(*ncol)++] = qualname (allcols[icol], itab);

    } else {
      /* Set table alias */

      alias[0] = 'a' + itab;
      alias[1] = EOS;

      /* Allocate flag array to indicate if column is matched */

	mcol = count_zlist (allcols);
	match = (int *) calloc (mcol, sizeof (int)); /* assumes NO is 0 */

	/* Loop over patterns, looking for matches */

	for (ifield = 0; cfield[ifield][0] != EOS; ifield ++) {
	    /* Only use unqualified part of column name */

	    safecopy (column, cfield[ifield], SZ_STRING);
	    strsplit ('.', column, pattern, 2);

	    /* Divide column into its two parts: 
	     * table alias and column name 
	     */

	    if (pattern[1][0] == EOS) {
	      /* Move column name into its array if there is no alias */
	        pattern[1] = pattern[0];

	    } else if (strcmp (pattern[0], alias) != 0) {
	        /* Skip column if its alias does not match the table alias */
	        continue;
	    }

	    if (strchr (pattern[1], '*') != NULL ||
		strchr (pattern[1], '?') != NULL   ) {

	        /*  Use pattern matching function if column name
		 *  contains wildcard characters
		 */

	        for (icol = 0; allcols[icol][0] != EOS; icol ++) {
		    if (patmatch (pattern[1], allcols[icol]))
		        match[icol] = YES;
		}

	    } else {
	        /* If no wildcards in column name, do simple string match */

	        for (icol = 0; allcols[icol][0] != EOS; icol ++) {
		    if (strcmp (pattern[1], allcols[icol]) == 0) {
		        match[icol] = YES;
			break;
		    }
		}
	    }
	}

	/* If negate flag set, invert array of matched columns */

	if (negate == YES) {
	    for (icol = 0; icol < mcol; icol ++)
	        match[icol] = match[icol] == YES ? NO : YES;
	}

	/* Copy matched columns to out put array */

	for (icol = 0; icol < mcol; icol ++) {
	    if (match[icol] == YES)
	        qcollist[(*ncol)++] = qualname (allcols[icol], itab);
	}

	free (match);
    }
}
