#include <ctype.h>
#include <stdio.h>
#include <stdlib.h>
#include "config.h"
#include "error.h"
#include "qrylex.h"

/* QRYLEX_CLOSE -- Free structure used by lexer
 *
 * lx		i: lexer structure
 */

void qrylex_close (qlexer *lx) 
{
    if (lx->file != NULL)
        fclose (lx->file);

    free (lx->line);
    free (lx);
}

/* QRYLEX_INIT -- Initialize structure used b lexer
 *
 * ftnexp	i: fortran expression to be lexed
 */

qlexer *qrylex_init (char *ftnexp)
{
    qlexer	*lx;

    lx = (qlexer *) malloc (sizeof (qlexer));
    lx->line = (char *) malloc (SZ_LINE+1);

    if (ftnexp[0] == '@') {
	lx->file = fopen (&ftnexp[1], "r");
	if (lx->file == NULL)
	    cdbs_error (NOTOPEN, "%s", &ftnexp[1]);

	lx->line[0] == EOS;

    } else {

        lx->file = NULL;
        safecopy (lx->line, ftnexp, SZ_LINE);
    }

    lx->ch = lx->line;
    return (lx);
}

/* QRYLEX_NEXT -- Retrieve next token from lexer
 *
 * lx		i: lexer structure
 * token	o: token retrieved
 * maxch	i: max length of token
 */

int qrylex_next (qlexer *lx, char *token, int maxch)
{
    char	limit;
    double	value;
    int		ic, type;
    char	*endch;

    /* Skip blanks. If line is exhausted, read next line */

    while (*lx->ch <= BLANK) {
        if (*lx->ch != EOS) {
	    *lx->ch ++;

	} else {
	    if (lx->file == NULL) {
	        break;
	    } else {
	        lx->ch = lx->line;
		if (fgets (lx->line, SZ_LINE, lx->file) == NULL) {
		    lx->line[0] = EOS;
		    break;
		}
	    }
	}
    }

    ic = 0;
    if (*lx->ch == EOS) {
        type = QRY_END;

    } else if (*lx->ch == SQUOTE || *lx->ch == DQUOTE) {
      /* Quoted string. Copy characters until matching quote */

        type = QRY_STRING;
	limit = *lx->ch ++;
	token[ic++] = SQUOTE;

	while (ic < maxch && *lx->ch != EOS && *lx->ch != limit)
	    token[ic++] = *lx->ch ++;


	if (*lx->ch != limit) {
	    token[ic] = EOS;
	    cdbs_error (NOQUOTE, "%s", token);
	}

	token[ic++] = SQUOTE;
	lx->ch ++;

    } else if (isalpha (*lx->ch)) {
        /* Identifier. Copy characters until non-id char */

        type = QRY_IDENT;
	while (ic < maxch && ISIDCHAR (*lx->ch)) {
	    if (*lx->ch == DOT && ic != 1)
	        break;

	    token[ic++] = tolower(*lx->ch++);
	}

    } else if (isdigit (*lx->ch)) {
        /* Number. Use strtod to find end of number */

        type = QRY_CONSTANT;
	value = strtod (lx->ch, &endch);

	while (ic < maxch && lx->ch < endch)
	    token[ic++] = *lx->ch ++;


    } else if (*lx->ch == DOT) {
      /* Token starting with a dot can be a constant or a symbol
       * Peek one char ahead to check
       */

        if (isdigit (*(lx->ch+1))) {
	    /* Number. Use strtod to find end of number */

	    type = QRY_CONSTANT;
	    value = strtod (lx->ch, &endch);

	    while (ic < maxch && lx->ch < endch)
	        token[ic++] = *lx->ch ++;

	} else {
	    /* Symbol. Copy characters until end of symbol */

	    type = QRY_SYMBOL;
	    while (ic < maxch && (isalpha(*lx->ch) || *lx->ch == DOT))
	        token[ic++] = *lx->ch ++;

	    if (token[ic-1] != DOT) {
	        token[ic] = EOS;
		cdbs_error (NODOT, "%s", token);
	    }
	}

    } else {
      /* Anything else must be a symbol */

        type = QRY_SYMBOL;
	while (ic < maxch && *lx->ch > BLANK) {
	    if (ISIDCHAR(*lx->ch) || *lx->ch == SQUOTE || *lx->ch == DQUOTE)
	        break;

	    token[ic++] = *lx->ch ++;
	}
    }

    /* Check to see if token overfills buffer */

    token[ic] = EOS;
    if (ic > maxch)
        cdbs_error (TOOLONG, "%s", token);

    /* Return token type */

    return (type);
}

