#include <string.h>
#include "error.h"
#include "datafile.h"
#include "config.h"
#include "cdbslib.h"
#include "loadfile.h"
#include "query.h"

#define  OUTPUT		1
#define  TOPLINK	2
#define  TXTLINK	3
#define  TASKURL	4

/* QRYOUT_HTML -- Produce html output  for the query task
 *
 * i: tab	table descriptor
 */

void qryout_html (char *template, table *tab)
{
    FILE	*fp;
    char	*var;
    int		html, title, icol, irow, iop;
    char	params[SZ_LIST+1];
    char	*option, *value;

    static char *nbsp = "&nbsp";
    static char *omit = "v|text|html";
    static char	*varlist = "output|toplink|txtlink|taskurl";

    /* Get task parameters */

    html = yorn (get_option("HTML"));
    title = yorn(get_option("title"));

    /* Open the html template file */

    fp = fopen (template, "r");
    if (fp == NULL)
	cdbs_error (NOTOPEN, "%s", template);

    /* Print the html response header if called as a cgi script */

    if (html == YES)
	printf ("Content-type: text/html\n\n");

    while ((var = html_template (fp)) != NULL) {
	switch (strmatch (var, varlist)) {
	case OUTPUT:
	    /* Print output in html table format */

	    printf ("<TABLE BORDER CELLPADDING=10> \n");

	    /* Print the title line */

	    if (title == YES) {
	        for (icol = 0; icol < ncol_table(tab); icol ++)
		    printf ("<TH> %s </TH> \n", get_tab_colname (tab, icol));
	    }

	    /* Print the cells in the table */

	    for (irow = 0; irow < nrow_table(tab); irow ++) {
		printf ("<TR> \n");
		for (icol = 0; icol < ncol_table(tab); icol ++) {
		    value = get_tab_cell_bynum (tab, icol, irow);
		    if (value[0] == EOS)
			value = nbsp;

		    printf ("<TD> %s </TD> \n", value);
		}

		printf ("</TR> \n");
	    }

	    printf ("</TABLE>");
	    break;

	case TOPLINK:
	    /* Print an anchor that will generate the top level form */

	    printf ("<A href=\"%s\">", QUERYURL);
	    break;

	case TXTLINK:
	    /* Print an anchor that will produce ascii output */

	    printf ("<A href=\"%s?", QUERYURL);

	    for (iop = 0; each_option (iop, &option, &value) != ERR; iop ++) {
	        if (strmatch (option, omit) == 0) {
		    cgi_encode (option, value, params, SZ_LIST);
		    printf ("%s&", params);
	        }
	    }

	    printf ("text=yes\">");
	    break;

	case TASKURL:
	    /* Print the url of this task */

	    printf (QUERYURL);
	    break;
	} 
    }

    fclose (fp);
}
