#include "ostdb.h"
#include "error.h"
#include "cdbslib.h"
#include "loadfile.h"
#include "dbquery.h"
#include "query.h"

/* QUERY -- Query one or more database tables
 * 
 */

table * query (void) 
{
    table	*tab;
    context	*qry;
    int		unique, ucase, text, html, irow, icol;
    char	colbuf[SZ_LIST+1], sqlqual[SZ_LIST+1];
    char	*tabname, *qualifier, *columns, *dbase, *distinct;
    char	**qcollist, **tablist, **aliases, **collist, **colvar;

    static char *qryfmt = "select ^ {[, ] ^ ^} from {[, ] ^ ^} where ^";

    /* Retrieve the arguments query was run with */

    tabname = get_option ("table");
    qualifier = get_option ("qual");
    columns = get_option ("columns");
    dbase = get_option ("dbase");
    unique = yorn(get_option ("unique"));
    ucase = yorn (get_option ("ucase"));
    text = yorn (get_option ("text"));
    html = yorn (get_option ("HTML"));

    if (html == YES) {
        if (lead_char (columns) == '@')
	   cdbs_error (NOLIST, "%s", columns);

        if (lead_char (qualifier) == '@')
	   cdbs_error (NOLIST, "%s", qualifier);
    }

    /* Initialize database access */

    qry = init_query ();
    if (dbase[0] == EOS)
        dbase = qry->cdbs_db;

    /* Read list of columns into a buffer */

    read_collist (columns, colbuf, SZ_LIST);

    /* Get column names for this table */

    qcollist = get_collist (qry, dbase, tabname, colbuf);

    /* Build strings to be inserted into query */

    if (unique == NO) {
        distinct = "";
    } else {
        distinct = "distinct";
    }

    tablist = split_list (tabname, ',');
    aliases = alias_tabname (tablist);
    collist = strip_collist (qcollist);

    /* Create ouput table */

    tab = create_table ();
    settabcols (tab, collist);

    /* Convert query qualifier from fortran syntax to sql */

    ftn_to_sql (tablist, qualifier, sqlqual, SZ_LIST);

    if (sqlqual[0] == EOS) 
        safecopy (sqlqual, "1 = 1", SZ_LIST);

    /* Build the query */

    ostdb_query_setup (qry->connection, "query", 1, STDB_SQL,
		       qry->server, dbase, db_error);

    colvar = bind_qryvars (qry->connection, collist);

    build_qry (qry->connection, qryfmt, distinct, qcollist, 
	       collist, tablist, aliases, sqlqual);

    /* Send the query to the database */

    irow = 0;
    while (ostdb_get_exec (qry->connection) == STDB_CONTINUE) {

        /* Save query results in table */

        for (icol = 0; collist[icol][0] != EOS; icol ++) {
	    strclean (colvar[icol]);

	    if (ucase == NO) {
	        strlcase (colvar[icol]);
	    } else {
	        strucase (colvar[icol]);
	    }

	    if (text == YES && strchr (colvar[icol], ' ')) {
	        put_tab_cell (tab, collist[icol], irow, 
			      enquote (colvar[icol]));

	    } else {
	        put_tab_cell (tab, collist[icol], irow, colvar[icol]);
	    }
	}

        irow ++;
    }

    stdb_close_query (qry->connection);

    /* Free memory used in this function */

    free_qryvars (colvar);

    free_zlist (qcollist);
    free_zlist (tablist);
    free_zlist (aliases);
    free_zlist (collist);

    /* Return table with results */

    free_query (qry);
    return (tab);
}
