#include <string.h>
#include "config.h"
#include "cdbslib.h"
#include "loadfile.h"
#include "uniqname.h"

/* BUILDNAME -- Build a new filename from two old names
 *
 * i: keyword	keyword name
 * i: rootname	file name supplying root
 * i: extname	file name supplying extension
 * o: newname	new filename
 * i: maxch	max length of new name
 */

void buildname (char *keyword, char *rootname, char *extname, 
		char *newname, int maxch)
{
    int		nc;
    char	rootdir[SZ_FNAME+1], rootroot[SZ_FNAME+1], rootext[SZ_FNAME+1];
    char	extdir[SZ_FNAME+1], extroot[SZ_FNAME+1], extext[SZ_FNAME+1];

    if (extname[0] == EOS) {
	/* Extension cannot be gotten from name, so we must build
	 * it from the root name
	 */

	if (is_datakeywd (keyword) == YES) {
	    /* Datafile names have an extension that can be
	     * derived from the extension of the root name
	     */

	    breakfname (rootname, rootdir, rootroot, rootext, SZ_FNAME);
	    nc = strlen (rootext) - 1;


	    if (rootext[nc] == 'h') {
		if (strcmp (rootext, ".imh") == 0) {
		    safecopy (extext, ".pix", SZ_FNAME);
		} else {
		    safecopy (extext, rootext, SZ_FNAME);
		    extext[nc] = 'd';
		}

		safecopy (newname, rootdir, maxch);
		safecat (newname, rootroot, maxch);
		safecat (newname, extext, maxch);
		
	    } else {
		safecopy (newname, rootname, maxch);
	    }

	} else if (is_rootkeywd (keyword) == YES) {
	    /* Rootname keywords have no extension at all */

	    breakfname (rootname, rootdir, rootroot, rootext, SZ_FNAME);
	    safecopy (newname, rootdir, maxch);
	    safecat (newname, rootroot, maxch);

	} else {
	    safecopy (newname, rootname, maxch);
	}

    } else {
	/* If the extension name is present, we take the directory
	 * and the extension from it and the root from the root name.
	 * We don't try to second guess things from the keyword name.
	 */

	breakfname (rootname, rootdir, rootroot, rootext, SZ_FNAME);
	breakfname (extname, extdir, extroot, extext, SZ_FNAME);

	safecopy (newname, extdir, maxch);
	safecat (newname, rootroot, maxch);
	safecat (newname, extext, maxch);

	/* If the extension name is in upper case, 
	 * put the new name in upper case
	 */

	if (is_upcase (extname) == YES)
	    strucase (newname);
    }
}
