#include "error.h"
#include "config.h"
#include "reffile.h"
#include "cdbslib.h"
#include "synfile.h"
#include "uniqname.h"

/* GETSYNROOT -- Compute the root of a synphot reference file name
 *
 * i: ref	reference file descriptor
 * i: reftype	reference file type
 * o: newroot	root file name
 * i: maxch	max length of root file name
 */

int getsynroot (reffile *ref, char *reftype, char *newroot, int maxch)
{
    static char	*targetid = "TARGETID";
    static char *compname = "COMPNAME";
    static char *fld_name = "FLD_NAME";

    char	value[SZ_STRING];
    int		typecode;

    newroot[0] = EOS;
    typecode = strmatch (reftype, SYNTYPES);

    switch (typecode) {
	case SPECOBS:
	    if (get_hdr_reffile (ref, targetid, value, SZ_STRING) == ERR)
		return (ERR);
	    clean_name (value, newroot, maxch);
	    break;
	case SPECTRUM:
	    if (get_hdr_reffile (ref, targetid, value, SZ_STRING) == ERR)
		return (ERR);
	    clean_name (value, newroot, maxch);
	    break;
	case THRU:
	    if (get_hdr_reffile (ref, compname, value, SZ_STRING) == ERR)
		return (ERR);
	    clean_name (value, newroot, maxch);
	    break;
	case PHOFLDS:
	    if (get_hdr_reffile (ref, fld_name, value, SZ_STRING) == ERR)
		return (ERR);
	    clean_name (value, newroot, maxch);
	    break;
	case PHOTOBS:
	    safecopy (newroot, reftype, maxch);
	    break;
	case POLAROBS:
	    safecopy (newroot, reftype, maxch);
	    break;
	case WAVECAL:
	    if (get_hdr_reffile (ref, targetid, value, SZ_STRING) == ERR)
		return (ERR);
	    clean_name (value, newroot, maxch);
	    break;
	case CLUSTERPOS:
	    safecopy (newroot, reftype, maxch);
	    break;
	default:
	    cdbs_warn (BADREF, "%s", reftype);
	    return (ERR);
    }

    return (OK);
}

