#include <string.h>
#include <stdio.h>
#include <stdlib.h>
#include "cdbslib.h"
#include "error.h"
#include "config.h"
#include "alist.h"
#include "uniqname.h"

/* GETUNIQNAME -- Calculate a new unique name for a reference file
 *
 * i: ref		reference file descriptor
 * i: reftype		reference file type
 * i: filetype		associated file type (image, table, loadfile)
 * i: instrument	instrument name
 * u: newlist		new names associated with old file names
 * o: newname		the unique name
 * i: maxch		maximum length of calculated name
 */

int getuniqname (reffile *ref, char *reftype, char *filetype, char *instrument,
		 alist *newlist, char *newname, int maxch)
{
    char	dir[SZ_FNAME+1], root[SZ_FNAME+1], ext[SZ_FNAME+1];
    char	newroot[SZ_FNAME+1], irafdir[SZ_FNAME+1], cdbsdir[SZ_FNAME+1];
    int		code, count;

    /* If other files with the same root name have already been renamed,
     * give this file the same root name
     */

    if (getlistname (newlist, name_reffile (ref), newname, maxch) == OK)
	return (OK);

    /* The cdbs name is the name the file will be known as 
     * when it is copied to the cdbs directory. It is this 
     * name that we want to ensure is unique.
     */

    if (getirafdir (ref, instrument, reftype, 
		    filetype, irafdir, SZ_FNAME) == ERR) {
	newname[0] = EOS;
	return (ERR);

    } else {
	xlate_fname (irafdir, cdbsdir, SZ_FNAME);
    }

    /* Different instruments use different naming conventions
     * Call the appropriate naming routine for the instrument
     */

    code = strmatch (instrument, INSTRUMENTS);

    switch (code) {
    case NO_INST:
	cdbs_error (BADINST, "%s", instrument);
	break;

    case NIC:
    case STIS:
        newinstname (reftype, cdbsdir, code, newroot, SZ_FNAME);
	break;

    case SYNPHOT:
        if (strcmp (reftype, "graphtab") == 0 ||
	    strcmp (reftype, "comptab") == 0    ) {
	    oldinstname (cdbsdir, code, newroot, SZ_FNAME);
	} else {
	    thruname (ref, reftype, cdbsdir, newroot, SZ_FNAME);
	}
	break;

    default:
        oldinstname (cdbsdir, code, newroot, SZ_FNAME);
    }

    /* Check the list for duplicate root names */

    count = 0;
    if (match_alist (newlist, newroot, &count) != NULL)
      return (ERR);

    /* Save the root name in the list of root names */

    breakfname (name_reffile (ref), dir, root, ext, SZ_FNAME);
    add_alist (newlist, root, newroot);

    safecopy (newname, dir, maxch);
    safecat (newname, newroot, maxch);
    safecat (newname, ext, maxch);

    return (OK);
}
