#include "config.h"
#include "reffile.h"
#include "cdbslib.h"
#include "loadfile.h"
#include "uniqname.h"

/* SETNAMES -- Update names in reference file to agree with new filename
 *
 * i: ref	reference file desciptor
 * i: newlist	new names associated with old file names
 * i: newname	new filename
 */

int setnames (reffile *ref, alist *newlist, char *newname)
{
    /* The list of keywords or columns in the file 
     * which may contain a filename 
     */

    static char *image_key[] = {"HEADNAME", "DATANAME", "ROOTNAME", 
				"FILENAME", ""};
    static char *tab_hdr_key[] = {"FILENAME", ""};
    static char *tab_body_key[] = {"HEADER_FILE", "DATA_FILE", ""};
    static char *load_key[] = {"FILE_NAME", ""};
			     
    int		ikey, irow, upcase;
    char	oldkey[SZ_FNAME+1], newkey[SZ_FNAME+1], altname[SZ_FNAME+1];

    /* Search the reference file for keywords or columns containg file names
     * Substitute the new name with the old extension. If the item is naming
     * a new file, add it to the list of files to be processed.
     */

    switch (kind_reffile (ref)) {
    case IMAGE:
	for (ikey = 0; image_key[ikey][0] != EOS; ikey ++) {
	    if (get_hdr_reffile (ref, image_key[ikey], 
				 oldkey, SZ_FNAME) == OK) {

		buildname (image_key[ikey], newname, oldkey, newkey, SZ_FNAME);
		put_hdr_reffile (ref, image_key[ikey], newkey);
	    }
	}
	break;

    case TABLE:
	for (ikey = 0; tab_hdr_key[ikey][0] != EOS; ikey ++) {
	    if (get_hdr_reffile (ref, tab_hdr_key[ikey], 
				 oldkey, SZ_FNAME) == OK) {

		buildname (tab_hdr_key[ikey], newname, oldkey, newkey, SZ_FNAME);
		put_hdr_reffile (ref, tab_hdr_key[ikey], newkey);
	    }
	}

	for (ikey = 0; tab_body_key[ikey][0] != EOS; ikey ++) {
	    if (get_body_reffile (ref, tab_body_key[ikey], 0, 
				  oldkey, SZ_FNAME) == ERR)
		continue;

	    for (irow = 0; irow < nrow_reffile (ref); irow ++) {
		if (get_body_reffile (ref, tab_body_key[ikey], irow, 
				     oldkey, SZ_FNAME) == OK) {

		    upcase = is_upcase (oldkey);
		    strlcase (oldkey);

		    if (getlistname (newlist, oldkey, 
				     altname, SZ_FNAME) == ERR) {
		        return (ERR);

		    } else {
		        if (upcase == YES) {
			    strucase (altname);
			    strucase (oldkey);
			}

		        buildname (tab_body_key[ikey], altname, 
				   oldkey, newkey, SZ_FNAME);
		    }

		    put_body_reffile (ref, tab_body_key[ikey], irow, newkey);
		}
	    }
	}
	break;

    case LOADFILE:
	for (ikey = 0; load_key[ikey][0] != EOS; ikey ++) {
	    if (get_hdr_reffile (ref, load_key[ikey], 
				 oldkey, SZ_FNAME) == OK) {

		buildname (load_key[ikey], newname, oldkey, newkey, SZ_FNAME);
		put_hdr_reffile (ref, load_key[ikey], newkey);
	    }
	}
	break;
    }

    return (OK);
}
