#include <stdio.h>
#include "error.h"
#include "config.h"
#include "cdbslib.h"
#include "reffile.h"
#include "loadfile.h"
#include "uniqname.h"

/* UNIQNAME -- Rename a file according to CDBS conventions
 *
 * i: look	lookup table of reference file types
 * i: oldname	file to be renamed
 * u: newlist	new names associated with old file names
 */

int uniqname (table *look, char *oldname, alist *newlist)
{
    double	mjd;
    FILE	*fd;
    reffile	*ref;
    int		row, irow, status;
    char	*filetype, *reftype, *instrument;
    char	altname[SZ_FNAME+1], childname[SZ_FNAME+1];
    char	newname[SZ_FNAME+1], date[SZ_STRING+1], history[SZ_LINE+1];

    /* Check to see if file has already been renamed */

    if (getlistname (newlist, oldname, altname, SZ_FNAME) == OK) {
        if ((fd = fopen (altname, "r")) != NULL) {
	    fclose (fd);
	    return (OK);
	}
    }

    /* Read podps type and instrument from the lookup table */

    if ((row = find_lookup (look, oldname)) == ERR) {
	cdbs_warn (NOLOOK, "%s", oldname);
	return (ERR);
    }

    instrument = get_tab_cell (look, "instrument", row);
    reftype = get_tab_cell (look, "reftype", row);
    filetype = get_tab_cell (look, "filetype", row);

    ref = open_reffile (oldname, filetype, "r+");
    if (ref == NULL) {
        cdbs_warn (NOTOPEN, "%s", oldname);
	return (ERR);
    }

    /* Call uniqname recursively on any files mentioned in this file */

    status = OK;
    switch (kind_reffile (ref)) {
    case IMAGE:
        break;

    case TABLE:
	if (get_body_reffile (ref, "HEADER_FILE", 0, 
			      childname, SZ_FNAME) == OK) {

	    if (renamable (newlist, ref) == NO) {
	        status = ERR;
		break;
	    }

	    for (irow = 0; irow < nrow_reffile (ref); irow ++) {
	        get_body_reffile (ref, "HEADER_FILE", irow, 
				  childname, SZ_FNAME);
		strlcase (childname);

		if (uniqname (look, childname, newlist) == ERR) {
		    status = ERR;
		    break;
		}
	    }
	}
	break;

    case LOADFILE:
	if (get_hdr_reffile (ref, "FILE_NAME", childname, SZ_FNAME) == OK) {
	    if (uniqname (look, childname, newlist) == ERR)
		status = ERR;
	}
	break;
    }

    if (status == ERR) {
        cdbs_warn (NOCHILD, "%s", oldname);
	return (ERR);
    }

    /* Generate a new filename */

    if (getuniqname (ref, reftype, filetype, instrument, 
		     newlist, newname, SZ_FNAME) == ERR) {
	cdbs_warn (NONUNIQ, "%s", oldname);
	close_reffile (ref);
	return (ERR);
    }

    /* Change names embedded in file; add to arglist */

    if (setnames (ref, newlist, newname) == ERR) {
	cdbs_warn (NOSETNAM, "%s", oldname);
	close_reffile (ref);
	return (ERR);
    }

    /* Add a history record to the reference file */

    mjd = get_now ();
    put_short_date (mjd, date, SZ_STRING);

    sprintf (history, "%s renamed to %s on %s", oldname, newname, date);
    put_hist_reffile (ref, "HISTORY", history);

    /* Rename the file itself */

    close_reffile (ref);

    if (rename_reffile (oldname, newname, filetype) == ERR) {
	cdbs_warn (RENAME, "%s", oldname);
	return (ERR);
    }

    cdbs_info (NEWNAME, "%s -> %s", oldname, newname);
    return (OK);
}

