#!/opt/gnu/bin/perl

# CDEPEND -- Compute dependencies for mafefile
#
# Usage: cdepend [flags] [files]
# Run with same options as cc, except no -xM1 flag

# Run sun's dependency file generator

$vax = 0;
if ($ARGV[0] eq '-vax') {
    shift @ARGV;
    $vax = 1;
}

$iraf = 0;
if ($ARGV[0] eq '-iraf') {
    shift @ARGV;
    $iraf = 1;
}

$cmdline = join (' ', @ARGV);
$includes = '-I../../include -I/usr/stsci/stsdasx/lib -I/usr/local/ostdb/ostdb1_5/include';

open (INPUT, "cc -xM1 $includes $cmdline |") || 
    die "Can't run cc\n";

# Create a hashed array of the function dependencies

while (<INPUT>) {
    chop;
    tr/ //d;
    ($name, $value) = split (/:/);
    next if $value =~ m%^/%;

    $name =~ s/\.o/\.c/ if $vax || $iraf;
    $value =~ s%//%/%g;
    $value =~ s%\.\./\.\./include/%[--.include]% if $vax;

    $pattern = $value;
    $pattern =~ s/(\W)/\\\1/g;
    next if $depend{$name} =~ /$pattern/;

    if ($depend{$name}) {
	$depend{$name} = "$depend{$name}|$value";
    } else {
	$depend{$name} = $value;
    }
}

close (INPUT);

# print the dependencies
    
@names = sort (keys (%depend));
foreach $name (@names) {
    @values = split (/\|/, $depend{$name});
    if ($iraf) {
	@values = grep (/\.h$/, @values);

	$line = join ('  ', @values);
	@line = &breakline ($line, 45);

	$line = shift (@line);
	if (length ($name) < 8) {
	    print "\t$name\t\t$line";
	} else {
	    print "\t$name\t$line";
	}

	if (@line) {
	    print "\\\n\t\t\t", join ("\\\n\t\t\t", @line);
	}

	print "\n";

    } else {
	foreach $value (@values) {
	    print "\$(LIB)($name) : $value\n";
	}
    }
}

sub breakline {
    local ($line, $maxlen) = @_;
    local ($lastbrk, $lastsp, $nextsp);
 
    $nextsp = $[;
    $lastbrk = $lastsp = $nextsp - 1;
    while (($nextsp = index ($line, ' ',  $nextsp)) >= $[) {
        if ($nextsp - $lastbrk > $maxlen && $lastsp >= $[) {
            substr ($line, $lastsp, 1) = "\n";
            $lastbrk = $lastsp;
        }
 
        $lastsp = $nextsp ++;
    }
 
    split (/\n/, $line);
}
